# -*- coding: utf-8 -*-

# Resource object code
#
# Created: Thu Dec 19 23:47:00 2019
#      by: The Resource Compiler for PySide2 (Qt v5.13.2)
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore

qt_resource_data = b"\
\x00\x00)I\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22siz\
egrip.svg\x22\x0a   in\
kscape:export-fi\
lename=\x22/home/ye\
ison/Development\
/piton/art/icon_\
lite.png\x22\x0a   ink\
scape:export-xdp\
i=\x2296\x22\x0a   inksca\
pe:export-ydpi=\x22\
96\x22>\x0a  <defs\x0a   \
  id=\x22defs2\x22 />\x0a\
  <sodipodi:name\
dview\x0a     id=\x22b\
ase\x22\x0a     pageco\
lor=\x22#ffffff\x22\x0a  \
   bordercolor=\x22\
#666666\x22\x0a     bo\
rderopacity=\x221.0\
\x22\x0a     inkscape:\
pageopacity=\x220.0\
\x22\x0a     inkscape:\
pageshadow=\x222\x22\x0a \
    inkscape:zoo\
m=\x2216\x22\x0a     inks\
cape:cx=\x224.85602\
4\x22\x0a     inkscape\
:cy=\x229.6877956\x22\x0a\
     inkscape:do\
cument-units=\x22px\
\x22\x0a     inkscape:\
current-layer=\x22l\
ayer1\x22\x0a     show\
grid=\x22true\x22\x0a    \
 inkscape:window\
-width=\x221920\x22\x0a  \
   inkscape:wind\
ow-height=\x221004\x22\
\x0a     inkscape:w\
indow-x=\x220\x22\x0a    \
 inkscape:window\
-y=\x220\x22\x0a     inks\
cape:window-maxi\
mized=\x221\x22\x0a     i\
nkscape:showpage\
shadow=\x22false\x22\x0a \
    units=\x22px\x22\x0a \
    inkscape:pag\
echeckerboard=\x22f\
alse\x22\x0a     showg\
uides=\x22true\x22\x0a   \
  inkscape:snap-\
bbox=\x22true\x22\x0a    \
 inkscape:bbox-p\
aths=\x22true\x22\x0a    \
 inkscape:bbox-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-b\
box-edge-midpoin\
ts=\x22true\x22\x0a     i\
nkscape:snap-bbo\
x-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-nodes=\x22tru\
e\x22\x0a     inkscape\
:object-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-intersec\
tion-paths=\x22true\
\x22\x0a     inkscape:\
snap-smooth-node\
s=\x22true\x22\x0a     in\
kscape:snap-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
global=\x22true\x22\x0a  \
   fit-margin-to\
p=\x220\x22\x0a     fit-m\
argin-left=\x220\x22\x0a \
    fit-margin-r\
ight=\x220\x22\x0a     fi\
t-margin-bottom=\
\x220\x22\x0a     inkscap\
e:guide-bbox=\x22tr\
ue\x22>\x0a    <inksca\
pe:grid\x0a       t\
ype=\x22xygrid\x22\x0a   \
    id=\x22grid974\x22\
\x0a       empspaci\
ng=\x228\x22\x0a       sp\
acingx=\x220.264583\
32\x22\x0a       spaci\
ngy=\x220.26458332\x22\
\x0a       dotted=\x22\
false\x22\x0a       vi\
sible=\x22true\x22\x0a   \
    enabled=\x22tru\
e\x22\x0a       snapvi\
siblegridlineson\
ly=\x22true\x22\x0a      \
 originx=\x220\x22\x0a   \
    originy=\x220\x22 \
/>\x0a  </sodipodi:\
namedview>\x0a  <me\
tadata\x0a     id=\x22\
metadata5\x22>\x0a    \
<rdf:RDF>\x0a      \
<cc:Work\x0a       \
  rdf:about=\x22\x22>\x0a\
        <dc:form\
at>image/svg+xml\
</dc:format>\x0a   \
     <dc:type\x0a  \
         rdf:res\
ource=\x22http://pu\
rl.org/dc/dcmity\
pe/StillImage\x22 /\
>\x0a        <dc:ti\
tle />\x0a      </c\
c:Work>\x0a    </rd\
f:RDF>\x0a  </metad\
ata>\x0a  <g\x0a     i\
nkscape:label=\x22L\
ayer 1\x22\x0a     ink\
scape:groupmode=\
\x22layer\x22\x0a     id=\
\x22layer1\x22\x0a     tr\
ansform=\x22transla\
te(0,-291.70835)\
\x22>\x0a    <g\x0a      \
 id=\x22g847\x22\x0a     \
  transform=\x22mat\
rix(0.05207439,0\
,0,0.05207453,-0\
.90125164,282.41\
203)\x22>\x0a      <g\x0a\
         id=\x22g85\
1\x22>\x0a        <g\x0a \
          id=\x22g1\
059\x22\x0a           \
transform=\x22matri\
x(1.9986219,0,0,\
1.9986185,17.324\
484,-313.52314)\x22\
>\x0a          <pat\
h\x0a             i\
nkscape:transfor\
m-center-y=\x223.17\
5\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07000433;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22\x0a         \
    d=\x22M 25.3999\
99,271.60002 -8.\
0000008e-7,246.2\
0002 H 50.799999\
 Z\x22\x0a            \
 id=\x22path883\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22 />\x0a          \
<path\x0a          \
   sodipodi:node\
types=\x22cccc\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        id=\x22path\
880\x22\x0a           \
  d=\x22m 25.399999\
,271.60002 25.39\
9999,25.4 H 0 Z\x22\
\x0a             in\
kscape:transform\
-center-y=\x22-3.17\
49995\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22 />\x0a  \
        <rect\x0a  \
           ry=\x225\
.0534658\x22\x0a      \
       y=\x22253.84\
885\x22\x0a           \
  x=\x227.6487389\x22\x0a\
             hei\
ght=\x2235.528759\x22\x0a\
             wid\
th=\x2235.528786\x22\x0a \
            id=\x22\
rect870\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0618441\
9;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <circl\
e\x0a             r\
=\x2225.396828\x22\x0a   \
          cy=\x2227\
1.60001\x22\x0a       \
      cx=\x2225.4\x22\x0a\
             id=\
\x22path872\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.076358\
82;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <circ\
le\x0a             \
transform=\x22rotat\
e(-45)\x22\x0a        \
     cx=\x22-174.08\
969\x22\x0a           \
  cy=\x22210.01071\x22\
\x0a             r=\
\x2212.656071\x22\x0a    \
         id=\x22pat\
h876\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07399406;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-x=\x22-3.174999\
9\x22\x0a             \
sodipodi:nodetyp\
es=\x22cccc\x22\x0a      \
       inkscape:\
connector-curvat\
ure=\x220\x22\x0a        \
     id=\x22path904\
\x22\x0a             d\
=\x22m 25.4,271.600\
02 -25.400000400\
00004,25.4 v -50\
.8 z\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-x=\x223.175\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a             d\
=\x22m 25.399999,27\
1.60002 25.4,-25\
.4 v 50.8 z\x22\x0a   \
          id=\x22pa\
th906\x22\x0a         \
    inkscape:con\
nector-curvature\
=\x220\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22 />\x0a \
         <rect\x0a \
            ry=\x22\
5.0514922\x22\x0a     \
        y=\x22256.3\
9301\x22\x0a          \
   x=\x222.5663135\x22\
\x0a             he\
ight=\x2230.440479\x22\
\x0a             wi\
dth=\x2245.693634\x22\x0a\
             id=\
\x22rect837\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.065743\
8;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
id=\x22rect831\x22\x0a   \
          width=\
\x2245.693588\x22\x0a    \
         height=\
\x2230.44051\x22\x0a     \
        x=\x22248.7\
6645\x22\x0a          \
   y=\x22-40.633385\
\x22\x0a             r\
y=\x225.051497\x22\x0a   \
          transf\
orm=\x22rotate(90)\x22\
 />\x0a        </g>\
\x0a      </g>\x0a    \
</g>\x0a    <path\x0a \
      style=\x22opa\
city:1;fill:#ffc\
107;fill-opacity\
:1;stroke:none;s\
troke-width:0.38\
596651;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-opacity:\
1\x22\x0a       d=\x22m 5\
0.206421,401.676\
83 c 110.217209,\
0.71279 55.10860\
9,0.3564 0,0 z\x22\x0a\
       id=\x22rect9\
97\x22\x0a       inksc\
ape:connector-cu\
rvature=\x220\x22 />\x0a \
   <rect\x0a       \
style=\x22opacity:1\
;fill:#0000ff;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:1.05832505\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1\x22\x0a    \
   id=\x22rect832\x22\x0a\
       width=\x220.\
52916664\x22\x0a      \
 height=\x220.52915\
841\x22\x0a       x=\x224\
.2333331\x22\x0a      \
 y=\x22295.94168\x22 /\
>\x0a    <rect\x0a    \
   y=\x22295.94168\x22\
\x0a       x=\x221.058\
3333\x22\x0a       hei\
ght=\x220.52915841\x22\
\x0a       width=\x220\
.52916664\x22\x0a     \
  id=\x22rect836\x22\x0a \
      style=\x22opa\
city:1;fill:#000\
0ff;fill-opacity\
:1;stroke:none;s\
troke-width:1.05\
832505;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
\x22 />\x0a    <rect\x0a \
      style=\x22opa\
city:1;fill:#000\
0ff;fill-opacity\
:1;stroke:none;s\
troke-width:1.05\
832505;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
\x22\x0a       id=\x22rec\
t838\x22\x0a       wid\
th=\x220.52916664\x22\x0a\
       height=\x220\
.52915841\x22\x0a     \
  x=\x222.6458333\x22\x0a\
       y=\x22295.94\
168\x22 />\x0a    <rec\
t\x0a       y=\x22292.\
76669\x22\x0a       x=\
\x224.2333331\x22\x0a    \
   height=\x220.529\
15841\x22\x0a       wi\
dth=\x220.52916664\x22\
\x0a       id=\x22rect\
840\x22\x0a       styl\
e=\x22opacity:1;fil\
l:#0000ff;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:1.05832505;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22 />\x0a    <\
rect\x0a       styl\
e=\x22opacity:1;fil\
l:#0000ff;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:1.05832505;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22\x0a       i\
d=\x22rect842\x22\x0a    \
   width=\x220.5291\
6664\x22\x0a       hei\
ght=\x220.52915841\x22\
\x0a       x=\x221.852\
0832\x22\x0a       y=\x22\
295.14795\x22 />\x0a  \
  <rect\x0a       s\
tyle=\x22opacity:1;\
fill:#0000ff;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:1.05832505;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1\x22\x0a     \
  id=\x22rect844\x22\x0a \
      width=\x220.5\
2916664\x22\x0a       \
height=\x220.529158\
41\x22\x0a       x=\x223.\
4395831\x22\x0a       \
y=\x22295.14795\x22 />\
\x0a    <rect\x0a     \
  y=\x22294.35419\x22\x0a\
       x=\x224.2333\
331\x22\x0a       heig\
ht=\x220.52915841\x22\x0a\
       width=\x220.\
52916664\x22\x0a      \
 id=\x22rect846\x22\x0a  \
     style=\x22opac\
ity:1;fill:#0000\
ff;fill-opacity:\
1;stroke:none;st\
roke-width:1.058\
32505;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1\x22\
 />\x0a    <rect\x0a  \
     style=\x22opac\
ity:1;fill:#0000\
ff;fill-opacity:\
1;stroke:none;st\
roke-width:1.058\
32505;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1\x22\
\x0a       id=\x22rect\
848\x22\x0a       widt\
h=\x220.52916664\x22\x0a \
      height=\x220.\
52915841\x22\x0a      \
 x=\x223.4395831\x22\x0a \
      y=\x22293.560\
42\x22 />\x0a    <rect\
\x0a       style=\x22o\
pacity:1;fill:#0\
000ff;fill-opaci\
ty:1;stroke:none\
;stroke-width:1.\
05832505;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22\x0a       id=\x22r\
ect852\x22\x0a       w\
idth=\x220.52916664\
\x22\x0a       height=\
\x220.52915841\x22\x0a   \
    x=\x222.6458333\
\x22\x0a       y=\x22294.\
35419\x22 />\x0a  </g>\
\x0a</svg>\x0a\
\x00\x00!#\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22dow\
narrow.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2211.745467\x22\x0a \
    inkscape:cx=\
\x22-8.0020924\x22\x0a   \
  inkscape:cy=\x22-\
13.919269\x22\x0a     \
inkscape:documen\
t-units=\x22px\x22\x0a   \
  inkscape:curre\
nt-layer=\x22layer1\
\x22\x0a     showgrid=\
\x22true\x22\x0a     inks\
cape:window-widt\
h=\x221920\x22\x0a     in\
kscape:window-he\
ight=\x221015\x22\x0a    \
 inkscape:window\
-x=\x220\x22\x0a     inks\
cape:window-y=\x220\
\x22\x0a     inkscape:\
window-maximized\
=\x221\x22\x0a     inksca\
pe:showpageshado\
w=\x22false\x22\x0a     u\
nits=\x22px\x22\x0a     i\
nkscape:pagechec\
kerboard=\x22false\x22\
\x0a     showguides\
=\x22true\x22\x0a     ink\
scape:snap-bbox=\
\x22true\x22\x0a     inks\
cape:bbox-paths=\
\x22true\x22\x0a     inks\
cape:bbox-nodes=\
\x22true\x22\x0a     inks\
cape:snap-bbox-e\
dge-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-bbox-mid\
points=\x22true\x22\x0a  \
   inkscape:snap\
-nodes=\x22true\x22\x0a  \
   inkscape:obje\
ct-paths=\x22true\x22\x0a\
     inkscape:sn\
ap-intersection-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
smooth-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-midpoints\
=\x22true\x22\x0a     ink\
scape:snap-globa\
l=\x22true\x22\x0a     fi\
t-margin-top=\x220\x22\
\x0a     fit-margin\
-left=\x220\x22\x0a     f\
it-margin-right=\
\x220\x22\x0a     fit-mar\
gin-bottom=\x220\x22\x0a \
    inkscape:gui\
de-bbox=\x22true\x22>\x0a\
    <inkscape:gr\
id\x0a       type=\x22\
xygrid\x22\x0a       i\
d=\x22grid974\x22\x0a    \
   empspacing=\x228\
\x22\x0a       spacing\
x=\x220.26458332\x22\x0a \
      spacingy=\x22\
0.26458332\x22\x0a    \
   dotted=\x22false\
\x22\x0a       visible\
=\x22true\x22\x0a       e\
nabled=\x22true\x22\x0a  \
     snapvisible\
gridlinesonly=\x22t\
rue\x22\x0a       orig\
inx=\x220\x22\x0a       o\
riginy=\x220\x22 />\x0a  \
</sodipodi:named\
view>\x0a  <metadat\
a\x0a     id=\x22metad\
ata5\x22>\x0a    <rdf:\
RDF>\x0a      <cc:W\
ork\x0a         rdf\
:about=\x22\x22>\x0a     \
   <dc:format>im\
age/svg+xml</dc:\
format>\x0a        \
<dc:type\x0a       \
    rdf:resource\
=\x22http://purl.or\
g/dc/dcmitype/St\
illImage\x22 />\x0a   \
     <dc:title><\
/dc:title>\x0a     \
 </cc:Work>\x0a    \
</rdf:RDF>\x0a  </m\
etadata>\x0a  <g\x0a  \
   inkscape:labe\
l=\x22Layer 1\x22\x0a    \
 inkscape:groupm\
ode=\x22layer\x22\x0a    \
 id=\x22layer1\x22\x0a   \
  transform=\x22tra\
nslate(0,-291.70\
835)\x22>\x0a    <g\x0a  \
     id=\x22g847\x22\x0a \
      transform=\
\x22matrix(0.052074\
39,0,0,0.0520745\
3,-0.90125164,28\
2.41203)\x22>\x0a     \
 <g\x0a         id=\
\x22g851\x22>\x0a        \
<g\x0a           id\
=\x22g1059\x22\x0a       \
    transform=\x22m\
atrix(1.9986219,\
0,0,1.9986185,17\
.324484,-313.523\
14)\x22>\x0a          \
<path\x0a          \
   inkscape:tran\
sform-center-y=\x22\
3.175\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22\x0a     \
        d=\x22M 25.\
399999,271.60002\
 -8.0000008e-7,2\
46.20002 H 50.79\
9999 Z\x22\x0a        \
     id=\x22path883\
\x22\x0a             i\
nkscape:connecto\
r-curvature=\x220\x22\x0a\
             sod\
ipodi:nodetypes=\
\x22cccc\x22 />\x0a      \
    <path\x0a      \
       sodipodi:\
nodetypes=\x22cccc\x22\
\x0a             in\
kscape:connector\
-curvature=\x220\x22\x0a \
            id=\x22\
path880\x22\x0a       \
      d=\x22m 25.39\
9999,271.60002 2\
5.399999,25.4 H \
0 Z\x22\x0a           \
  inkscape:trans\
form-center-y=\x22-\
3.1749995\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.07000\
433;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <rec\
t\x0a             r\
y=\x225.0534658\x22\x0a  \
           y=\x2225\
3.84885\x22\x0a       \
      x=\x227.64873\
89\x22\x0a            \
 height=\x2235.5287\
59\x22\x0a            \
 width=\x2235.52878\
6\x22\x0a             \
id=\x22rect870\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.061\
84419;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <c\
ircle\x0a          \
   r=\x2225.396828\x22\
\x0a             cy\
=\x22271.60001\x22\x0a   \
          cx=\x2225\
.4\x22\x0a            \
 id=\x22path872\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
635882;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
circle\x0a         \
    transform=\x22r\
otate(-45)\x22\x0a    \
         cx=\x22-17\
4.08969\x22\x0a       \
      cy=\x22210.01\
071\x22\x0a           \
  r=\x2212.656071\x22\x0a\
             id=\
\x22path876\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.073994\
06;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <path\
\x0a             in\
kscape:transform\
-center-x=\x22-3.17\
49999\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         id=\x22pat\
h904\x22\x0a          \
   d=\x22m 25.4,271\
.60002 -25.40000\
040000004,25.4 v\
 -50.8 z\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.070004\
33;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <path\
\x0a             in\
kscape:transform\
-center-x=\x223.175\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22\x0a          \
   d=\x22m 25.39999\
9,271.60002 25.4\
,-25.4 v 50.8 z\x22\
\x0a             id\
=\x22path906\x22\x0a     \
        inkscape\
:connector-curva\
ture=\x220\x22\x0a       \
      sodipodi:n\
odetypes=\x22cccc\x22 \
/>\x0a          <re\
ct\x0a             \
ry=\x225.0514922\x22\x0a \
            y=\x222\
56.39301\x22\x0a      \
       x=\x222.5663\
135\x22\x0a           \
  height=\x2230.440\
479\x22\x0a           \
  width=\x2245.6936\
34\x22\x0a            \
 id=\x22rect837\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.06\
57438;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <r\
ect\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.0657438;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22\x0a         \
    id=\x22rect831\x22\
\x0a             wi\
dth=\x2245.693588\x22\x0a\
             hei\
ght=\x2230.44051\x22\x0a \
            x=\x222\
48.76645\x22\x0a      \
       y=\x22-40.63\
3385\x22\x0a          \
   ry=\x225.051497\x22\
\x0a             tr\
ansform=\x22rotate(\
90)\x22 />\x0a        \
</g>\x0a      </g>\x0a\
    </g>\x0a    <pa\
th\x0a       style=\
\x22opacity:1;fill:\
#ffc107;fill-opa\
city:1;stroke:no\
ne;stroke-width:\
0.38596651;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-opac\
ity:1\x22\x0a       d=\
\x22m 50.206421,401\
.67683 c 110.217\
209,0.71279 55.1\
08609,0.3564 0,0\
 z\x22\x0a       id=\x22r\
ect997\x22\x0a       i\
nkscape:connecto\
r-curvature=\x220\x22 \
/>\x0a    <path\x0a   \
    sodipodi:typ\
e=\x22star\x22\x0a       \
style=\x22opacity:1\
;fill:#0000ff;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:1.38742065\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22\x0a    \
   id=\x22path828\x22\x0a\
       sodipodi:\
sides=\x223\x22\x0a      \
 sodipodi:cx=\x22-2\
.6458383\x22\x0a      \
 sodipodi:cy=\x22-2\
94.16339\x22\x0a      \
 sodipodi:r1=\x221.\
3874207\x22\x0a       \
sodipodi:r2=\x220.6\
9371033\x22\x0a       \
sodipodi:arg1=\x221\
.5707963\x22\x0a      \
 sodipodi:arg2=\x22\
2.6179939\x22\x0a     \
  inkscape:flats\
ided=\x22true\x22\x0a    \
   inkscape:roun\
ded=\x220.1\x22\x0a      \
 inkscape:random\
ized=\x220\x22\x0a       \
d=\x22m -2.6458382,\
-292.77597 c -0.\
2403083,0 -1.321\
6958,-1.87302 -1\
.2015416,-2.0811\
3 0.1201541,-0.2\
0811 2.2829289,-\
0.20811 2.403083\
1,0 0.1201541,0.\
20811 -0.9612332\
,2.08113 -1.2015\
415,2.08113 z\x22\x0a \
      inkscape:t\
ransform-center-\
y=\x22-0.22979664\x22\x0a\
       transform\
=\x22scale(-1)\x22\x0a   \
    inkscape:tra\
nsform-center-x=\
\x22-5.0457959e-06\x22\
 />\x0a  </g>\x0a</svg\
>\x0a\
\x00\x00\x1f\xb4\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22tab\
_close.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2220.297438\x22\x0a \
    inkscape:cx=\
\x2210.202825\x22\x0a    \
 inkscape:cy=\x228.\
9235955\x22\x0a     in\
kscape:document-\
units=\x22px\x22\x0a     \
inkscape:current\
-layer=\x22layer1\x22\x0a\
     showgrid=\x22t\
rue\x22\x0a     inksca\
pe:window-width=\
\x221920\x22\x0a     inks\
cape:window-heig\
ht=\x221015\x22\x0a     i\
nkscape:window-x\
=\x220\x22\x0a     inksca\
pe:window-y=\x220\x22\x0a\
     inkscape:wi\
ndow-maximized=\x22\
1\x22\x0a     inkscape\
:showpageshadow=\
\x22false\x22\x0a     uni\
ts=\x22px\x22\x0a     ink\
scape:pagechecke\
rboard=\x22false\x22\x0a \
    showguides=\x22\
false\x22\x0a     inks\
cape:snap-bbox=\x22\
true\x22\x0a     inksc\
ape:bbox-paths=\x22\
true\x22\x0a     inksc\
ape:bbox-nodes=\x22\
true\x22\x0a     inksc\
ape:snap-bbox-ed\
ge-midpoints=\x22tr\
ue\x22\x0a     inkscap\
e:snap-bbox-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
nodes=\x22true\x22\x0a   \
  inkscape:objec\
t-paths=\x22true\x22\x0a \
    inkscape:sna\
p-intersection-p\
aths=\x22true\x22\x0a    \
 inkscape:snap-s\
mooth-nodes=\x22tru\
e\x22\x0a     inkscape\
:snap-midpoints=\
\x22true\x22\x0a     inks\
cape:snap-global\
=\x22true\x22\x0a     fit\
-margin-top=\x220\x22\x0a\
     fit-margin-\
left=\x220\x22\x0a     fi\
t-margin-right=\x22\
0\x22\x0a     fit-marg\
in-bottom=\x220\x22\x0a  \
   inkscape:guid\
e-bbox=\x22true\x22>\x0a \
   <inkscape:gri\
d\x0a       type=\x22x\
ygrid\x22\x0a       id\
=\x22grid974\x22\x0a     \
  empspacing=\x228\x22\
\x0a       spacingx\
=\x220.26458332\x22\x0a  \
     spacingy=\x220\
.26458332\x22\x0a     \
  dotted=\x22false\x22\
\x0a       visible=\
\x22true\x22\x0a       en\
abled=\x22true\x22\x0a   \
    snapvisibleg\
ridlinesonly=\x22tr\
ue\x22\x0a       origi\
nx=\x220\x22\x0a       or\
iginy=\x220\x22 />\x0a  <\
/sodipodi:namedv\
iew>\x0a  <metadata\
\x0a     id=\x22metada\
ta5\x22>\x0a    <rdf:R\
DF>\x0a      <cc:Wo\
rk\x0a         rdf:\
about=\x22\x22>\x0a      \
  <dc:format>ima\
ge/svg+xml</dc:f\
ormat>\x0a        <\
dc:type\x0a        \
   rdf:resource=\
\x22http://purl.org\
/dc/dcmitype/Sti\
llImage\x22 />\x0a    \
    <dc:title />\
\x0a      </cc:Work\
>\x0a    </rdf:RDF>\
\x0a  </metadata>\x0a \
 <g\x0a     inkscap\
e:label=\x22Layer 1\
\x22\x0a     inkscape:\
groupmode=\x22layer\
\x22\x0a     id=\x22layer\
1\x22\x0a     transfor\
m=\x22translate(0,-\
291.70835)\x22>\x0a   \
 <g\x0a       id=\x22g\
847\x22\x0a       tran\
sform=\x22matrix(0.\
05207439,0,0,0.0\
5207453,-0.90125\
164,282.41203)\x22>\
\x0a      <g\x0a      \
   id=\x22g851\x22>\x0a  \
      <g\x0a       \
    id=\x22g1059\x22\x0a \
          transf\
orm=\x22matrix(1.99\
86219,0,0,1.9986\
185,17.324484,-3\
13.52314)\x22>\x0a    \
      <path\x0a    \
         inkscap\
e:transform-cent\
er-y=\x223.175\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
\x0a             d=\
\x22M 25.399999,271\
.60002 -8.000000\
8e-7,246.20002 H\
 50.799999 Z\x22\x0a  \
           id=\x22p\
ath883\x22\x0a        \
     inkscape:co\
nnector-curvatur\
e=\x220\x22\x0a          \
   sodipodi:node\
types=\x22cccc\x22 />\x0a\
          <path\x0a\
             sod\
ipodi:nodetypes=\
\x22cccc\x22\x0a         \
    inkscape:con\
nector-curvature\
=\x220\x22\x0a           \
  id=\x22path880\x22\x0a \
            d=\x22m\
 25.399999,271.6\
0002 25.399999,2\
5.4 H 0 Z\x22\x0a     \
        inkscape\
:transform-cente\
r-y=\x22-3.1749995\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.07000433;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <rect\x0a        \
     ry=\x225.05346\
58\x22\x0a            \
 y=\x22253.84885\x22\x0a \
            x=\x227\
.6487389\x22\x0a      \
       height=\x223\
5.528759\x22\x0a      \
       width=\x2235\
.528786\x22\x0a       \
      id=\x22rect87\
0\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.06184419;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <circle\x0a    \
         r=\x2225.3\
96828\x22\x0a         \
    cy=\x22271.6000\
1\x22\x0a             \
cx=\x2225.4\x22\x0a      \
       id=\x22path8\
72\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07635882;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22 />\x0a     \
     <circle\x0a   \
          transf\
orm=\x22rotate(-45)\
\x22\x0a             c\
x=\x22-174.08969\x22\x0a \
            cy=\x22\
210.01071\x22\x0a     \
        r=\x2212.65\
6071\x22\x0a          \
   id=\x22path876\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07399406;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <path\x0a         \
    inkscape:tra\
nsform-center-x=\
\x22-3.1749999\x22\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             i\
d=\x22path904\x22\x0a    \
         d=\x22m 25\
.4,271.60002 -25\
.40000040000004,\
25.4 v -50.8 z\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <path\x0a         \
    inkscape:tra\
nsform-center-x=\
\x223.175\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22\x0a    \
         d=\x22m 25\
.399999,271.6000\
2 25.4,-25.4 v 5\
0.8 z\x22\x0a         \
    id=\x22path906\x22\
\x0a             in\
kscape:connector\
-curvature=\x220\x22\x0a \
            sodi\
podi:nodetypes=\x22\
cccc\x22 />\x0a       \
   <rect\x0a       \
      ry=\x225.0514\
922\x22\x0a           \
  y=\x22256.39301\x22\x0a\
             x=\x22\
2.5663135\x22\x0a     \
        height=\x22\
30.440479\x22\x0a     \
        width=\x224\
5.693634\x22\x0a      \
       id=\x22rect8\
37\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.0657438;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <rect\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.065743\
8;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          id=\x22re\
ct831\x22\x0a         \
    width=\x2245.69\
3588\x22\x0a          \
   height=\x2230.44\
051\x22\x0a           \
  x=\x22248.76645\x22\x0a\
             y=\x22\
-40.633385\x22\x0a    \
         ry=\x225.0\
51497\x22\x0a         \
    transform=\x22r\
otate(90)\x22 />\x0a  \
      </g>\x0a     \
 </g>\x0a    </g>\x0a \
   <path\x0a       \
style=\x22opacity:1\
;fill:#ffc107;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:0.38596651\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-opacity:1\x22\x0a   \
    d=\x22m 50.2064\
21,401.67683 c 1\
10.217209,0.7127\
9 55.108609,0.35\
64 0,0 z\x22\x0a      \
 id=\x22rect997\x22\x0a  \
     inkscape:co\
nnector-curvatur\
e=\x220\x22 />\x0a    <pa\
th\x0a       style=\
\x22fill:#0000ff;st\
roke:#0000ff;str\
oke-width:0.5291\
6664;stroke-line\
cap:butt;stroke-\
linejoin:miter;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
opacity:1\x22\x0a     \
  d=\x22m 0.9809021\
5,292.68924 3.32\
986205,3.32989\x22\x0a\
       id=\x22path8\
26\x22\x0a       inksc\
ape:connector-cu\
rvature=\x220\x22 />\x0a \
   <path\x0a       \
inkscape:connect\
or-curvature=\x220\x22\
\x0a       id=\x22path\
842\x22\x0a       d=\x22m\
 4.3107782,292.6\
8925 -3.32989002\
,3.32987\x22\x0a      \
 style=\x22fill:#00\
00ff;stroke:#000\
0ff;stroke-width\
:0.52916664;stro\
ke-linecap:butt;\
stroke-linejoin:\
miter;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-opacity:1\
\x22 />\x0a  </g>\x0a</sv\
g>\x0a\
\x00\x00$\xad\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22spl\
itter-vertical.s\
vg\x22\x0a   inkscape:\
export-filename=\
\x22/home/yeison/De\
velopment/piton/\
art/icon_lite.pn\
g\x22\x0a   inkscape:e\
xport-xdpi=\x2296\x22\x0a\
   inkscape:expo\
rt-ydpi=\x2296\x22>\x0a  \
<defs\x0a     id=\x22d\
efs2\x22 />\x0a  <sodi\
podi:namedview\x0a \
    id=\x22base\x22\x0a  \
   pagecolor=\x22#f\
fffff\x22\x0a     bord\
ercolor=\x22#666666\
\x22\x0a     borderopa\
city=\x221.0\x22\x0a     \
inkscape:pageopa\
city=\x220.0\x22\x0a     \
inkscape:pagesha\
dow=\x222\x22\x0a     ink\
scape:zoom=\x2224.8\
02598\x22\x0a     inks\
cape:cx=\x226.30230\
18\x22\x0a     inkscap\
e:cy=\x228.969841\x22\x0a\
     inkscape:do\
cument-units=\x22px\
\x22\x0a     inkscape:\
current-layer=\x22l\
ayer1\x22\x0a     show\
grid=\x22true\x22\x0a    \
 inkscape:window\
-width=\x221920\x22\x0a  \
   inkscape:wind\
ow-height=\x221004\x22\
\x0a     inkscape:w\
indow-x=\x220\x22\x0a    \
 inkscape:window\
-y=\x220\x22\x0a     inks\
cape:window-maxi\
mized=\x221\x22\x0a     i\
nkscape:showpage\
shadow=\x22false\x22\x0a \
    units=\x22px\x22\x0a \
    inkscape:pag\
echeckerboard=\x22f\
alse\x22\x0a     showg\
uides=\x22true\x22\x0a   \
  inkscape:snap-\
bbox=\x22true\x22\x0a    \
 inkscape:bbox-p\
aths=\x22true\x22\x0a    \
 inkscape:bbox-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-b\
box-edge-midpoin\
ts=\x22true\x22\x0a     i\
nkscape:snap-bbo\
x-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-nodes=\x22tru\
e\x22\x0a     inkscape\
:object-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-intersec\
tion-paths=\x22true\
\x22\x0a     inkscape:\
snap-smooth-node\
s=\x22true\x22\x0a     in\
kscape:snap-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
global=\x22true\x22\x0a  \
   fit-margin-to\
p=\x220\x22\x0a     fit-m\
argin-left=\x220\x22\x0a \
    fit-margin-r\
ight=\x220\x22\x0a     fi\
t-margin-bottom=\
\x220\x22\x0a     inkscap\
e:guide-bbox=\x22tr\
ue\x22>\x0a    <inksca\
pe:grid\x0a       t\
ype=\x22xygrid\x22\x0a   \
    id=\x22grid974\x22\
\x0a       empspaci\
ng=\x228\x22\x0a       sp\
acingx=\x220.264583\
32\x22\x0a       spaci\
ngy=\x220.26458332\x22\
\x0a       dotted=\x22\
false\x22\x0a       vi\
sible=\x22true\x22\x0a   \
    enabled=\x22tru\
e\x22\x0a       snapvi\
siblegridlineson\
ly=\x22true\x22\x0a      \
 originx=\x220\x22\x0a   \
    originy=\x220\x22 \
/>\x0a  </sodipodi:\
namedview>\x0a  <me\
tadata\x0a     id=\x22\
metadata5\x22>\x0a    \
<rdf:RDF>\x0a      \
<cc:Work\x0a       \
  rdf:about=\x22\x22>\x0a\
        <dc:form\
at>image/svg+xml\
</dc:format>\x0a   \
     <dc:type\x0a  \
         rdf:res\
ource=\x22http://pu\
rl.org/dc/dcmity\
pe/StillImage\x22 /\
>\x0a        <dc:ti\
tle />\x0a      </c\
c:Work>\x0a    </rd\
f:RDF>\x0a  </metad\
ata>\x0a  <g\x0a     i\
nkscape:label=\x22L\
ayer 1\x22\x0a     ink\
scape:groupmode=\
\x22layer\x22\x0a     id=\
\x22layer1\x22\x0a     tr\
ansform=\x22transla\
te(0,-291.70835)\
\x22>\x0a    <g\x0a      \
 id=\x22g847\x22\x0a     \
  transform=\x22mat\
rix(0.05207439,0\
,0,0.05207453,-0\
.90125164,282.41\
203)\x22>\x0a      <g\x0a\
         id=\x22g85\
1\x22>\x0a        <g\x0a \
          id=\x22g1\
059\x22\x0a           \
transform=\x22matri\
x(1.9986219,0,0,\
1.9986185,17.324\
484,-313.52314)\x22\
>\x0a          <pat\
h\x0a             i\
nkscape:transfor\
m-center-y=\x223.17\
5\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07000433;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22\x0a         \
    d=\x22M 25.3999\
99,271.60002 -8.\
0000008e-7,246.2\
0002 H 50.799999\
 Z\x22\x0a            \
 id=\x22path883\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22 />\x0a          \
<path\x0a          \
   sodipodi:node\
types=\x22cccc\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        id=\x22path\
880\x22\x0a           \
  d=\x22m 25.399999\
,271.60002 25.39\
9999,25.4 H 0 Z\x22\
\x0a             in\
kscape:transform\
-center-y=\x22-3.17\
49995\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22 />\x0a  \
        <rect\x0a  \
           ry=\x225\
.0534658\x22\x0a      \
       y=\x22253.84\
885\x22\x0a           \
  x=\x227.6487389\x22\x0a\
             hei\
ght=\x2235.528759\x22\x0a\
             wid\
th=\x2235.528786\x22\x0a \
            id=\x22\
rect870\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0618441\
9;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <circl\
e\x0a             r\
=\x2225.396828\x22\x0a   \
          cy=\x2227\
1.60001\x22\x0a       \
      cx=\x2225.4\x22\x0a\
             id=\
\x22path872\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.076358\
82;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <circ\
le\x0a             \
transform=\x22rotat\
e(-45)\x22\x0a        \
     cx=\x22-174.08\
969\x22\x0a           \
  cy=\x22210.01071\x22\
\x0a             r=\
\x2212.656071\x22\x0a    \
         id=\x22pat\
h876\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07399406;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-x=\x22-3.174999\
9\x22\x0a             \
sodipodi:nodetyp\
es=\x22cccc\x22\x0a      \
       inkscape:\
connector-curvat\
ure=\x220\x22\x0a        \
     id=\x22path904\
\x22\x0a             d\
=\x22m 25.4,271.600\
02 -25.400000400\
00004,25.4 v -50\
.8 z\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-x=\x223.175\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a             d\
=\x22m 25.399999,27\
1.60002 25.4,-25\
.4 v 50.8 z\x22\x0a   \
          id=\x22pa\
th906\x22\x0a         \
    inkscape:con\
nector-curvature\
=\x220\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22 />\x0a \
         <rect\x0a \
            ry=\x22\
5.0514922\x22\x0a     \
        y=\x22256.3\
9301\x22\x0a          \
   x=\x222.5663135\x22\
\x0a             he\
ight=\x2230.440479\x22\
\x0a             wi\
dth=\x2245.693634\x22\x0a\
             id=\
\x22rect837\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.065743\
8;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
id=\x22rect831\x22\x0a   \
          width=\
\x2245.693588\x22\x0a    \
         height=\
\x2230.44051\x22\x0a     \
        x=\x22248.7\
6645\x22\x0a          \
   y=\x22-40.633385\
\x22\x0a             r\
y=\x225.051497\x22\x0a   \
          transf\
orm=\x22rotate(90)\x22\
 />\x0a        </g>\
\x0a      </g>\x0a    \
</g>\x0a    <path\x0a \
      style=\x22opa\
city:1;fill:#ffc\
107;fill-opacity\
:1;stroke:none;s\
troke-width:0.38\
596651;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-opacity:\
1\x22\x0a       d=\x22m 5\
0.206421,401.676\
83 c 110.217209,\
0.71279 55.10860\
9,0.3564 0,0 z\x22\x0a\
       id=\x22rect9\
97\x22\x0a       inksc\
ape:connector-cu\
rvature=\x220\x22 />\x0a \
   <g\x0a       id=\
\x22g839\x22\x0a       tr\
ansform=\x22matrix(\
0,-1,-1,0,297.00\
002,297.00002)\x22>\
\x0a      <rect\x0a   \
      y=\x22291.972\
93\x22\x0a         x=\x22\
2.3812499\x22\x0a     \
    height=\x220.52\
916664\x22\x0a        \
 width=\x220.529166\
64\x22\x0a         id=\
\x22rect827\x22\x0a      \
   style=\x22opacit\
y:1;fill:#0000ff\
;fill-opacity:1;\
stroke:none;stro\
ke-width:0.52916\
664;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1\x22 /\
>\x0a      <rect\x0a  \
       style=\x22op\
acity:1;fill:#00\
00ff;fill-opacit\
y:1;stroke:none;\
stroke-width:0.5\
2916664;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1\x22\x0a         id=\x22\
rect829\x22\x0a       \
  width=\x220.52916\
664\x22\x0a         he\
ight=\x220.52916664\
\x22\x0a         x=\x222.\
3812499\x22\x0a       \
  y=\x22296.20627\x22 \
/>\x0a      <rect\x0a \
        y=\x22295.1\
4792\x22\x0a         x\
=\x222.3812499\x22\x0a   \
      height=\x220.\
52916664\x22\x0a      \
   width=\x220.5291\
6664\x22\x0a         i\
d=\x22rect832\x22\x0a    \
     style=\x22opac\
ity:1;fill:#0000\
ff;fill-opacity:\
1;stroke:none;st\
roke-width:0.529\
16664;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1\x22\
 />\x0a      <rect\x0a\
         style=\x22\
opacity:1;fill:#\
0000ff;fill-opac\
ity:1;stroke:non\
e;stroke-width:0\
.52916664;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1\x22\x0a         id\
=\x22rect834\x22\x0a     \
    width=\x220.529\
16664\x22\x0a         \
height=\x220.529166\
64\x22\x0a         x=\x22\
2.3812499\x22\x0a     \
    y=\x22294.0896\x22\
 />\x0a      <rect\x0a\
         y=\x22293.\
03128\x22\x0a         \
x=\x222.3812499\x22\x0a  \
       height=\x220\
.52916664\x22\x0a     \
    width=\x220.529\
16664\x22\x0a         \
id=\x22rect836\x22\x0a   \
      style=\x22opa\
city:1;fill:#000\
0ff;fill-opacity\
:1;stroke:none;s\
troke-width:0.52\
916664;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
\x22 />\x0a    </g>\x0a  \
</g>\x0a</svg>\x0a\
\x00\x00\x1f\xef\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22sli\
der.svg\x22\x0a   inks\
cape:export-file\
name=\x22/home/yeis\
on/Development/p\
iton/art/icon_li\
te.png\x22\x0a   inksc\
ape:export-xdpi=\
\x2296\x22\x0a   inkscape\
:export-ydpi=\x2296\
\x22>\x0a  <defs\x0a     \
id=\x22defs2\x22 />\x0a  \
<sodipodi:namedv\
iew\x0a     id=\x22bas\
e\x22\x0a     pagecolo\
r=\x22#ffffff\x22\x0a    \
 bordercolor=\x22#6\
66666\x22\x0a     bord\
eropacity=\x221.0\x22\x0a\
     inkscape:pa\
geopacity=\x220.0\x22\x0a\
     inkscape:pa\
geshadow=\x222\x22\x0a   \
  inkscape:zoom=\
\x2228.704913\x22\x0a    \
 inkscape:cx=\x228.\
5671075\x22\x0a     in\
kscape:cy=\x228.802\
1939\x22\x0a     inksc\
ape:document-uni\
ts=\x22px\x22\x0a     ink\
scape:current-la\
yer=\x22layer1\x22\x0a   \
  showgrid=\x22true\
\x22\x0a     inkscape:\
window-width=\x2219\
20\x22\x0a     inkscap\
e:window-height=\
\x221015\x22\x0a     inks\
cape:window-x=\x220\
\x22\x0a     inkscape:\
window-y=\x220\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22\x0a\
     inkscape:sh\
owpageshadow=\x22fa\
lse\x22\x0a     units=\
\x22px\x22\x0a     inksca\
pe:pagecheckerbo\
ard=\x22false\x22\x0a    \
 showguides=\x22tru\
e\x22\x0a     inkscape\
:snap-bbox=\x22true\
\x22\x0a     inkscape:\
bbox-paths=\x22true\
\x22\x0a     inkscape:\
bbox-nodes=\x22true\
\x22\x0a     inkscape:\
snap-bbox-edge-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-node\
s=\x22true\x22\x0a     in\
kscape:object-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-in\
tersection-paths\
=\x22true\x22\x0a     ink\
scape:snap-smoot\
h-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-global=\x22tr\
ue\x22\x0a     fit-mar\
gin-top=\x220\x22\x0a    \
 fit-margin-left\
=\x220\x22\x0a     fit-ma\
rgin-right=\x220\x22\x0a \
    fit-margin-b\
ottom=\x220\x22\x0a     i\
nkscape:guide-bb\
ox=\x22true\x22>\x0a    <\
inkscape:grid\x0a  \
     type=\x22xygri\
d\x22\x0a       id=\x22gr\
id974\x22\x0a       em\
pspacing=\x228\x22\x0a   \
    spacingx=\x220.\
26458332\x22\x0a      \
 spacingy=\x220.264\
58332\x22\x0a       do\
tted=\x22false\x22\x0a   \
    visible=\x22tru\
e\x22\x0a       enable\
d=\x22true\x22\x0a       \
snapvisiblegridl\
inesonly=\x22true\x22\x0a\
       originx=\x22\
0\x22\x0a       origin\
y=\x220\x22 />\x0a  </sod\
ipodi:namedview>\
\x0a  <metadata\x0a   \
  id=\x22metadata5\x22\
>\x0a    <rdf:RDF>\x0a\
      <cc:Work\x0a \
        rdf:abou\
t=\x22\x22>\x0a        <d\
c:format>image/s\
vg+xml</dc:forma\
t>\x0a        <dc:t\
ype\x0a           r\
df:resource=\x22htt\
p://purl.org/dc/\
dcmitype/StillIm\
age\x22 />\x0a        \
<dc:title />\x0a   \
   </cc:Work>\x0a  \
  </rdf:RDF>\x0a  <\
/metadata>\x0a  <g\x0a\
     inkscape:la\
bel=\x22Layer 1\x22\x0a  \
   inkscape:grou\
pmode=\x22layer\x22\x0a  \
   id=\x22layer1\x22\x0a \
    transform=\x22t\
ranslate(0,-291.\
70835)\x22>\x0a    <g\x0a\
       id=\x22g847\x22\
\x0a       transfor\
m=\x22matrix(0.0520\
7439,0,0,0.05207\
453,-0.90125164,\
282.41203)\x22>\x0a   \
   <g\x0a         i\
d=\x22g851\x22>\x0a      \
  <g\x0a           \
id=\x22g1059\x22\x0a     \
      transform=\
\x22matrix(1.998621\
9,0,0,1.9986185,\
17.324484,-313.5\
2314)\x22>\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-y\
=\x223.175\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          d=\x22M 2\
5.399999,271.600\
02 -8.0000008e-7\
,246.20002 H 50.\
799999 Z\x22\x0a      \
       id=\x22path8\
83\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22 />\x0a    \
      <path\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             id\
=\x22path880\x22\x0a     \
        d=\x22m 25.\
399999,271.60002\
 25.399999,25.4 \
H 0 Z\x22\x0a         \
    inkscape:tra\
nsform-center-y=\
\x22-3.1749995\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <r\
ect\x0a            \
 ry=\x225.0534658\x22\x0a\
             y=\x22\
253.84885\x22\x0a     \
        x=\x227.648\
7389\x22\x0a          \
   height=\x2235.52\
8759\x22\x0a          \
   width=\x2235.528\
786\x22\x0a           \
  id=\x22rect870\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
6184419;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<circle\x0a        \
     r=\x2225.39682\
8\x22\x0a             \
cy=\x22271.60001\x22\x0a \
            cx=\x22\
25.4\x22\x0a          \
   id=\x22path872\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07635882;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <circle\x0a       \
      transform=\
\x22rotate(-45)\x22\x0a  \
           cx=\x22-\
174.08969\x22\x0a     \
        cy=\x22210.\
01071\x22\x0a         \
    r=\x2212.656071\
\x22\x0a             i\
d=\x22path876\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0739\
9406;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x22-3.\
1749999\x22\x0a       \
      sodipodi:n\
odetypes=\x22cccc\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           id=\x22p\
ath904\x22\x0a        \
     d=\x22m 25.4,2\
71.60002 -25.400\
00040000004,25.4\
 v -50.8 z\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0700\
0433;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x223.1\
75\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07000433;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a        \
     d=\x22m 25.399\
999,271.60002 25\
.4,-25.4 v 50.8 \
z\x22\x0a             \
id=\x22path906\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22 />\x0a          <\
rect\x0a           \
  ry=\x225.0514922\x22\
\x0a             y=\
\x22256.39301\x22\x0a    \
         x=\x222.56\
63135\x22\x0a         \
    height=\x2230.4\
40479\x22\x0a         \
    width=\x2245.69\
3634\x22\x0a          \
   id=\x22rect837\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      id=\x22rect83\
1\x22\x0a             \
width=\x2245.693588\
\x22\x0a             h\
eight=\x2230.44051\x22\
\x0a             x=\
\x22248.76645\x22\x0a    \
         y=\x22-40.\
633385\x22\x0a        \
     ry=\x225.05149\
7\x22\x0a             \
transform=\x22rotat\
e(90)\x22 />\x0a      \
  </g>\x0a      </g\
>\x0a    </g>\x0a    <\
path\x0a       styl\
e=\x22opacity:1;fil\
l:#ffc107;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.38596651;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-op\
acity:1\x22\x0a       \
d=\x22m 50.206421,4\
01.67683 c 110.2\
17209,0.71279 55\
.108609,0.3564 0\
,0 z\x22\x0a       id=\
\x22rect997\x22\x0a      \
 inkscape:connec\
tor-curvature=\x220\
\x22 />\x0a    <path\x0a \
      style=\x22opa\
city:1;fill:#000\
0ff;fill-opacity\
:1;stroke:none;s\
troke-width:3;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
d=\x22M 10,0.013671\
88 C 4.4846749,0\
.01360343 0.0136\
0343,4.4846749 0\
.01367188,10 0.0\
136035,15.515325\
 4.484675,19.986\
396 10,19.986328\
 15.515325,19.98\
6396 19.986396,1\
5.515325 19.9863\
28,10 19.986396,\
4.484675 15.5153\
25,0.0136035 10,\
0.01367188 Z\x22\x0a  \
     transform=\x22\
matrix(0.2645833\
2,0,0,0.26458332\
,0,291.70835)\x22\x0a \
      id=\x22path82\
6\x22\x0a       inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
  sodipodi:nodet\
ypes=\x22ccccc\x22 />\x0a\
  </g>\x0a</svg>\x0a\
\x00\x00\x1f\xaf\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22che\
ckbox_indetermin\
ate.svg\x22\x0a   inks\
cape:export-file\
name=\x22/home/yeis\
on/Development/p\
iton/art/icon_li\
te.png\x22\x0a   inksc\
ape:export-xdpi=\
\x2296\x22\x0a   inkscape\
:export-ydpi=\x2296\
\x22>\x0a  <defs\x0a     \
id=\x22defs2\x22 />\x0a  \
<sodipodi:namedv\
iew\x0a     id=\x22bas\
e\x22\x0a     pagecolo\
r=\x22#ffffff\x22\x0a    \
 bordercolor=\x22#6\
66666\x22\x0a     bord\
eropacity=\x221.0\x22\x0a\
     inkscape:pa\
geopacity=\x220.0\x22\x0a\
     inkscape:pa\
geshadow=\x222\x22\x0a   \
  inkscape:zoom=\
\x2216.610599\x22\x0a    \
 inkscape:cx=\x22-4\
.7529072\x22\x0a     i\
nkscape:cy=\x2211.9\
84039\x22\x0a     inks\
cape:document-un\
its=\x22px\x22\x0a     in\
kscape:current-l\
ayer=\x22layer1\x22\x0a  \
   showgrid=\x22tru\
e\x22\x0a     inkscape\
:window-width=\x221\
920\x22\x0a     inksca\
pe:window-height\
=\x221015\x22\x0a     ink\
scape:window-x=\x22\
0\x22\x0a     inkscape\
:window-y=\x220\x22\x0a  \
   inkscape:wind\
ow-maximized=\x221\x22\
\x0a     inkscape:s\
howpageshadow=\x22f\
alse\x22\x0a     units\
=\x22px\x22\x0a     inksc\
ape:pagecheckerb\
oard=\x22false\x22\x0a   \
  showguides=\x22fa\
lse\x22\x0a     inksca\
pe:snap-bbox=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-paths=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-bbox-edge\
-midpoints=\x22true\
\x22\x0a     inkscape:\
snap-bbox-midpoi\
nts=\x22true\x22\x0a     \
inkscape:snap-no\
des=\x22true\x22\x0a     \
inkscape:object-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
intersection-pat\
hs=\x22true\x22\x0a     i\
nkscape:snap-smo\
oth-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-global=\x22\
true\x22\x0a     fit-m\
argin-top=\x220\x22\x0a  \
   fit-margin-le\
ft=\x220\x22\x0a     fit-\
margin-right=\x220\x22\
\x0a     fit-margin\
-bottom=\x220\x22\x0a    \
 inkscape:guide-\
bbox=\x22true\x22>\x0a   \
 <inkscape:grid\x0a\
       type=\x22xyg\
rid\x22\x0a       id=\x22\
grid974\x22\x0a       \
empspacing=\x228\x22\x0a \
      spacingx=\x22\
0.26458332\x22\x0a    \
   spacingy=\x220.2\
6458332\x22\x0a       \
dotted=\x22false\x22\x0a \
      visible=\x22t\
rue\x22\x0a       enab\
led=\x22true\x22\x0a     \
  snapvisiblegri\
dlinesonly=\x22true\
\x22\x0a       originx\
=\x220\x22\x0a       orig\
iny=\x220\x22 />\x0a  </s\
odipodi:namedvie\
w>\x0a  <metadata\x0a \
    id=\x22metadata\
5\x22>\x0a    <rdf:RDF\
>\x0a      <cc:Work\
\x0a         rdf:ab\
out=\x22\x22>\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0a        <dc\
:type\x0a          \
 rdf:resource=\x22h\
ttp://purl.org/d\
c/dcmitype/Still\
Image\x22 />\x0a      \
  <dc:title></dc\
:title>\x0a      </\
cc:Work>\x0a    </r\
df:RDF>\x0a  </meta\
data>\x0a  <g\x0a     \
inkscape:label=\x22\
Layer 1\x22\x0a     in\
kscape:groupmode\
=\x22layer\x22\x0a     id\
=\x22layer1\x22\x0a     t\
ransform=\x22transl\
ate(0,-291.70835\
)\x22>\x0a    <path\x0a  \
     style=\x22opac\
ity:1;fill:#0000\
ff;fill-opacity:\
1;stroke:none;st\
roke-width:2;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a       d\
=\x22M 2,0 C 0.8919\
9975,0 0,0.89198\
64 0,2 v 16 c 0,\
1.108014 0.89199\
975,2 2,2 h 16 c\
 1.108,0 2,-0.89\
1986 2,-2 V 2 C \
20,0.8919864 19.\
108,0 18,0 Z\x22\x0a  \
     transform=\x22\
matrix(0.2645833\
2,0,0,0.26458332\
,0,291.70835)\x22\x0a \
      id=\x22rect83\
3\x22\x0a       inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
  sodipodi:nodet\
ypes=\x22sssssssss\x22\
 />\x0a    <g\x0a     \
  id=\x22g847\x22\x0a    \
   transform=\x22ma\
trix(0.05207439,\
0,0,0.05207453,-\
0.90125164,282.4\
1203)\x22>\x0a      <g\
\x0a         id=\x22g8\
51\x22>\x0a        <g\x0a\
           id=\x22g\
1059\x22\x0a          \
 transform=\x22matr\
ix(1.9986219,0,0\
,1.9986185,17.32\
4484,-313.52314)\
\x22>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-y=\x223.1\
75\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07000433;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a        \
     d=\x22M 25.399\
999,271.60002 -8\
.0000008e-7,246.\
20002 H 50.79999\
9 Z\x22\x0a           \
  id=\x22path883\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22 />\x0a         \
 <path\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         id=\x22pat\
h880\x22\x0a          \
   d=\x22m 25.39999\
9,271.60002 25.3\
99999,25.4 H 0 Z\
\x22\x0a             i\
nkscape:transfor\
m-center-y=\x22-3.1\
749995\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <rect\x0a \
            ry=\x22\
5.0534658\x22\x0a     \
        y=\x22253.8\
4885\x22\x0a          \
   x=\x227.6487389\x22\
\x0a             he\
ight=\x2235.528759\x22\
\x0a             wi\
dth=\x2235.528786\x22\x0a\
             id=\
\x22rect870\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.061844\
19;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <circ\
le\x0a             \
r=\x2225.396828\x22\x0a  \
           cy=\x222\
71.60001\x22\x0a      \
       cx=\x2225.4\x22\
\x0a             id\
=\x22path872\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.07635\
882;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <cir\
cle\x0a            \
 transform=\x22rota\
te(-45)\x22\x0a       \
      cx=\x22-174.0\
8969\x22\x0a          \
   cy=\x22210.01071\
\x22\x0a             r\
=\x2212.656071\x22\x0a   \
          id=\x22pa\
th876\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07399406;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22 />\x0a  \
        <path\x0a  \
           inksc\
ape:transform-ce\
nter-x=\x22-3.17499\
99\x22\x0a            \
 sodipodi:nodety\
pes=\x22cccc\x22\x0a     \
        inkscape\
:connector-curva\
ture=\x220\x22\x0a       \
      id=\x22path90\
4\x22\x0a             \
d=\x22m 25.4,271.60\
002 -25.40000040\
000004,25.4 v -5\
0.8 z\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22 />\x0a  \
        <path\x0a  \
           inksc\
ape:transform-ce\
nter-x=\x223.175\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
d=\x22m 25.399999,2\
71.60002 25.4,-2\
5.4 v 50.8 z\x22\x0a  \
           id=\x22p\
ath906\x22\x0a        \
     inkscape:co\
nnector-curvatur\
e=\x220\x22\x0a          \
   sodipodi:node\
types=\x22cccc\x22 />\x0a\
          <rect\x0a\
             ry=\
\x225.0514922\x22\x0a    \
         y=\x22256.\
39301\x22\x0a         \
    x=\x222.5663135\
\x22\x0a             h\
eight=\x2230.440479\
\x22\x0a             w\
idth=\x2245.693634\x22\
\x0a             id\
=\x22rect837\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06574\
38;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <rect\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.0657438;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a            \
 id=\x22rect831\x22\x0a  \
           width\
=\x2245.693588\x22\x0a   \
          height\
=\x2230.44051\x22\x0a    \
         x=\x22248.\
76645\x22\x0a         \
    y=\x22-40.63338\
5\x22\x0a             \
ry=\x225.051497\x22\x0a  \
           trans\
form=\x22rotate(90)\
\x22 />\x0a        </g\
>\x0a      </g>\x0a   \
 </g>\x0a    <path\x0a\
       style=\x22op\
acity:1;fill:#ff\
c107;fill-opacit\
y:1;stroke:none;\
stroke-width:0.3\
8596651;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-opacity\
:1\x22\x0a       d=\x22m \
50.206421,401.67\
683 c 110.217209\
,0.71279 55.1086\
09,0.3564 0,0 z\x22\
\x0a       id=\x22rect\
997\x22\x0a       inks\
cape:connector-c\
urvature=\x220\x22 />\x0a\
  </g>\x0a</svg>\x0a\
\x00\x00!u\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22rad\
iobutton_checked\
.svg\x22\x0a   inkscap\
e:export-filenam\
e=\x22/home/yeison/\
Development/pito\
n/art/icon_lite.\
png\x22\x0a   inkscape\
:export-xdpi=\x2296\
\x22\x0a   inkscape:ex\
port-ydpi=\x2296\x22>\x0a\
  <defs\x0a     id=\
\x22defs2\x22 />\x0a  <so\
dipodi:namedview\
\x0a     id=\x22base\x22\x0a\
     pagecolor=\x22\
#ffffff\x22\x0a     bo\
rdercolor=\x22#6666\
66\x22\x0a     bordero\
pacity=\x221.0\x22\x0a   \
  inkscape:pageo\
pacity=\x220.0\x22\x0a   \
  inkscape:pages\
hadow=\x222\x22\x0a     i\
nkscape:zoom=\x2228\
.704913\x22\x0a     in\
kscape:cx=\x228.567\
1075\x22\x0a     inksc\
ape:cy=\x226.015214\
5\x22\x0a     inkscape\
:document-units=\
\x22px\x22\x0a     inksca\
pe:current-layer\
=\x22layer1\x22\x0a     s\
howgrid=\x22true\x22\x0a \
    inkscape:win\
dow-width=\x221920\x22\
\x0a     inkscape:w\
indow-height=\x2210\
15\x22\x0a     inkscap\
e:window-x=\x220\x22\x0a \
    inkscape:win\
dow-y=\x220\x22\x0a     i\
nkscape:window-m\
aximized=\x221\x22\x0a   \
  inkscape:showp\
ageshadow=\x22false\
\x22\x0a     units=\x22px\
\x22\x0a     inkscape:\
pagecheckerboard\
=\x22false\x22\x0a     sh\
owguides=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox=\x22true\x22\x0a \
    inkscape:bbo\
x-paths=\x22true\x22\x0a \
    inkscape:bbo\
x-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-bbox-edge-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
bbox-midpoints=\x22\
true\x22\x0a     inksc\
ape:snap-nodes=\x22\
true\x22\x0a     inksc\
ape:object-paths\
=\x22true\x22\x0a     ink\
scape:snap-inter\
section-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-smooth-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-global=\x22true\x22\
\x0a     fit-margin\
-top=\x220\x22\x0a     fi\
t-margin-left=\x220\
\x22\x0a     fit-margi\
n-right=\x220\x22\x0a    \
 fit-margin-bott\
om=\x220\x22\x0a     inks\
cape:guide-bbox=\
\x22true\x22>\x0a    <ink\
scape:grid\x0a     \
  type=\x22xygrid\x22\x0a\
       id=\x22grid9\
74\x22\x0a       empsp\
acing=\x228\x22\x0a      \
 spacingx=\x220.264\
58332\x22\x0a       sp\
acingy=\x220.264583\
32\x22\x0a       dotte\
d=\x22false\x22\x0a      \
 visible=\x22true\x22\x0a\
       enabled=\x22\
true\x22\x0a       sna\
pvisiblegridline\
sonly=\x22true\x22\x0a   \
    originx=\x220\x22\x0a\
       originy=\x22\
0\x22 />\x0a  </sodipo\
di:namedview>\x0a  \
<metadata\x0a     i\
d=\x22metadata5\x22>\x0a \
   <rdf:RDF>\x0a   \
   <cc:Work\x0a    \
     rdf:about=\x22\
\x22>\x0a        <dc:f\
ormat>image/svg+\
xml</dc:format>\x0a\
        <dc:type\
\x0a           rdf:\
resource=\x22http:/\
/purl.org/dc/dcm\
itype/StillImage\
\x22 />\x0a        <dc\
:title></dc:titl\
e>\x0a      </cc:Wo\
rk>\x0a    </rdf:RD\
F>\x0a  </metadata>\
\x0a  <g\x0a     inksc\
ape:label=\x22Layer\
 1\x22\x0a     inkscap\
e:groupmode=\x22lay\
er\x22\x0a     id=\x22lay\
er1\x22\x0a     transf\
orm=\x22translate(0\
,-291.70835)\x22>\x0a \
   <g\x0a       id=\
\x22g847\x22\x0a       tr\
ansform=\x22matrix(\
0.05207439,0,0,0\
.05207453,-0.901\
25164,282.41203)\
\x22>\x0a      <g\x0a    \
     id=\x22g851\x22>\x0a\
        <g\x0a     \
      id=\x22g1059\x22\
\x0a           tran\
sform=\x22matrix(1.\
9986219,0,0,1.99\
86185,17.324484,\
-313.52314)\x22>\x0a  \
        <path\x0a  \
           inksc\
ape:transform-ce\
nter-y=\x223.175\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
d=\x22M 25.399999,2\
71.60002 -8.0000\
008e-7,246.20002\
 H 50.799999 Z\x22\x0a\
             id=\
\x22path883\x22\x0a      \
       inkscape:\
connector-curvat\
ure=\x220\x22\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22 /\
>\x0a          <pat\
h\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    id=\x22path880\x22\
\x0a             d=\
\x22m 25.399999,271\
.60002 25.399999\
,25.4 H 0 Z\x22\x0a   \
          inksca\
pe:transform-cen\
ter-y=\x22-3.174999\
5\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07000433;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <rect\x0a      \
       ry=\x225.053\
4658\x22\x0a          \
   y=\x22253.84885\x22\
\x0a             x=\
\x227.6487389\x22\x0a    \
         height=\
\x2235.528759\x22\x0a    \
         width=\x22\
35.528786\x22\x0a     \
        id=\x22rect\
870\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.06184419;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <circle\x0a  \
           r=\x2225\
.396828\x22\x0a       \
      cy=\x22271.60\
001\x22\x0a           \
  cx=\x2225.4\x22\x0a    \
         id=\x22pat\
h872\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07635882;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <circle\x0a \
            tran\
sform=\x22rotate(-4\
5)\x22\x0a            \
 cx=\x22-174.08969\x22\
\x0a             cy\
=\x22210.01071\x22\x0a   \
          r=\x2212.\
656071\x22\x0a        \
     id=\x22path876\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07399406;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
x=\x22-3.1749999\x22\x0a \
            sodi\
podi:nodetypes=\x22\
cccc\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 id=\x22path904\x22\x0a  \
           d=\x22m \
25.4,271.60002 -\
25.4000004000000\
4,25.4 v -50.8 z\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
x=\x223.175\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.070004\
33;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22\x0a  \
           d=\x22m \
25.399999,271.60\
002 25.4,-25.4 v\
 50.8 z\x22\x0a       \
      id=\x22path90\
6\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             so\
dipodi:nodetypes\
=\x22cccc\x22 />\x0a     \
     <rect\x0a     \
        ry=\x225.05\
14922\x22\x0a         \
    y=\x22256.39301\
\x22\x0a             x\
=\x222.5663135\x22\x0a   \
          height\
=\x2230.440479\x22\x0a   \
          width=\
\x2245.693634\x22\x0a    \
         id=\x22rec\
t837\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <rect\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
            id=\x22\
rect831\x22\x0a       \
      width=\x2245.\
693588\x22\x0a        \
     height=\x2230.\
44051\x22\x0a         \
    x=\x22248.76645\
\x22\x0a             y\
=\x22-40.633385\x22\x0a  \
           ry=\x225\
.051497\x22\x0a       \
      transform=\
\x22rotate(90)\x22 />\x0a\
        </g>\x0a   \
   </g>\x0a    </g>\
\x0a    <path\x0a     \
  style=\x22opacity\
:1;fill:#ffc107;\
fill-opacity:1;s\
troke:none;strok\
e-width:0.385966\
51;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-opacity:1\x22\x0a \
      d=\x22m 50.20\
6421,401.67683 c\
 110.217209,0.71\
279 55.108609,0.\
3564 0,0 z\x22\x0a    \
   id=\x22rect997\x22\x0a\
       inkscape:\
connector-curvat\
ure=\x220\x22 />\x0a    <\
path\x0a       styl\
e=\x22opacity:1;fil\
l:#0000ff;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:3;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
      d=\x22M 10 0.\
013671875 A 9.98\
62042 9.9862042 \
0 0 0 0.01367187\
5 10 A 9.9862042\
 9.9862042 0 0 0\
 10 19.986328 A \
9.9862042 9.9862\
042 0 0 0 19.986\
328 10 A 9.98620\
42 9.9862042 0 0\
 0 10 0.01367187\
5 z M 10 3 A 7.0\
000143 7.0000143\
 0 0 1 17 10 A 7\
.0000143 7.00001\
43 0 0 1 10 17 A\
 7.0000143 7.000\
0143 0 0 1 3 10 \
A 7.0000143 7.00\
00143 0 0 1 10 3\
 z \x22\x0a       tran\
sform=\x22matrix(0.\
26458332,0,0,0.2\
6458332,0,291.70\
835)\x22\x0a       id=\
\x22path826\x22 />\x0a   \
 <circle\x0a       \
style=\x22opacity:1\
;fill:#0000ff;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:0.31793979\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22\x0a    \
   id=\x22circle830\
\x22\x0a       cx=\x222.6\
458333\x22\x0a       c\
y=\x22294.35419\x22\x0a  \
     r=\x221.058337\
1\x22 />\x0a  </g>\x0a</s\
vg>\x0a\
\x00\x00$v\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22spl\
itter-horizontal\
.svg\x22\x0a   inkscap\
e:export-filenam\
e=\x22/home/yeison/\
Development/pito\
n/art/icon_lite.\
png\x22\x0a   inkscape\
:export-xdpi=\x2296\
\x22\x0a   inkscape:ex\
port-ydpi=\x2296\x22>\x0a\
  <defs\x0a     id=\
\x22defs2\x22 />\x0a  <so\
dipodi:namedview\
\x0a     id=\x22base\x22\x0a\
     pagecolor=\x22\
#ffffff\x22\x0a     bo\
rdercolor=\x22#6666\
66\x22\x0a     bordero\
pacity=\x221.0\x22\x0a   \
  inkscape:pageo\
pacity=\x220.0\x22\x0a   \
  inkscape:pages\
hadow=\x222\x22\x0a     i\
nkscape:zoom=\x2224\
.802598\x22\x0a     in\
kscape:cx=\x226.302\
3018\x22\x0a     inksc\
ape:cy=\x228.969841\
\x22\x0a     inkscape:\
document-units=\x22\
px\x22\x0a     inkscap\
e:current-layer=\
\x22layer1\x22\x0a     sh\
owgrid=\x22true\x22\x0a  \
   inkscape:wind\
ow-width=\x221920\x22\x0a\
     inkscape:wi\
ndow-height=\x22100\
4\x22\x0a     inkscape\
:window-x=\x220\x22\x0a  \
   inkscape:wind\
ow-y=\x220\x22\x0a     in\
kscape:window-ma\
ximized=\x221\x22\x0a    \
 inkscape:showpa\
geshadow=\x22false\x22\
\x0a     units=\x22px\x22\
\x0a     inkscape:p\
agecheckerboard=\
\x22false\x22\x0a     sho\
wguides=\x22true\x22\x0a \
    inkscape:sna\
p-bbox=\x22true\x22\x0a  \
   inkscape:bbox\
-paths=\x22true\x22\x0a  \
   inkscape:bbox\
-nodes=\x22true\x22\x0a  \
   inkscape:snap\
-bbox-edge-midpo\
ints=\x22true\x22\x0a    \
 inkscape:snap-b\
box-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-nodes=\x22t\
rue\x22\x0a     inksca\
pe:object-paths=\
\x22true\x22\x0a     inks\
cape:snap-inters\
ection-paths=\x22tr\
ue\x22\x0a     inkscap\
e:snap-smooth-no\
des=\x22true\x22\x0a     \
inkscape:snap-mi\
dpoints=\x22true\x22\x0a \
    inkscape:sna\
p-global=\x22true\x22\x0a\
     fit-margin-\
top=\x220\x22\x0a     fit\
-margin-left=\x220\x22\
\x0a     fit-margin\
-right=\x220\x22\x0a     \
fit-margin-botto\
m=\x220\x22\x0a     inksc\
ape:guide-bbox=\x22\
true\x22>\x0a    <inks\
cape:grid\x0a      \
 type=\x22xygrid\x22\x0a \
      id=\x22grid97\
4\x22\x0a       empspa\
cing=\x228\x22\x0a       \
spacingx=\x220.2645\
8332\x22\x0a       spa\
cingy=\x220.2645833\
2\x22\x0a       dotted\
=\x22false\x22\x0a       \
visible=\x22true\x22\x0a \
      enabled=\x22t\
rue\x22\x0a       snap\
visiblegridlines\
only=\x22true\x22\x0a    \
   originx=\x220\x22\x0a \
      originy=\x220\
\x22 />\x0a  </sodipod\
i:namedview>\x0a  <\
metadata\x0a     id\
=\x22metadata5\x22>\x0a  \
  <rdf:RDF>\x0a    \
  <cc:Work\x0a     \
    rdf:about=\x22\x22\
>\x0a        <dc:fo\
rmat>image/svg+x\
ml</dc:format>\x0a \
       <dc:type\x0a\
           rdf:r\
esource=\x22http://\
purl.org/dc/dcmi\
type/StillImage\x22\
 />\x0a        <dc:\
title />\x0a      <\
/cc:Work>\x0a    </\
rdf:RDF>\x0a  </met\
adata>\x0a  <g\x0a    \
 inkscape:label=\
\x22Layer 1\x22\x0a     i\
nkscape:groupmod\
e=\x22layer\x22\x0a     i\
d=\x22layer1\x22\x0a     \
transform=\x22trans\
late(0,-291.7083\
5)\x22>\x0a    <g\x0a    \
   id=\x22g847\x22\x0a   \
    transform=\x22m\
atrix(0.05207439\
,0,0,0.05207453,\
-0.90125164,282.\
41203)\x22>\x0a      <\
g\x0a         id=\x22g\
851\x22>\x0a        <g\
\x0a           id=\x22\
g1059\x22\x0a         \
  transform=\x22mat\
rix(1.9986219,0,\
0,1.9986185,17.3\
24484,-313.52314\
)\x22>\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-y=\x223.\
175\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      d=\x22M 25.39\
9999,271.60002 -\
8.0000008e-7,246\
.20002 H 50.7999\
99 Z\x22\x0a          \
   id=\x22path883\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22 />\x0a        \
  <path\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          id=\x22pa\
th880\x22\x0a         \
    d=\x22m 25.3999\
99,271.60002 25.\
399999,25.4 H 0 \
Z\x22\x0a             \
inkscape:transfo\
rm-center-y=\x22-3.\
1749995\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             ry=\
\x225.0534658\x22\x0a    \
         y=\x22253.\
84885\x22\x0a         \
    x=\x227.6487389\
\x22\x0a             h\
eight=\x2235.528759\
\x22\x0a             w\
idth=\x2235.528786\x22\
\x0a             id\
=\x22rect870\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06184\
419;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <cir\
cle\x0a            \
 r=\x2225.396828\x22\x0a \
            cy=\x22\
271.60001\x22\x0a     \
        cx=\x2225.4\
\x22\x0a             i\
d=\x22path872\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0763\
5882;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <ci\
rcle\x0a           \
  transform=\x22rot\
ate(-45)\x22\x0a      \
       cx=\x22-174.\
08969\x22\x0a         \
    cy=\x22210.0107\
1\x22\x0a             \
r=\x2212.656071\x22\x0a  \
           id=\x22p\
ath876\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07399406\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x22-3.1749\
999\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22\x0a    \
         inkscap\
e:connector-curv\
ature=\x220\x22\x0a      \
       id=\x22path9\
04\x22\x0a            \
 d=\x22m 25.4,271.6\
0002 -25.4000004\
0000004,25.4 v -\
50.8 z\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x223.175\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a            \
 d=\x22m 25.399999,\
271.60002 25.4,-\
25.4 v 50.8 z\x22\x0a \
            id=\x22\
path906\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22 />\
\x0a          <rect\
\x0a             ry\
=\x225.0514922\x22\x0a   \
          y=\x22256\
.39301\x22\x0a        \
     x=\x222.566313\
5\x22\x0a             \
height=\x2230.44047\
9\x22\x0a             \
width=\x2245.693634\
\x22\x0a             i\
d=\x22rect837\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <rec\
t\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22\x0a           \
  id=\x22rect831\x22\x0a \
            widt\
h=\x2245.693588\x22\x0a  \
           heigh\
t=\x2230.44051\x22\x0a   \
          x=\x22248\
.76645\x22\x0a        \
     y=\x22-40.6333\
85\x22\x0a            \
 ry=\x225.051497\x22\x0a \
            tran\
sform=\x22rotate(90\
)\x22 />\x0a        </\
g>\x0a      </g>\x0a  \
  </g>\x0a    <path\
\x0a       style=\x22o\
pacity:1;fill:#f\
fc107;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
38596651;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-opacit\
y:1\x22\x0a       d=\x22m\
 50.206421,401.6\
7683 c 110.21720\
9,0.71279 55.108\
609,0.3564 0,0 z\
\x22\x0a       id=\x22rec\
t997\x22\x0a       ink\
scape:connector-\
curvature=\x220\x22 />\
\x0a    <g\x0a       i\
d=\x22g839\x22>\x0a      \
<rect\x0a         y\
=\x22291.97293\x22\x0a   \
      x=\x222.38124\
99\x22\x0a         hei\
ght=\x220.52916664\x22\
\x0a         width=\
\x220.52916664\x22\x0a   \
      id=\x22rect82\
7\x22\x0a         styl\
e=\x22opacity:1;fil\
l:#0000ff;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22 />\x0a     \
 <rect\x0a         \
style=\x22opacity:1\
;fill:#0000ff;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:0.52916664\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1\x22\x0a    \
     id=\x22rect829\
\x22\x0a         width\
=\x220.52916664\x22\x0a  \
       height=\x220\
.52916664\x22\x0a     \
    x=\x222.3812499\
\x22\x0a         y=\x2229\
6.20627\x22 />\x0a    \
  <rect\x0a        \
 y=\x22295.14792\x22\x0a \
        x=\x222.381\
2499\x22\x0a         h\
eight=\x220.5291666\
4\x22\x0a         widt\
h=\x220.52916664\x22\x0a \
        id=\x22rect\
832\x22\x0a         st\
yle=\x22opacity:1;f\
ill:#0000ff;fill\
-opacity:1;strok\
e:none;stroke-wi\
dth:0.52916664;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1\x22 />\x0a   \
   <rect\x0a       \
  style=\x22opacity\
:1;fill:#0000ff;\
fill-opacity:1;s\
troke:none;strok\
e-width:0.529166\
64;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1\x22\x0a  \
       id=\x22rect8\
34\x22\x0a         wid\
th=\x220.52916664\x22\x0a\
         height=\
\x220.52916664\x22\x0a   \
      x=\x222.38124\
99\x22\x0a         y=\x22\
294.0896\x22 />\x0a   \
   <rect\x0a       \
  y=\x22293.03128\x22\x0a\
         x=\x222.38\
12499\x22\x0a         \
height=\x220.529166\
64\x22\x0a         wid\
th=\x220.52916664\x22\x0a\
         id=\x22rec\
t836\x22\x0a         s\
tyle=\x22opacity:1;\
fill:#0000ff;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:0.52916664;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1\x22 />\x0a  \
  </g>\x0a  </g>\x0a</\
svg>\x0a\
\x00\x00!1\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22rig\
htarrow.svg\x22\x0a   \
inkscape:export-\
filename=\x22/home/\
yeison/Developme\
nt/piton/art/ico\
n_lite.png\x22\x0a   i\
nkscape:export-x\
dpi=\x2296\x22\x0a   inks\
cape:export-ydpi\
=\x2296\x22>\x0a  <defs\x0a \
    id=\x22defs2\x22 /\
>\x0a  <sodipodi:na\
medview\x0a     id=\
\x22base\x22\x0a     page\
color=\x22#ffffff\x22\x0a\
     bordercolor\
=\x22#666666\x22\x0a     \
borderopacity=\x221\
.0\x22\x0a     inkscap\
e:pageopacity=\x220\
.0\x22\x0a     inkscap\
e:pageshadow=\x222\x22\
\x0a     inkscape:z\
oom=\x2211.745467\x22\x0a\
     inkscape:cx\
=\x22-8.0020924\x22\x0a  \
   inkscape:cy=\x22\
-13.919269\x22\x0a    \
 inkscape:docume\
nt-units=\x22px\x22\x0a  \
   inkscape:curr\
ent-layer=\x22layer\
1\x22\x0a     showgrid\
=\x22true\x22\x0a     ink\
scape:window-wid\
th=\x221920\x22\x0a     i\
nkscape:window-h\
eight=\x221015\x22\x0a   \
  inkscape:windo\
w-x=\x220\x22\x0a     ink\
scape:window-y=\x22\
0\x22\x0a     inkscape\
:window-maximize\
d=\x221\x22\x0a     inksc\
ape:showpageshad\
ow=\x22false\x22\x0a     \
units=\x22px\x22\x0a     \
inkscape:pageche\
ckerboard=\x22false\
\x22\x0a     showguide\
s=\x22true\x22\x0a     in\
kscape:snap-bbox\
=\x22true\x22\x0a     ink\
scape:bbox-paths\
=\x22true\x22\x0a     ink\
scape:bbox-nodes\
=\x22true\x22\x0a     ink\
scape:snap-bbox-\
edge-midpoints=\x22\
true\x22\x0a     inksc\
ape:snap-bbox-mi\
dpoints=\x22true\x22\x0a \
    inkscape:sna\
p-nodes=\x22true\x22\x0a \
    inkscape:obj\
ect-paths=\x22true\x22\
\x0a     inkscape:s\
nap-intersection\
-paths=\x22true\x22\x0a  \
   inkscape:snap\
-smooth-nodes=\x22t\
rue\x22\x0a     inksca\
pe:snap-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-glob\
al=\x22true\x22\x0a     f\
it-margin-top=\x220\
\x22\x0a     fit-margi\
n-left=\x220\x22\x0a     \
fit-margin-right\
=\x220\x22\x0a     fit-ma\
rgin-bottom=\x220\x22\x0a\
     inkscape:gu\
ide-bbox=\x22true\x22>\
\x0a    <inkscape:g\
rid\x0a       type=\
\x22xygrid\x22\x0a       \
id=\x22grid974\x22\x0a   \
    empspacing=\x22\
8\x22\x0a       spacin\
gx=\x220.26458332\x22\x0a\
       spacingy=\
\x220.26458332\x22\x0a   \
    dotted=\x22fals\
e\x22\x0a       visibl\
e=\x22true\x22\x0a       \
enabled=\x22true\x22\x0a \
      snapvisibl\
egridlinesonly=\x22\
true\x22\x0a       ori\
ginx=\x220\x22\x0a       \
originy=\x220\x22 />\x0a \
 </sodipodi:name\
dview>\x0a  <metada\
ta\x0a     id=\x22meta\
data5\x22>\x0a    <rdf\
:RDF>\x0a      <cc:\
Work\x0a         rd\
f:about=\x22\x22>\x0a    \
    <dc:format>i\
mage/svg+xml</dc\
:format>\x0a       \
 <dc:type\x0a      \
     rdf:resourc\
e=\x22http://purl.o\
rg/dc/dcmitype/S\
tillImage\x22 />\x0a  \
      <dc:title \
/>\x0a      </cc:Wo\
rk>\x0a    </rdf:RD\
F>\x0a  </metadata>\
\x0a  <g\x0a     inksc\
ape:label=\x22Layer\
 1\x22\x0a     inkscap\
e:groupmode=\x22lay\
er\x22\x0a     id=\x22lay\
er1\x22\x0a     transf\
orm=\x22translate(0\
,-291.70835)\x22>\x0a \
   <g\x0a       id=\
\x22g847\x22\x0a       tr\
ansform=\x22matrix(\
0.05207439,0,0,0\
.05207453,-0.901\
25164,282.41203)\
\x22>\x0a      <g\x0a    \
     id=\x22g851\x22>\x0a\
        <g\x0a     \
      id=\x22g1059\x22\
\x0a           tran\
sform=\x22matrix(1.\
9986219,0,0,1.99\
86185,17.324484,\
-313.52314)\x22>\x0a  \
        <path\x0a  \
           inksc\
ape:transform-ce\
nter-y=\x223.175\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
d=\x22M 25.399999,2\
71.60002 -8.0000\
008e-7,246.20002\
 H 50.799999 Z\x22\x0a\
             id=\
\x22path883\x22\x0a      \
       inkscape:\
connector-curvat\
ure=\x220\x22\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22 /\
>\x0a          <pat\
h\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    id=\x22path880\x22\
\x0a             d=\
\x22m 25.399999,271\
.60002 25.399999\
,25.4 H 0 Z\x22\x0a   \
          inksca\
pe:transform-cen\
ter-y=\x22-3.174999\
5\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07000433;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <rect\x0a      \
       ry=\x225.053\
4658\x22\x0a          \
   y=\x22253.84885\x22\
\x0a             x=\
\x227.6487389\x22\x0a    \
         height=\
\x2235.528759\x22\x0a    \
         width=\x22\
35.528786\x22\x0a     \
        id=\x22rect\
870\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.06184419;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <circle\x0a  \
           r=\x2225\
.396828\x22\x0a       \
      cy=\x22271.60\
001\x22\x0a           \
  cx=\x2225.4\x22\x0a    \
         id=\x22pat\
h872\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07635882;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <circle\x0a \
            tran\
sform=\x22rotate(-4\
5)\x22\x0a            \
 cx=\x22-174.08969\x22\
\x0a             cy\
=\x22210.01071\x22\x0a   \
          r=\x2212.\
656071\x22\x0a        \
     id=\x22path876\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07399406;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
x=\x22-3.1749999\x22\x0a \
            sodi\
podi:nodetypes=\x22\
cccc\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 id=\x22path904\x22\x0a  \
           d=\x22m \
25.4,271.60002 -\
25.4000004000000\
4,25.4 v -50.8 z\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
x=\x223.175\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.070004\
33;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22\x0a  \
           d=\x22m \
25.399999,271.60\
002 25.4,-25.4 v\
 50.8 z\x22\x0a       \
      id=\x22path90\
6\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             so\
dipodi:nodetypes\
=\x22cccc\x22 />\x0a     \
     <rect\x0a     \
        ry=\x225.05\
14922\x22\x0a         \
    y=\x22256.39301\
\x22\x0a             x\
=\x222.5663135\x22\x0a   \
          height\
=\x2230.440479\x22\x0a   \
          width=\
\x2245.693634\x22\x0a    \
         id=\x22rec\
t837\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <rect\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
            id=\x22\
rect831\x22\x0a       \
      width=\x2245.\
693588\x22\x0a        \
     height=\x2230.\
44051\x22\x0a         \
    x=\x22248.76645\
\x22\x0a             y\
=\x22-40.633385\x22\x0a  \
           ry=\x225\
.051497\x22\x0a       \
      transform=\
\x22rotate(90)\x22 />\x0a\
        </g>\x0a   \
   </g>\x0a    </g>\
\x0a    <path\x0a     \
  style=\x22opacity\
:1;fill:#ffc107;\
fill-opacity:1;s\
troke:none;strok\
e-width:0.385966\
51;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-opacity:1\x22\x0a \
      d=\x22m 50.20\
6421,401.67683 c\
 110.217209,0.71\
279 55.108609,0.\
3564 0,0 z\x22\x0a    \
   id=\x22rect997\x22\x0a\
       inkscape:\
connector-curvat\
ure=\x220\x22 />\x0a    <\
path\x0a       sodi\
podi:type=\x22star\x22\
\x0a       style=\x22o\
pacity:1;fill:#0\
000ff;fill-opaci\
ty:1;stroke:none\
;stroke-width:1.\
38742065;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a       id=\x22p\
ath828\x22\x0a       s\
odipodi:sides=\x223\
\x22\x0a       sodipod\
i:cx=\x22-2.6458383\
\x22\x0a       sodipod\
i:cy=\x22-294.16339\
\x22\x0a       sodipod\
i:r1=\x221.3874207\x22\
\x0a       sodipodi\
:r2=\x220.69371033\x22\
\x0a       sodipodi\
:arg1=\x221.5707963\
\x22\x0a       sodipod\
i:arg2=\x222.617993\
9\x22\x0a       inksca\
pe:flatsided=\x22tr\
ue\x22\x0a       inksc\
ape:rounded=\x220.1\
\x22\x0a       inkscap\
e:randomized=\x220\x22\
\x0a       d=\x22m -2.\
6458382,-292.775\
97 c -0.2403083,\
0 -1.3216958,-1.\
87302 -1.2015416\
,-2.08113 0.1201\
541,-0.20811 2.2\
829289,-0.20811 \
2.4030831,0 0.12\
01541,0.20811 -0\
.9612332,2.08113\
 -1.2015415,2.08\
113 z\x22\x0a       in\
kscape:transform\
-center-y=\x221.007\
6499e-05\x22\x0a      \
 transform=\x22rota\
te(-90,294.12438\
,-2.6458332)\x22\x0a  \
     inkscape:tr\
ansform-center-x\
=\x22-0.22980161\x22 /\
>\x0a  </g>\x0a</svg>\x0a\
\
\x00\x00\x09{\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Gener\
ator: Adobe Illu\
strator 19.0.0, \
SVG Export Plug-\
In . SVG Version\
: 6.00 Build 0) \
 -->\x0a\x0a<svg\x0a   xm\
lns:dc=\x22http://p\
url.org/dc/eleme\
nts/1.1/\x22\x0a   xml\
ns:cc=\x22http://cr\
eativecommons.or\
g/ns#\x22\x0a   xmlns:\
rdf=\x22http://www.\
w3.org/1999/02/2\
2-rdf-syntax-ns#\
\x22\x0a   xmlns:svg=\x22\
http://www.w3.or\
g/2000/svg\x22\x0a   x\
mlns=\x22http://www\
.w3.org/2000/svg\
\x22\x0a   xmlns:sodip\
odi=\x22http://sodi\
podi.sourceforge\
.net/DTD/sodipod\
i-0.dtd\x22\x0a   xmln\
s:inkscape=\x22http\
://www.inkscape.\
org/namespaces/i\
nkscape\x22\x0a   vers\
ion=\x221.1\x22\x0a   id=\
\x22content\x22\x0a   x=\x22\
0px\x22\x0a   y=\x220px\x22\x0a\
   viewBox=\x2256 -\
56 512 512\x22\x0a   x\
ml:space=\x22preser\
ve\x22\x0a   sodipodi:\
docname=\x22logo.sv\
g\x22\x0a   width=\x22512\
\x22\x0a   height=\x22512\
\x22\x0a   inkscape:ex\
port-filename=\x22/\
home/yeison/Deve\
lopment/gcpds/py\
side-material/do\
cs/source/_stati\
c/logo.png\x22\x0a   i\
nkscape:export-x\
dpi=\x2296\x22\x0a   inks\
cape:export-ydpi\
=\x2296\x22\x0a   inkscap\
e:version=\x220.92.\
4 5da689c313, 20\
19-01-14\x22><metad\
ata\x0a   id=\x22metad\
ata17\x22><rdf:RDF>\
<cc:Work\x0a       \
rdf:about=\x22\x22><dc\
:format>image/sv\
g+xml</dc:format\
><dc:type\x0a      \
   rdf:resource=\
\x22http://purl.org\
/dc/dcmitype/Sti\
llImage\x22 /><dc:t\
itle></dc:title>\
</cc:Work></rdf:\
RDF></metadata><\
defs\x0a   id=\x22defs\
15\x22 /><sodipodi:\
namedview\x0a   pag\
ecolor=\x22#ffffff\x22\
\x0a   bordercolor=\
\x22#666666\x22\x0a   bor\
deropacity=\x221\x22\x0a \
  objecttoleranc\
e=\x2210\x22\x0a   gridto\
lerance=\x2210\x22\x0a   \
guidetolerance=\x22\
10\x22\x0a   inkscape:\
pageopacity=\x220\x22\x0a\
   inkscape:page\
shadow=\x222\x22\x0a   in\
kscape:window-wi\
dth=\x221920\x22\x0a   in\
kscape:window-he\
ight=\x221015\x22\x0a   i\
d=\x22namedview13\x22\x0a\
   showgrid=\x22tru\
e\x22\x0a   inkscape:z\
oom=\x220.61631945\x22\
\x0a   inkscape:cx=\
\x22156.74186\x22\x0a   i\
nkscape:cy=\x2210.3\
16892\x22\x0a   inksca\
pe:window-x=\x220\x22\x0a\
   inkscape:wind\
ow-y=\x220\x22\x0a   inks\
cape:window-maxi\
mized=\x221\x22\x0a   ink\
scape:current-la\
yer=\x22content\x22\x0a  \
 showguides=\x22fal\
se\x22\x0a   fit-margi\
n-top=\x220\x22\x0a   fit\
-margin-left=\x220\x22\
\x0a   fit-margin-r\
ight=\x220\x22\x0a   fit-\
margin-bottom=\x220\
\x22 />\x0a<style\x0a   t\
ype=\x22text/css\x22\x0a \
  id=\x22style2\x22>\x0a\x09\
.st0{fill:#21212\
1;}\x0a\x09.st1{fill:#\
FF80AB;}\x0a\x09.st2{f\
ill:#FF1744;}\x0a</\
style>\x0a<g\x0a   id=\
\x22g4554\x22\x0a   trans\
form=\x22matrix(3.5\
555556,0,0,3.555\
5556,-143.11111,\
143.11111)\x22><g\x0a \
    id=\x22g10\x22>\x0a\x09<\
polygon\x0a   style\
=\x22fill:#41cd5f;f\
ill-opacity:0.94\
117647\x22\x0a   id=\x22p\
olygon4\x22\x0a   poin\
ts=\x22176,-8 80,-8\
 56,-56 200,-56 \
\x22\x0a   class=\x22st0\x22\
 />\x0a\x09<rect\x0a   st\
yle=\x22fill:#ffd80\
f;fill-opacity:0\
.94117647\x22\x0a   id\
=\x22rect6\x22\x0a   heig\
ht=\x2296\x22\x0a   width\
=\x22144\x22\x0a   class=\
\x22st1\x22\x0a   y=\x22-8\x22\x0a\
   x=\x2256\x22 />\x0a\x09<p\
olygon\x0a   style=\
\x22fill:#00939f;fi\
ll-opacity:0.941\
17647\x22\x0a   id=\x22po\
lygon8\x22\x0a   point\
s=\x22176,-8 80,-8 \
128,88 \x22\x0a   clas\
s=\x22st2\x22 />\x0a</g><\
/g>\x0a</svg>\
\x00\x00\x15<\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2251\
2\x22\x0a   height=\x2251\
2\x22\x0a   viewBox=\x220\
 0 135.46667 135\
.46667\x22\x0a   versi\
on=\x221.1\x22\x0a   id=\x22\
svg8\x22\x0a   inkscap\
e:version=\x220.92.\
4 5da689c313, 20\
19-01-14\x22\x0a   sod\
ipodi:docname=\x22l\
ogo_frame.svg\x22\x0a \
  inkscape:expor\
t-filename=\x22/hom\
e/yeison/Develop\
ment/gcpds/bci-u\
nscented/assets/\
logo.png\x22\x0a   ink\
scape:export-xdp\
i=\x2296\x22\x0a   inksca\
pe:export-ydpi=\x22\
96\x22>\x0a  <defs\x0a   \
  id=\x22defs2\x22 />\x0a\
  <sodipodi:name\
dview\x0a     id=\x22b\
ase\x22\x0a     pageco\
lor=\x22#ffffff\x22\x0a  \
   bordercolor=\x22\
#666666\x22\x0a     bo\
rderopacity=\x221.0\
\x22\x0a     inkscape:\
pageopacity=\x220.0\
\x22\x0a     inkscape:\
pageshadow=\x222\x22\x0a \
    inkscape:zoo\
m=\x220.96260433\x22\x0a \
    inkscape:cx=\
\x22263.56863\x22\x0a    \
 inkscape:cy=\x2215\
4.89649\x22\x0a     in\
kscape:document-\
units=\x22px\x22\x0a     \
inkscape:current\
-layer=\x22layer1\x22\x0a\
     showgrid=\x22f\
alse\x22\x0a     inksc\
ape:window-width\
=\x221920\x22\x0a     ink\
scape:window-hei\
ght=\x221004\x22\x0a     \
inkscape:window-\
x=\x220\x22\x0a     inksc\
ape:window-y=\x220\x22\
\x0a     inkscape:w\
indow-maximized=\
\x221\x22\x0a     units=\x22\
px\x22\x0a     inkscap\
e:showpageshadow\
=\x22false\x22\x0a     sh\
owguides=\x22false\x22\
\x0a     inkscape:s\
nap-bbox=\x22true\x22\x0a\
     inkscape:bb\
ox-paths=\x22true\x22\x0a\
     inkscape:bb\
ox-nodes=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-bbox\
-edge-midpoints=\
\x22true\x22\x0a     inks\
cape:object-path\
s=\x22true\x22\x0a     in\
kscape:snap-inte\
rsection-paths=\x22\
true\x22\x0a     inksc\
ape:snap-midpoin\
ts=\x22true\x22\x0a     i\
nkscape:snap-smo\
oth-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-object-midpo\
ints=\x22true\x22\x0a    \
 inkscape:snap-c\
enter=\x22true\x22\x0a   \
  fit-margin-top\
=\x220\x22\x0a     fit-ma\
rgin-left=\x220\x22\x0a  \
   fit-margin-ri\
ght=\x220\x22\x0a     fit\
-margin-bottom=\x22\
0\x22 />\x0a  <metadat\
a\x0a     id=\x22metad\
ata5\x22>\x0a    <rdf:\
RDF>\x0a      <cc:W\
ork\x0a         rdf\
:about=\x22\x22>\x0a     \
   <dc:format>im\
age/svg+xml</dc:\
format>\x0a        \
<dc:type\x0a       \
    rdf:resource\
=\x22http://purl.or\
g/dc/dcmitype/St\
illImage\x22 />\x0a   \
     <dc:title /\
>\x0a      </cc:Wor\
k>\x0a    </rdf:RDF\
>\x0a  </metadata>\x0a\
  <g\x0a     inksca\
pe:label=\x22Capa 1\
\x22\x0a     inkscape:\
groupmode=\x22layer\
\x22\x0a     id=\x22layer\
1\x22\x0a     transfor\
m=\x22translate(21.\
700237,-922.5195\
4)\x22>\x0a    <path\x0a \
      sodipodi:t\
ype=\x22star\x22\x0a     \
  style=\x22opacity\
:0.33;fill:#0e97\
98;fill-opacity:\
0.99607843;strok\
e:none;stroke-wi\
dth:1.16275263;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:0.1415525\
\x22\x0a       id=\x22pat\
h1578\x22\x0a       so\
dipodi:sides=\x224\x22\
\x0a       sodipodi\
:cx=\x2246.033096\x22\x0a\
       sodipodi:\
cy=\x22990.25287\x22\x0a \
      sodipodi:r\
1=\x2275.712967\x22\x0a  \
     sodipodi:r2\
=\x2253.537148\x22\x0a   \
    sodipodi:arg\
1=\x220.78539816\x22\x0a \
      sodipodi:a\
rg2=\x221.5707963\x22\x0a\
       inkscape:\
flatsided=\x22true\x22\
\x0a       inkscape\
:rounded=\x220.25\x22\x0a\
       inkscape:\
randomized=\x220\x22\x0a \
      d=\x22m 99.57\
0249,1043.79 c -\
18.928242,18.928\
3 -88.146063,18.\
9283 -107.074304\
8,0 -18.9282422,\
-18.9282 -18.928\
2422,-88.14604 -\
4e-7,-107.07428 \
18.9282412,-18.9\
2825 88.1460632,\
-18.92825 107.07\
43042,0 18.92824\
2,18.92824 18.92\
8242,88.14608 10\
e-7,107.07428 z\x22\
\x0a       inkscape\
:transform-cente\
r-y=\x22-2.0420979e\
-05\x22 />\x0a    <cir\
cle\x0a       cy=\x221\
39.7252\x22\x0a       \
cx=\x22-591.70111\x22\x0a\
       id=\x22circl\
e1545\x22\x0a       st\
yle=\x22opacity:0.6\
7299996;fill:#aa\
aaff;fill-opacit\
y:0.30136988;str\
oke:#ffffff00;st\
roke-width:0.304\
04934;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-opacity:1\
\x22\x0a       r=\x220\x22 /\
>\x0a    <circle\x0a  \
     r=\x220\x22\x0a     \
  style=\x22opacity\
:0.67299996;fill\
:#aaaaff;fill-op\
acity:0.30136988\
;stroke:#ffffff0\
0;stroke-width:0\
.30404934;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-opaci\
ty:1\x22\x0a       id=\
\x22ellipse1617\x22\x0a  \
     cx=\x22-993.51\
282\x22\x0a       cy=\x22\
168.13614\x22 />\x0a  \
  <circle\x0a      \
 r=\x220\x22\x0a       cy\
=\x22733.2077\x22\x0a    \
   cx=\x22-958.1440\
4\x22\x0a       id=\x22el\
lipse1906\x22\x0a     \
  style=\x22opacity\
:0.67299996;fill\
:none;fill-opaci\
ty:0.30136988;st\
roke:#ffffff00;s\
troke-width:0.79\
374999;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-opacity:\
1\x22 />\x0a    <circl\
e\x0a       r=\x220\x22\x0a \
      cy=\x22582.33\
099\x22\x0a       cx=\x22\
-1500.9722\x22\x0a    \
   id=\x22ellipse19\
26\x22\x0a       style\
=\x22opacity:0.6729\
9996;fill:none;f\
ill-opacity:0.30\
136988;stroke:#f\
fffff00;stroke-w\
idth:0.79374999;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-opacity:1\x22 />\x0a \
   <circle\x0a     \
  r=\x220\x22\x0a       c\
y=\x22255.9781\x22\x0a   \
    cx=\x22-958.144\
04\x22\x0a       id=\x22e\
llipse1946\x22\x0a    \
   style=\x22opacit\
y:0.67299996;fil\
l:none;fill-opac\
ity:0.30136988;s\
troke:#ffffff00;\
stroke-width:0.7\
9374999;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-opacity\
:1\x22 />\x0a    <g\x0a  \
     transform=\x22\
matrix(0.5879629\
8,0,0,0.58796298\
,-29.226163,980.\
84547)\x22\x0a       i\
d=\x22g4554\x22>\x0a     \
 <g\x0a         id=\
\x22g10\x22>\x0a        <\
polygon\x0a        \
   class=\x22st0\x22\x0a \
          points\
=\x2256,-56 200,-56\
 176,-8 80,-8 \x22\x0a\
           id=\x22p\
olygon4\x22\x0a       \
    style=\x22fill:\
#41cd5f;fill-opa\
city:0.94117647\x22\
 />\x0a        <rec\
t\x0a           x=\x22\
56\x22\x0a           y\
=\x22-8\x22\x0a          \
 class=\x22st1\x22\x0a   \
        width=\x221\
44\x22\x0a           h\
eight=\x2296\x22\x0a     \
      id=\x22rect6\x22\
\x0a           styl\
e=\x22fill:#ffd80f;\
fill-opacity:0.9\
4117647\x22 />\x0a    \
    <polygon\x0a   \
        class=\x22s\
t2\x22\x0a           p\
oints=\x22128,88 17\
6,-8 80,-8 \x22\x0a   \
        id=\x22poly\
gon8\x22\x0a          \
 style=\x22fill:#00\
939f;fill-opacit\
y:0.94117647\x22 />\
\x0a      </g>\x0a    \
</g>\x0a  </g>\x0a  <s\
tyle\x0a     id=\x22st\
yle2\x22\x0a     type=\
\x22text/css\x22>\x0a\x09.st\
0{fill:#212121;}\
\x0a\x09.st1{fill:#FF8\
0AB;}\x0a\x09.st2{fill\
:#FF1744;}\x0a</sty\
le>\x0a</svg>\x0a\
\x00\x00 \x1f\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22rad\
iobutton_uncheck\
ed.svg\x22\x0a   inksc\
ape:export-filen\
ame=\x22/home/yeiso\
n/Development/pi\
ton/art/icon_lit\
e.png\x22\x0a   inksca\
pe:export-xdpi=\x22\
96\x22\x0a   inkscape:\
export-ydpi=\x2296\x22\
>\x0a  <defs\x0a     i\
d=\x22defs2\x22 />\x0a  <\
sodipodi:namedvi\
ew\x0a     id=\x22base\
\x22\x0a     pagecolor\
=\x22#ffffff\x22\x0a     \
bordercolor=\x22#66\
6666\x22\x0a     borde\
ropacity=\x221.0\x22\x0a \
    inkscape:pag\
eopacity=\x220.0\x22\x0a \
    inkscape:pag\
eshadow=\x222\x22\x0a    \
 inkscape:zoom=\x22\
23.490935\x22\x0a     \
inkscape:cx=\x220.9\
1214654\x22\x0a     in\
kscape:cy=\x225.283\
5214\x22\x0a     inksc\
ape:document-uni\
ts=\x22px\x22\x0a     ink\
scape:current-la\
yer=\x22layer1\x22\x0a   \
  showgrid=\x22true\
\x22\x0a     inkscape:\
window-width=\x2219\
20\x22\x0a     inkscap\
e:window-height=\
\x221015\x22\x0a     inks\
cape:window-x=\x220\
\x22\x0a     inkscape:\
window-y=\x220\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22\x0a\
     inkscape:sh\
owpageshadow=\x22fa\
lse\x22\x0a     units=\
\x22px\x22\x0a     inksca\
pe:pagecheckerbo\
ard=\x22false\x22\x0a    \
 showguides=\x22tru\
e\x22\x0a     inkscape\
:snap-bbox=\x22true\
\x22\x0a     inkscape:\
bbox-paths=\x22true\
\x22\x0a     inkscape:\
bbox-nodes=\x22true\
\x22\x0a     inkscape:\
snap-bbox-edge-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-node\
s=\x22true\x22\x0a     in\
kscape:object-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-in\
tersection-paths\
=\x22true\x22\x0a     ink\
scape:snap-smoot\
h-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-global=\x22tr\
ue\x22\x0a     fit-mar\
gin-top=\x220\x22\x0a    \
 fit-margin-left\
=\x220\x22\x0a     fit-ma\
rgin-right=\x220\x22\x0a \
    fit-margin-b\
ottom=\x220\x22\x0a     i\
nkscape:guide-bb\
ox=\x22true\x22>\x0a    <\
inkscape:grid\x0a  \
     type=\x22xygri\
d\x22\x0a       id=\x22gr\
id974\x22\x0a       em\
pspacing=\x228\x22\x0a   \
    spacingx=\x220.\
26458332\x22\x0a      \
 spacingy=\x220.264\
58332\x22\x0a       do\
tted=\x22false\x22\x0a   \
    visible=\x22tru\
e\x22\x0a       enable\
d=\x22true\x22\x0a       \
snapvisiblegridl\
inesonly=\x22true\x22\x0a\
       originx=\x22\
0\x22\x0a       origin\
y=\x220\x22 />\x0a  </sod\
ipodi:namedview>\
\x0a  <metadata\x0a   \
  id=\x22metadata5\x22\
>\x0a    <rdf:RDF>\x0a\
      <cc:Work\x0a \
        rdf:abou\
t=\x22\x22>\x0a        <d\
c:format>image/s\
vg+xml</dc:forma\
t>\x0a        <dc:t\
ype\x0a           r\
df:resource=\x22htt\
p://purl.org/dc/\
dcmitype/StillIm\
age\x22 />\x0a        \
<dc:title></dc:t\
itle>\x0a      </cc\
:Work>\x0a    </rdf\
:RDF>\x0a  </metada\
ta>\x0a  <g\x0a     in\
kscape:label=\x22La\
yer 1\x22\x0a     inks\
cape:groupmode=\x22\
layer\x22\x0a     id=\x22\
layer1\x22\x0a     tra\
nsform=\x22translat\
e(0,-291.70835)\x22\
>\x0a    <g\x0a       \
id=\x22g847\x22\x0a      \
 transform=\x22matr\
ix(0.05207439,0,\
0,0.05207453,-0.\
90125164,282.412\
03)\x22>\x0a      <g\x0a \
        id=\x22g851\
\x22>\x0a        <g\x0a  \
         id=\x22g10\
59\x22\x0a           t\
ransform=\x22matrix\
(1.9986219,0,0,1\
.9986185,17.3244\
84,-313.52314)\x22>\
\x0a          <path\
\x0a             in\
kscape:transform\
-center-y=\x223.175\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22\x0a          \
   d=\x22M 25.39999\
9,271.60002 -8.0\
000008e-7,246.20\
002 H 50.799999 \
Z\x22\x0a             \
id=\x22path883\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22 />\x0a          <\
path\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22\x0a    \
         inkscap\
e:connector-curv\
ature=\x220\x22\x0a      \
       id=\x22path8\
80\x22\x0a            \
 d=\x22m 25.399999,\
271.60002 25.399\
999,25.4 H 0 Z\x22\x0a\
             ink\
scape:transform-\
center-y=\x22-3.174\
9995\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <rect\x0a   \
          ry=\x225.\
0534658\x22\x0a       \
      y=\x22253.848\
85\x22\x0a            \
 x=\x227.6487389\x22\x0a \
            heig\
ht=\x2235.528759\x22\x0a \
            widt\
h=\x2235.528786\x22\x0a  \
           id=\x22r\
ect870\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.06184419\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <circle\
\x0a             r=\
\x2225.396828\x22\x0a    \
         cy=\x22271\
.60001\x22\x0a        \
     cx=\x2225.4\x22\x0a \
            id=\x22\
path872\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0763588\
2;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <circl\
e\x0a             t\
ransform=\x22rotate\
(-45)\x22\x0a         \
    cx=\x22-174.089\
69\x22\x0a            \
 cy=\x22210.01071\x22\x0a\
             r=\x22\
12.656071\x22\x0a     \
        id=\x22path\
876\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07399406;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <path\x0a    \
         inkscap\
e:transform-cent\
er-x=\x22-3.1749999\
\x22\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    id=\x22path904\x22\
\x0a             d=\
\x22m 25.4,271.6000\
2 -25.4000004000\
0004,25.4 v -50.\
8 z\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <path\x0a    \
         inkscap\
e:transform-cent\
er-x=\x223.175\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
\x0a             d=\
\x22m 25.399999,271\
.60002 25.4,-25.\
4 v 50.8 z\x22\x0a    \
         id=\x22pat\
h906\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 sodipodi:nodety\
pes=\x22cccc\x22 />\x0a  \
        <rect\x0a  \
           ry=\x225\
.0514922\x22\x0a      \
       y=\x22256.39\
301\x22\x0a           \
  x=\x222.5663135\x22\x0a\
             hei\
ght=\x2230.440479\x22\x0a\
             wid\
th=\x2245.693634\x22\x0a \
            id=\x22\
rect837\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0657438\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <rect\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
657438;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a             i\
d=\x22rect831\x22\x0a    \
         width=\x22\
45.693588\x22\x0a     \
        height=\x22\
30.44051\x22\x0a      \
       x=\x22248.76\
645\x22\x0a           \
  y=\x22-40.633385\x22\
\x0a             ry\
=\x225.051497\x22\x0a    \
         transfo\
rm=\x22rotate(90)\x22 \
/>\x0a        </g>\x0a\
      </g>\x0a    <\
/g>\x0a    <path\x0a  \
     style=\x22opac\
ity:1;fill:#ffc1\
07;fill-opacity:\
1;stroke:none;st\
roke-width:0.385\
96651;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-opacity:1\
\x22\x0a       d=\x22m 50\
.206421,401.6768\
3 c 110.217209,0\
.71279 55.108609\
,0.3564 0,0 z\x22\x0a \
      id=\x22rect99\
7\x22\x0a       inksca\
pe:connector-cur\
vature=\x220\x22 />\x0a  \
  <path\x0a       s\
tyle=\x22opacity:1;\
fill:#0000ff;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:3;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a       d=\x22M 10\
 0.013671875 A 9\
.9862042 9.98620\
42 0 0 0 0.01367\
1875 10 A 9.9862\
042 9.9862042 0 \
0 0 10 19.986328\
 A 9.9862042 9.9\
862042 0 0 0 19.\
986328 10 A 9.98\
62042 9.9862042 \
0 0 0 10 0.01367\
1875 z M 10 3 A \
7.0000143 7.0000\
143 0 0 1 17 10 \
A 7.0000143 7.00\
00143 0 0 1 10 1\
7 A 7.0000143 7.\
0000143 0 0 1 3 \
10 A 7.0000143 7\
.0000143 0 0 1 1\
0 3 z \x22\x0a       t\
ransform=\x22matrix\
(0.26458332,0,0,\
0.26458332,0,291\
.70835)\x22\x0a       \
id=\x22path826\x22 />\x0a\
  </g>\x0a</svg>\x0a\
\x00\x00\x1f\xba\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22clo\
se.svg\x22\x0a   inksc\
ape:export-filen\
ame=\x22/home/yeiso\
n/Development/pi\
ton/art/icon_lit\
e.png\x22\x0a   inksca\
pe:export-xdpi=\x22\
96\x22\x0a   inkscape:\
export-ydpi=\x2296\x22\
>\x0a  <defs\x0a     i\
d=\x22defs2\x22 />\x0a  <\
sodipodi:namedvi\
ew\x0a     id=\x22base\
\x22\x0a     pagecolor\
=\x22#ffffff\x22\x0a     \
bordercolor=\x22#66\
6666\x22\x0a     borde\
ropacity=\x221.0\x22\x0a \
    inkscape:pag\
eopacity=\x220.0\x22\x0a \
    inkscape:pag\
eshadow=\x222\x22\x0a    \
 inkscape:zoom=\x22\
0.44851425\x22\x0a    \
 inkscape:cx=\x22-4\
61.15031\x22\x0a     i\
nkscape:cy=\x2268.2\
80762\x22\x0a     inks\
cape:document-un\
its=\x22px\x22\x0a     in\
kscape:current-l\
ayer=\x22layer1\x22\x0a  \
   showgrid=\x22tru\
e\x22\x0a     inkscape\
:window-width=\x221\
920\x22\x0a     inksca\
pe:window-height\
=\x221004\x22\x0a     ink\
scape:window-x=\x22\
0\x22\x0a     inkscape\
:window-y=\x220\x22\x0a  \
   inkscape:wind\
ow-maximized=\x221\x22\
\x0a     inkscape:s\
howpageshadow=\x22f\
alse\x22\x0a     units\
=\x22px\x22\x0a     inksc\
ape:pagecheckerb\
oard=\x22false\x22\x0a   \
  showguides=\x22fa\
lse\x22\x0a     inksca\
pe:snap-bbox=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-paths=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-bbox-edge\
-midpoints=\x22true\
\x22\x0a     inkscape:\
snap-bbox-midpoi\
nts=\x22true\x22\x0a     \
inkscape:snap-no\
des=\x22true\x22\x0a     \
inkscape:object-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
intersection-pat\
hs=\x22true\x22\x0a     i\
nkscape:snap-smo\
oth-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-global=\x22\
true\x22\x0a     fit-m\
argin-top=\x220\x22\x0a  \
   fit-margin-le\
ft=\x220\x22\x0a     fit-\
margin-right=\x220\x22\
\x0a     fit-margin\
-bottom=\x220\x22\x0a    \
 inkscape:guide-\
bbox=\x22true\x22>\x0a   \
 <inkscape:grid\x0a\
       type=\x22xyg\
rid\x22\x0a       id=\x22\
grid974\x22\x0a       \
empspacing=\x228\x22\x0a \
      spacingx=\x22\
0.26458332\x22\x0a    \
   spacingy=\x220.2\
6458332\x22\x0a       \
dotted=\x22false\x22\x0a \
      visible=\x22t\
rue\x22\x0a       enab\
led=\x22true\x22\x0a     \
  snapvisiblegri\
dlinesonly=\x22true\
\x22\x0a       originx\
=\x220\x22\x0a       orig\
iny=\x220\x22 />\x0a  </s\
odipodi:namedvie\
w>\x0a  <metadata\x0a \
    id=\x22metadata\
5\x22>\x0a    <rdf:RDF\
>\x0a      <cc:Work\
\x0a         rdf:ab\
out=\x22\x22>\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0a        <dc\
:type\x0a          \
 rdf:resource=\x22h\
ttp://purl.org/d\
c/dcmitype/Still\
Image\x22 />\x0a      \
  <dc:title />\x0a \
     </cc:Work>\x0a\
    </rdf:RDF>\x0a \
 </metadata>\x0a  <\
g\x0a     inkscape:\
label=\x22Layer 1\x22\x0a\
     inkscape:gr\
oupmode=\x22layer\x22\x0a\
     id=\x22layer1\x22\
\x0a     transform=\
\x22translate(0,-29\
1.70835)\x22>\x0a    <\
g\x0a       id=\x22g84\
7\x22\x0a       transf\
orm=\x22matrix(0.05\
207439,0,0,0.052\
07453,-0.9012516\
4,282.41203)\x22>\x0a \
     <g\x0a        \
 id=\x22g851\x22>\x0a    \
    <g\x0a         \
  id=\x22g1059\x22\x0a   \
        transfor\
m=\x22matrix(1.9986\
219,0,0,1.998618\
5,17.324484,-313\
.52314)\x22>\x0a      \
    <path\x0a      \
       inkscape:\
transform-center\
-y=\x223.175\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.07000\
433;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
            d=\x22M\
 25.399999,271.6\
0002 -8.0000008e\
-7,246.20002 H 5\
0.799999 Z\x22\x0a    \
         id=\x22pat\
h883\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 sodipodi:nodety\
pes=\x22cccc\x22 />\x0a  \
        <path\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22\x0a           \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a             \
id=\x22path880\x22\x0a   \
          d=\x22m 2\
5.399999,271.600\
02 25.399999,25.\
4 H 0 Z\x22\x0a       \
      inkscape:t\
ransform-center-\
y=\x22-3.1749995\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   ry=\x225.0534658\
\x22\x0a             y\
=\x22253.84885\x22\x0a   \
          x=\x227.6\
487389\x22\x0a        \
     height=\x2235.\
528759\x22\x0a        \
     width=\x2235.5\
28786\x22\x0a         \
    id=\x22rect870\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.06184419;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <circle\x0a      \
       r=\x2225.396\
828\x22\x0a           \
  cy=\x22271.60001\x22\
\x0a             cx\
=\x2225.4\x22\x0a        \
     id=\x22path872\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07635882;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <circle\x0a     \
        transfor\
m=\x22rotate(-45)\x22\x0a\
             cx=\
\x22-174.08969\x22\x0a   \
          cy=\x2221\
0.01071\x22\x0a       \
      r=\x2212.6560\
71\x22\x0a            \
 id=\x22path876\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
399406;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
path\x0a           \
  inkscape:trans\
form-center-x=\x22-\
3.1749999\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22\x0a             i\
nkscape:connecto\
r-curvature=\x220\x22\x0a\
             id=\
\x22path904\x22\x0a      \
       d=\x22m 25.4\
,271.60002 -25.4\
0000040000004,25\
.4 v -50.8 z\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
path\x0a           \
  inkscape:trans\
form-center-x=\x223\
.175\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22\x0a      \
       d=\x22m 25.3\
99999,271.60002 \
25.4,-25.4 v 50.\
8 z\x22\x0a           \
  id=\x22path906\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22 />\x0a         \
 <rect\x0a         \
    ry=\x225.051492\
2\x22\x0a             \
y=\x22256.39301\x22\x0a  \
           x=\x222.\
5663135\x22\x0a       \
      height=\x2230\
.440479\x22\x0a       \
      width=\x2245.\
693634\x22\x0a        \
     id=\x22rect837\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <rect\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.0657438;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22\x0a     \
        id=\x22rect\
831\x22\x0a           \
  width=\x2245.6935\
88\x22\x0a            \
 height=\x2230.4405\
1\x22\x0a             \
x=\x22248.76645\x22\x0a  \
           y=\x22-4\
0.633385\x22\x0a      \
       ry=\x225.051\
497\x22\x0a           \
  transform=\x22rot\
ate(90)\x22 />\x0a    \
    </g>\x0a      <\
/g>\x0a    </g>\x0a   \
 <path\x0a       st\
yle=\x22fill:#0000f\
f;stroke:#0000ff\
;stroke-width:0.\
52916664;stroke-\
linecap:butt;str\
oke-linejoin:mit\
er;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-opacity:1\x22\x0a \
      d=\x22m 1.319\
2054,293.02755 2\
.6532555,2.65327\
\x22\x0a       id=\x22pat\
h826\x22\x0a       ink\
scape:connector-\
curvature=\x220\x22 />\
\x0a    <path\x0a     \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a       id=\x22pa\
th842\x22\x0a       d=\
\x22m 3.9724723,293\
.02756 -2.653278\
2,2.65325\x22\x0a     \
  style=\x22fill:#0\
000ff;stroke:#00\
00ff;stroke-widt\
h:0.52916664;str\
oke-linecap:butt\
;stroke-linejoin\
:miter;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-opacity:\
1\x22 />\x0a    <circl\
e\x0a       style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:1;stroke:#0000f\
f;stroke-width:0\
.5292387;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22\x0a       id=\x22p\
ath829\x22\x0a       c\
x=\x222.6458311\x22\x0a  \
     cy=\x22294.354\
19\x22\x0a       r=\x222.\
381216\x22 />\x0a  </g\
>\x0a</svg>\x0a\
\x00\x00 \x00\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22che\
ckbox_checked.sv\
g\x22\x0a   inkscape:e\
xport-filename=\x22\
/home/yeison/Dev\
elopment/piton/a\
rt/icon_lite.png\
\x22\x0a   inkscape:ex\
port-xdpi=\x2296\x22\x0a \
  inkscape:expor\
t-ydpi=\x2296\x22>\x0a  <\
defs\x0a     id=\x22de\
fs2\x22 />\x0a  <sodip\
odi:namedview\x0a  \
   id=\x22base\x22\x0a   \
  pagecolor=\x22#ff\
ffff\x22\x0a     borde\
rcolor=\x22#666666\x22\
\x0a     borderopac\
ity=\x221.0\x22\x0a     i\
nkscape:pageopac\
ity=\x220.0\x22\x0a     i\
nkscape:pageshad\
ow=\x222\x22\x0a     inks\
cape:zoom=\x2228.70\
4912\x22\x0a     inksc\
ape:cx=\x227.427174\
9\x22\x0a     inkscape\
:cy=\x2212.838164\x22\x0a\
     inkscape:do\
cument-units=\x22px\
\x22\x0a     inkscape:\
current-layer=\x22l\
ayer1\x22\x0a     show\
grid=\x22true\x22\x0a    \
 inkscape:window\
-width=\x221920\x22\x0a  \
   inkscape:wind\
ow-height=\x221015\x22\
\x0a     inkscape:w\
indow-x=\x220\x22\x0a    \
 inkscape:window\
-y=\x220\x22\x0a     inks\
cape:window-maxi\
mized=\x221\x22\x0a     i\
nkscape:showpage\
shadow=\x22false\x22\x0a \
    units=\x22px\x22\x0a \
    inkscape:pag\
echeckerboard=\x22f\
alse\x22\x0a     showg\
uides=\x22false\x22\x0a  \
   inkscape:snap\
-bbox=\x22true\x22\x0a   \
  inkscape:bbox-\
paths=\x22true\x22\x0a   \
  inkscape:bbox-\
nodes=\x22true\x22\x0a   \
  inkscape:snap-\
bbox-edge-midpoi\
nts=\x22true\x22\x0a     \
inkscape:snap-bb\
ox-midpoints=\x22tr\
ue\x22\x0a     inkscap\
e:snap-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:object-paths=\x22\
true\x22\x0a     inksc\
ape:snap-interse\
ction-paths=\x22tru\
e\x22\x0a     inkscape\
:snap-smooth-nod\
es=\x22true\x22\x0a     i\
nkscape:snap-mid\
points=\x22true\x22\x0a  \
   inkscape:snap\
-global=\x22true\x22\x0a \
    fit-margin-t\
op=\x220\x22\x0a     fit-\
margin-left=\x220\x22\x0a\
     fit-margin-\
right=\x220\x22\x0a     f\
it-margin-bottom\
=\x220\x22\x0a     inksca\
pe:guide-bbox=\x22t\
rue\x22>\x0a    <inksc\
ape:grid\x0a       \
type=\x22xygrid\x22\x0a  \
     id=\x22grid974\
\x22\x0a       empspac\
ing=\x228\x22\x0a       s\
pacingx=\x220.26458\
332\x22\x0a       spac\
ingy=\x220.26458332\
\x22\x0a       dotted=\
\x22false\x22\x0a       v\
isible=\x22true\x22\x0a  \
     enabled=\x22tr\
ue\x22\x0a       snapv\
isiblegridlineso\
nly=\x22true\x22\x0a     \
  originx=\x220\x22\x0a  \
     originy=\x220\x22\
 />\x0a  </sodipodi\
:namedview>\x0a  <m\
etadata\x0a     id=\
\x22metadata5\x22>\x0a   \
 <rdf:RDF>\x0a     \
 <cc:Work\x0a      \
   rdf:about=\x22\x22>\
\x0a        <dc:for\
mat>image/svg+xm\
l</dc:format>\x0a  \
      <dc:type\x0a \
          rdf:re\
source=\x22http://p\
url.org/dc/dcmit\
ype/StillImage\x22 \
/>\x0a        <dc:t\
itle></dc:title>\
\x0a      </cc:Work\
>\x0a    </rdf:RDF>\
\x0a  </metadata>\x0a \
 <g\x0a     inkscap\
e:label=\x22Layer 1\
\x22\x0a     inkscape:\
groupmode=\x22layer\
\x22\x0a     id=\x22layer\
1\x22\x0a     transfor\
m=\x22translate(0,-\
291.70835)\x22>\x0a   \
 <path\x0a       st\
yle=\x22opacity:1;f\
ill:#0000ff;fill\
-opacity:1;strok\
e:none;stroke-wi\
dth:2;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
\x0a       d=\x22M 2 0\
 C 0.89199975 0 \
0 0.8919864 0 2 \
L 0 18 C 0 19.10\
8014 0.89199975 \
20 2 20 L 18 20 \
C 19.108 20 20 1\
9.108014 20 18 L\
 20 2 C 20 0.891\
9864 19.108 0 18\
 0 L 2 0 z M 15.\
878906 3.78125 L\
 17.996094 5.900\
3906 L 7.6835938\
 16.220703 L 2 1\
0.529297 L 4.119\
1406 8.4101562 L\
 7.6835938 11.97\
6562 L 15.878906\
 3.78125 z \x22\x0a   \
    transform=\x22m\
atrix(0.26458332\
,0,0,0.26458332,\
0,291.70835)\x22\x0a  \
     id=\x22rect833\
\x22 />\x0a    <g\x0a    \
   id=\x22g847\x22\x0a   \
    transform=\x22m\
atrix(0.05207439\
,0,0,0.05207453,\
-0.90125164,282.\
41203)\x22>\x0a      <\
g\x0a         id=\x22g\
851\x22>\x0a        <g\
\x0a           id=\x22\
g1059\x22\x0a         \
  transform=\x22mat\
rix(1.9986219,0,\
0,1.9986185,17.3\
24484,-313.52314\
)\x22>\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-y=\x223.\
175\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      d=\x22M 25.39\
9999,271.60002 -\
8.0000008e-7,246\
.20002 H 50.7999\
99 Z\x22\x0a          \
   id=\x22path883\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22 />\x0a        \
  <path\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          id=\x22pa\
th880\x22\x0a         \
    d=\x22m 25.3999\
99,271.60002 25.\
399999,25.4 H 0 \
Z\x22\x0a             \
inkscape:transfo\
rm-center-y=\x22-3.\
1749995\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             ry=\
\x225.0534658\x22\x0a    \
         y=\x22253.\
84885\x22\x0a         \
    x=\x227.6487389\
\x22\x0a             h\
eight=\x2235.528759\
\x22\x0a             w\
idth=\x2235.528786\x22\
\x0a             id\
=\x22rect870\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06184\
419;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <cir\
cle\x0a            \
 r=\x2225.396828\x22\x0a \
            cy=\x22\
271.60001\x22\x0a     \
        cx=\x2225.4\
\x22\x0a             i\
d=\x22path872\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0763\
5882;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <ci\
rcle\x0a           \
  transform=\x22rot\
ate(-45)\x22\x0a      \
       cx=\x22-174.\
08969\x22\x0a         \
    cy=\x22210.0107\
1\x22\x0a             \
r=\x2212.656071\x22\x0a  \
           id=\x22p\
ath876\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07399406\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x22-3.1749\
999\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22\x0a    \
         inkscap\
e:connector-curv\
ature=\x220\x22\x0a      \
       id=\x22path9\
04\x22\x0a            \
 d=\x22m 25.4,271.6\
0002 -25.4000004\
0000004,25.4 v -\
50.8 z\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x223.175\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a            \
 d=\x22m 25.399999,\
271.60002 25.4,-\
25.4 v 50.8 z\x22\x0a \
            id=\x22\
path906\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22 />\
\x0a          <rect\
\x0a             ry\
=\x225.0514922\x22\x0a   \
          y=\x22256\
.39301\x22\x0a        \
     x=\x222.566313\
5\x22\x0a             \
height=\x2230.44047\
9\x22\x0a             \
width=\x2245.693634\
\x22\x0a             i\
d=\x22rect837\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <rec\
t\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22\x0a           \
  id=\x22rect831\x22\x0a \
            widt\
h=\x2245.693588\x22\x0a  \
           heigh\
t=\x2230.44051\x22\x0a   \
          x=\x22248\
.76645\x22\x0a        \
     y=\x22-40.6333\
85\x22\x0a            \
 ry=\x225.051497\x22\x0a \
            tran\
sform=\x22rotate(90\
)\x22 />\x0a        </\
g>\x0a      </g>\x0a  \
  </g>\x0a    <path\
\x0a       style=\x22o\
pacity:1;fill:#f\
fc107;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
38596651;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-opacit\
y:1\x22\x0a       d=\x22m\
 50.206421,401.6\
7683 c 110.21720\
9,0.71279 55.108\
609,0.3564 0,0 z\
\x22\x0a       id=\x22rec\
t997\x22\x0a       ink\
scape:connector-\
curvature=\x220\x22 />\
\x0a  </g>\x0a</svg>\x0a\
\x00\x00 \x15\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22che\
ckbox_unchecked.\
svg\x22\x0a   inkscape\
:export-filename\
=\x22/home/yeison/D\
evelopment/piton\
/art/icon_lite.p\
ng\x22\x0a   inkscape:\
export-xdpi=\x2296\x22\
\x0a   inkscape:exp\
ort-ydpi=\x2296\x22>\x0a \
 <defs\x0a     id=\x22\
defs2\x22 />\x0a  <sod\
ipodi:namedview\x0a\
     id=\x22base\x22\x0a \
    pagecolor=\x22#\
ffffff\x22\x0a     bor\
dercolor=\x22#66666\
6\x22\x0a     borderop\
acity=\x221.0\x22\x0a    \
 inkscape:pageop\
acity=\x220.0\x22\x0a    \
 inkscape:pagesh\
adow=\x222\x22\x0a     in\
kscape:zoom=\x2224.\
802597\x22\x0a     ink\
scape:cx=\x228.2644\
565\x22\x0a     inksca\
pe:cy=\x226.6655853\
\x22\x0a     inkscape:\
document-units=\x22\
px\x22\x0a     inkscap\
e:current-layer=\
\x22layer1\x22\x0a     sh\
owgrid=\x22true\x22\x0a  \
   inkscape:wind\
ow-width=\x221920\x22\x0a\
     inkscape:wi\
ndow-height=\x22101\
5\x22\x0a     inkscape\
:window-x=\x220\x22\x0a  \
   inkscape:wind\
ow-y=\x220\x22\x0a     in\
kscape:window-ma\
ximized=\x221\x22\x0a    \
 inkscape:showpa\
geshadow=\x22false\x22\
\x0a     units=\x22px\x22\
\x0a     inkscape:p\
agecheckerboard=\
\x22false\x22\x0a     sho\
wguides=\x22false\x22\x0a\
     inkscape:sn\
ap-bbox=\x22true\x22\x0a \
    inkscape:bbo\
x-paths=\x22true\x22\x0a \
    inkscape:bbo\
x-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-bbox-edge-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
bbox-midpoints=\x22\
true\x22\x0a     inksc\
ape:snap-nodes=\x22\
true\x22\x0a     inksc\
ape:object-paths\
=\x22true\x22\x0a     ink\
scape:snap-inter\
section-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-smooth-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-global=\x22true\x22\
\x0a     fit-margin\
-top=\x220\x22\x0a     fi\
t-margin-left=\x220\
\x22\x0a     fit-margi\
n-right=\x220\x22\x0a    \
 fit-margin-bott\
om=\x220\x22\x0a     inks\
cape:guide-bbox=\
\x22true\x22>\x0a    <ink\
scape:grid\x0a     \
  type=\x22xygrid\x22\x0a\
       id=\x22grid9\
74\x22\x0a       empsp\
acing=\x228\x22\x0a      \
 spacingx=\x220.264\
58332\x22\x0a       sp\
acingy=\x220.264583\
32\x22\x0a       dotte\
d=\x22false\x22\x0a      \
 visible=\x22true\x22\x0a\
       enabled=\x22\
true\x22\x0a       sna\
pvisiblegridline\
sonly=\x22true\x22\x0a   \
    originx=\x220\x22\x0a\
       originy=\x22\
0\x22 />\x0a  </sodipo\
di:namedview>\x0a  \
<metadata\x0a     i\
d=\x22metadata5\x22>\x0a \
   <rdf:RDF>\x0a   \
   <cc:Work\x0a    \
     rdf:about=\x22\
\x22>\x0a        <dc:f\
ormat>image/svg+\
xml</dc:format>\x0a\
        <dc:type\
\x0a           rdf:\
resource=\x22http:/\
/purl.org/dc/dcm\
itype/StillImage\
\x22 />\x0a        <dc\
:title></dc:titl\
e>\x0a      </cc:Wo\
rk>\x0a    </rdf:RD\
F>\x0a  </metadata>\
\x0a  <g\x0a     inksc\
ape:label=\x22Layer\
 1\x22\x0a     inkscap\
e:groupmode=\x22lay\
er\x22\x0a     id=\x22lay\
er1\x22\x0a     transf\
orm=\x22translate(0\
,-291.70835)\x22>\x0a \
   <path\x0a       \
style=\x22opacity:1\
;fill:#0000ff;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:2;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a       d=\x22M 2\
 0 C 0.89199975 \
0 0 0.8919864 0 \
2 L 0 18 C -2.96\
05947e-16 19.108\
014 0.89199975 2\
0 2 20 L 18 20 C\
 19.108 20 20 19\
.108014 20 18 L \
20 2 C 20 0.8919\
864 19.108 0 18 \
0 L 2 0 z M 5 3 \
L 15 3 C 16.108 \
3 17 3.8919889 1\
7 5 L 17 15 C 17\
 16.108011 16.10\
8 17 15 17 L 5 1\
7 C 3.892 17 3 1\
6.108011 3 15 L \
3 5 C 3 3.891988\
9 3.892 3 5 3 z \
\x22\x0a       transfo\
rm=\x22matrix(0.264\
58332,0,0,0.2645\
8332,0,291.70835\
)\x22\x0a       id=\x22re\
ct833\x22 />\x0a    <g\
\x0a       id=\x22g847\
\x22\x0a       transfo\
rm=\x22matrix(0.052\
07439,0,0,0.0520\
7453,-0.90125164\
,282.41203)\x22>\x0a  \
    <g\x0a         \
id=\x22g851\x22>\x0a     \
   <g\x0a          \
 id=\x22g1059\x22\x0a    \
       transform\
=\x22matrix(1.99862\
19,0,0,1.9986185\
,17.324484,-313.\
52314)\x22>\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
y=\x223.175\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.070004\
33;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22\x0a  \
           d=\x22M \
25.399999,271.60\
002 -8.0000008e-\
7,246.20002 H 50\
.799999 Z\x22\x0a     \
        id=\x22path\
883\x22\x0a           \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a             \
sodipodi:nodetyp\
es=\x22cccc\x22 />\x0a   \
       <path\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             i\
d=\x22path880\x22\x0a    \
         d=\x22m 25\
.399999,271.6000\
2 25.399999,25.4\
 H 0 Z\x22\x0a        \
     inkscape:tr\
ansform-center-y\
=\x22-3.1749995\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
rect\x0a           \
  ry=\x225.0534658\x22\
\x0a             y=\
\x22253.84885\x22\x0a    \
         x=\x227.64\
87389\x22\x0a         \
    height=\x2235.5\
28759\x22\x0a         \
    width=\x2235.52\
8786\x22\x0a          \
   id=\x22rect870\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
06184419;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <circle\x0a       \
      r=\x2225.3968\
28\x22\x0a            \
 cy=\x22271.60001\x22\x0a\
             cx=\
\x2225.4\x22\x0a         \
    id=\x22path872\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.07635882;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <circle\x0a      \
       transform\
=\x22rotate(-45)\x22\x0a \
            cx=\x22\
-174.08969\x22\x0a    \
         cy=\x22210\
.01071\x22\x0a        \
     r=\x2212.65607\
1\x22\x0a             \
id=\x22path876\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.073\
99406;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-x=\x22-3\
.1749999\x22\x0a      \
       sodipodi:\
nodetypes=\x22cccc\x22\
\x0a             in\
kscape:connector\
-curvature=\x220\x22\x0a \
            id=\x22\
path904\x22\x0a       \
      d=\x22m 25.4,\
271.60002 -25.40\
000040000004,25.\
4 v -50.8 z\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-x=\x223.\
175\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      d=\x22m 25.39\
9999,271.60002 2\
5.4,-25.4 v 50.8\
 z\x22\x0a            \
 id=\x22path906\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22 />\x0a          \
<rect\x0a          \
   ry=\x225.0514922\
\x22\x0a             y\
=\x22256.39301\x22\x0a   \
          x=\x222.5\
663135\x22\x0a        \
     height=\x2230.\
440479\x22\x0a        \
     width=\x2245.6\
93634\x22\x0a         \
    id=\x22rect837\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.0657438;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <rect\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.0657438;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22\x0a      \
       id=\x22rect8\
31\x22\x0a            \
 width=\x2245.69358\
8\x22\x0a             \
height=\x2230.44051\
\x22\x0a             x\
=\x22248.76645\x22\x0a   \
          y=\x22-40\
.633385\x22\x0a       \
      ry=\x225.0514\
97\x22\x0a            \
 transform=\x22rota\
te(90)\x22 />\x0a     \
   </g>\x0a      </\
g>\x0a    </g>\x0a    \
<path\x0a       sty\
le=\x22opacity:1;fi\
ll:#ffc107;fill-\
opacity:1;stroke\
:none;stroke-wid\
th:0.38596651;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-o\
pacity:1\x22\x0a      \
 d=\x22m 50.206421,\
401.67683 c 110.\
217209,0.71279 5\
5.108609,0.3564 \
0,0 z\x22\x0a       id\
=\x22rect997\x22\x0a     \
  inkscape:conne\
ctor-curvature=\x22\
0\x22 />\x0a  </g>\x0a</s\
vg>\x0a\
\x00\x00 \xca\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22dow\
narrow.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2228.704913\x22\x0a \
    inkscape:cx=\
\x2210.702147\x22\x0a    \
 inkscape:cy=\x222.\
4334445\x22\x0a     in\
kscape:document-\
units=\x22px\x22\x0a     \
inkscape:current\
-layer=\x22layer1\x22\x0a\
     showgrid=\x22t\
rue\x22\x0a     inksca\
pe:window-width=\
\x221920\x22\x0a     inks\
cape:window-heig\
ht=\x221015\x22\x0a     i\
nkscape:window-x\
=\x220\x22\x0a     inksca\
pe:window-y=\x220\x22\x0a\
     inkscape:wi\
ndow-maximized=\x22\
1\x22\x0a     inkscape\
:showpageshadow=\
\x22false\x22\x0a     uni\
ts=\x22px\x22\x0a     ink\
scape:pagechecke\
rboard=\x22false\x22\x0a \
    showguides=\x22\
true\x22\x0a     inksc\
ape:snap-bbox=\x22t\
rue\x22\x0a     inksca\
pe:bbox-paths=\x22t\
rue\x22\x0a     inksca\
pe:bbox-nodes=\x22t\
rue\x22\x0a     inksca\
pe:snap-bbox-edg\
e-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-bbox-midpo\
ints=\x22true\x22\x0a    \
 inkscape:snap-n\
odes=\x22true\x22\x0a    \
 inkscape:object\
-paths=\x22true\x22\x0a  \
   inkscape:snap\
-intersection-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-sm\
ooth-nodes=\x22true\
\x22\x0a     inkscape:\
snap-midpoints=\x22\
true\x22\x0a     inksc\
ape:snap-global=\
\x22true\x22\x0a     fit-\
margin-top=\x220\x22\x0a \
    fit-margin-l\
eft=\x220\x22\x0a     fit\
-margin-right=\x220\
\x22\x0a     fit-margi\
n-bottom=\x220\x22\x0a   \
  inkscape:guide\
-bbox=\x22true\x22>\x0a  \
  <inkscape:grid\
\x0a       type=\x22xy\
grid\x22\x0a       id=\
\x22grid974\x22\x0a      \
 empspacing=\x228\x22\x0a\
       spacingx=\
\x220.26458332\x22\x0a   \
    spacingy=\x220.\
26458332\x22\x0a      \
 dotted=\x22false\x22\x0a\
       visible=\x22\
true\x22\x0a       ena\
bled=\x22true\x22\x0a    \
   snapvisiblegr\
idlinesonly=\x22tru\
e\x22\x0a       origin\
x=\x220\x22\x0a       ori\
giny=\x220\x22 />\x0a  </\
sodipodi:namedvi\
ew>\x0a  <metadata\x0a\
     id=\x22metadat\
a5\x22>\x0a    <rdf:RD\
F>\x0a      <cc:Wor\
k\x0a         rdf:a\
bout=\x22\x22>\x0a       \
 <dc:format>imag\
e/svg+xml</dc:fo\
rmat>\x0a        <d\
c:type\x0a         \
  rdf:resource=\x22\
http://purl.org/\
dc/dcmitype/Stil\
lImage\x22 />\x0a     \
   <dc:title></d\
c:title>\x0a      <\
/cc:Work>\x0a    </\
rdf:RDF>\x0a  </met\
adata>\x0a  <g\x0a    \
 inkscape:label=\
\x22Layer 1\x22\x0a     i\
nkscape:groupmod\
e=\x22layer\x22\x0a     i\
d=\x22layer1\x22\x0a     \
transform=\x22trans\
late(0,-291.7083\
5)\x22>\x0a    <g\x0a    \
   id=\x22g847\x22\x0a   \
    transform=\x22m\
atrix(0.05207439\
,0,0,0.05207453,\
-0.90125164,282.\
41203)\x22>\x0a      <\
g\x0a         id=\x22g\
851\x22>\x0a        <g\
\x0a           id=\x22\
g1059\x22\x0a         \
  transform=\x22mat\
rix(1.9986219,0,\
0,1.9986185,17.3\
24484,-313.52314\
)\x22>\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-y=\x223.\
175\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      d=\x22M 25.39\
9999,271.60002 -\
8.0000008e-7,246\
.20002 H 50.7999\
99 Z\x22\x0a          \
   id=\x22path883\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22 />\x0a        \
  <path\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          id=\x22pa\
th880\x22\x0a         \
    d=\x22m 25.3999\
99,271.60002 25.\
399999,25.4 H 0 \
Z\x22\x0a             \
inkscape:transfo\
rm-center-y=\x22-3.\
1749995\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             ry=\
\x225.0534658\x22\x0a    \
         y=\x22253.\
84885\x22\x0a         \
    x=\x227.6487389\
\x22\x0a             h\
eight=\x2235.528759\
\x22\x0a             w\
idth=\x2235.528786\x22\
\x0a             id\
=\x22rect870\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06184\
419;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <cir\
cle\x0a            \
 r=\x2225.396828\x22\x0a \
            cy=\x22\
271.60001\x22\x0a     \
        cx=\x2225.4\
\x22\x0a             i\
d=\x22path872\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0763\
5882;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <ci\
rcle\x0a           \
  transform=\x22rot\
ate(-45)\x22\x0a      \
       cx=\x22-174.\
08969\x22\x0a         \
    cy=\x22210.0107\
1\x22\x0a             \
r=\x2212.656071\x22\x0a  \
           id=\x22p\
ath876\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07399406\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x22-3.1749\
999\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22\x0a    \
         inkscap\
e:connector-curv\
ature=\x220\x22\x0a      \
       id=\x22path9\
04\x22\x0a            \
 d=\x22m 25.4,271.6\
0002 -25.4000004\
0000004,25.4 v -\
50.8 z\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x223.175\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a            \
 d=\x22m 25.399999,\
271.60002 25.4,-\
25.4 v 50.8 z\x22\x0a \
            id=\x22\
path906\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22 />\
\x0a          <rect\
\x0a             ry\
=\x225.0514922\x22\x0a   \
          y=\x22256\
.39301\x22\x0a        \
     x=\x222.566313\
5\x22\x0a             \
height=\x2230.44047\
9\x22\x0a             \
width=\x2245.693634\
\x22\x0a             i\
d=\x22rect837\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <rec\
t\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22\x0a           \
  id=\x22rect831\x22\x0a \
            widt\
h=\x2245.693588\x22\x0a  \
           heigh\
t=\x2230.44051\x22\x0a   \
          x=\x22248\
.76645\x22\x0a        \
     y=\x22-40.6333\
85\x22\x0a            \
 ry=\x225.051497\x22\x0a \
            tran\
sform=\x22rotate(90\
)\x22 />\x0a        </\
g>\x0a      </g>\x0a  \
  </g>\x0a    <path\
\x0a       style=\x22o\
pacity:1;fill:#f\
fc107;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
38596651;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-opacit\
y:1\x22\x0a       d=\x22m\
 50.206421,401.6\
7683 c 110.21720\
9,0.71279 55.108\
609,0.3564 0,0 z\
\x22\x0a       id=\x22rec\
t997\x22\x0a       ink\
scape:connector-\
curvature=\x220\x22 />\
\x0a    <path\x0a     \
  sodipodi:type=\
\x22star\x22\x0a       st\
yle=\x22opacity:1;f\
ill:#0000ff;fill\
-opacity:1;strok\
e:none;stroke-wi\
dth:1.38742065;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22\x0a      \
 id=\x22path828\x22\x0a  \
     sodipodi:si\
des=\x223\x22\x0a       s\
odipodi:cx=\x222.64\
58332\x22\x0a       so\
dipodi:cy=\x22294.0\
8537\x22\x0a       sod\
ipodi:r1=\x221.3874\
207\x22\x0a       sodi\
podi:r2=\x220.69371\
033\x22\x0a       sodi\
podi:arg1=\x221.570\
7963\x22\x0a       sod\
ipodi:arg2=\x222.61\
79939\x22\x0a       in\
kscape:flatsided\
=\x22true\x22\x0a       i\
nkscape:rounded=\
\x220.1\x22\x0a       ink\
scape:randomized\
=\x220\x22\x0a       d=\x22m\
 2.6458333,295.4\
7278 c -0.240308\
4,0 -1.3216958,-\
1.87302 -1.20154\
16,-2.08113 0.12\
01541,-0.20812 2\
.2829289,-0.2081\
2 2.403083,0 0.1\
201542,0.20811 -\
0.9612331,2.0811\
3 -1.2015414,2.0\
8113 z\x22\x0a       i\
nkscape:transfor\
m-center-y=\x220.22\
979542\x22 />\x0a  </g\
>\x0a</svg>\x0a\
\x00\x00-\x9a\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22too\
lbar-handle-vert\
ical.svg\x22\x0a   ink\
scape:export-fil\
ename=\x22/home/yei\
son/Development/\
piton/art/icon_l\
ite.png\x22\x0a   inks\
cape:export-xdpi\
=\x2296\x22\x0a   inkscap\
e:export-ydpi=\x229\
6\x22>\x0a  <defs\x0a    \
 id=\x22defs2\x22 />\x0a \
 <sodipodi:named\
view\x0a     id=\x22ba\
se\x22\x0a     pagecol\
or=\x22#ffffff\x22\x0a   \
  bordercolor=\x22#\
666666\x22\x0a     bor\
deropacity=\x221.0\x22\
\x0a     inkscape:p\
ageopacity=\x220.0\x22\
\x0a     inkscape:p\
ageshadow=\x222\x22\x0a  \
   inkscape:zoom\
=\x2212.401299\x22\x0a   \
  inkscape:cx=\x22-\
6.6600281\x22\x0a     \
inkscape:cy=\x225.8\
024891\x22\x0a     ink\
scape:document-u\
nits=\x22px\x22\x0a     i\
nkscape:current-\
layer=\x22layer1\x22\x0a \
    showgrid=\x22tr\
ue\x22\x0a     inkscap\
e:window-width=\x22\
1920\x22\x0a     inksc\
ape:window-heigh\
t=\x221004\x22\x0a     in\
kscape:window-x=\
\x220\x22\x0a     inkscap\
e:window-y=\x220\x22\x0a \
    inkscape:win\
dow-maximized=\x221\
\x22\x0a     inkscape:\
showpageshadow=\x22\
false\x22\x0a     unit\
s=\x22px\x22\x0a     inks\
cape:pagechecker\
board=\x22false\x22\x0a  \
   showguides=\x22t\
rue\x22\x0a     inksca\
pe:snap-bbox=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-paths=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-bbox-edge\
-midpoints=\x22true\
\x22\x0a     inkscape:\
snap-bbox-midpoi\
nts=\x22true\x22\x0a     \
inkscape:snap-no\
des=\x22true\x22\x0a     \
inkscape:object-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
intersection-pat\
hs=\x22true\x22\x0a     i\
nkscape:snap-smo\
oth-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-global=\x22\
true\x22\x0a     fit-m\
argin-top=\x220\x22\x0a  \
   fit-margin-le\
ft=\x220\x22\x0a     fit-\
margin-right=\x220\x22\
\x0a     fit-margin\
-bottom=\x220\x22\x0a    \
 inkscape:guide-\
bbox=\x22true\x22>\x0a   \
 <inkscape:grid\x0a\
       type=\x22xyg\
rid\x22\x0a       id=\x22\
grid974\x22\x0a       \
empspacing=\x228\x22\x0a \
      spacingx=\x22\
0.26458332\x22\x0a    \
   spacingy=\x220.2\
6458332\x22\x0a       \
dotted=\x22false\x22\x0a \
      visible=\x22t\
rue\x22\x0a       enab\
led=\x22true\x22\x0a     \
  snapvisiblegri\
dlinesonly=\x22true\
\x22\x0a       originx\
=\x220\x22\x0a       orig\
iny=\x220\x22 />\x0a  </s\
odipodi:namedvie\
w>\x0a  <metadata\x0a \
    id=\x22metadata\
5\x22>\x0a    <rdf:RDF\
>\x0a      <cc:Work\
\x0a         rdf:ab\
out=\x22\x22>\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0a        <dc\
:type\x0a          \
 rdf:resource=\x22h\
ttp://purl.org/d\
c/dcmitype/Still\
Image\x22 />\x0a      \
  <dc:title />\x0a \
     </cc:Work>\x0a\
    </rdf:RDF>\x0a \
 </metadata>\x0a  <\
g\x0a     inkscape:\
label=\x22Layer 1\x22\x0a\
     inkscape:gr\
oupmode=\x22layer\x22\x0a\
     id=\x22layer1\x22\
\x0a     transform=\
\x22translate(0,-29\
1.70835)\x22>\x0a    <\
g\x0a       id=\x22g84\
7\x22\x0a       transf\
orm=\x22matrix(0.05\
207439,0,0,0.052\
07453,-0.9012516\
4,282.41203)\x22>\x0a \
     <g\x0a        \
 id=\x22g851\x22>\x0a    \
    <g\x0a         \
  id=\x22g1059\x22\x0a   \
        transfor\
m=\x22matrix(1.9986\
219,0,0,1.998618\
5,17.324484,-313\
.52314)\x22>\x0a      \
    <path\x0a      \
       inkscape:\
transform-center\
-y=\x223.175\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.07000\
433;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
            d=\x22M\
 25.399999,271.6\
0002 -8.0000008e\
-7,246.20002 H 5\
0.799999 Z\x22\x0a    \
         id=\x22pat\
h883\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 sodipodi:nodety\
pes=\x22cccc\x22 />\x0a  \
        <path\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22\x0a           \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a             \
id=\x22path880\x22\x0a   \
          d=\x22m 2\
5.399999,271.600\
02 25.399999,25.\
4 H 0 Z\x22\x0a       \
      inkscape:t\
ransform-center-\
y=\x22-3.1749995\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   ry=\x225.0534658\
\x22\x0a             y\
=\x22253.84885\x22\x0a   \
          x=\x227.6\
487389\x22\x0a        \
     height=\x2235.\
528759\x22\x0a        \
     width=\x2235.5\
28786\x22\x0a         \
    id=\x22rect870\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.06184419;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <circle\x0a      \
       r=\x2225.396\
828\x22\x0a           \
  cy=\x22271.60001\x22\
\x0a             cx\
=\x2225.4\x22\x0a        \
     id=\x22path872\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07635882;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <circle\x0a     \
        transfor\
m=\x22rotate(-45)\x22\x0a\
             cx=\
\x22-174.08969\x22\x0a   \
          cy=\x2221\
0.01071\x22\x0a       \
      r=\x2212.6560\
71\x22\x0a            \
 id=\x22path876\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
399406;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
path\x0a           \
  inkscape:trans\
form-center-x=\x22-\
3.1749999\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22\x0a             i\
nkscape:connecto\
r-curvature=\x220\x22\x0a\
             id=\
\x22path904\x22\x0a      \
       d=\x22m 25.4\
,271.60002 -25.4\
0000040000004,25\
.4 v -50.8 z\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
path\x0a           \
  inkscape:trans\
form-center-x=\x223\
.175\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22\x0a      \
       d=\x22m 25.3\
99999,271.60002 \
25.4,-25.4 v 50.\
8 z\x22\x0a           \
  id=\x22path906\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22 />\x0a         \
 <rect\x0a         \
    ry=\x225.051492\
2\x22\x0a             \
y=\x22256.39301\x22\x0a  \
           x=\x222.\
5663135\x22\x0a       \
      height=\x2230\
.440479\x22\x0a       \
      width=\x2245.\
693634\x22\x0a        \
     id=\x22rect837\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <rect\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.0657438;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22\x0a     \
        id=\x22rect\
831\x22\x0a           \
  width=\x2245.6935\
88\x22\x0a            \
 height=\x2230.4405\
1\x22\x0a             \
x=\x22248.76645\x22\x0a  \
           y=\x22-4\
0.633385\x22\x0a      \
       ry=\x225.051\
497\x22\x0a           \
  transform=\x22rot\
ate(90)\x22 />\x0a    \
    </g>\x0a      <\
/g>\x0a    </g>\x0a   \
 <path\x0a       st\
yle=\x22opacity:1;f\
ill:#ffc107;fill\
-opacity:1;strok\
e:none;stroke-wi\
dth:0.38596651;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
opacity:1\x22\x0a     \
  d=\x22m 50.206421\
,401.67683 c 110\
.217209,0.71279 \
55.108609,0.3564\
 0,0 z\x22\x0a       i\
d=\x22rect997\x22\x0a    \
   inkscape:conn\
ector-curvature=\
\x220\x22 />\x0a    <g\x0a  \
     id=\x22g850\x22\x0a \
      transform=\
\x22rotate(90,2.645\
8333,294.35418)\x22\
>\x0a      <g\x0a     \
    id=\x22g839\x22>\x0a \
       <rect\x0a   \
        y=\x22291.7\
0834\x22\x0a          \
 x=\x221.5875\x22\x0a    \
       height=\x220\
.52916664\x22\x0a     \
      width=\x220.5\
2916664\x22\x0a       \
    id=\x22rect830\x22\
\x0a           styl\
e=\x22opacity:1;fil\
l:#0000ff;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22 />\x0a     \
   <rect\x0a       \
    style=\x22opaci\
ty:1;fill:#0000f\
f;fill-opacity:1\
;stroke:none;str\
oke-width:0.5291\
6664;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1\x22\x0a\
           id=\x22r\
ect832\x22\x0a        \
   width=\x220.5291\
6664\x22\x0a          \
 height=\x220.52916\
664\x22\x0a           \
x=\x221.5875\x22\x0a     \
      y=\x22293.295\
84\x22 />\x0a        <\
rect\x0a           \
y=\x22294.88336\x22\x0a  \
         x=\x221.58\
75\x22\x0a           h\
eight=\x220.5291666\
4\x22\x0a           wi\
dth=\x220.52916664\x22\
\x0a           id=\x22\
rect834\x22\x0a       \
    style=\x22opaci\
ty:1;fill:#0000f\
f;fill-opacity:1\
;stroke:none;str\
oke-width:0.5291\
6664;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1\x22 \
/>\x0a        <rect\
\x0a           styl\
e=\x22opacity:1;fil\
l:#0000ff;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22\x0a        \
   id=\x22rect836\x22\x0a\
           width\
=\x220.52916664\x22\x0a  \
         height=\
\x220.52916664\x22\x0a   \
        x=\x221.587\
5\x22\x0a           y=\
\x22296.47086\x22 />\x0a \
       <rect\x0a   \
        y=\x22292.5\
0208\x22\x0a          \
 x=\x222.3812499\x22\x0a \
          height\
=\x220.52916664\x22\x0a  \
         width=\x22\
0.52916664\x22\x0a    \
       id=\x22rect8\
38\x22\x0a           s\
tyle=\x22opacity:1;\
fill:#0000ff;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:0.52916664;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1\x22 />\x0a  \
      <rect\x0a    \
       style=\x22op\
acity:1;fill:#00\
00ff;fill-opacit\
y:1;stroke:none;\
stroke-width:0.5\
2916664;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1\x22\x0a           id\
=\x22rect840\x22\x0a     \
      width=\x220.5\
2916664\x22\x0a       \
    height=\x220.52\
916664\x22\x0a        \
   x=\x222.3812499\x22\
\x0a           y=\x222\
94.0896\x22 />\x0a    \
    <rect\x0a      \
     y=\x22295.6770\
9\x22\x0a           x=\
\x222.3812499\x22\x0a    \
       height=\x220\
.52916664\x22\x0a     \
      width=\x220.5\
2916664\x22\x0a       \
    id=\x22rect842\x22\
\x0a           styl\
e=\x22opacity:1;fil\
l:#0000ff;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22 />\x0a     \
   <rect\x0a       \
    style=\x22opaci\
ty:1;fill:#0000f\
f;fill-opacity:1\
;stroke:none;str\
oke-width:0.5291\
6664;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1\x22\x0a\
           id=\x22r\
ect844\x22\x0a        \
   width=\x220.5291\
6664\x22\x0a          \
 height=\x220.52916\
664\x22\x0a           \
x=\x223.175\x22\x0a      \
     y=\x22291.7083\
4\x22 />\x0a        <r\
ect\x0a           y\
=\x22293.29584\x22\x0a   \
        x=\x223.175\
\x22\x0a           hei\
ght=\x220.52916664\x22\
\x0a           widt\
h=\x220.52916664\x22\x0a \
          id=\x22re\
ct846\x22\x0a         \
  style=\x22opacity\
:1;fill:#0000ff;\
fill-opacity:1;s\
troke:none;strok\
e-width:0.529166\
64;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1\x22 />\
\x0a        <rect\x0a \
          style=\
\x22opacity:1;fill:\
#0000ff;fill-opa\
city:1;stroke:no\
ne;stroke-width:\
0.52916664;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1\x22\x0a          \
 id=\x22rect848\x22\x0a  \
         width=\x22\
0.52916664\x22\x0a    \
       height=\x220\
.52916664\x22\x0a     \
      x=\x223.175\x22\x0a\
           y=\x2229\
4.88336\x22 />\x0a    \
    <rect\x0a      \
     y=\x22296.4708\
6\x22\x0a           x=\
\x223.175\x22\x0a        \
   height=\x220.529\
16664\x22\x0a         \
  width=\x220.52916\
664\x22\x0a           \
id=\x22rect850\x22\x0a   \
        style=\x22o\
pacity:1;fill:#0\
000ff;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
52916664;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22 />\x0a      </g\
>\x0a    </g>\x0a  </g\
>\x0a</svg>\x0a\
\x00\x00!.\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22lef\
tarrow.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2211.745467\x22\x0a \
    inkscape:cx=\
\x22-19.921584\x22\x0a   \
  inkscape:cy=\x22-\
13.919269\x22\x0a     \
inkscape:documen\
t-units=\x22px\x22\x0a   \
  inkscape:curre\
nt-layer=\x22layer1\
\x22\x0a     showgrid=\
\x22true\x22\x0a     inks\
cape:window-widt\
h=\x221920\x22\x0a     in\
kscape:window-he\
ight=\x221015\x22\x0a    \
 inkscape:window\
-x=\x220\x22\x0a     inks\
cape:window-y=\x220\
\x22\x0a     inkscape:\
window-maximized\
=\x221\x22\x0a     inksca\
pe:showpageshado\
w=\x22false\x22\x0a     u\
nits=\x22px\x22\x0a     i\
nkscape:pagechec\
kerboard=\x22false\x22\
\x0a     showguides\
=\x22true\x22\x0a     ink\
scape:snap-bbox=\
\x22true\x22\x0a     inks\
cape:bbox-paths=\
\x22true\x22\x0a     inks\
cape:bbox-nodes=\
\x22true\x22\x0a     inks\
cape:snap-bbox-e\
dge-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-bbox-mid\
points=\x22true\x22\x0a  \
   inkscape:snap\
-nodes=\x22true\x22\x0a  \
   inkscape:obje\
ct-paths=\x22true\x22\x0a\
     inkscape:sn\
ap-intersection-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
smooth-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-midpoints\
=\x22true\x22\x0a     ink\
scape:snap-globa\
l=\x22true\x22\x0a     fi\
t-margin-top=\x220\x22\
\x0a     fit-margin\
-left=\x220\x22\x0a     f\
it-margin-right=\
\x220\x22\x0a     fit-mar\
gin-bottom=\x220\x22\x0a \
    inkscape:gui\
de-bbox=\x22true\x22>\x0a\
    <inkscape:gr\
id\x0a       type=\x22\
xygrid\x22\x0a       i\
d=\x22grid974\x22\x0a    \
   empspacing=\x228\
\x22\x0a       spacing\
x=\x220.26458332\x22\x0a \
      spacingy=\x22\
0.26458332\x22\x0a    \
   dotted=\x22false\
\x22\x0a       visible\
=\x22true\x22\x0a       e\
nabled=\x22true\x22\x0a  \
     snapvisible\
gridlinesonly=\x22t\
rue\x22\x0a       orig\
inx=\x220\x22\x0a       o\
riginy=\x220\x22 />\x0a  \
</sodipodi:named\
view>\x0a  <metadat\
a\x0a     id=\x22metad\
ata5\x22>\x0a    <rdf:\
RDF>\x0a      <cc:W\
ork\x0a         rdf\
:about=\x22\x22>\x0a     \
   <dc:format>im\
age/svg+xml</dc:\
format>\x0a        \
<dc:type\x0a       \
    rdf:resource\
=\x22http://purl.or\
g/dc/dcmitype/St\
illImage\x22 />\x0a   \
     <dc:title /\
>\x0a      </cc:Wor\
k>\x0a    </rdf:RDF\
>\x0a  </metadata>\x0a\
  <g\x0a     inksca\
pe:label=\x22Layer \
1\x22\x0a     inkscape\
:groupmode=\x22laye\
r\x22\x0a     id=\x22laye\
r1\x22\x0a     transfo\
rm=\x22translate(0,\
-291.70835)\x22>\x0a  \
  <g\x0a       id=\x22\
g847\x22\x0a       tra\
nsform=\x22matrix(0\
.05207439,0,0,0.\
05207453,-0.9012\
5164,282.41203)\x22\
>\x0a      <g\x0a     \
    id=\x22g851\x22>\x0a \
       <g\x0a      \
     id=\x22g1059\x22\x0a\
           trans\
form=\x22matrix(1.9\
986219,0,0,1.998\
6185,17.324484,-\
313.52314)\x22>\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-y=\x223.175\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a             d\
=\x22M 25.399999,27\
1.60002 -8.00000\
08e-7,246.20002 \
H 50.799999 Z\x22\x0a \
            id=\x22\
path883\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22 />\
\x0a          <path\
\x0a             so\
dipodi:nodetypes\
=\x22cccc\x22\x0a        \
     inkscape:co\
nnector-curvatur\
e=\x220\x22\x0a          \
   id=\x22path880\x22\x0a\
             d=\x22\
m 25.399999,271.\
60002 25.399999,\
25.4 H 0 Z\x22\x0a    \
         inkscap\
e:transform-cent\
er-y=\x22-3.1749995\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <rect\x0a       \
      ry=\x225.0534\
658\x22\x0a           \
  y=\x22253.84885\x22\x0a\
             x=\x22\
7.6487389\x22\x0a     \
        height=\x22\
35.528759\x22\x0a     \
        width=\x223\
5.528786\x22\x0a      \
       id=\x22rect8\
70\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.06184419;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22 />\x0a     \
     <circle\x0a   \
          r=\x2225.\
396828\x22\x0a        \
     cy=\x22271.600\
01\x22\x0a            \
 cx=\x2225.4\x22\x0a     \
        id=\x22path\
872\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07635882;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <circle\x0a  \
           trans\
form=\x22rotate(-45\
)\x22\x0a             \
cx=\x22-174.08969\x22\x0a\
             cy=\
\x22210.01071\x22\x0a    \
         r=\x2212.6\
56071\x22\x0a         \
    id=\x22path876\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.07399406;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-x\
=\x22-3.1749999\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22\x0a           \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a             \
id=\x22path904\x22\x0a   \
          d=\x22m 2\
5.4,271.60002 -2\
5.40000040000004\
,25.4 v -50.8 z\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.07000433;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-x\
=\x223.175\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          d=\x22m 2\
5.399999,271.600\
02 25.4,-25.4 v \
50.8 z\x22\x0a        \
     id=\x22path906\
\x22\x0a             i\
nkscape:connecto\
r-curvature=\x220\x22\x0a\
             sod\
ipodi:nodetypes=\
\x22cccc\x22 />\x0a      \
    <rect\x0a      \
       ry=\x225.051\
4922\x22\x0a          \
   y=\x22256.39301\x22\
\x0a             x=\
\x222.5663135\x22\x0a    \
         height=\
\x2230.440479\x22\x0a    \
         width=\x22\
45.693634\x22\x0a     \
        id=\x22rect\
837\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.0657438;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22 />\x0a     \
     <rect\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06574\
38;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22\x0a  \
           id=\x22r\
ect831\x22\x0a        \
     width=\x2245.6\
93588\x22\x0a         \
    height=\x2230.4\
4051\x22\x0a          \
   x=\x22248.76645\x22\
\x0a             y=\
\x22-40.633385\x22\x0a   \
          ry=\x225.\
051497\x22\x0a        \
     transform=\x22\
rotate(90)\x22 />\x0a \
       </g>\x0a    \
  </g>\x0a    </g>\x0a\
    <path\x0a      \
 style=\x22opacity:\
1;fill:#ffc107;f\
ill-opacity:1;st\
roke:none;stroke\
-width:0.3859665\
1;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-opacity:1\x22\x0a  \
     d=\x22m 50.206\
421,401.67683 c \
110.217209,0.712\
79 55.108609,0.3\
564 0,0 z\x22\x0a     \
  id=\x22rect997\x22\x0a \
      inkscape:c\
onnector-curvatu\
re=\x220\x22 />\x0a    <p\
ath\x0a       sodip\
odi:type=\x22star\x22\x0a\
       style=\x22op\
acity:1;fill:#00\
00ff;fill-opacit\
y:1;stroke:none;\
stroke-width:1.3\
8742065;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a       id=\x22pa\
th828\x22\x0a       so\
dipodi:sides=\x223\x22\
\x0a       sodipodi\
:cx=\x22-2.6458433\x22\
\x0a       sodipodi\
:cy=\x22-294.16339\x22\
\x0a       sodipodi\
:r1=\x221.3874207\x22\x0a\
       sodipodi:\
r2=\x220.69371033\x22\x0a\
       sodipodi:\
arg1=\x221.5707963\x22\
\x0a       sodipodi\
:arg2=\x222.6179939\
\x22\x0a       inkscap\
e:flatsided=\x22tru\
e\x22\x0a       inksca\
pe:rounded=\x220.1\x22\
\x0a       inkscape\
:randomized=\x220\x22\x0a\
       d=\x22m -2.6\
458432,-292.7759\
7 c -0.2403083,0\
 -1.3216958,-1.8\
7301 -1.2015416,\
-2.08113 0.12015\
41,-0.20811 2.28\
29289,-0.20811 2\
.403083,0 0.1201\
542,0.20812 -0.9\
612331,2.08113 -\
1.2015414,2.0811\
3 z\x22\x0a       inks\
cape:transform-c\
enter-y=\x22-5.0863\
116e-06\x22\x0a       \
transform=\x22rotat\
e(90,-294.12438,\
2.6458332)\x22\x0a    \
   inkscape:tran\
sform-center-x=\x22\
0.22980664\x22 />\x0a \
 </g>\x0a</svg>\x0a\
\x00\x00 q\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22flo\
at.svg\x22\x0a   inksc\
ape:export-filen\
ame=\x22/home/yeiso\
n/Development/pi\
ton/art/icon_lit\
e.png\x22\x0a   inksca\
pe:export-xdpi=\x22\
96\x22\x0a   inkscape:\
export-ydpi=\x2296\x22\
>\x0a  <defs\x0a     i\
d=\x22defs2\x22 />\x0a  <\
sodipodi:namedvi\
ew\x0a     id=\x22base\
\x22\x0a     pagecolor\
=\x22#ffffff\x22\x0a     \
bordercolor=\x22#66\
6666\x22\x0a     borde\
ropacity=\x221.0\x22\x0a \
    inkscape:pag\
eopacity=\x220.0\x22\x0a \
    inkscape:pag\
eshadow=\x222\x22\x0a    \
 inkscape:zoom=\x22\
23.490934\x22\x0a     \
inkscape:cx=\x2212.\
388735\x22\x0a     ink\
scape:cy=\x227.1323\
576\x22\x0a     inksca\
pe:document-unit\
s=\x22px\x22\x0a     inks\
cape:current-lay\
er=\x22layer1\x22\x0a    \
 showgrid=\x22true\x22\
\x0a     inkscape:w\
indow-width=\x22192\
0\x22\x0a     inkscape\
:window-height=\x22\
1004\x22\x0a     inksc\
ape:window-x=\x220\x22\
\x0a     inkscape:w\
indow-y=\x220\x22\x0a    \
 inkscape:window\
-maximized=\x221\x22\x0a \
    inkscape:sho\
wpageshadow=\x22fal\
se\x22\x0a     units=\x22\
px\x22\x0a     inkscap\
e:pagecheckerboa\
rd=\x22false\x22\x0a     \
showguides=\x22true\
\x22\x0a     inkscape:\
snap-bbox=\x22true\x22\
\x0a     inkscape:b\
box-paths=\x22true\x22\
\x0a     inkscape:b\
box-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-bbox-edge-mi\
dpoints=\x22true\x22\x0a \
    inkscape:sna\
p-bbox-midpoints\
=\x22true\x22\x0a     ink\
scape:snap-nodes\
=\x22false\x22\x0a     in\
kscape:object-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-in\
tersection-paths\
=\x22true\x22\x0a     ink\
scape:snap-smoot\
h-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-global=\x22tr\
ue\x22\x0a     fit-mar\
gin-top=\x220\x22\x0a    \
 fit-margin-left\
=\x220\x22\x0a     fit-ma\
rgin-right=\x220\x22\x0a \
    fit-margin-b\
ottom=\x220\x22\x0a     i\
nkscape:guide-bb\
ox=\x22true\x22>\x0a    <\
inkscape:grid\x0a  \
     type=\x22xygri\
d\x22\x0a       id=\x22gr\
id974\x22\x0a       em\
pspacing=\x228\x22\x0a   \
    spacingx=\x220.\
26458332\x22\x0a      \
 spacingy=\x220.264\
58332\x22\x0a       do\
tted=\x22false\x22\x0a   \
    visible=\x22tru\
e\x22\x0a       enable\
d=\x22true\x22\x0a       \
snapvisiblegridl\
inesonly=\x22true\x22\x0a\
       originx=\x22\
0\x22\x0a       origin\
y=\x220\x22 />\x0a  </sod\
ipodi:namedview>\
\x0a  <metadata\x0a   \
  id=\x22metadata5\x22\
>\x0a    <rdf:RDF>\x0a\
      <cc:Work\x0a \
        rdf:abou\
t=\x22\x22>\x0a        <d\
c:format>image/s\
vg+xml</dc:forma\
t>\x0a        <dc:t\
ype\x0a           r\
df:resource=\x22htt\
p://purl.org/dc/\
dcmitype/StillIm\
age\x22 />\x0a        \
<dc:title />\x0a   \
   </cc:Work>\x0a  \
  </rdf:RDF>\x0a  <\
/metadata>\x0a  <g\x0a\
     inkscape:la\
bel=\x22Layer 1\x22\x0a  \
   inkscape:grou\
pmode=\x22layer\x22\x0a  \
   id=\x22layer1\x22\x0a \
    transform=\x22t\
ranslate(0,-291.\
70835)\x22>\x0a    <g\x0a\
       id=\x22g847\x22\
\x0a       transfor\
m=\x22matrix(0.0520\
7439,0,0,0.05207\
453,-0.90125164,\
282.41203)\x22>\x0a   \
   <g\x0a         i\
d=\x22g851\x22>\x0a      \
  <g\x0a           \
id=\x22g1059\x22\x0a     \
      transform=\
\x22matrix(1.998621\
9,0,0,1.9986185,\
17.324484,-313.5\
2314)\x22>\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-y\
=\x223.175\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          d=\x22M 2\
5.399999,271.600\
02 -8.0000008e-7\
,246.20002 H 50.\
799999 Z\x22\x0a      \
       id=\x22path8\
83\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22 />\x0a    \
      <path\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             id\
=\x22path880\x22\x0a     \
        d=\x22m 25.\
399999,271.60002\
 25.399999,25.4 \
H 0 Z\x22\x0a         \
    inkscape:tra\
nsform-center-y=\
\x22-3.1749995\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <r\
ect\x0a            \
 ry=\x225.0534658\x22\x0a\
             y=\x22\
253.84885\x22\x0a     \
        x=\x227.648\
7389\x22\x0a          \
   height=\x2235.52\
8759\x22\x0a          \
   width=\x2235.528\
786\x22\x0a           \
  id=\x22rect870\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
6184419;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<circle\x0a        \
     r=\x2225.39682\
8\x22\x0a             \
cy=\x22271.60001\x22\x0a \
            cx=\x22\
25.4\x22\x0a          \
   id=\x22path872\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07635882;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <circle\x0a       \
      transform=\
\x22rotate(-45)\x22\x0a  \
           cx=\x22-\
174.08969\x22\x0a     \
        cy=\x22210.\
01071\x22\x0a         \
    r=\x2212.656071\
\x22\x0a             i\
d=\x22path876\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0739\
9406;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x22-3.\
1749999\x22\x0a       \
      sodipodi:n\
odetypes=\x22cccc\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           id=\x22p\
ath904\x22\x0a        \
     d=\x22m 25.4,2\
71.60002 -25.400\
00040000004,25.4\
 v -50.8 z\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0700\
0433;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x223.1\
75\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07000433;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a        \
     d=\x22m 25.399\
999,271.60002 25\
.4,-25.4 v 50.8 \
z\x22\x0a             \
id=\x22path906\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22 />\x0a          <\
rect\x0a           \
  ry=\x225.0514922\x22\
\x0a             y=\
\x22256.39301\x22\x0a    \
         x=\x222.56\
63135\x22\x0a         \
    height=\x2230.4\
40479\x22\x0a         \
    width=\x2245.69\
3634\x22\x0a          \
   id=\x22rect837\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      id=\x22rect83\
1\x22\x0a             \
width=\x2245.693588\
\x22\x0a             h\
eight=\x2230.44051\x22\
\x0a             x=\
\x22248.76645\x22\x0a    \
         y=\x22-40.\
633385\x22\x0a        \
     ry=\x225.05149\
7\x22\x0a             \
transform=\x22rotat\
e(90)\x22 />\x0a      \
  </g>\x0a      </g\
>\x0a    </g>\x0a    <\
path\x0a       styl\
e=\x22opacity:1;fil\
l:#ffc107;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.38596651;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-op\
acity:1\x22\x0a       \
d=\x22m 50.206421,4\
01.67683 c 110.2\
17209,0.71279 55\
.108609,0.3564 0\
,0 z\x22\x0a       id=\
\x22rect997\x22\x0a      \
 inkscape:connec\
tor-curvature=\x220\
\x22 />\x0a    <rect\x0a \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:1;\
stroke:#0000ff;s\
troke-width:0.52\
916664;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a       id=\x22rec\
t829\x22\x0a       wid\
th=\x222.6581812\x22\x0a \
      height=\x222.\
658181\x22\x0a       x\
=\x220.6522209\x22\x0a   \
    y=\x22293.68961\
\x22\x0a       ry=\x220.2\
9536656\x22 />\x0a    \
<rect\x0a       ry=\
\x220.29536656\x22\x0a   \
    y=\x22292.3606\x22\
\x0a       x=\x221.981\
2645\x22\x0a       hei\
ght=\x222.658181\x22\x0a \
      width=\x222.6\
581812\x22\x0a       i\
d=\x22rect839\x22\x0a    \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:1;str\
oke:#0000ff;stro\
ke-width:0.52916\
664;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a  </g>\x0a</svg>\x0a\
\
\x00\x00,\xc0\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22too\
lbar-handle-hori\
zontal.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2224.802598\x22\x0a \
    inkscape:cx=\
\x223.483525\x22\x0a     \
inkscape:cy=\x2210.\
683358\x22\x0a     ink\
scape:document-u\
nits=\x22px\x22\x0a     i\
nkscape:current-\
layer=\x22g839\x22\x0a   \
  showgrid=\x22true\
\x22\x0a     inkscape:\
window-width=\x2219\
20\x22\x0a     inkscap\
e:window-height=\
\x221004\x22\x0a     inks\
cape:window-x=\x220\
\x22\x0a     inkscape:\
window-y=\x220\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22\x0a\
     inkscape:sh\
owpageshadow=\x22fa\
lse\x22\x0a     units=\
\x22px\x22\x0a     inksca\
pe:pagecheckerbo\
ard=\x22false\x22\x0a    \
 showguides=\x22tru\
e\x22\x0a     inkscape\
:snap-bbox=\x22true\
\x22\x0a     inkscape:\
bbox-paths=\x22true\
\x22\x0a     inkscape:\
bbox-nodes=\x22true\
\x22\x0a     inkscape:\
snap-bbox-edge-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-node\
s=\x22true\x22\x0a     in\
kscape:object-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-in\
tersection-paths\
=\x22true\x22\x0a     ink\
scape:snap-smoot\
h-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-global=\x22tr\
ue\x22\x0a     fit-mar\
gin-top=\x220\x22\x0a    \
 fit-margin-left\
=\x220\x22\x0a     fit-ma\
rgin-right=\x220\x22\x0a \
    fit-margin-b\
ottom=\x220\x22\x0a     i\
nkscape:guide-bb\
ox=\x22true\x22>\x0a    <\
inkscape:grid\x0a  \
     type=\x22xygri\
d\x22\x0a       id=\x22gr\
id974\x22\x0a       em\
pspacing=\x228\x22\x0a   \
    spacingx=\x220.\
26458332\x22\x0a      \
 spacingy=\x220.264\
58332\x22\x0a       do\
tted=\x22false\x22\x0a   \
    visible=\x22tru\
e\x22\x0a       enable\
d=\x22true\x22\x0a       \
snapvisiblegridl\
inesonly=\x22true\x22\x0a\
       originx=\x22\
0\x22\x0a       origin\
y=\x220\x22 />\x0a  </sod\
ipodi:namedview>\
\x0a  <metadata\x0a   \
  id=\x22metadata5\x22\
>\x0a    <rdf:RDF>\x0a\
      <cc:Work\x0a \
        rdf:abou\
t=\x22\x22>\x0a        <d\
c:format>image/s\
vg+xml</dc:forma\
t>\x0a        <dc:t\
ype\x0a           r\
df:resource=\x22htt\
p://purl.org/dc/\
dcmitype/StillIm\
age\x22 />\x0a        \
<dc:title />\x0a   \
   </cc:Work>\x0a  \
  </rdf:RDF>\x0a  <\
/metadata>\x0a  <g\x0a\
     inkscape:la\
bel=\x22Layer 1\x22\x0a  \
   inkscape:grou\
pmode=\x22layer\x22\x0a  \
   id=\x22layer1\x22\x0a \
    transform=\x22t\
ranslate(0,-291.\
70835)\x22>\x0a    <g\x0a\
       id=\x22g847\x22\
\x0a       transfor\
m=\x22matrix(0.0520\
7439,0,0,0.05207\
453,-0.90125164,\
282.41203)\x22>\x0a   \
   <g\x0a         i\
d=\x22g851\x22>\x0a      \
  <g\x0a           \
id=\x22g1059\x22\x0a     \
      transform=\
\x22matrix(1.998621\
9,0,0,1.9986185,\
17.324484,-313.5\
2314)\x22>\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-y\
=\x223.175\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          d=\x22M 2\
5.399999,271.600\
02 -8.0000008e-7\
,246.20002 H 50.\
799999 Z\x22\x0a      \
       id=\x22path8\
83\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22 />\x0a    \
      <path\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             id\
=\x22path880\x22\x0a     \
        d=\x22m 25.\
399999,271.60002\
 25.399999,25.4 \
H 0 Z\x22\x0a         \
    inkscape:tra\
nsform-center-y=\
\x22-3.1749995\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <r\
ect\x0a            \
 ry=\x225.0534658\x22\x0a\
             y=\x22\
253.84885\x22\x0a     \
        x=\x227.648\
7389\x22\x0a          \
   height=\x2235.52\
8759\x22\x0a          \
   width=\x2235.528\
786\x22\x0a           \
  id=\x22rect870\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
6184419;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<circle\x0a        \
     r=\x2225.39682\
8\x22\x0a             \
cy=\x22271.60001\x22\x0a \
            cx=\x22\
25.4\x22\x0a          \
   id=\x22path872\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07635882;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <circle\x0a       \
      transform=\
\x22rotate(-45)\x22\x0a  \
           cx=\x22-\
174.08969\x22\x0a     \
        cy=\x22210.\
01071\x22\x0a         \
    r=\x2212.656071\
\x22\x0a             i\
d=\x22path876\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0739\
9406;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x22-3.\
1749999\x22\x0a       \
      sodipodi:n\
odetypes=\x22cccc\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           id=\x22p\
ath904\x22\x0a        \
     d=\x22m 25.4,2\
71.60002 -25.400\
00040000004,25.4\
 v -50.8 z\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0700\
0433;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x223.1\
75\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07000433;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a        \
     d=\x22m 25.399\
999,271.60002 25\
.4,-25.4 v 50.8 \
z\x22\x0a             \
id=\x22path906\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22 />\x0a          <\
rect\x0a           \
  ry=\x225.0514922\x22\
\x0a             y=\
\x22256.39301\x22\x0a    \
         x=\x222.56\
63135\x22\x0a         \
    height=\x2230.4\
40479\x22\x0a         \
    width=\x2245.69\
3634\x22\x0a          \
   id=\x22rect837\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      id=\x22rect83\
1\x22\x0a             \
width=\x2245.693588\
\x22\x0a             h\
eight=\x2230.44051\x22\
\x0a             x=\
\x22248.76645\x22\x0a    \
         y=\x22-40.\
633385\x22\x0a        \
     ry=\x225.05149\
7\x22\x0a             \
transform=\x22rotat\
e(90)\x22 />\x0a      \
  </g>\x0a      </g\
>\x0a    </g>\x0a    <\
path\x0a       styl\
e=\x22opacity:1;fil\
l:#ffc107;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.38596651;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-op\
acity:1\x22\x0a       \
d=\x22m 50.206421,4\
01.67683 c 110.2\
17209,0.71279 55\
.108609,0.3564 0\
,0 z\x22\x0a       id=\
\x22rect997\x22\x0a      \
 inkscape:connec\
tor-curvature=\x220\
\x22 />\x0a    <g\x0a    \
   id=\x22g839\x22>\x0a  \
    <rect\x0a      \
   style=\x22opacit\
y:1;fill:#0000ff\
;fill-opacity:1;\
stroke:none;stro\
ke-width:0.52916\
664;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1\x22\x0a \
        id=\x22rect\
830\x22\x0a         wi\
dth=\x220.52916664\x22\
\x0a         height\
=\x220.52916664\x22\x0a  \
       x=\x221.8520\
832\x22\x0a         y=\
\x22291.70834\x22 />\x0a \
     <rect\x0a     \
    y=\x22293.29584\
\x22\x0a         x=\x221.\
8520832\x22\x0a       \
  height=\x220.5291\
6664\x22\x0a         w\
idth=\x220.52916664\
\x22\x0a         id=\x22r\
ect832\x22\x0a        \
 style=\x22opacity:\
1;fill:#0000ff;f\
ill-opacity:1;st\
roke:none;stroke\
-width:0.5291666\
4;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1\x22 />\x0a\
      <rect\x0a    \
     style=\x22opac\
ity:1;fill:#0000\
ff;fill-opacity:\
1;stroke:none;st\
roke-width:0.529\
16664;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1\x22\
\x0a         id=\x22re\
ct834\x22\x0a         \
width=\x220.5291666\
4\x22\x0a         heig\
ht=\x220.52916664\x22\x0a\
         x=\x221.85\
20832\x22\x0a         \
y=\x22294.88336\x22 />\
\x0a      <rect\x0a   \
      y=\x22296.470\
86\x22\x0a         x=\x22\
1.8520832\x22\x0a     \
    height=\x220.52\
916664\x22\x0a        \
 width=\x220.529166\
64\x22\x0a         id=\
\x22rect836\x22\x0a      \
   style=\x22opacit\
y:1;fill:#0000ff\
;fill-opacity:1;\
stroke:none;stro\
ke-width:0.52916\
664;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1\x22 /\
>\x0a      <rect\x0a  \
       style=\x22op\
acity:1;fill:#00\
00ff;fill-opacit\
y:1;stroke:none;\
stroke-width:0.5\
2916664;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1\x22\x0a         id=\x22\
rect838\x22\x0a       \
  width=\x220.52916\
664\x22\x0a         he\
ight=\x220.52916664\
\x22\x0a         x=\x222.\
3812499\x22\x0a       \
  y=\x22292.50208\x22 \
/>\x0a      <rect\x0a \
        y=\x22294.0\
896\x22\x0a         x=\
\x222.3812499\x22\x0a    \
     height=\x220.5\
2916664\x22\x0a       \
  width=\x220.52916\
664\x22\x0a         id\
=\x22rect840\x22\x0a     \
    style=\x22opaci\
ty:1;fill:#0000f\
f;fill-opacity:1\
;stroke:none;str\
oke-width:0.5291\
6664;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1\x22 \
/>\x0a      <rect\x0a \
        style=\x22o\
pacity:1;fill:#0\
000ff;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
52916664;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22\x0a         id=\
\x22rect842\x22\x0a      \
   width=\x220.5291\
6664\x22\x0a         h\
eight=\x220.5291666\
4\x22\x0a         x=\x222\
.3812499\x22\x0a      \
   y=\x22295.67709\x22\
 />\x0a      <rect\x0a\
         y=\x22291.\
70834\x22\x0a         \
x=\x222.9104166\x22\x0a  \
       height=\x220\
.52916664\x22\x0a     \
    width=\x220.529\
16664\x22\x0a         \
id=\x22rect844\x22\x0a   \
      style=\x22opa\
city:1;fill:#000\
0ff;fill-opacity\
:1;stroke:none;s\
troke-width:0.52\
916664;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
\x22 />\x0a      <rect\
\x0a         style=\
\x22opacity:1;fill:\
#0000ff;fill-opa\
city:1;stroke:no\
ne;stroke-width:\
0.52916664;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1\x22\x0a         i\
d=\x22rect846\x22\x0a    \
     width=\x220.52\
916664\x22\x0a        \
 height=\x220.52916\
664\x22\x0a         x=\
\x222.9104166\x22\x0a    \
     y=\x22293.2958\
4\x22 />\x0a      <rec\
t\x0a         y=\x2229\
4.88336\x22\x0a       \
  x=\x222.9104166\x22\x0a\
         height=\
\x220.52916664\x22\x0a   \
      width=\x220.5\
2916664\x22\x0a       \
  id=\x22rect848\x22\x0a \
        style=\x22o\
pacity:1;fill:#0\
000ff;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
52916664;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22 />\x0a      <re\
ct\x0a         styl\
e=\x22opacity:1;fil\
l:#0000ff;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22\x0a        \
 id=\x22rect850\x22\x0a  \
       width=\x220.\
52916664\x22\x0a      \
   height=\x220.529\
16664\x22\x0a         \
x=\x222.9104166\x22\x0a  \
       y=\x22296.47\
086\x22 />\x0a    </g>\
\x0a  </g>\x0a</svg>\x0a\
\x00\x00\x1dw\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22che\
ckbox_checked.sv\
g\x22\x0a   inkscape:e\
xport-filename=\x22\
/home/yeison/Dev\
elopment/piton/a\
rt/icon_lite.png\
\x22\x0a   inkscape:ex\
port-xdpi=\x2296\x22\x0a \
  inkscape:expor\
t-ydpi=\x2296\x22>\x0a  <\
defs\x0a     id=\x22de\
fs2\x22 />\x0a  <sodip\
odi:namedview\x0a  \
   id=\x22base\x22\x0a   \
  pagecolor=\x22#ff\
ffff\x22\x0a     borde\
rcolor=\x22#666666\x22\
\x0a     borderopac\
ity=\x221.0\x22\x0a     i\
nkscape:pageopac\
ity=\x220.0\x22\x0a     i\
nkscape:pageshad\
ow=\x222\x22\x0a     inks\
cape:zoom=\x2217.53\
8085\x22\x0a     inksc\
ape:cx=\x226.604083\
6\x22\x0a     inkscape\
:cy=\x229.0271347\x22\x0a\
     inkscape:do\
cument-units=\x22px\
\x22\x0a     inkscape:\
current-layer=\x22l\
ayer1\x22\x0a     show\
grid=\x22true\x22\x0a    \
 inkscape:window\
-width=\x221920\x22\x0a  \
   inkscape:wind\
ow-height=\x221015\x22\
\x0a     inkscape:w\
indow-x=\x220\x22\x0a    \
 inkscape:window\
-y=\x220\x22\x0a     inks\
cape:window-maxi\
mized=\x221\x22\x0a     i\
nkscape:showpage\
shadow=\x22false\x22\x0a \
    units=\x22px\x22\x0a \
    inkscape:pag\
echeckerboard=\x22f\
alse\x22\x0a     showg\
uides=\x22true\x22\x0a   \
  inkscape:snap-\
bbox=\x22true\x22\x0a    \
 inkscape:bbox-p\
aths=\x22true\x22\x0a    \
 inkscape:bbox-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-b\
box-edge-midpoin\
ts=\x22true\x22\x0a     i\
nkscape:snap-bbo\
x-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-nodes=\x22tru\
e\x22\x0a     inkscape\
:object-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-intersec\
tion-paths=\x22true\
\x22\x0a     inkscape:\
snap-smooth-node\
s=\x22true\x22\x0a     in\
kscape:snap-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
global=\x22true\x22\x0a  \
   fit-margin-to\
p=\x220\x22\x0a     fit-m\
argin-left=\x220\x22\x0a \
    fit-margin-r\
ight=\x220\x22\x0a     fi\
t-margin-bottom=\
\x220\x22\x0a     inkscap\
e:guide-bbox=\x22tr\
ue\x22>\x0a    <inksca\
pe:grid\x0a       t\
ype=\x22xygrid\x22\x0a   \
    id=\x22grid974\x22\
\x0a       empspaci\
ng=\x228\x22\x0a       sp\
acingx=\x220.264583\
32\x22\x0a       spaci\
ngy=\x220.26458332\x22\
\x0a       dotted=\x22\
false\x22\x0a       vi\
sible=\x22true\x22\x0a   \
    enabled=\x22tru\
e\x22\x0a       snapvi\
siblegridlineson\
ly=\x22true\x22\x0a      \
 originx=\x220\x22\x0a   \
    originy=\x220\x22 \
/>\x0a  </sodipodi:\
namedview>\x0a  <me\
tadata\x0a     id=\x22\
metadata5\x22>\x0a    \
<rdf:RDF>\x0a      \
<cc:Work\x0a       \
  rdf:about=\x22\x22>\x0a\
        <dc:form\
at>image/svg+xml\
</dc:format>\x0a   \
     <dc:type\x0a  \
         rdf:res\
ource=\x22http://pu\
rl.org/dc/dcmity\
pe/StillImage\x22 /\
>\x0a        <dc:ti\
tle></dc:title>\x0a\
      </cc:Work>\
\x0a    </rdf:RDF>\x0a\
  </metadata>\x0a  \
<g\x0a     inkscape\
:label=\x22Layer 1\x22\
\x0a     inkscape:g\
roupmode=\x22layer\x22\
\x0a     id=\x22layer1\
\x22\x0a     transform\
=\x22translate(0,-2\
91.70835)\x22>\x0a    \
<g\x0a       id=\x22g8\
47\x22\x0a       trans\
form=\x22matrix(0.0\
5207439,0,0,0.05\
207453,-0.901251\
64,282.41203)\x22>\x0a\
      <g\x0a       \
  id=\x22g851\x22>\x0a   \
     <g\x0a        \
   id=\x22g1059\x22\x0a  \
         transfo\
rm=\x22matrix(1.998\
6219,0,0,1.99861\
85,17.324484,-31\
3.52314)\x22>\x0a     \
     <path\x0a     \
        inkscape\
:transform-cente\
r-y=\x223.175\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0700\
0433;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22\x0a\
             d=\x22\
M 25.399999,271.\
60002 -8.0000008\
e-7,246.20002 H \
50.799999 Z\x22\x0a   \
          id=\x22pa\
th883\x22\x0a         \
    inkscape:con\
nector-curvature\
=\x220\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22 />\x0a \
         <path\x0a \
            sodi\
podi:nodetypes=\x22\
cccc\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 id=\x22path880\x22\x0a  \
           d=\x22m \
25.399999,271.60\
002 25.399999,25\
.4 H 0 Z\x22\x0a      \
       inkscape:\
transform-center\
-y=\x22-3.1749995\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <rect\x0a         \
    ry=\x225.053465\
8\x22\x0a             \
y=\x22253.84885\x22\x0a  \
           x=\x227.\
6487389\x22\x0a       \
      height=\x2235\
.528759\x22\x0a       \
      width=\x2235.\
528786\x22\x0a        \
     id=\x22rect870\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.06184419;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <circle\x0a     \
        r=\x2225.39\
6828\x22\x0a          \
   cy=\x22271.60001\
\x22\x0a             c\
x=\x2225.4\x22\x0a       \
      id=\x22path87\
2\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07635882;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <circle\x0a    \
         transfo\
rm=\x22rotate(-45)\x22\
\x0a             cx\
=\x22-174.08969\x22\x0a  \
           cy=\x222\
10.01071\x22\x0a      \
       r=\x2212.656\
071\x22\x0a           \
  id=\x22path876\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7399406;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<path\x0a          \
   inkscape:tran\
sform-center-x=\x22\
-3.1749999\x22\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             id\
=\x22path904\x22\x0a     \
        d=\x22m 25.\
4,271.60002 -25.\
40000040000004,2\
5.4 v -50.8 z\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<path\x0a          \
   inkscape:tran\
sform-center-x=\x22\
3.175\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22\x0a     \
        d=\x22m 25.\
399999,271.60002\
 25.4,-25.4 v 50\
.8 z\x22\x0a          \
   id=\x22path906\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22 />\x0a        \
  <rect\x0a        \
     ry=\x225.05149\
22\x22\x0a            \
 y=\x22256.39301\x22\x0a \
            x=\x222\
.5663135\x22\x0a      \
       height=\x223\
0.440479\x22\x0a      \
       width=\x2245\
.693634\x22\x0a       \
      id=\x22rect83\
7\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.0657438;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <rect\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0657438\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22\x0a    \
         id=\x22rec\
t831\x22\x0a          \
   width=\x2245.693\
588\x22\x0a           \
  height=\x2230.440\
51\x22\x0a            \
 x=\x22248.76645\x22\x0a \
            y=\x22-\
40.633385\x22\x0a     \
        ry=\x225.05\
1497\x22\x0a          \
   transform=\x22ro\
tate(90)\x22 />\x0a   \
     </g>\x0a      \
</g>\x0a    </g>\x0a  \
  <path\x0a       s\
tyle=\x22opacity:1;\
fill:#ffc107;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:0.38596651;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-opacity:1\x22\x0a    \
   d=\x22m 50.20642\
1,401.67683 c 11\
0.217209,0.71279\
 55.108609,0.356\
4 0,0 z\x22\x0a       \
id=\x22rect997\x22\x0a   \
    inkscape:con\
nector-curvature\
=\x220\x22 />\x0a  </g>\x0a<\
/svg>\x0a\
\x00\x00)I\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22siz\
egrip.svg\x22\x0a   in\
kscape:export-fi\
lename=\x22/home/ye\
ison/Development\
/piton/art/icon_\
lite.png\x22\x0a   ink\
scape:export-xdp\
i=\x2296\x22\x0a   inksca\
pe:export-ydpi=\x22\
96\x22>\x0a  <defs\x0a   \
  id=\x22defs2\x22 />\x0a\
  <sodipodi:name\
dview\x0a     id=\x22b\
ase\x22\x0a     pageco\
lor=\x22#ffffff\x22\x0a  \
   bordercolor=\x22\
#666666\x22\x0a     bo\
rderopacity=\x221.0\
\x22\x0a     inkscape:\
pageopacity=\x220.0\
\x22\x0a     inkscape:\
pageshadow=\x222\x22\x0a \
    inkscape:zoo\
m=\x2216\x22\x0a     inks\
cape:cx=\x224.85602\
4\x22\x0a     inkscape\
:cy=\x229.6877956\x22\x0a\
     inkscape:do\
cument-units=\x22px\
\x22\x0a     inkscape:\
current-layer=\x22l\
ayer1\x22\x0a     show\
grid=\x22true\x22\x0a    \
 inkscape:window\
-width=\x221920\x22\x0a  \
   inkscape:wind\
ow-height=\x221004\x22\
\x0a     inkscape:w\
indow-x=\x220\x22\x0a    \
 inkscape:window\
-y=\x220\x22\x0a     inks\
cape:window-maxi\
mized=\x221\x22\x0a     i\
nkscape:showpage\
shadow=\x22false\x22\x0a \
    units=\x22px\x22\x0a \
    inkscape:pag\
echeckerboard=\x22f\
alse\x22\x0a     showg\
uides=\x22true\x22\x0a   \
  inkscape:snap-\
bbox=\x22true\x22\x0a    \
 inkscape:bbox-p\
aths=\x22true\x22\x0a    \
 inkscape:bbox-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-b\
box-edge-midpoin\
ts=\x22true\x22\x0a     i\
nkscape:snap-bbo\
x-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-nodes=\x22tru\
e\x22\x0a     inkscape\
:object-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-intersec\
tion-paths=\x22true\
\x22\x0a     inkscape:\
snap-smooth-node\
s=\x22true\x22\x0a     in\
kscape:snap-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
global=\x22true\x22\x0a  \
   fit-margin-to\
p=\x220\x22\x0a     fit-m\
argin-left=\x220\x22\x0a \
    fit-margin-r\
ight=\x220\x22\x0a     fi\
t-margin-bottom=\
\x220\x22\x0a     inkscap\
e:guide-bbox=\x22tr\
ue\x22>\x0a    <inksca\
pe:grid\x0a       t\
ype=\x22xygrid\x22\x0a   \
    id=\x22grid974\x22\
\x0a       empspaci\
ng=\x228\x22\x0a       sp\
acingx=\x220.264583\
32\x22\x0a       spaci\
ngy=\x220.26458332\x22\
\x0a       dotted=\x22\
false\x22\x0a       vi\
sible=\x22true\x22\x0a   \
    enabled=\x22tru\
e\x22\x0a       snapvi\
siblegridlineson\
ly=\x22true\x22\x0a      \
 originx=\x220\x22\x0a   \
    originy=\x220\x22 \
/>\x0a  </sodipodi:\
namedview>\x0a  <me\
tadata\x0a     id=\x22\
metadata5\x22>\x0a    \
<rdf:RDF>\x0a      \
<cc:Work\x0a       \
  rdf:about=\x22\x22>\x0a\
        <dc:form\
at>image/svg+xml\
</dc:format>\x0a   \
     <dc:type\x0a  \
         rdf:res\
ource=\x22http://pu\
rl.org/dc/dcmity\
pe/StillImage\x22 /\
>\x0a        <dc:ti\
tle />\x0a      </c\
c:Work>\x0a    </rd\
f:RDF>\x0a  </metad\
ata>\x0a  <g\x0a     i\
nkscape:label=\x22L\
ayer 1\x22\x0a     ink\
scape:groupmode=\
\x22layer\x22\x0a     id=\
\x22layer1\x22\x0a     tr\
ansform=\x22transla\
te(0,-291.70835)\
\x22>\x0a    <g\x0a      \
 id=\x22g847\x22\x0a     \
  transform=\x22mat\
rix(0.05207439,0\
,0,0.05207453,-0\
.90125164,282.41\
203)\x22>\x0a      <g\x0a\
         id=\x22g85\
1\x22>\x0a        <g\x0a \
          id=\x22g1\
059\x22\x0a           \
transform=\x22matri\
x(1.9986219,0,0,\
1.9986185,17.324\
484,-313.52314)\x22\
>\x0a          <pat\
h\x0a             i\
nkscape:transfor\
m-center-y=\x223.17\
5\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07000433;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22\x0a         \
    d=\x22M 25.3999\
99,271.60002 -8.\
0000008e-7,246.2\
0002 H 50.799999\
 Z\x22\x0a            \
 id=\x22path883\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22 />\x0a          \
<path\x0a          \
   sodipodi:node\
types=\x22cccc\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        id=\x22path\
880\x22\x0a           \
  d=\x22m 25.399999\
,271.60002 25.39\
9999,25.4 H 0 Z\x22\
\x0a             in\
kscape:transform\
-center-y=\x22-3.17\
49995\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22 />\x0a  \
        <rect\x0a  \
           ry=\x225\
.0534658\x22\x0a      \
       y=\x22253.84\
885\x22\x0a           \
  x=\x227.6487389\x22\x0a\
             hei\
ght=\x2235.528759\x22\x0a\
             wid\
th=\x2235.528786\x22\x0a \
            id=\x22\
rect870\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0618441\
9;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <circl\
e\x0a             r\
=\x2225.396828\x22\x0a   \
          cy=\x2227\
1.60001\x22\x0a       \
      cx=\x2225.4\x22\x0a\
             id=\
\x22path872\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.076358\
82;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <circ\
le\x0a             \
transform=\x22rotat\
e(-45)\x22\x0a        \
     cx=\x22-174.08\
969\x22\x0a           \
  cy=\x22210.01071\x22\
\x0a             r=\
\x2212.656071\x22\x0a    \
         id=\x22pat\
h876\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07399406;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-x=\x22-3.174999\
9\x22\x0a             \
sodipodi:nodetyp\
es=\x22cccc\x22\x0a      \
       inkscape:\
connector-curvat\
ure=\x220\x22\x0a        \
     id=\x22path904\
\x22\x0a             d\
=\x22m 25.4,271.600\
02 -25.400000400\
00004,25.4 v -50\
.8 z\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-x=\x223.175\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a             d\
=\x22m 25.399999,27\
1.60002 25.4,-25\
.4 v 50.8 z\x22\x0a   \
          id=\x22pa\
th906\x22\x0a         \
    inkscape:con\
nector-curvature\
=\x220\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22 />\x0a \
         <rect\x0a \
            ry=\x22\
5.0514922\x22\x0a     \
        y=\x22256.3\
9301\x22\x0a          \
   x=\x222.5663135\x22\
\x0a             he\
ight=\x2230.440479\x22\
\x0a             wi\
dth=\x2245.693634\x22\x0a\
             id=\
\x22rect837\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.065743\
8;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
id=\x22rect831\x22\x0a   \
          width=\
\x2245.693588\x22\x0a    \
         height=\
\x2230.44051\x22\x0a     \
        x=\x22248.7\
6645\x22\x0a          \
   y=\x22-40.633385\
\x22\x0a             r\
y=\x225.051497\x22\x0a   \
          transf\
orm=\x22rotate(90)\x22\
 />\x0a        </g>\
\x0a      </g>\x0a    \
</g>\x0a    <path\x0a \
      style=\x22opa\
city:1;fill:#ffc\
107;fill-opacity\
:1;stroke:none;s\
troke-width:0.38\
596651;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-opacity:\
1\x22\x0a       d=\x22m 5\
0.206421,401.676\
83 c 110.217209,\
0.71279 55.10860\
9,0.3564 0,0 z\x22\x0a\
       id=\x22rect9\
97\x22\x0a       inksc\
ape:connector-cu\
rvature=\x220\x22 />\x0a \
   <rect\x0a       \
style=\x22opacity:1\
;fill:#ff0000;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:1.05832505\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1\x22\x0a    \
   id=\x22rect832\x22\x0a\
       width=\x220.\
52916664\x22\x0a      \
 height=\x220.52915\
841\x22\x0a       x=\x224\
.2333331\x22\x0a      \
 y=\x22295.94168\x22 /\
>\x0a    <rect\x0a    \
   y=\x22295.94168\x22\
\x0a       x=\x221.058\
3333\x22\x0a       hei\
ght=\x220.52915841\x22\
\x0a       width=\x220\
.52916664\x22\x0a     \
  id=\x22rect836\x22\x0a \
      style=\x22opa\
city:1;fill:#ff0\
000;fill-opacity\
:1;stroke:none;s\
troke-width:1.05\
832505;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
\x22 />\x0a    <rect\x0a \
      style=\x22opa\
city:1;fill:#ff0\
000;fill-opacity\
:1;stroke:none;s\
troke-width:1.05\
832505;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
\x22\x0a       id=\x22rec\
t838\x22\x0a       wid\
th=\x220.52916664\x22\x0a\
       height=\x220\
.52915841\x22\x0a     \
  x=\x222.6458333\x22\x0a\
       y=\x22295.94\
168\x22 />\x0a    <rec\
t\x0a       y=\x22292.\
76669\x22\x0a       x=\
\x224.2333331\x22\x0a    \
   height=\x220.529\
15841\x22\x0a       wi\
dth=\x220.52916664\x22\
\x0a       id=\x22rect\
840\x22\x0a       styl\
e=\x22opacity:1;fil\
l:#ff0000;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:1.05832505;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22 />\x0a    <\
rect\x0a       styl\
e=\x22opacity:1;fil\
l:#ff0000;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:1.05832505;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22\x0a       i\
d=\x22rect842\x22\x0a    \
   width=\x220.5291\
6664\x22\x0a       hei\
ght=\x220.52915841\x22\
\x0a       x=\x221.852\
0832\x22\x0a       y=\x22\
295.14795\x22 />\x0a  \
  <rect\x0a       s\
tyle=\x22opacity:1;\
fill:#ff0000;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:1.05832505;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1\x22\x0a     \
  id=\x22rect844\x22\x0a \
      width=\x220.5\
2916664\x22\x0a       \
height=\x220.529158\
41\x22\x0a       x=\x223.\
4395831\x22\x0a       \
y=\x22295.14795\x22 />\
\x0a    <rect\x0a     \
  y=\x22294.35419\x22\x0a\
       x=\x224.2333\
331\x22\x0a       heig\
ht=\x220.52915841\x22\x0a\
       width=\x220.\
52916664\x22\x0a      \
 id=\x22rect846\x22\x0a  \
     style=\x22opac\
ity:1;fill:#ff00\
00;fill-opacity:\
1;stroke:none;st\
roke-width:1.058\
32505;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1\x22\
 />\x0a    <rect\x0a  \
     style=\x22opac\
ity:1;fill:#ff00\
00;fill-opacity:\
1;stroke:none;st\
roke-width:1.058\
32505;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1\x22\
\x0a       id=\x22rect\
848\x22\x0a       widt\
h=\x220.52916664\x22\x0a \
      height=\x220.\
52915841\x22\x0a      \
 x=\x223.4395831\x22\x0a \
      y=\x22293.560\
42\x22 />\x0a    <rect\
\x0a       style=\x22o\
pacity:1;fill:#f\
f0000;fill-opaci\
ty:1;stroke:none\
;stroke-width:1.\
05832505;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22\x0a       id=\x22r\
ect852\x22\x0a       w\
idth=\x220.52916664\
\x22\x0a       height=\
\x220.52915841\x22\x0a   \
    x=\x222.6458333\
\x22\x0a       y=\x22294.\
35419\x22 />\x0a  </g>\
\x0a</svg>\x0a\
\x00\x00!#\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22dow\
narrow.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2211.745467\x22\x0a \
    inkscape:cx=\
\x22-8.0020924\x22\x0a   \
  inkscape:cy=\x22-\
13.919269\x22\x0a     \
inkscape:documen\
t-units=\x22px\x22\x0a   \
  inkscape:curre\
nt-layer=\x22layer1\
\x22\x0a     showgrid=\
\x22true\x22\x0a     inks\
cape:window-widt\
h=\x221920\x22\x0a     in\
kscape:window-he\
ight=\x221015\x22\x0a    \
 inkscape:window\
-x=\x220\x22\x0a     inks\
cape:window-y=\x220\
\x22\x0a     inkscape:\
window-maximized\
=\x221\x22\x0a     inksca\
pe:showpageshado\
w=\x22false\x22\x0a     u\
nits=\x22px\x22\x0a     i\
nkscape:pagechec\
kerboard=\x22false\x22\
\x0a     showguides\
=\x22true\x22\x0a     ink\
scape:snap-bbox=\
\x22true\x22\x0a     inks\
cape:bbox-paths=\
\x22true\x22\x0a     inks\
cape:bbox-nodes=\
\x22true\x22\x0a     inks\
cape:snap-bbox-e\
dge-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-bbox-mid\
points=\x22true\x22\x0a  \
   inkscape:snap\
-nodes=\x22true\x22\x0a  \
   inkscape:obje\
ct-paths=\x22true\x22\x0a\
     inkscape:sn\
ap-intersection-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
smooth-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-midpoints\
=\x22true\x22\x0a     ink\
scape:snap-globa\
l=\x22true\x22\x0a     fi\
t-margin-top=\x220\x22\
\x0a     fit-margin\
-left=\x220\x22\x0a     f\
it-margin-right=\
\x220\x22\x0a     fit-mar\
gin-bottom=\x220\x22\x0a \
    inkscape:gui\
de-bbox=\x22true\x22>\x0a\
    <inkscape:gr\
id\x0a       type=\x22\
xygrid\x22\x0a       i\
d=\x22grid974\x22\x0a    \
   empspacing=\x228\
\x22\x0a       spacing\
x=\x220.26458332\x22\x0a \
      spacingy=\x22\
0.26458332\x22\x0a    \
   dotted=\x22false\
\x22\x0a       visible\
=\x22true\x22\x0a       e\
nabled=\x22true\x22\x0a  \
     snapvisible\
gridlinesonly=\x22t\
rue\x22\x0a       orig\
inx=\x220\x22\x0a       o\
riginy=\x220\x22 />\x0a  \
</sodipodi:named\
view>\x0a  <metadat\
a\x0a     id=\x22metad\
ata5\x22>\x0a    <rdf:\
RDF>\x0a      <cc:W\
ork\x0a         rdf\
:about=\x22\x22>\x0a     \
   <dc:format>im\
age/svg+xml</dc:\
format>\x0a        \
<dc:type\x0a       \
    rdf:resource\
=\x22http://purl.or\
g/dc/dcmitype/St\
illImage\x22 />\x0a   \
     <dc:title><\
/dc:title>\x0a     \
 </cc:Work>\x0a    \
</rdf:RDF>\x0a  </m\
etadata>\x0a  <g\x0a  \
   inkscape:labe\
l=\x22Layer 1\x22\x0a    \
 inkscape:groupm\
ode=\x22layer\x22\x0a    \
 id=\x22layer1\x22\x0a   \
  transform=\x22tra\
nslate(0,-291.70\
835)\x22>\x0a    <g\x0a  \
     id=\x22g847\x22\x0a \
      transform=\
\x22matrix(0.052074\
39,0,0,0.0520745\
3,-0.90125164,28\
2.41203)\x22>\x0a     \
 <g\x0a         id=\
\x22g851\x22>\x0a        \
<g\x0a           id\
=\x22g1059\x22\x0a       \
    transform=\x22m\
atrix(1.9986219,\
0,0,1.9986185,17\
.324484,-313.523\
14)\x22>\x0a          \
<path\x0a          \
   inkscape:tran\
sform-center-y=\x22\
3.175\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22\x0a     \
        d=\x22M 25.\
399999,271.60002\
 -8.0000008e-7,2\
46.20002 H 50.79\
9999 Z\x22\x0a        \
     id=\x22path883\
\x22\x0a             i\
nkscape:connecto\
r-curvature=\x220\x22\x0a\
             sod\
ipodi:nodetypes=\
\x22cccc\x22 />\x0a      \
    <path\x0a      \
       sodipodi:\
nodetypes=\x22cccc\x22\
\x0a             in\
kscape:connector\
-curvature=\x220\x22\x0a \
            id=\x22\
path880\x22\x0a       \
      d=\x22m 25.39\
9999,271.60002 2\
5.399999,25.4 H \
0 Z\x22\x0a           \
  inkscape:trans\
form-center-y=\x22-\
3.1749995\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.07000\
433;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <rec\
t\x0a             r\
y=\x225.0534658\x22\x0a  \
           y=\x2225\
3.84885\x22\x0a       \
      x=\x227.64873\
89\x22\x0a            \
 height=\x2235.5287\
59\x22\x0a            \
 width=\x2235.52878\
6\x22\x0a             \
id=\x22rect870\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.061\
84419;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <c\
ircle\x0a          \
   r=\x2225.396828\x22\
\x0a             cy\
=\x22271.60001\x22\x0a   \
          cx=\x2225\
.4\x22\x0a            \
 id=\x22path872\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
635882;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
circle\x0a         \
    transform=\x22r\
otate(-45)\x22\x0a    \
         cx=\x22-17\
4.08969\x22\x0a       \
      cy=\x22210.01\
071\x22\x0a           \
  r=\x2212.656071\x22\x0a\
             id=\
\x22path876\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.073994\
06;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <path\
\x0a             in\
kscape:transform\
-center-x=\x22-3.17\
49999\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         id=\x22pat\
h904\x22\x0a          \
   d=\x22m 25.4,271\
.60002 -25.40000\
040000004,25.4 v\
 -50.8 z\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.070004\
33;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <path\
\x0a             in\
kscape:transform\
-center-x=\x223.175\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22\x0a          \
   d=\x22m 25.39999\
9,271.60002 25.4\
,-25.4 v 50.8 z\x22\
\x0a             id\
=\x22path906\x22\x0a     \
        inkscape\
:connector-curva\
ture=\x220\x22\x0a       \
      sodipodi:n\
odetypes=\x22cccc\x22 \
/>\x0a          <re\
ct\x0a             \
ry=\x225.0514922\x22\x0a \
            y=\x222\
56.39301\x22\x0a      \
       x=\x222.5663\
135\x22\x0a           \
  height=\x2230.440\
479\x22\x0a           \
  width=\x2245.6936\
34\x22\x0a            \
 id=\x22rect837\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.06\
57438;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <r\
ect\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.0657438;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22\x0a         \
    id=\x22rect831\x22\
\x0a             wi\
dth=\x2245.693588\x22\x0a\
             hei\
ght=\x2230.44051\x22\x0a \
            x=\x222\
48.76645\x22\x0a      \
       y=\x22-40.63\
3385\x22\x0a          \
   ry=\x225.051497\x22\
\x0a             tr\
ansform=\x22rotate(\
90)\x22 />\x0a        \
</g>\x0a      </g>\x0a\
    </g>\x0a    <pa\
th\x0a       style=\
\x22opacity:1;fill:\
#ffc107;fill-opa\
city:1;stroke:no\
ne;stroke-width:\
0.38596651;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-opac\
ity:1\x22\x0a       d=\
\x22m 50.206421,401\
.67683 c 110.217\
209,0.71279 55.1\
08609,0.3564 0,0\
 z\x22\x0a       id=\x22r\
ect997\x22\x0a       i\
nkscape:connecto\
r-curvature=\x220\x22 \
/>\x0a    <path\x0a   \
    sodipodi:typ\
e=\x22star\x22\x0a       \
style=\x22opacity:1\
;fill:#ff0000;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:1.38742065\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22\x0a    \
   id=\x22path828\x22\x0a\
       sodipodi:\
sides=\x223\x22\x0a      \
 sodipodi:cx=\x22-2\
.6458383\x22\x0a      \
 sodipodi:cy=\x22-2\
94.16339\x22\x0a      \
 sodipodi:r1=\x221.\
3874207\x22\x0a       \
sodipodi:r2=\x220.6\
9371033\x22\x0a       \
sodipodi:arg1=\x221\
.5707963\x22\x0a      \
 sodipodi:arg2=\x22\
2.6179939\x22\x0a     \
  inkscape:flats\
ided=\x22true\x22\x0a    \
   inkscape:roun\
ded=\x220.1\x22\x0a      \
 inkscape:random\
ized=\x220\x22\x0a       \
d=\x22m -2.6458382,\
-292.77597 c -0.\
2403083,0 -1.321\
6958,-1.87302 -1\
.2015416,-2.0811\
3 0.1201541,-0.2\
0811 2.2829289,-\
0.20811 2.403083\
1,0 0.1201541,0.\
20811 -0.9612332\
,2.08113 -1.2015\
415,2.08113 z\x22\x0a \
      inkscape:t\
ransform-center-\
y=\x22-0.22979664\x22\x0a\
       transform\
=\x22scale(-1)\x22\x0a   \
    inkscape:tra\
nsform-center-x=\
\x22-5.0457959e-06\x22\
 />\x0a  </g>\x0a</svg\
>\x0a\
\x00\x00\x1f\xb4\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22tab\
_close.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2220.297438\x22\x0a \
    inkscape:cx=\
\x2210.202825\x22\x0a    \
 inkscape:cy=\x228.\
9235955\x22\x0a     in\
kscape:document-\
units=\x22px\x22\x0a     \
inkscape:current\
-layer=\x22layer1\x22\x0a\
     showgrid=\x22t\
rue\x22\x0a     inksca\
pe:window-width=\
\x221920\x22\x0a     inks\
cape:window-heig\
ht=\x221015\x22\x0a     i\
nkscape:window-x\
=\x220\x22\x0a     inksca\
pe:window-y=\x220\x22\x0a\
     inkscape:wi\
ndow-maximized=\x22\
1\x22\x0a     inkscape\
:showpageshadow=\
\x22false\x22\x0a     uni\
ts=\x22px\x22\x0a     ink\
scape:pagechecke\
rboard=\x22false\x22\x0a \
    showguides=\x22\
false\x22\x0a     inks\
cape:snap-bbox=\x22\
true\x22\x0a     inksc\
ape:bbox-paths=\x22\
true\x22\x0a     inksc\
ape:bbox-nodes=\x22\
true\x22\x0a     inksc\
ape:snap-bbox-ed\
ge-midpoints=\x22tr\
ue\x22\x0a     inkscap\
e:snap-bbox-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
nodes=\x22true\x22\x0a   \
  inkscape:objec\
t-paths=\x22true\x22\x0a \
    inkscape:sna\
p-intersection-p\
aths=\x22true\x22\x0a    \
 inkscape:snap-s\
mooth-nodes=\x22tru\
e\x22\x0a     inkscape\
:snap-midpoints=\
\x22true\x22\x0a     inks\
cape:snap-global\
=\x22true\x22\x0a     fit\
-margin-top=\x220\x22\x0a\
     fit-margin-\
left=\x220\x22\x0a     fi\
t-margin-right=\x22\
0\x22\x0a     fit-marg\
in-bottom=\x220\x22\x0a  \
   inkscape:guid\
e-bbox=\x22true\x22>\x0a \
   <inkscape:gri\
d\x0a       type=\x22x\
ygrid\x22\x0a       id\
=\x22grid974\x22\x0a     \
  empspacing=\x228\x22\
\x0a       spacingx\
=\x220.26458332\x22\x0a  \
     spacingy=\x220\
.26458332\x22\x0a     \
  dotted=\x22false\x22\
\x0a       visible=\
\x22true\x22\x0a       en\
abled=\x22true\x22\x0a   \
    snapvisibleg\
ridlinesonly=\x22tr\
ue\x22\x0a       origi\
nx=\x220\x22\x0a       or\
iginy=\x220\x22 />\x0a  <\
/sodipodi:namedv\
iew>\x0a  <metadata\
\x0a     id=\x22metada\
ta5\x22>\x0a    <rdf:R\
DF>\x0a      <cc:Wo\
rk\x0a         rdf:\
about=\x22\x22>\x0a      \
  <dc:format>ima\
ge/svg+xml</dc:f\
ormat>\x0a        <\
dc:type\x0a        \
   rdf:resource=\
\x22http://purl.org\
/dc/dcmitype/Sti\
llImage\x22 />\x0a    \
    <dc:title />\
\x0a      </cc:Work\
>\x0a    </rdf:RDF>\
\x0a  </metadata>\x0a \
 <g\x0a     inkscap\
e:label=\x22Layer 1\
\x22\x0a     inkscape:\
groupmode=\x22layer\
\x22\x0a     id=\x22layer\
1\x22\x0a     transfor\
m=\x22translate(0,-\
291.70835)\x22>\x0a   \
 <g\x0a       id=\x22g\
847\x22\x0a       tran\
sform=\x22matrix(0.\
05207439,0,0,0.0\
5207453,-0.90125\
164,282.41203)\x22>\
\x0a      <g\x0a      \
   id=\x22g851\x22>\x0a  \
      <g\x0a       \
    id=\x22g1059\x22\x0a \
          transf\
orm=\x22matrix(1.99\
86219,0,0,1.9986\
185,17.324484,-3\
13.52314)\x22>\x0a    \
      <path\x0a    \
         inkscap\
e:transform-cent\
er-y=\x223.175\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
\x0a             d=\
\x22M 25.399999,271\
.60002 -8.000000\
8e-7,246.20002 H\
 50.799999 Z\x22\x0a  \
           id=\x22p\
ath883\x22\x0a        \
     inkscape:co\
nnector-curvatur\
e=\x220\x22\x0a          \
   sodipodi:node\
types=\x22cccc\x22 />\x0a\
          <path\x0a\
             sod\
ipodi:nodetypes=\
\x22cccc\x22\x0a         \
    inkscape:con\
nector-curvature\
=\x220\x22\x0a           \
  id=\x22path880\x22\x0a \
            d=\x22m\
 25.399999,271.6\
0002 25.399999,2\
5.4 H 0 Z\x22\x0a     \
        inkscape\
:transform-cente\
r-y=\x22-3.1749995\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.07000433;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <rect\x0a        \
     ry=\x225.05346\
58\x22\x0a            \
 y=\x22253.84885\x22\x0a \
            x=\x227\
.6487389\x22\x0a      \
       height=\x223\
5.528759\x22\x0a      \
       width=\x2235\
.528786\x22\x0a       \
      id=\x22rect87\
0\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.06184419;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <circle\x0a    \
         r=\x2225.3\
96828\x22\x0a         \
    cy=\x22271.6000\
1\x22\x0a             \
cx=\x2225.4\x22\x0a      \
       id=\x22path8\
72\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07635882;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22 />\x0a     \
     <circle\x0a   \
          transf\
orm=\x22rotate(-45)\
\x22\x0a             c\
x=\x22-174.08969\x22\x0a \
            cy=\x22\
210.01071\x22\x0a     \
        r=\x2212.65\
6071\x22\x0a          \
   id=\x22path876\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07399406;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <path\x0a         \
    inkscape:tra\
nsform-center-x=\
\x22-3.1749999\x22\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             i\
d=\x22path904\x22\x0a    \
         d=\x22m 25\
.4,271.60002 -25\
.40000040000004,\
25.4 v -50.8 z\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <path\x0a         \
    inkscape:tra\
nsform-center-x=\
\x223.175\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22\x0a    \
         d=\x22m 25\
.399999,271.6000\
2 25.4,-25.4 v 5\
0.8 z\x22\x0a         \
    id=\x22path906\x22\
\x0a             in\
kscape:connector\
-curvature=\x220\x22\x0a \
            sodi\
podi:nodetypes=\x22\
cccc\x22 />\x0a       \
   <rect\x0a       \
      ry=\x225.0514\
922\x22\x0a           \
  y=\x22256.39301\x22\x0a\
             x=\x22\
2.5663135\x22\x0a     \
        height=\x22\
30.440479\x22\x0a     \
        width=\x224\
5.693634\x22\x0a      \
       id=\x22rect8\
37\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.0657438;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <rect\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.065743\
8;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          id=\x22re\
ct831\x22\x0a         \
    width=\x2245.69\
3588\x22\x0a          \
   height=\x2230.44\
051\x22\x0a           \
  x=\x22248.76645\x22\x0a\
             y=\x22\
-40.633385\x22\x0a    \
         ry=\x225.0\
51497\x22\x0a         \
    transform=\x22r\
otate(90)\x22 />\x0a  \
      </g>\x0a     \
 </g>\x0a    </g>\x0a \
   <path\x0a       \
style=\x22opacity:1\
;fill:#ffc107;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:0.38596651\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-opacity:1\x22\x0a   \
    d=\x22m 50.2064\
21,401.67683 c 1\
10.217209,0.7127\
9 55.108609,0.35\
64 0,0 z\x22\x0a      \
 id=\x22rect997\x22\x0a  \
     inkscape:co\
nnector-curvatur\
e=\x220\x22 />\x0a    <pa\
th\x0a       style=\
\x22fill:#ff0000;st\
roke:#ff0000;str\
oke-width:0.5291\
6664;stroke-line\
cap:butt;stroke-\
linejoin:miter;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
opacity:1\x22\x0a     \
  d=\x22m 0.9809021\
5,292.68924 3.32\
986205,3.32989\x22\x0a\
       id=\x22path8\
26\x22\x0a       inksc\
ape:connector-cu\
rvature=\x220\x22 />\x0a \
   <path\x0a       \
inkscape:connect\
or-curvature=\x220\x22\
\x0a       id=\x22path\
842\x22\x0a       d=\x22m\
 4.3107782,292.6\
8925 -3.32989002\
,3.32987\x22\x0a      \
 style=\x22fill:#ff\
0000;stroke:#ff0\
000;stroke-width\
:0.52916664;stro\
ke-linecap:butt;\
stroke-linejoin:\
miter;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-opacity:1\
\x22 />\x0a  </g>\x0a</sv\
g>\x0a\
\x00\x00$\xad\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22spl\
itter-vertical.s\
vg\x22\x0a   inkscape:\
export-filename=\
\x22/home/yeison/De\
velopment/piton/\
art/icon_lite.pn\
g\x22\x0a   inkscape:e\
xport-xdpi=\x2296\x22\x0a\
   inkscape:expo\
rt-ydpi=\x2296\x22>\x0a  \
<defs\x0a     id=\x22d\
efs2\x22 />\x0a  <sodi\
podi:namedview\x0a \
    id=\x22base\x22\x0a  \
   pagecolor=\x22#f\
fffff\x22\x0a     bord\
ercolor=\x22#666666\
\x22\x0a     borderopa\
city=\x221.0\x22\x0a     \
inkscape:pageopa\
city=\x220.0\x22\x0a     \
inkscape:pagesha\
dow=\x222\x22\x0a     ink\
scape:zoom=\x2224.8\
02598\x22\x0a     inks\
cape:cx=\x226.30230\
18\x22\x0a     inkscap\
e:cy=\x228.969841\x22\x0a\
     inkscape:do\
cument-units=\x22px\
\x22\x0a     inkscape:\
current-layer=\x22l\
ayer1\x22\x0a     show\
grid=\x22true\x22\x0a    \
 inkscape:window\
-width=\x221920\x22\x0a  \
   inkscape:wind\
ow-height=\x221004\x22\
\x0a     inkscape:w\
indow-x=\x220\x22\x0a    \
 inkscape:window\
-y=\x220\x22\x0a     inks\
cape:window-maxi\
mized=\x221\x22\x0a     i\
nkscape:showpage\
shadow=\x22false\x22\x0a \
    units=\x22px\x22\x0a \
    inkscape:pag\
echeckerboard=\x22f\
alse\x22\x0a     showg\
uides=\x22true\x22\x0a   \
  inkscape:snap-\
bbox=\x22true\x22\x0a    \
 inkscape:bbox-p\
aths=\x22true\x22\x0a    \
 inkscape:bbox-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-b\
box-edge-midpoin\
ts=\x22true\x22\x0a     i\
nkscape:snap-bbo\
x-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-nodes=\x22tru\
e\x22\x0a     inkscape\
:object-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-intersec\
tion-paths=\x22true\
\x22\x0a     inkscape:\
snap-smooth-node\
s=\x22true\x22\x0a     in\
kscape:snap-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
global=\x22true\x22\x0a  \
   fit-margin-to\
p=\x220\x22\x0a     fit-m\
argin-left=\x220\x22\x0a \
    fit-margin-r\
ight=\x220\x22\x0a     fi\
t-margin-bottom=\
\x220\x22\x0a     inkscap\
e:guide-bbox=\x22tr\
ue\x22>\x0a    <inksca\
pe:grid\x0a       t\
ype=\x22xygrid\x22\x0a   \
    id=\x22grid974\x22\
\x0a       empspaci\
ng=\x228\x22\x0a       sp\
acingx=\x220.264583\
32\x22\x0a       spaci\
ngy=\x220.26458332\x22\
\x0a       dotted=\x22\
false\x22\x0a       vi\
sible=\x22true\x22\x0a   \
    enabled=\x22tru\
e\x22\x0a       snapvi\
siblegridlineson\
ly=\x22true\x22\x0a      \
 originx=\x220\x22\x0a   \
    originy=\x220\x22 \
/>\x0a  </sodipodi:\
namedview>\x0a  <me\
tadata\x0a     id=\x22\
metadata5\x22>\x0a    \
<rdf:RDF>\x0a      \
<cc:Work\x0a       \
  rdf:about=\x22\x22>\x0a\
        <dc:form\
at>image/svg+xml\
</dc:format>\x0a   \
     <dc:type\x0a  \
         rdf:res\
ource=\x22http://pu\
rl.org/dc/dcmity\
pe/StillImage\x22 /\
>\x0a        <dc:ti\
tle />\x0a      </c\
c:Work>\x0a    </rd\
f:RDF>\x0a  </metad\
ata>\x0a  <g\x0a     i\
nkscape:label=\x22L\
ayer 1\x22\x0a     ink\
scape:groupmode=\
\x22layer\x22\x0a     id=\
\x22layer1\x22\x0a     tr\
ansform=\x22transla\
te(0,-291.70835)\
\x22>\x0a    <g\x0a      \
 id=\x22g847\x22\x0a     \
  transform=\x22mat\
rix(0.05207439,0\
,0,0.05207453,-0\
.90125164,282.41\
203)\x22>\x0a      <g\x0a\
         id=\x22g85\
1\x22>\x0a        <g\x0a \
          id=\x22g1\
059\x22\x0a           \
transform=\x22matri\
x(1.9986219,0,0,\
1.9986185,17.324\
484,-313.52314)\x22\
>\x0a          <pat\
h\x0a             i\
nkscape:transfor\
m-center-y=\x223.17\
5\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07000433;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22\x0a         \
    d=\x22M 25.3999\
99,271.60002 -8.\
0000008e-7,246.2\
0002 H 50.799999\
 Z\x22\x0a            \
 id=\x22path883\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22 />\x0a          \
<path\x0a          \
   sodipodi:node\
types=\x22cccc\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        id=\x22path\
880\x22\x0a           \
  d=\x22m 25.399999\
,271.60002 25.39\
9999,25.4 H 0 Z\x22\
\x0a             in\
kscape:transform\
-center-y=\x22-3.17\
49995\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22 />\x0a  \
        <rect\x0a  \
           ry=\x225\
.0534658\x22\x0a      \
       y=\x22253.84\
885\x22\x0a           \
  x=\x227.6487389\x22\x0a\
             hei\
ght=\x2235.528759\x22\x0a\
             wid\
th=\x2235.528786\x22\x0a \
            id=\x22\
rect870\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0618441\
9;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <circl\
e\x0a             r\
=\x2225.396828\x22\x0a   \
          cy=\x2227\
1.60001\x22\x0a       \
      cx=\x2225.4\x22\x0a\
             id=\
\x22path872\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.076358\
82;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <circ\
le\x0a             \
transform=\x22rotat\
e(-45)\x22\x0a        \
     cx=\x22-174.08\
969\x22\x0a           \
  cy=\x22210.01071\x22\
\x0a             r=\
\x2212.656071\x22\x0a    \
         id=\x22pat\
h876\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07399406;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-x=\x22-3.174999\
9\x22\x0a             \
sodipodi:nodetyp\
es=\x22cccc\x22\x0a      \
       inkscape:\
connector-curvat\
ure=\x220\x22\x0a        \
     id=\x22path904\
\x22\x0a             d\
=\x22m 25.4,271.600\
02 -25.400000400\
00004,25.4 v -50\
.8 z\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-x=\x223.175\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a             d\
=\x22m 25.399999,27\
1.60002 25.4,-25\
.4 v 50.8 z\x22\x0a   \
          id=\x22pa\
th906\x22\x0a         \
    inkscape:con\
nector-curvature\
=\x220\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22 />\x0a \
         <rect\x0a \
            ry=\x22\
5.0514922\x22\x0a     \
        y=\x22256.3\
9301\x22\x0a          \
   x=\x222.5663135\x22\
\x0a             he\
ight=\x2230.440479\x22\
\x0a             wi\
dth=\x2245.693634\x22\x0a\
             id=\
\x22rect837\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.065743\
8;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
id=\x22rect831\x22\x0a   \
          width=\
\x2245.693588\x22\x0a    \
         height=\
\x2230.44051\x22\x0a     \
        x=\x22248.7\
6645\x22\x0a          \
   y=\x22-40.633385\
\x22\x0a             r\
y=\x225.051497\x22\x0a   \
          transf\
orm=\x22rotate(90)\x22\
 />\x0a        </g>\
\x0a      </g>\x0a    \
</g>\x0a    <path\x0a \
      style=\x22opa\
city:1;fill:#ffc\
107;fill-opacity\
:1;stroke:none;s\
troke-width:0.38\
596651;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-opacity:\
1\x22\x0a       d=\x22m 5\
0.206421,401.676\
83 c 110.217209,\
0.71279 55.10860\
9,0.3564 0,0 z\x22\x0a\
       id=\x22rect9\
97\x22\x0a       inksc\
ape:connector-cu\
rvature=\x220\x22 />\x0a \
   <g\x0a       id=\
\x22g839\x22\x0a       tr\
ansform=\x22matrix(\
0,-1,-1,0,297.00\
002,297.00002)\x22>\
\x0a      <rect\x0a   \
      y=\x22291.972\
93\x22\x0a         x=\x22\
2.3812499\x22\x0a     \
    height=\x220.52\
916664\x22\x0a        \
 width=\x220.529166\
64\x22\x0a         id=\
\x22rect827\x22\x0a      \
   style=\x22opacit\
y:1;fill:#ff0000\
;fill-opacity:1;\
stroke:none;stro\
ke-width:0.52916\
664;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1\x22 /\
>\x0a      <rect\x0a  \
       style=\x22op\
acity:1;fill:#ff\
0000;fill-opacit\
y:1;stroke:none;\
stroke-width:0.5\
2916664;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1\x22\x0a         id=\x22\
rect829\x22\x0a       \
  width=\x220.52916\
664\x22\x0a         he\
ight=\x220.52916664\
\x22\x0a         x=\x222.\
3812499\x22\x0a       \
  y=\x22296.20627\x22 \
/>\x0a      <rect\x0a \
        y=\x22295.1\
4792\x22\x0a         x\
=\x222.3812499\x22\x0a   \
      height=\x220.\
52916664\x22\x0a      \
   width=\x220.5291\
6664\x22\x0a         i\
d=\x22rect832\x22\x0a    \
     style=\x22opac\
ity:1;fill:#ff00\
00;fill-opacity:\
1;stroke:none;st\
roke-width:0.529\
16664;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1\x22\
 />\x0a      <rect\x0a\
         style=\x22\
opacity:1;fill:#\
ff0000;fill-opac\
ity:1;stroke:non\
e;stroke-width:0\
.52916664;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1\x22\x0a         id\
=\x22rect834\x22\x0a     \
    width=\x220.529\
16664\x22\x0a         \
height=\x220.529166\
64\x22\x0a         x=\x22\
2.3812499\x22\x0a     \
    y=\x22294.0896\x22\
 />\x0a      <rect\x0a\
         y=\x22293.\
03128\x22\x0a         \
x=\x222.3812499\x22\x0a  \
       height=\x220\
.52916664\x22\x0a     \
    width=\x220.529\
16664\x22\x0a         \
id=\x22rect836\x22\x0a   \
      style=\x22opa\
city:1;fill:#ff0\
000;fill-opacity\
:1;stroke:none;s\
troke-width:0.52\
916664;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
\x22 />\x0a    </g>\x0a  \
</g>\x0a</svg>\x0a\
\x00\x00\x1f\xef\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22sli\
der.svg\x22\x0a   inks\
cape:export-file\
name=\x22/home/yeis\
on/Development/p\
iton/art/icon_li\
te.png\x22\x0a   inksc\
ape:export-xdpi=\
\x2296\x22\x0a   inkscape\
:export-ydpi=\x2296\
\x22>\x0a  <defs\x0a     \
id=\x22defs2\x22 />\x0a  \
<sodipodi:namedv\
iew\x0a     id=\x22bas\
e\x22\x0a     pagecolo\
r=\x22#ffffff\x22\x0a    \
 bordercolor=\x22#6\
66666\x22\x0a     bord\
eropacity=\x221.0\x22\x0a\
     inkscape:pa\
geopacity=\x220.0\x22\x0a\
     inkscape:pa\
geshadow=\x222\x22\x0a   \
  inkscape:zoom=\
\x2228.704913\x22\x0a    \
 inkscape:cx=\x228.\
5671075\x22\x0a     in\
kscape:cy=\x228.802\
1939\x22\x0a     inksc\
ape:document-uni\
ts=\x22px\x22\x0a     ink\
scape:current-la\
yer=\x22layer1\x22\x0a   \
  showgrid=\x22true\
\x22\x0a     inkscape:\
window-width=\x2219\
20\x22\x0a     inkscap\
e:window-height=\
\x221015\x22\x0a     inks\
cape:window-x=\x220\
\x22\x0a     inkscape:\
window-y=\x220\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22\x0a\
     inkscape:sh\
owpageshadow=\x22fa\
lse\x22\x0a     units=\
\x22px\x22\x0a     inksca\
pe:pagecheckerbo\
ard=\x22false\x22\x0a    \
 showguides=\x22tru\
e\x22\x0a     inkscape\
:snap-bbox=\x22true\
\x22\x0a     inkscape:\
bbox-paths=\x22true\
\x22\x0a     inkscape:\
bbox-nodes=\x22true\
\x22\x0a     inkscape:\
snap-bbox-edge-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-node\
s=\x22true\x22\x0a     in\
kscape:object-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-in\
tersection-paths\
=\x22true\x22\x0a     ink\
scape:snap-smoot\
h-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-global=\x22tr\
ue\x22\x0a     fit-mar\
gin-top=\x220\x22\x0a    \
 fit-margin-left\
=\x220\x22\x0a     fit-ma\
rgin-right=\x220\x22\x0a \
    fit-margin-b\
ottom=\x220\x22\x0a     i\
nkscape:guide-bb\
ox=\x22true\x22>\x0a    <\
inkscape:grid\x0a  \
     type=\x22xygri\
d\x22\x0a       id=\x22gr\
id974\x22\x0a       em\
pspacing=\x228\x22\x0a   \
    spacingx=\x220.\
26458332\x22\x0a      \
 spacingy=\x220.264\
58332\x22\x0a       do\
tted=\x22false\x22\x0a   \
    visible=\x22tru\
e\x22\x0a       enable\
d=\x22true\x22\x0a       \
snapvisiblegridl\
inesonly=\x22true\x22\x0a\
       originx=\x22\
0\x22\x0a       origin\
y=\x220\x22 />\x0a  </sod\
ipodi:namedview>\
\x0a  <metadata\x0a   \
  id=\x22metadata5\x22\
>\x0a    <rdf:RDF>\x0a\
      <cc:Work\x0a \
        rdf:abou\
t=\x22\x22>\x0a        <d\
c:format>image/s\
vg+xml</dc:forma\
t>\x0a        <dc:t\
ype\x0a           r\
df:resource=\x22htt\
p://purl.org/dc/\
dcmitype/StillIm\
age\x22 />\x0a        \
<dc:title />\x0a   \
   </cc:Work>\x0a  \
  </rdf:RDF>\x0a  <\
/metadata>\x0a  <g\x0a\
     inkscape:la\
bel=\x22Layer 1\x22\x0a  \
   inkscape:grou\
pmode=\x22layer\x22\x0a  \
   id=\x22layer1\x22\x0a \
    transform=\x22t\
ranslate(0,-291.\
70835)\x22>\x0a    <g\x0a\
       id=\x22g847\x22\
\x0a       transfor\
m=\x22matrix(0.0520\
7439,0,0,0.05207\
453,-0.90125164,\
282.41203)\x22>\x0a   \
   <g\x0a         i\
d=\x22g851\x22>\x0a      \
  <g\x0a           \
id=\x22g1059\x22\x0a     \
      transform=\
\x22matrix(1.998621\
9,0,0,1.9986185,\
17.324484,-313.5\
2314)\x22>\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-y\
=\x223.175\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          d=\x22M 2\
5.399999,271.600\
02 -8.0000008e-7\
,246.20002 H 50.\
799999 Z\x22\x0a      \
       id=\x22path8\
83\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22 />\x0a    \
      <path\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             id\
=\x22path880\x22\x0a     \
        d=\x22m 25.\
399999,271.60002\
 25.399999,25.4 \
H 0 Z\x22\x0a         \
    inkscape:tra\
nsform-center-y=\
\x22-3.1749995\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <r\
ect\x0a            \
 ry=\x225.0534658\x22\x0a\
             y=\x22\
253.84885\x22\x0a     \
        x=\x227.648\
7389\x22\x0a          \
   height=\x2235.52\
8759\x22\x0a          \
   width=\x2235.528\
786\x22\x0a           \
  id=\x22rect870\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
6184419;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<circle\x0a        \
     r=\x2225.39682\
8\x22\x0a             \
cy=\x22271.60001\x22\x0a \
            cx=\x22\
25.4\x22\x0a          \
   id=\x22path872\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07635882;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <circle\x0a       \
      transform=\
\x22rotate(-45)\x22\x0a  \
           cx=\x22-\
174.08969\x22\x0a     \
        cy=\x22210.\
01071\x22\x0a         \
    r=\x2212.656071\
\x22\x0a             i\
d=\x22path876\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0739\
9406;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x22-3.\
1749999\x22\x0a       \
      sodipodi:n\
odetypes=\x22cccc\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           id=\x22p\
ath904\x22\x0a        \
     d=\x22m 25.4,2\
71.60002 -25.400\
00040000004,25.4\
 v -50.8 z\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0700\
0433;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x223.1\
75\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07000433;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a        \
     d=\x22m 25.399\
999,271.60002 25\
.4,-25.4 v 50.8 \
z\x22\x0a             \
id=\x22path906\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22 />\x0a          <\
rect\x0a           \
  ry=\x225.0514922\x22\
\x0a             y=\
\x22256.39301\x22\x0a    \
         x=\x222.56\
63135\x22\x0a         \
    height=\x2230.4\
40479\x22\x0a         \
    width=\x2245.69\
3634\x22\x0a          \
   id=\x22rect837\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      id=\x22rect83\
1\x22\x0a             \
width=\x2245.693588\
\x22\x0a             h\
eight=\x2230.44051\x22\
\x0a             x=\
\x22248.76645\x22\x0a    \
         y=\x22-40.\
633385\x22\x0a        \
     ry=\x225.05149\
7\x22\x0a             \
transform=\x22rotat\
e(90)\x22 />\x0a      \
  </g>\x0a      </g\
>\x0a    </g>\x0a    <\
path\x0a       styl\
e=\x22opacity:1;fil\
l:#ffc107;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.38596651;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-op\
acity:1\x22\x0a       \
d=\x22m 50.206421,4\
01.67683 c 110.2\
17209,0.71279 55\
.108609,0.3564 0\
,0 z\x22\x0a       id=\
\x22rect997\x22\x0a      \
 inkscape:connec\
tor-curvature=\x220\
\x22 />\x0a    <path\x0a \
      style=\x22opa\
city:1;fill:#ff0\
000;fill-opacity\
:1;stroke:none;s\
troke-width:3;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
d=\x22M 10,0.013671\
88 C 4.4846749,0\
.01360343 0.0136\
0343,4.4846749 0\
.01367188,10 0.0\
136035,15.515325\
 4.484675,19.986\
396 10,19.986328\
 15.515325,19.98\
6396 19.986396,1\
5.515325 19.9863\
28,10 19.986396,\
4.484675 15.5153\
25,0.0136035 10,\
0.01367188 Z\x22\x0a  \
     transform=\x22\
matrix(0.2645833\
2,0,0,0.26458332\
,0,291.70835)\x22\x0a \
      id=\x22path82\
6\x22\x0a       inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
  sodipodi:nodet\
ypes=\x22ccccc\x22 />\x0a\
  </g>\x0a</svg>\x0a\
\x00\x00\x1f\xaf\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22che\
ckbox_indetermin\
ate.svg\x22\x0a   inks\
cape:export-file\
name=\x22/home/yeis\
on/Development/p\
iton/art/icon_li\
te.png\x22\x0a   inksc\
ape:export-xdpi=\
\x2296\x22\x0a   inkscape\
:export-ydpi=\x2296\
\x22>\x0a  <defs\x0a     \
id=\x22defs2\x22 />\x0a  \
<sodipodi:namedv\
iew\x0a     id=\x22bas\
e\x22\x0a     pagecolo\
r=\x22#ffffff\x22\x0a    \
 bordercolor=\x22#6\
66666\x22\x0a     bord\
eropacity=\x221.0\x22\x0a\
     inkscape:pa\
geopacity=\x220.0\x22\x0a\
     inkscape:pa\
geshadow=\x222\x22\x0a   \
  inkscape:zoom=\
\x2216.610599\x22\x0a    \
 inkscape:cx=\x22-4\
.7529072\x22\x0a     i\
nkscape:cy=\x2211.9\
84039\x22\x0a     inks\
cape:document-un\
its=\x22px\x22\x0a     in\
kscape:current-l\
ayer=\x22layer1\x22\x0a  \
   showgrid=\x22tru\
e\x22\x0a     inkscape\
:window-width=\x221\
920\x22\x0a     inksca\
pe:window-height\
=\x221015\x22\x0a     ink\
scape:window-x=\x22\
0\x22\x0a     inkscape\
:window-y=\x220\x22\x0a  \
   inkscape:wind\
ow-maximized=\x221\x22\
\x0a     inkscape:s\
howpageshadow=\x22f\
alse\x22\x0a     units\
=\x22px\x22\x0a     inksc\
ape:pagecheckerb\
oard=\x22false\x22\x0a   \
  showguides=\x22fa\
lse\x22\x0a     inksca\
pe:snap-bbox=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-paths=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-bbox-edge\
-midpoints=\x22true\
\x22\x0a     inkscape:\
snap-bbox-midpoi\
nts=\x22true\x22\x0a     \
inkscape:snap-no\
des=\x22true\x22\x0a     \
inkscape:object-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
intersection-pat\
hs=\x22true\x22\x0a     i\
nkscape:snap-smo\
oth-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-global=\x22\
true\x22\x0a     fit-m\
argin-top=\x220\x22\x0a  \
   fit-margin-le\
ft=\x220\x22\x0a     fit-\
margin-right=\x220\x22\
\x0a     fit-margin\
-bottom=\x220\x22\x0a    \
 inkscape:guide-\
bbox=\x22true\x22>\x0a   \
 <inkscape:grid\x0a\
       type=\x22xyg\
rid\x22\x0a       id=\x22\
grid974\x22\x0a       \
empspacing=\x228\x22\x0a \
      spacingx=\x22\
0.26458332\x22\x0a    \
   spacingy=\x220.2\
6458332\x22\x0a       \
dotted=\x22false\x22\x0a \
      visible=\x22t\
rue\x22\x0a       enab\
led=\x22true\x22\x0a     \
  snapvisiblegri\
dlinesonly=\x22true\
\x22\x0a       originx\
=\x220\x22\x0a       orig\
iny=\x220\x22 />\x0a  </s\
odipodi:namedvie\
w>\x0a  <metadata\x0a \
    id=\x22metadata\
5\x22>\x0a    <rdf:RDF\
>\x0a      <cc:Work\
\x0a         rdf:ab\
out=\x22\x22>\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0a        <dc\
:type\x0a          \
 rdf:resource=\x22h\
ttp://purl.org/d\
c/dcmitype/Still\
Image\x22 />\x0a      \
  <dc:title></dc\
:title>\x0a      </\
cc:Work>\x0a    </r\
df:RDF>\x0a  </meta\
data>\x0a  <g\x0a     \
inkscape:label=\x22\
Layer 1\x22\x0a     in\
kscape:groupmode\
=\x22layer\x22\x0a     id\
=\x22layer1\x22\x0a     t\
ransform=\x22transl\
ate(0,-291.70835\
)\x22>\x0a    <path\x0a  \
     style=\x22opac\
ity:1;fill:#ff00\
00;fill-opacity:\
1;stroke:none;st\
roke-width:2;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a       d\
=\x22M 2,0 C 0.8919\
9975,0 0,0.89198\
64 0,2 v 16 c 0,\
1.108014 0.89199\
975,2 2,2 h 16 c\
 1.108,0 2,-0.89\
1986 2,-2 V 2 C \
20,0.8919864 19.\
108,0 18,0 Z\x22\x0a  \
     transform=\x22\
matrix(0.2645833\
2,0,0,0.26458332\
,0,291.70835)\x22\x0a \
      id=\x22rect83\
3\x22\x0a       inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
  sodipodi:nodet\
ypes=\x22sssssssss\x22\
 />\x0a    <g\x0a     \
  id=\x22g847\x22\x0a    \
   transform=\x22ma\
trix(0.05207439,\
0,0,0.05207453,-\
0.90125164,282.4\
1203)\x22>\x0a      <g\
\x0a         id=\x22g8\
51\x22>\x0a        <g\x0a\
           id=\x22g\
1059\x22\x0a          \
 transform=\x22matr\
ix(1.9986219,0,0\
,1.9986185,17.32\
4484,-313.52314)\
\x22>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-y=\x223.1\
75\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07000433;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a        \
     d=\x22M 25.399\
999,271.60002 -8\
.0000008e-7,246.\
20002 H 50.79999\
9 Z\x22\x0a           \
  id=\x22path883\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22 />\x0a         \
 <path\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         id=\x22pat\
h880\x22\x0a          \
   d=\x22m 25.39999\
9,271.60002 25.3\
99999,25.4 H 0 Z\
\x22\x0a             i\
nkscape:transfor\
m-center-y=\x22-3.1\
749995\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <rect\x0a \
            ry=\x22\
5.0534658\x22\x0a     \
        y=\x22253.8\
4885\x22\x0a          \
   x=\x227.6487389\x22\
\x0a             he\
ight=\x2235.528759\x22\
\x0a             wi\
dth=\x2235.528786\x22\x0a\
             id=\
\x22rect870\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.061844\
19;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <circ\
le\x0a             \
r=\x2225.396828\x22\x0a  \
           cy=\x222\
71.60001\x22\x0a      \
       cx=\x2225.4\x22\
\x0a             id\
=\x22path872\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.07635\
882;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <cir\
cle\x0a            \
 transform=\x22rota\
te(-45)\x22\x0a       \
      cx=\x22-174.0\
8969\x22\x0a          \
   cy=\x22210.01071\
\x22\x0a             r\
=\x2212.656071\x22\x0a   \
          id=\x22pa\
th876\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07399406;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22 />\x0a  \
        <path\x0a  \
           inksc\
ape:transform-ce\
nter-x=\x22-3.17499\
99\x22\x0a            \
 sodipodi:nodety\
pes=\x22cccc\x22\x0a     \
        inkscape\
:connector-curva\
ture=\x220\x22\x0a       \
      id=\x22path90\
4\x22\x0a             \
d=\x22m 25.4,271.60\
002 -25.40000040\
000004,25.4 v -5\
0.8 z\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22 />\x0a  \
        <path\x0a  \
           inksc\
ape:transform-ce\
nter-x=\x223.175\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
d=\x22m 25.399999,2\
71.60002 25.4,-2\
5.4 v 50.8 z\x22\x0a  \
           id=\x22p\
ath906\x22\x0a        \
     inkscape:co\
nnector-curvatur\
e=\x220\x22\x0a          \
   sodipodi:node\
types=\x22cccc\x22 />\x0a\
          <rect\x0a\
             ry=\
\x225.0514922\x22\x0a    \
         y=\x22256.\
39301\x22\x0a         \
    x=\x222.5663135\
\x22\x0a             h\
eight=\x2230.440479\
\x22\x0a             w\
idth=\x2245.693634\x22\
\x0a             id\
=\x22rect837\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06574\
38;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22 />\
\x0a          <rect\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.0657438;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a            \
 id=\x22rect831\x22\x0a  \
           width\
=\x2245.693588\x22\x0a   \
          height\
=\x2230.44051\x22\x0a    \
         x=\x22248.\
76645\x22\x0a         \
    y=\x22-40.63338\
5\x22\x0a             \
ry=\x225.051497\x22\x0a  \
           trans\
form=\x22rotate(90)\
\x22 />\x0a        </g\
>\x0a      </g>\x0a   \
 </g>\x0a    <path\x0a\
       style=\x22op\
acity:1;fill:#ff\
c107;fill-opacit\
y:1;stroke:none;\
stroke-width:0.3\
8596651;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-opacity\
:1\x22\x0a       d=\x22m \
50.206421,401.67\
683 c 110.217209\
,0.71279 55.1086\
09,0.3564 0,0 z\x22\
\x0a       id=\x22rect\
997\x22\x0a       inks\
cape:connector-c\
urvature=\x220\x22 />\x0a\
  </g>\x0a</svg>\x0a\
\x00\x00!u\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22rad\
iobutton_checked\
.svg\x22\x0a   inkscap\
e:export-filenam\
e=\x22/home/yeison/\
Development/pito\
n/art/icon_lite.\
png\x22\x0a   inkscape\
:export-xdpi=\x2296\
\x22\x0a   inkscape:ex\
port-ydpi=\x2296\x22>\x0a\
  <defs\x0a     id=\
\x22defs2\x22 />\x0a  <so\
dipodi:namedview\
\x0a     id=\x22base\x22\x0a\
     pagecolor=\x22\
#ffffff\x22\x0a     bo\
rdercolor=\x22#6666\
66\x22\x0a     bordero\
pacity=\x221.0\x22\x0a   \
  inkscape:pageo\
pacity=\x220.0\x22\x0a   \
  inkscape:pages\
hadow=\x222\x22\x0a     i\
nkscape:zoom=\x2228\
.704913\x22\x0a     in\
kscape:cx=\x228.567\
1075\x22\x0a     inksc\
ape:cy=\x226.015214\
5\x22\x0a     inkscape\
:document-units=\
\x22px\x22\x0a     inksca\
pe:current-layer\
=\x22layer1\x22\x0a     s\
howgrid=\x22true\x22\x0a \
    inkscape:win\
dow-width=\x221920\x22\
\x0a     inkscape:w\
indow-height=\x2210\
15\x22\x0a     inkscap\
e:window-x=\x220\x22\x0a \
    inkscape:win\
dow-y=\x220\x22\x0a     i\
nkscape:window-m\
aximized=\x221\x22\x0a   \
  inkscape:showp\
ageshadow=\x22false\
\x22\x0a     units=\x22px\
\x22\x0a     inkscape:\
pagecheckerboard\
=\x22false\x22\x0a     sh\
owguides=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox=\x22true\x22\x0a \
    inkscape:bbo\
x-paths=\x22true\x22\x0a \
    inkscape:bbo\
x-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-bbox-edge-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
bbox-midpoints=\x22\
true\x22\x0a     inksc\
ape:snap-nodes=\x22\
true\x22\x0a     inksc\
ape:object-paths\
=\x22true\x22\x0a     ink\
scape:snap-inter\
section-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-smooth-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-global=\x22true\x22\
\x0a     fit-margin\
-top=\x220\x22\x0a     fi\
t-margin-left=\x220\
\x22\x0a     fit-margi\
n-right=\x220\x22\x0a    \
 fit-margin-bott\
om=\x220\x22\x0a     inks\
cape:guide-bbox=\
\x22true\x22>\x0a    <ink\
scape:grid\x0a     \
  type=\x22xygrid\x22\x0a\
       id=\x22grid9\
74\x22\x0a       empsp\
acing=\x228\x22\x0a      \
 spacingx=\x220.264\
58332\x22\x0a       sp\
acingy=\x220.264583\
32\x22\x0a       dotte\
d=\x22false\x22\x0a      \
 visible=\x22true\x22\x0a\
       enabled=\x22\
true\x22\x0a       sna\
pvisiblegridline\
sonly=\x22true\x22\x0a   \
    originx=\x220\x22\x0a\
       originy=\x22\
0\x22 />\x0a  </sodipo\
di:namedview>\x0a  \
<metadata\x0a     i\
d=\x22metadata5\x22>\x0a \
   <rdf:RDF>\x0a   \
   <cc:Work\x0a    \
     rdf:about=\x22\
\x22>\x0a        <dc:f\
ormat>image/svg+\
xml</dc:format>\x0a\
        <dc:type\
\x0a           rdf:\
resource=\x22http:/\
/purl.org/dc/dcm\
itype/StillImage\
\x22 />\x0a        <dc\
:title></dc:titl\
e>\x0a      </cc:Wo\
rk>\x0a    </rdf:RD\
F>\x0a  </metadata>\
\x0a  <g\x0a     inksc\
ape:label=\x22Layer\
 1\x22\x0a     inkscap\
e:groupmode=\x22lay\
er\x22\x0a     id=\x22lay\
er1\x22\x0a     transf\
orm=\x22translate(0\
,-291.70835)\x22>\x0a \
   <g\x0a       id=\
\x22g847\x22\x0a       tr\
ansform=\x22matrix(\
0.05207439,0,0,0\
.05207453,-0.901\
25164,282.41203)\
\x22>\x0a      <g\x0a    \
     id=\x22g851\x22>\x0a\
        <g\x0a     \
      id=\x22g1059\x22\
\x0a           tran\
sform=\x22matrix(1.\
9986219,0,0,1.99\
86185,17.324484,\
-313.52314)\x22>\x0a  \
        <path\x0a  \
           inksc\
ape:transform-ce\
nter-y=\x223.175\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
d=\x22M 25.399999,2\
71.60002 -8.0000\
008e-7,246.20002\
 H 50.799999 Z\x22\x0a\
             id=\
\x22path883\x22\x0a      \
       inkscape:\
connector-curvat\
ure=\x220\x22\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22 /\
>\x0a          <pat\
h\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    id=\x22path880\x22\
\x0a             d=\
\x22m 25.399999,271\
.60002 25.399999\
,25.4 H 0 Z\x22\x0a   \
          inksca\
pe:transform-cen\
ter-y=\x22-3.174999\
5\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07000433;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <rect\x0a      \
       ry=\x225.053\
4658\x22\x0a          \
   y=\x22253.84885\x22\
\x0a             x=\
\x227.6487389\x22\x0a    \
         height=\
\x2235.528759\x22\x0a    \
         width=\x22\
35.528786\x22\x0a     \
        id=\x22rect\
870\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.06184419;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <circle\x0a  \
           r=\x2225\
.396828\x22\x0a       \
      cy=\x22271.60\
001\x22\x0a           \
  cx=\x2225.4\x22\x0a    \
         id=\x22pat\
h872\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07635882;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <circle\x0a \
            tran\
sform=\x22rotate(-4\
5)\x22\x0a            \
 cx=\x22-174.08969\x22\
\x0a             cy\
=\x22210.01071\x22\x0a   \
          r=\x2212.\
656071\x22\x0a        \
     id=\x22path876\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07399406;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
x=\x22-3.1749999\x22\x0a \
            sodi\
podi:nodetypes=\x22\
cccc\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 id=\x22path904\x22\x0a  \
           d=\x22m \
25.4,271.60002 -\
25.4000004000000\
4,25.4 v -50.8 z\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
x=\x223.175\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.070004\
33;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22\x0a  \
           d=\x22m \
25.399999,271.60\
002 25.4,-25.4 v\
 50.8 z\x22\x0a       \
      id=\x22path90\
6\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             so\
dipodi:nodetypes\
=\x22cccc\x22 />\x0a     \
     <rect\x0a     \
        ry=\x225.05\
14922\x22\x0a         \
    y=\x22256.39301\
\x22\x0a             x\
=\x222.5663135\x22\x0a   \
          height\
=\x2230.440479\x22\x0a   \
          width=\
\x2245.693634\x22\x0a    \
         id=\x22rec\
t837\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <rect\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
            id=\x22\
rect831\x22\x0a       \
      width=\x2245.\
693588\x22\x0a        \
     height=\x2230.\
44051\x22\x0a         \
    x=\x22248.76645\
\x22\x0a             y\
=\x22-40.633385\x22\x0a  \
           ry=\x225\
.051497\x22\x0a       \
      transform=\
\x22rotate(90)\x22 />\x0a\
        </g>\x0a   \
   </g>\x0a    </g>\
\x0a    <path\x0a     \
  style=\x22opacity\
:1;fill:#ffc107;\
fill-opacity:1;s\
troke:none;strok\
e-width:0.385966\
51;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-opacity:1\x22\x0a \
      d=\x22m 50.20\
6421,401.67683 c\
 110.217209,0.71\
279 55.108609,0.\
3564 0,0 z\x22\x0a    \
   id=\x22rect997\x22\x0a\
       inkscape:\
connector-curvat\
ure=\x220\x22 />\x0a    <\
path\x0a       styl\
e=\x22opacity:1;fil\
l:#ff0000;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:3;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
      d=\x22M 10 0.\
013671875 A 9.98\
62042 9.9862042 \
0 0 0 0.01367187\
5 10 A 9.9862042\
 9.9862042 0 0 0\
 10 19.986328 A \
9.9862042 9.9862\
042 0 0 0 19.986\
328 10 A 9.98620\
42 9.9862042 0 0\
 0 10 0.01367187\
5 z M 10 3 A 7.0\
000143 7.0000143\
 0 0 1 17 10 A 7\
.0000143 7.00001\
43 0 0 1 10 17 A\
 7.0000143 7.000\
0143 0 0 1 3 10 \
A 7.0000143 7.00\
00143 0 0 1 10 3\
 z \x22\x0a       tran\
sform=\x22matrix(0.\
26458332,0,0,0.2\
6458332,0,291.70\
835)\x22\x0a       id=\
\x22path826\x22 />\x0a   \
 <circle\x0a       \
style=\x22opacity:1\
;fill:#ff0000;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:0.31793979\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22\x0a    \
   id=\x22circle830\
\x22\x0a       cx=\x222.6\
458333\x22\x0a       c\
y=\x22294.35419\x22\x0a  \
     r=\x221.058337\
1\x22 />\x0a  </g>\x0a</s\
vg>\x0a\
\x00\x00$v\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22spl\
itter-horizontal\
.svg\x22\x0a   inkscap\
e:export-filenam\
e=\x22/home/yeison/\
Development/pito\
n/art/icon_lite.\
png\x22\x0a   inkscape\
:export-xdpi=\x2296\
\x22\x0a   inkscape:ex\
port-ydpi=\x2296\x22>\x0a\
  <defs\x0a     id=\
\x22defs2\x22 />\x0a  <so\
dipodi:namedview\
\x0a     id=\x22base\x22\x0a\
     pagecolor=\x22\
#ffffff\x22\x0a     bo\
rdercolor=\x22#6666\
66\x22\x0a     bordero\
pacity=\x221.0\x22\x0a   \
  inkscape:pageo\
pacity=\x220.0\x22\x0a   \
  inkscape:pages\
hadow=\x222\x22\x0a     i\
nkscape:zoom=\x2224\
.802598\x22\x0a     in\
kscape:cx=\x226.302\
3018\x22\x0a     inksc\
ape:cy=\x228.969841\
\x22\x0a     inkscape:\
document-units=\x22\
px\x22\x0a     inkscap\
e:current-layer=\
\x22layer1\x22\x0a     sh\
owgrid=\x22true\x22\x0a  \
   inkscape:wind\
ow-width=\x221920\x22\x0a\
     inkscape:wi\
ndow-height=\x22100\
4\x22\x0a     inkscape\
:window-x=\x220\x22\x0a  \
   inkscape:wind\
ow-y=\x220\x22\x0a     in\
kscape:window-ma\
ximized=\x221\x22\x0a    \
 inkscape:showpa\
geshadow=\x22false\x22\
\x0a     units=\x22px\x22\
\x0a     inkscape:p\
agecheckerboard=\
\x22false\x22\x0a     sho\
wguides=\x22true\x22\x0a \
    inkscape:sna\
p-bbox=\x22true\x22\x0a  \
   inkscape:bbox\
-paths=\x22true\x22\x0a  \
   inkscape:bbox\
-nodes=\x22true\x22\x0a  \
   inkscape:snap\
-bbox-edge-midpo\
ints=\x22true\x22\x0a    \
 inkscape:snap-b\
box-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-nodes=\x22t\
rue\x22\x0a     inksca\
pe:object-paths=\
\x22true\x22\x0a     inks\
cape:snap-inters\
ection-paths=\x22tr\
ue\x22\x0a     inkscap\
e:snap-smooth-no\
des=\x22true\x22\x0a     \
inkscape:snap-mi\
dpoints=\x22true\x22\x0a \
    inkscape:sna\
p-global=\x22true\x22\x0a\
     fit-margin-\
top=\x220\x22\x0a     fit\
-margin-left=\x220\x22\
\x0a     fit-margin\
-right=\x220\x22\x0a     \
fit-margin-botto\
m=\x220\x22\x0a     inksc\
ape:guide-bbox=\x22\
true\x22>\x0a    <inks\
cape:grid\x0a      \
 type=\x22xygrid\x22\x0a \
      id=\x22grid97\
4\x22\x0a       empspa\
cing=\x228\x22\x0a       \
spacingx=\x220.2645\
8332\x22\x0a       spa\
cingy=\x220.2645833\
2\x22\x0a       dotted\
=\x22false\x22\x0a       \
visible=\x22true\x22\x0a \
      enabled=\x22t\
rue\x22\x0a       snap\
visiblegridlines\
only=\x22true\x22\x0a    \
   originx=\x220\x22\x0a \
      originy=\x220\
\x22 />\x0a  </sodipod\
i:namedview>\x0a  <\
metadata\x0a     id\
=\x22metadata5\x22>\x0a  \
  <rdf:RDF>\x0a    \
  <cc:Work\x0a     \
    rdf:about=\x22\x22\
>\x0a        <dc:fo\
rmat>image/svg+x\
ml</dc:format>\x0a \
       <dc:type\x0a\
           rdf:r\
esource=\x22http://\
purl.org/dc/dcmi\
type/StillImage\x22\
 />\x0a        <dc:\
title />\x0a      <\
/cc:Work>\x0a    </\
rdf:RDF>\x0a  </met\
adata>\x0a  <g\x0a    \
 inkscape:label=\
\x22Layer 1\x22\x0a     i\
nkscape:groupmod\
e=\x22layer\x22\x0a     i\
d=\x22layer1\x22\x0a     \
transform=\x22trans\
late(0,-291.7083\
5)\x22>\x0a    <g\x0a    \
   id=\x22g847\x22\x0a   \
    transform=\x22m\
atrix(0.05207439\
,0,0,0.05207453,\
-0.90125164,282.\
41203)\x22>\x0a      <\
g\x0a         id=\x22g\
851\x22>\x0a        <g\
\x0a           id=\x22\
g1059\x22\x0a         \
  transform=\x22mat\
rix(1.9986219,0,\
0,1.9986185,17.3\
24484,-313.52314\
)\x22>\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-y=\x223.\
175\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      d=\x22M 25.39\
9999,271.60002 -\
8.0000008e-7,246\
.20002 H 50.7999\
99 Z\x22\x0a          \
   id=\x22path883\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22 />\x0a        \
  <path\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          id=\x22pa\
th880\x22\x0a         \
    d=\x22m 25.3999\
99,271.60002 25.\
399999,25.4 H 0 \
Z\x22\x0a             \
inkscape:transfo\
rm-center-y=\x22-3.\
1749995\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             ry=\
\x225.0534658\x22\x0a    \
         y=\x22253.\
84885\x22\x0a         \
    x=\x227.6487389\
\x22\x0a             h\
eight=\x2235.528759\
\x22\x0a             w\
idth=\x2235.528786\x22\
\x0a             id\
=\x22rect870\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06184\
419;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <cir\
cle\x0a            \
 r=\x2225.396828\x22\x0a \
            cy=\x22\
271.60001\x22\x0a     \
        cx=\x2225.4\
\x22\x0a             i\
d=\x22path872\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0763\
5882;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <ci\
rcle\x0a           \
  transform=\x22rot\
ate(-45)\x22\x0a      \
       cx=\x22-174.\
08969\x22\x0a         \
    cy=\x22210.0107\
1\x22\x0a             \
r=\x2212.656071\x22\x0a  \
           id=\x22p\
ath876\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07399406\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x22-3.1749\
999\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22\x0a    \
         inkscap\
e:connector-curv\
ature=\x220\x22\x0a      \
       id=\x22path9\
04\x22\x0a            \
 d=\x22m 25.4,271.6\
0002 -25.4000004\
0000004,25.4 v -\
50.8 z\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x223.175\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a            \
 d=\x22m 25.399999,\
271.60002 25.4,-\
25.4 v 50.8 z\x22\x0a \
            id=\x22\
path906\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22 />\
\x0a          <rect\
\x0a             ry\
=\x225.0514922\x22\x0a   \
          y=\x22256\
.39301\x22\x0a        \
     x=\x222.566313\
5\x22\x0a             \
height=\x2230.44047\
9\x22\x0a             \
width=\x2245.693634\
\x22\x0a             i\
d=\x22rect837\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <rec\
t\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22\x0a           \
  id=\x22rect831\x22\x0a \
            widt\
h=\x2245.693588\x22\x0a  \
           heigh\
t=\x2230.44051\x22\x0a   \
          x=\x22248\
.76645\x22\x0a        \
     y=\x22-40.6333\
85\x22\x0a            \
 ry=\x225.051497\x22\x0a \
            tran\
sform=\x22rotate(90\
)\x22 />\x0a        </\
g>\x0a      </g>\x0a  \
  </g>\x0a    <path\
\x0a       style=\x22o\
pacity:1;fill:#f\
fc107;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
38596651;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-opacit\
y:1\x22\x0a       d=\x22m\
 50.206421,401.6\
7683 c 110.21720\
9,0.71279 55.108\
609,0.3564 0,0 z\
\x22\x0a       id=\x22rec\
t997\x22\x0a       ink\
scape:connector-\
curvature=\x220\x22 />\
\x0a    <g\x0a       i\
d=\x22g839\x22>\x0a      \
<rect\x0a         y\
=\x22291.97293\x22\x0a   \
      x=\x222.38124\
99\x22\x0a         hei\
ght=\x220.52916664\x22\
\x0a         width=\
\x220.52916664\x22\x0a   \
      id=\x22rect82\
7\x22\x0a         styl\
e=\x22opacity:1;fil\
l:#ff0000;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22 />\x0a     \
 <rect\x0a         \
style=\x22opacity:1\
;fill:#ff0000;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:0.52916664\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1\x22\x0a    \
     id=\x22rect829\
\x22\x0a         width\
=\x220.52916664\x22\x0a  \
       height=\x220\
.52916664\x22\x0a     \
    x=\x222.3812499\
\x22\x0a         y=\x2229\
6.20627\x22 />\x0a    \
  <rect\x0a        \
 y=\x22295.14792\x22\x0a \
        x=\x222.381\
2499\x22\x0a         h\
eight=\x220.5291666\
4\x22\x0a         widt\
h=\x220.52916664\x22\x0a \
        id=\x22rect\
832\x22\x0a         st\
yle=\x22opacity:1;f\
ill:#ff0000;fill\
-opacity:1;strok\
e:none;stroke-wi\
dth:0.52916664;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1\x22 />\x0a   \
   <rect\x0a       \
  style=\x22opacity\
:1;fill:#ff0000;\
fill-opacity:1;s\
troke:none;strok\
e-width:0.529166\
64;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1\x22\x0a  \
       id=\x22rect8\
34\x22\x0a         wid\
th=\x220.52916664\x22\x0a\
         height=\
\x220.52916664\x22\x0a   \
      x=\x222.38124\
99\x22\x0a         y=\x22\
294.0896\x22 />\x0a   \
   <rect\x0a       \
  y=\x22293.03128\x22\x0a\
         x=\x222.38\
12499\x22\x0a         \
height=\x220.529166\
64\x22\x0a         wid\
th=\x220.52916664\x22\x0a\
         id=\x22rec\
t836\x22\x0a         s\
tyle=\x22opacity:1;\
fill:#ff0000;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:0.52916664;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1\x22 />\x0a  \
  </g>\x0a  </g>\x0a</\
svg>\x0a\
\x00\x00!1\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22rig\
htarrow.svg\x22\x0a   \
inkscape:export-\
filename=\x22/home/\
yeison/Developme\
nt/piton/art/ico\
n_lite.png\x22\x0a   i\
nkscape:export-x\
dpi=\x2296\x22\x0a   inks\
cape:export-ydpi\
=\x2296\x22>\x0a  <defs\x0a \
    id=\x22defs2\x22 /\
>\x0a  <sodipodi:na\
medview\x0a     id=\
\x22base\x22\x0a     page\
color=\x22#ffffff\x22\x0a\
     bordercolor\
=\x22#666666\x22\x0a     \
borderopacity=\x221\
.0\x22\x0a     inkscap\
e:pageopacity=\x220\
.0\x22\x0a     inkscap\
e:pageshadow=\x222\x22\
\x0a     inkscape:z\
oom=\x2211.745467\x22\x0a\
     inkscape:cx\
=\x22-8.0020924\x22\x0a  \
   inkscape:cy=\x22\
-13.919269\x22\x0a    \
 inkscape:docume\
nt-units=\x22px\x22\x0a  \
   inkscape:curr\
ent-layer=\x22layer\
1\x22\x0a     showgrid\
=\x22true\x22\x0a     ink\
scape:window-wid\
th=\x221920\x22\x0a     i\
nkscape:window-h\
eight=\x221015\x22\x0a   \
  inkscape:windo\
w-x=\x220\x22\x0a     ink\
scape:window-y=\x22\
0\x22\x0a     inkscape\
:window-maximize\
d=\x221\x22\x0a     inksc\
ape:showpageshad\
ow=\x22false\x22\x0a     \
units=\x22px\x22\x0a     \
inkscape:pageche\
ckerboard=\x22false\
\x22\x0a     showguide\
s=\x22true\x22\x0a     in\
kscape:snap-bbox\
=\x22true\x22\x0a     ink\
scape:bbox-paths\
=\x22true\x22\x0a     ink\
scape:bbox-nodes\
=\x22true\x22\x0a     ink\
scape:snap-bbox-\
edge-midpoints=\x22\
true\x22\x0a     inksc\
ape:snap-bbox-mi\
dpoints=\x22true\x22\x0a \
    inkscape:sna\
p-nodes=\x22true\x22\x0a \
    inkscape:obj\
ect-paths=\x22true\x22\
\x0a     inkscape:s\
nap-intersection\
-paths=\x22true\x22\x0a  \
   inkscape:snap\
-smooth-nodes=\x22t\
rue\x22\x0a     inksca\
pe:snap-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-glob\
al=\x22true\x22\x0a     f\
it-margin-top=\x220\
\x22\x0a     fit-margi\
n-left=\x220\x22\x0a     \
fit-margin-right\
=\x220\x22\x0a     fit-ma\
rgin-bottom=\x220\x22\x0a\
     inkscape:gu\
ide-bbox=\x22true\x22>\
\x0a    <inkscape:g\
rid\x0a       type=\
\x22xygrid\x22\x0a       \
id=\x22grid974\x22\x0a   \
    empspacing=\x22\
8\x22\x0a       spacin\
gx=\x220.26458332\x22\x0a\
       spacingy=\
\x220.26458332\x22\x0a   \
    dotted=\x22fals\
e\x22\x0a       visibl\
e=\x22true\x22\x0a       \
enabled=\x22true\x22\x0a \
      snapvisibl\
egridlinesonly=\x22\
true\x22\x0a       ori\
ginx=\x220\x22\x0a       \
originy=\x220\x22 />\x0a \
 </sodipodi:name\
dview>\x0a  <metada\
ta\x0a     id=\x22meta\
data5\x22>\x0a    <rdf\
:RDF>\x0a      <cc:\
Work\x0a         rd\
f:about=\x22\x22>\x0a    \
    <dc:format>i\
mage/svg+xml</dc\
:format>\x0a       \
 <dc:type\x0a      \
     rdf:resourc\
e=\x22http://purl.o\
rg/dc/dcmitype/S\
tillImage\x22 />\x0a  \
      <dc:title \
/>\x0a      </cc:Wo\
rk>\x0a    </rdf:RD\
F>\x0a  </metadata>\
\x0a  <g\x0a     inksc\
ape:label=\x22Layer\
 1\x22\x0a     inkscap\
e:groupmode=\x22lay\
er\x22\x0a     id=\x22lay\
er1\x22\x0a     transf\
orm=\x22translate(0\
,-291.70835)\x22>\x0a \
   <g\x0a       id=\
\x22g847\x22\x0a       tr\
ansform=\x22matrix(\
0.05207439,0,0,0\
.05207453,-0.901\
25164,282.41203)\
\x22>\x0a      <g\x0a    \
     id=\x22g851\x22>\x0a\
        <g\x0a     \
      id=\x22g1059\x22\
\x0a           tran\
sform=\x22matrix(1.\
9986219,0,0,1.99\
86185,17.324484,\
-313.52314)\x22>\x0a  \
        <path\x0a  \
           inksc\
ape:transform-ce\
nter-y=\x223.175\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a             \
d=\x22M 25.399999,2\
71.60002 -8.0000\
008e-7,246.20002\
 H 50.799999 Z\x22\x0a\
             id=\
\x22path883\x22\x0a      \
       inkscape:\
connector-curvat\
ure=\x220\x22\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22 /\
>\x0a          <pat\
h\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    id=\x22path880\x22\
\x0a             d=\
\x22m 25.399999,271\
.60002 25.399999\
,25.4 H 0 Z\x22\x0a   \
          inksca\
pe:transform-cen\
ter-y=\x22-3.174999\
5\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07000433;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <rect\x0a      \
       ry=\x225.053\
4658\x22\x0a          \
   y=\x22253.84885\x22\
\x0a             x=\
\x227.6487389\x22\x0a    \
         height=\
\x2235.528759\x22\x0a    \
         width=\x22\
35.528786\x22\x0a     \
        id=\x22rect\
870\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.06184419;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <circle\x0a  \
           r=\x2225\
.396828\x22\x0a       \
      cy=\x22271.60\
001\x22\x0a           \
  cx=\x2225.4\x22\x0a    \
         id=\x22pat\
h872\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07635882;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <circle\x0a \
            tran\
sform=\x22rotate(-4\
5)\x22\x0a            \
 cx=\x22-174.08969\x22\
\x0a             cy\
=\x22210.01071\x22\x0a   \
          r=\x2212.\
656071\x22\x0a        \
     id=\x22path876\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07399406;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
x=\x22-3.1749999\x22\x0a \
            sodi\
podi:nodetypes=\x22\
cccc\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 id=\x22path904\x22\x0a  \
           d=\x22m \
25.4,271.60002 -\
25.4000004000000\
4,25.4 v -50.8 z\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
x=\x223.175\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.070004\
33;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22\x0a  \
           d=\x22m \
25.399999,271.60\
002 25.4,-25.4 v\
 50.8 z\x22\x0a       \
      id=\x22path90\
6\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             so\
dipodi:nodetypes\
=\x22cccc\x22 />\x0a     \
     <rect\x0a     \
        ry=\x225.05\
14922\x22\x0a         \
    y=\x22256.39301\
\x22\x0a             x\
=\x222.5663135\x22\x0a   \
          height\
=\x2230.440479\x22\x0a   \
          width=\
\x2245.693634\x22\x0a    \
         id=\x22rec\
t837\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <rect\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
            id=\x22\
rect831\x22\x0a       \
      width=\x2245.\
693588\x22\x0a        \
     height=\x2230.\
44051\x22\x0a         \
    x=\x22248.76645\
\x22\x0a             y\
=\x22-40.633385\x22\x0a  \
           ry=\x225\
.051497\x22\x0a       \
      transform=\
\x22rotate(90)\x22 />\x0a\
        </g>\x0a   \
   </g>\x0a    </g>\
\x0a    <path\x0a     \
  style=\x22opacity\
:1;fill:#ffc107;\
fill-opacity:1;s\
troke:none;strok\
e-width:0.385966\
51;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-opacity:1\x22\x0a \
      d=\x22m 50.20\
6421,401.67683 c\
 110.217209,0.71\
279 55.108609,0.\
3564 0,0 z\x22\x0a    \
   id=\x22rect997\x22\x0a\
       inkscape:\
connector-curvat\
ure=\x220\x22 />\x0a    <\
path\x0a       sodi\
podi:type=\x22star\x22\
\x0a       style=\x22o\
pacity:1;fill:#f\
f0000;fill-opaci\
ty:1;stroke:none\
;stroke-width:1.\
38742065;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a       id=\x22p\
ath828\x22\x0a       s\
odipodi:sides=\x223\
\x22\x0a       sodipod\
i:cx=\x22-2.6458383\
\x22\x0a       sodipod\
i:cy=\x22-294.16339\
\x22\x0a       sodipod\
i:r1=\x221.3874207\x22\
\x0a       sodipodi\
:r2=\x220.69371033\x22\
\x0a       sodipodi\
:arg1=\x221.5707963\
\x22\x0a       sodipod\
i:arg2=\x222.617993\
9\x22\x0a       inksca\
pe:flatsided=\x22tr\
ue\x22\x0a       inksc\
ape:rounded=\x220.1\
\x22\x0a       inkscap\
e:randomized=\x220\x22\
\x0a       d=\x22m -2.\
6458382,-292.775\
97 c -0.2403083,\
0 -1.3216958,-1.\
87302 -1.2015416\
,-2.08113 0.1201\
541,-0.20811 2.2\
829289,-0.20811 \
2.4030831,0 0.12\
01541,0.20811 -0\
.9612332,2.08113\
 -1.2015415,2.08\
113 z\x22\x0a       in\
kscape:transform\
-center-y=\x221.007\
6499e-05\x22\x0a      \
 transform=\x22rota\
te(-90,294.12438\
,-2.6458332)\x22\x0a  \
     inkscape:tr\
ansform-center-x\
=\x22-0.22980161\x22 /\
>\x0a  </g>\x0a</svg>\x0a\
\
\x00\x00\x09{\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Gener\
ator: Adobe Illu\
strator 19.0.0, \
SVG Export Plug-\
In . SVG Version\
: 6.00 Build 0) \
 -->\x0a\x0a<svg\x0a   xm\
lns:dc=\x22http://p\
url.org/dc/eleme\
nts/1.1/\x22\x0a   xml\
ns:cc=\x22http://cr\
eativecommons.or\
g/ns#\x22\x0a   xmlns:\
rdf=\x22http://www.\
w3.org/1999/02/2\
2-rdf-syntax-ns#\
\x22\x0a   xmlns:svg=\x22\
http://www.w3.or\
g/2000/svg\x22\x0a   x\
mlns=\x22http://www\
.w3.org/2000/svg\
\x22\x0a   xmlns:sodip\
odi=\x22http://sodi\
podi.sourceforge\
.net/DTD/sodipod\
i-0.dtd\x22\x0a   xmln\
s:inkscape=\x22http\
://www.inkscape.\
org/namespaces/i\
nkscape\x22\x0a   vers\
ion=\x221.1\x22\x0a   id=\
\x22content\x22\x0a   x=\x22\
0px\x22\x0a   y=\x220px\x22\x0a\
   viewBox=\x2256 -\
56 512 512\x22\x0a   x\
ml:space=\x22preser\
ve\x22\x0a   sodipodi:\
docname=\x22logo.sv\
g\x22\x0a   width=\x22512\
\x22\x0a   height=\x22512\
\x22\x0a   inkscape:ex\
port-filename=\x22/\
home/yeison/Deve\
lopment/gcpds/py\
side-material/do\
cs/source/_stati\
c/logo.png\x22\x0a   i\
nkscape:export-x\
dpi=\x2296\x22\x0a   inks\
cape:export-ydpi\
=\x2296\x22\x0a   inkscap\
e:version=\x220.92.\
4 5da689c313, 20\
19-01-14\x22><metad\
ata\x0a   id=\x22metad\
ata17\x22><rdf:RDF>\
<cc:Work\x0a       \
rdf:about=\x22\x22><dc\
:format>image/sv\
g+xml</dc:format\
><dc:type\x0a      \
   rdf:resource=\
\x22http://purl.org\
/dc/dcmitype/Sti\
llImage\x22 /><dc:t\
itle></dc:title>\
</cc:Work></rdf:\
RDF></metadata><\
defs\x0a   id=\x22defs\
15\x22 /><sodipodi:\
namedview\x0a   pag\
ecolor=\x22#ffffff\x22\
\x0a   bordercolor=\
\x22#666666\x22\x0a   bor\
deropacity=\x221\x22\x0a \
  objecttoleranc\
e=\x2210\x22\x0a   gridto\
lerance=\x2210\x22\x0a   \
guidetolerance=\x22\
10\x22\x0a   inkscape:\
pageopacity=\x220\x22\x0a\
   inkscape:page\
shadow=\x222\x22\x0a   in\
kscape:window-wi\
dth=\x221920\x22\x0a   in\
kscape:window-he\
ight=\x221015\x22\x0a   i\
d=\x22namedview13\x22\x0a\
   showgrid=\x22tru\
e\x22\x0a   inkscape:z\
oom=\x220.61631945\x22\
\x0a   inkscape:cx=\
\x22156.74186\x22\x0a   i\
nkscape:cy=\x2210.3\
16892\x22\x0a   inksca\
pe:window-x=\x220\x22\x0a\
   inkscape:wind\
ow-y=\x220\x22\x0a   inks\
cape:window-maxi\
mized=\x221\x22\x0a   ink\
scape:current-la\
yer=\x22content\x22\x0a  \
 showguides=\x22fal\
se\x22\x0a   fit-margi\
n-top=\x220\x22\x0a   fit\
-margin-left=\x220\x22\
\x0a   fit-margin-r\
ight=\x220\x22\x0a   fit-\
margin-bottom=\x220\
\x22 />\x0a<style\x0a   t\
ype=\x22text/css\x22\x0a \
  id=\x22style2\x22>\x0a\x09\
.st0{fill:#21212\
1;}\x0a\x09.st1{fill:#\
FF80AB;}\x0a\x09.st2{f\
ill:#FF1744;}\x0a</\
style>\x0a<g\x0a   id=\
\x22g4554\x22\x0a   trans\
form=\x22matrix(3.5\
555556,0,0,3.555\
5556,-143.11111,\
143.11111)\x22><g\x0a \
    id=\x22g10\x22>\x0a\x09<\
polygon\x0a   style\
=\x22fill:#41cd5f;f\
ill-opacity:0.94\
117647\x22\x0a   id=\x22p\
olygon4\x22\x0a   poin\
ts=\x22176,-8 80,-8\
 56,-56 200,-56 \
\x22\x0a   class=\x22st0\x22\
 />\x0a\x09<rect\x0a   st\
yle=\x22fill:#ffd80\
f;fill-opacity:0\
.94117647\x22\x0a   id\
=\x22rect6\x22\x0a   heig\
ht=\x2296\x22\x0a   width\
=\x22144\x22\x0a   class=\
\x22st1\x22\x0a   y=\x22-8\x22\x0a\
   x=\x2256\x22 />\x0a\x09<p\
olygon\x0a   style=\
\x22fill:#00939f;fi\
ll-opacity:0.941\
17647\x22\x0a   id=\x22po\
lygon8\x22\x0a   point\
s=\x22176,-8 80,-8 \
128,88 \x22\x0a   clas\
s=\x22st2\x22 />\x0a</g><\
/g>\x0a</svg>\
\x00\x00\x15<\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2251\
2\x22\x0a   height=\x2251\
2\x22\x0a   viewBox=\x220\
 0 135.46667 135\
.46667\x22\x0a   versi\
on=\x221.1\x22\x0a   id=\x22\
svg8\x22\x0a   inkscap\
e:version=\x220.92.\
4 5da689c313, 20\
19-01-14\x22\x0a   sod\
ipodi:docname=\x22l\
ogo_frame.svg\x22\x0a \
  inkscape:expor\
t-filename=\x22/hom\
e/yeison/Develop\
ment/gcpds/bci-u\
nscented/assets/\
logo.png\x22\x0a   ink\
scape:export-xdp\
i=\x2296\x22\x0a   inksca\
pe:export-ydpi=\x22\
96\x22>\x0a  <defs\x0a   \
  id=\x22defs2\x22 />\x0a\
  <sodipodi:name\
dview\x0a     id=\x22b\
ase\x22\x0a     pageco\
lor=\x22#ffffff\x22\x0a  \
   bordercolor=\x22\
#666666\x22\x0a     bo\
rderopacity=\x221.0\
\x22\x0a     inkscape:\
pageopacity=\x220.0\
\x22\x0a     inkscape:\
pageshadow=\x222\x22\x0a \
    inkscape:zoo\
m=\x220.96260433\x22\x0a \
    inkscape:cx=\
\x22263.56863\x22\x0a    \
 inkscape:cy=\x2215\
4.89649\x22\x0a     in\
kscape:document-\
units=\x22px\x22\x0a     \
inkscape:current\
-layer=\x22layer1\x22\x0a\
     showgrid=\x22f\
alse\x22\x0a     inksc\
ape:window-width\
=\x221920\x22\x0a     ink\
scape:window-hei\
ght=\x221004\x22\x0a     \
inkscape:window-\
x=\x220\x22\x0a     inksc\
ape:window-y=\x220\x22\
\x0a     inkscape:w\
indow-maximized=\
\x221\x22\x0a     units=\x22\
px\x22\x0a     inkscap\
e:showpageshadow\
=\x22false\x22\x0a     sh\
owguides=\x22false\x22\
\x0a     inkscape:s\
nap-bbox=\x22true\x22\x0a\
     inkscape:bb\
ox-paths=\x22true\x22\x0a\
     inkscape:bb\
ox-nodes=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-bbox\
-edge-midpoints=\
\x22true\x22\x0a     inks\
cape:object-path\
s=\x22true\x22\x0a     in\
kscape:snap-inte\
rsection-paths=\x22\
true\x22\x0a     inksc\
ape:snap-midpoin\
ts=\x22true\x22\x0a     i\
nkscape:snap-smo\
oth-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-object-midpo\
ints=\x22true\x22\x0a    \
 inkscape:snap-c\
enter=\x22true\x22\x0a   \
  fit-margin-top\
=\x220\x22\x0a     fit-ma\
rgin-left=\x220\x22\x0a  \
   fit-margin-ri\
ght=\x220\x22\x0a     fit\
-margin-bottom=\x22\
0\x22 />\x0a  <metadat\
a\x0a     id=\x22metad\
ata5\x22>\x0a    <rdf:\
RDF>\x0a      <cc:W\
ork\x0a         rdf\
:about=\x22\x22>\x0a     \
   <dc:format>im\
age/svg+xml</dc:\
format>\x0a        \
<dc:type\x0a       \
    rdf:resource\
=\x22http://purl.or\
g/dc/dcmitype/St\
illImage\x22 />\x0a   \
     <dc:title /\
>\x0a      </cc:Wor\
k>\x0a    </rdf:RDF\
>\x0a  </metadata>\x0a\
  <g\x0a     inksca\
pe:label=\x22Capa 1\
\x22\x0a     inkscape:\
groupmode=\x22layer\
\x22\x0a     id=\x22layer\
1\x22\x0a     transfor\
m=\x22translate(21.\
700237,-922.5195\
4)\x22>\x0a    <path\x0a \
      sodipodi:t\
ype=\x22star\x22\x0a     \
  style=\x22opacity\
:0.33;fill:#0e97\
98;fill-opacity:\
0.99607843;strok\
e:none;stroke-wi\
dth:1.16275263;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:0.1415525\
\x22\x0a       id=\x22pat\
h1578\x22\x0a       so\
dipodi:sides=\x224\x22\
\x0a       sodipodi\
:cx=\x2246.033096\x22\x0a\
       sodipodi:\
cy=\x22990.25287\x22\x0a \
      sodipodi:r\
1=\x2275.712967\x22\x0a  \
     sodipodi:r2\
=\x2253.537148\x22\x0a   \
    sodipodi:arg\
1=\x220.78539816\x22\x0a \
      sodipodi:a\
rg2=\x221.5707963\x22\x0a\
       inkscape:\
flatsided=\x22true\x22\
\x0a       inkscape\
:rounded=\x220.25\x22\x0a\
       inkscape:\
randomized=\x220\x22\x0a \
      d=\x22m 99.57\
0249,1043.79 c -\
18.928242,18.928\
3 -88.146063,18.\
9283 -107.074304\
8,0 -18.9282422,\
-18.9282 -18.928\
2422,-88.14604 -\
4e-7,-107.07428 \
18.9282412,-18.9\
2825 88.1460632,\
-18.92825 107.07\
43042,0 18.92824\
2,18.92824 18.92\
8242,88.14608 10\
e-7,107.07428 z\x22\
\x0a       inkscape\
:transform-cente\
r-y=\x22-2.0420979e\
-05\x22 />\x0a    <cir\
cle\x0a       cy=\x221\
39.7252\x22\x0a       \
cx=\x22-591.70111\x22\x0a\
       id=\x22circl\
e1545\x22\x0a       st\
yle=\x22opacity:0.6\
7299996;fill:#aa\
aaff;fill-opacit\
y:0.30136988;str\
oke:#ffffff00;st\
roke-width:0.304\
04934;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-opacity:1\
\x22\x0a       r=\x220\x22 /\
>\x0a    <circle\x0a  \
     r=\x220\x22\x0a     \
  style=\x22opacity\
:0.67299996;fill\
:#aaaaff;fill-op\
acity:0.30136988\
;stroke:#ffffff0\
0;stroke-width:0\
.30404934;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-opaci\
ty:1\x22\x0a       id=\
\x22ellipse1617\x22\x0a  \
     cx=\x22-993.51\
282\x22\x0a       cy=\x22\
168.13614\x22 />\x0a  \
  <circle\x0a      \
 r=\x220\x22\x0a       cy\
=\x22733.2077\x22\x0a    \
   cx=\x22-958.1440\
4\x22\x0a       id=\x22el\
lipse1906\x22\x0a     \
  style=\x22opacity\
:0.67299996;fill\
:none;fill-opaci\
ty:0.30136988;st\
roke:#ffffff00;s\
troke-width:0.79\
374999;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-opacity:\
1\x22 />\x0a    <circl\
e\x0a       r=\x220\x22\x0a \
      cy=\x22582.33\
099\x22\x0a       cx=\x22\
-1500.9722\x22\x0a    \
   id=\x22ellipse19\
26\x22\x0a       style\
=\x22opacity:0.6729\
9996;fill:none;f\
ill-opacity:0.30\
136988;stroke:#f\
fffff00;stroke-w\
idth:0.79374999;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-opacity:1\x22 />\x0a \
   <circle\x0a     \
  r=\x220\x22\x0a       c\
y=\x22255.9781\x22\x0a   \
    cx=\x22-958.144\
04\x22\x0a       id=\x22e\
llipse1946\x22\x0a    \
   style=\x22opacit\
y:0.67299996;fil\
l:none;fill-opac\
ity:0.30136988;s\
troke:#ffffff00;\
stroke-width:0.7\
9374999;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-opacity\
:1\x22 />\x0a    <g\x0a  \
     transform=\x22\
matrix(0.5879629\
8,0,0,0.58796298\
,-29.226163,980.\
84547)\x22\x0a       i\
d=\x22g4554\x22>\x0a     \
 <g\x0a         id=\
\x22g10\x22>\x0a        <\
polygon\x0a        \
   class=\x22st0\x22\x0a \
          points\
=\x2256,-56 200,-56\
 176,-8 80,-8 \x22\x0a\
           id=\x22p\
olygon4\x22\x0a       \
    style=\x22fill:\
#41cd5f;fill-opa\
city:0.94117647\x22\
 />\x0a        <rec\
t\x0a           x=\x22\
56\x22\x0a           y\
=\x22-8\x22\x0a          \
 class=\x22st1\x22\x0a   \
        width=\x221\
44\x22\x0a           h\
eight=\x2296\x22\x0a     \
      id=\x22rect6\x22\
\x0a           styl\
e=\x22fill:#ffd80f;\
fill-opacity:0.9\
4117647\x22 />\x0a    \
    <polygon\x0a   \
        class=\x22s\
t2\x22\x0a           p\
oints=\x22128,88 17\
6,-8 80,-8 \x22\x0a   \
        id=\x22poly\
gon8\x22\x0a          \
 style=\x22fill:#00\
939f;fill-opacit\
y:0.94117647\x22 />\
\x0a      </g>\x0a    \
</g>\x0a  </g>\x0a  <s\
tyle\x0a     id=\x22st\
yle2\x22\x0a     type=\
\x22text/css\x22>\x0a\x09.st\
0{fill:#212121;}\
\x0a\x09.st1{fill:#FF8\
0AB;}\x0a\x09.st2{fill\
:#FF1744;}\x0a</sty\
le>\x0a</svg>\x0a\
\x00\x00 \x1f\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22rad\
iobutton_uncheck\
ed.svg\x22\x0a   inksc\
ape:export-filen\
ame=\x22/home/yeiso\
n/Development/pi\
ton/art/icon_lit\
e.png\x22\x0a   inksca\
pe:export-xdpi=\x22\
96\x22\x0a   inkscape:\
export-ydpi=\x2296\x22\
>\x0a  <defs\x0a     i\
d=\x22defs2\x22 />\x0a  <\
sodipodi:namedvi\
ew\x0a     id=\x22base\
\x22\x0a     pagecolor\
=\x22#ffffff\x22\x0a     \
bordercolor=\x22#66\
6666\x22\x0a     borde\
ropacity=\x221.0\x22\x0a \
    inkscape:pag\
eopacity=\x220.0\x22\x0a \
    inkscape:pag\
eshadow=\x222\x22\x0a    \
 inkscape:zoom=\x22\
23.490935\x22\x0a     \
inkscape:cx=\x220.9\
1214654\x22\x0a     in\
kscape:cy=\x225.283\
5214\x22\x0a     inksc\
ape:document-uni\
ts=\x22px\x22\x0a     ink\
scape:current-la\
yer=\x22layer1\x22\x0a   \
  showgrid=\x22true\
\x22\x0a     inkscape:\
window-width=\x2219\
20\x22\x0a     inkscap\
e:window-height=\
\x221015\x22\x0a     inks\
cape:window-x=\x220\
\x22\x0a     inkscape:\
window-y=\x220\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22\x0a\
     inkscape:sh\
owpageshadow=\x22fa\
lse\x22\x0a     units=\
\x22px\x22\x0a     inksca\
pe:pagecheckerbo\
ard=\x22false\x22\x0a    \
 showguides=\x22tru\
e\x22\x0a     inkscape\
:snap-bbox=\x22true\
\x22\x0a     inkscape:\
bbox-paths=\x22true\
\x22\x0a     inkscape:\
bbox-nodes=\x22true\
\x22\x0a     inkscape:\
snap-bbox-edge-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-node\
s=\x22true\x22\x0a     in\
kscape:object-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-in\
tersection-paths\
=\x22true\x22\x0a     ink\
scape:snap-smoot\
h-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-global=\x22tr\
ue\x22\x0a     fit-mar\
gin-top=\x220\x22\x0a    \
 fit-margin-left\
=\x220\x22\x0a     fit-ma\
rgin-right=\x220\x22\x0a \
    fit-margin-b\
ottom=\x220\x22\x0a     i\
nkscape:guide-bb\
ox=\x22true\x22>\x0a    <\
inkscape:grid\x0a  \
     type=\x22xygri\
d\x22\x0a       id=\x22gr\
id974\x22\x0a       em\
pspacing=\x228\x22\x0a   \
    spacingx=\x220.\
26458332\x22\x0a      \
 spacingy=\x220.264\
58332\x22\x0a       do\
tted=\x22false\x22\x0a   \
    visible=\x22tru\
e\x22\x0a       enable\
d=\x22true\x22\x0a       \
snapvisiblegridl\
inesonly=\x22true\x22\x0a\
       originx=\x22\
0\x22\x0a       origin\
y=\x220\x22 />\x0a  </sod\
ipodi:namedview>\
\x0a  <metadata\x0a   \
  id=\x22metadata5\x22\
>\x0a    <rdf:RDF>\x0a\
      <cc:Work\x0a \
        rdf:abou\
t=\x22\x22>\x0a        <d\
c:format>image/s\
vg+xml</dc:forma\
t>\x0a        <dc:t\
ype\x0a           r\
df:resource=\x22htt\
p://purl.org/dc/\
dcmitype/StillIm\
age\x22 />\x0a        \
<dc:title></dc:t\
itle>\x0a      </cc\
:Work>\x0a    </rdf\
:RDF>\x0a  </metada\
ta>\x0a  <g\x0a     in\
kscape:label=\x22La\
yer 1\x22\x0a     inks\
cape:groupmode=\x22\
layer\x22\x0a     id=\x22\
layer1\x22\x0a     tra\
nsform=\x22translat\
e(0,-291.70835)\x22\
>\x0a    <g\x0a       \
id=\x22g847\x22\x0a      \
 transform=\x22matr\
ix(0.05207439,0,\
0,0.05207453,-0.\
90125164,282.412\
03)\x22>\x0a      <g\x0a \
        id=\x22g851\
\x22>\x0a        <g\x0a  \
         id=\x22g10\
59\x22\x0a           t\
ransform=\x22matrix\
(1.9986219,0,0,1\
.9986185,17.3244\
84,-313.52314)\x22>\
\x0a          <path\
\x0a             in\
kscape:transform\
-center-y=\x223.175\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22\x0a          \
   d=\x22M 25.39999\
9,271.60002 -8.0\
000008e-7,246.20\
002 H 50.799999 \
Z\x22\x0a             \
id=\x22path883\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22 />\x0a          <\
path\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22\x0a    \
         inkscap\
e:connector-curv\
ature=\x220\x22\x0a      \
       id=\x22path8\
80\x22\x0a            \
 d=\x22m 25.399999,\
271.60002 25.399\
999,25.4 H 0 Z\x22\x0a\
             ink\
scape:transform-\
center-y=\x22-3.174\
9995\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22 />\x0a   \
       <rect\x0a   \
          ry=\x225.\
0534658\x22\x0a       \
      y=\x22253.848\
85\x22\x0a            \
 x=\x227.6487389\x22\x0a \
            heig\
ht=\x2235.528759\x22\x0a \
            widt\
h=\x2235.528786\x22\x0a  \
           id=\x22r\
ect870\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.06184419\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <circle\
\x0a             r=\
\x2225.396828\x22\x0a    \
         cy=\x22271\
.60001\x22\x0a        \
     cx=\x2225.4\x22\x0a \
            id=\x22\
path872\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0763588\
2;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <circl\
e\x0a             t\
ransform=\x22rotate\
(-45)\x22\x0a         \
    cx=\x22-174.089\
69\x22\x0a            \
 cy=\x22210.01071\x22\x0a\
             r=\x22\
12.656071\x22\x0a     \
        id=\x22path\
876\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07399406;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <path\x0a    \
         inkscap\
e:transform-cent\
er-x=\x22-3.1749999\
\x22\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    id=\x22path904\x22\
\x0a             d=\
\x22m 25.4,271.6000\
2 -25.4000004000\
0004,25.4 v -50.\
8 z\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <path\x0a    \
         inkscap\
e:transform-cent\
er-x=\x223.175\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
\x0a             d=\
\x22m 25.399999,271\
.60002 25.4,-25.\
4 v 50.8 z\x22\x0a    \
         id=\x22pat\
h906\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 sodipodi:nodety\
pes=\x22cccc\x22 />\x0a  \
        <rect\x0a  \
           ry=\x225\
.0514922\x22\x0a      \
       y=\x22256.39\
301\x22\x0a           \
  x=\x222.5663135\x22\x0a\
             hei\
ght=\x2230.440479\x22\x0a\
             wid\
th=\x2245.693634\x22\x0a \
            id=\x22\
rect837\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0657438\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <rect\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
657438;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a             i\
d=\x22rect831\x22\x0a    \
         width=\x22\
45.693588\x22\x0a     \
        height=\x22\
30.44051\x22\x0a      \
       x=\x22248.76\
645\x22\x0a           \
  y=\x22-40.633385\x22\
\x0a             ry\
=\x225.051497\x22\x0a    \
         transfo\
rm=\x22rotate(90)\x22 \
/>\x0a        </g>\x0a\
      </g>\x0a    <\
/g>\x0a    <path\x0a  \
     style=\x22opac\
ity:1;fill:#ffc1\
07;fill-opacity:\
1;stroke:none;st\
roke-width:0.385\
96651;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-opacity:1\
\x22\x0a       d=\x22m 50\
.206421,401.6768\
3 c 110.217209,0\
.71279 55.108609\
,0.3564 0,0 z\x22\x0a \
      id=\x22rect99\
7\x22\x0a       inksca\
pe:connector-cur\
vature=\x220\x22 />\x0a  \
  <path\x0a       s\
tyle=\x22opacity:1;\
fill:#ff0000;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:3;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a       d=\x22M 10\
 0.013671875 A 9\
.9862042 9.98620\
42 0 0 0 0.01367\
1875 10 A 9.9862\
042 9.9862042 0 \
0 0 10 19.986328\
 A 9.9862042 9.9\
862042 0 0 0 19.\
986328 10 A 9.98\
62042 9.9862042 \
0 0 0 10 0.01367\
1875 z M 10 3 A \
7.0000143 7.0000\
143 0 0 1 17 10 \
A 7.0000143 7.00\
00143 0 0 1 10 1\
7 A 7.0000143 7.\
0000143 0 0 1 3 \
10 A 7.0000143 7\
.0000143 0 0 1 1\
0 3 z \x22\x0a       t\
ransform=\x22matrix\
(0.26458332,0,0,\
0.26458332,0,291\
.70835)\x22\x0a       \
id=\x22path826\x22 />\x0a\
  </g>\x0a</svg>\x0a\
\x00\x00\x1f\xba\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22clo\
se.svg\x22\x0a   inksc\
ape:export-filen\
ame=\x22/home/yeiso\
n/Development/pi\
ton/art/icon_lit\
e.png\x22\x0a   inksca\
pe:export-xdpi=\x22\
96\x22\x0a   inkscape:\
export-ydpi=\x2296\x22\
>\x0a  <defs\x0a     i\
d=\x22defs2\x22 />\x0a  <\
sodipodi:namedvi\
ew\x0a     id=\x22base\
\x22\x0a     pagecolor\
=\x22#ffffff\x22\x0a     \
bordercolor=\x22#66\
6666\x22\x0a     borde\
ropacity=\x221.0\x22\x0a \
    inkscape:pag\
eopacity=\x220.0\x22\x0a \
    inkscape:pag\
eshadow=\x222\x22\x0a    \
 inkscape:zoom=\x22\
0.44851425\x22\x0a    \
 inkscape:cx=\x22-4\
61.15031\x22\x0a     i\
nkscape:cy=\x2268.2\
80762\x22\x0a     inks\
cape:document-un\
its=\x22px\x22\x0a     in\
kscape:current-l\
ayer=\x22layer1\x22\x0a  \
   showgrid=\x22tru\
e\x22\x0a     inkscape\
:window-width=\x221\
920\x22\x0a     inksca\
pe:window-height\
=\x221004\x22\x0a     ink\
scape:window-x=\x22\
0\x22\x0a     inkscape\
:window-y=\x220\x22\x0a  \
   inkscape:wind\
ow-maximized=\x221\x22\
\x0a     inkscape:s\
howpageshadow=\x22f\
alse\x22\x0a     units\
=\x22px\x22\x0a     inksc\
ape:pagecheckerb\
oard=\x22false\x22\x0a   \
  showguides=\x22fa\
lse\x22\x0a     inksca\
pe:snap-bbox=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-paths=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-bbox-edge\
-midpoints=\x22true\
\x22\x0a     inkscape:\
snap-bbox-midpoi\
nts=\x22true\x22\x0a     \
inkscape:snap-no\
des=\x22true\x22\x0a     \
inkscape:object-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
intersection-pat\
hs=\x22true\x22\x0a     i\
nkscape:snap-smo\
oth-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-global=\x22\
true\x22\x0a     fit-m\
argin-top=\x220\x22\x0a  \
   fit-margin-le\
ft=\x220\x22\x0a     fit-\
margin-right=\x220\x22\
\x0a     fit-margin\
-bottom=\x220\x22\x0a    \
 inkscape:guide-\
bbox=\x22true\x22>\x0a   \
 <inkscape:grid\x0a\
       type=\x22xyg\
rid\x22\x0a       id=\x22\
grid974\x22\x0a       \
empspacing=\x228\x22\x0a \
      spacingx=\x22\
0.26458332\x22\x0a    \
   spacingy=\x220.2\
6458332\x22\x0a       \
dotted=\x22false\x22\x0a \
      visible=\x22t\
rue\x22\x0a       enab\
led=\x22true\x22\x0a     \
  snapvisiblegri\
dlinesonly=\x22true\
\x22\x0a       originx\
=\x220\x22\x0a       orig\
iny=\x220\x22 />\x0a  </s\
odipodi:namedvie\
w>\x0a  <metadata\x0a \
    id=\x22metadata\
5\x22>\x0a    <rdf:RDF\
>\x0a      <cc:Work\
\x0a         rdf:ab\
out=\x22\x22>\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0a        <dc\
:type\x0a          \
 rdf:resource=\x22h\
ttp://purl.org/d\
c/dcmitype/Still\
Image\x22 />\x0a      \
  <dc:title />\x0a \
     </cc:Work>\x0a\
    </rdf:RDF>\x0a \
 </metadata>\x0a  <\
g\x0a     inkscape:\
label=\x22Layer 1\x22\x0a\
     inkscape:gr\
oupmode=\x22layer\x22\x0a\
     id=\x22layer1\x22\
\x0a     transform=\
\x22translate(0,-29\
1.70835)\x22>\x0a    <\
g\x0a       id=\x22g84\
7\x22\x0a       transf\
orm=\x22matrix(0.05\
207439,0,0,0.052\
07453,-0.9012516\
4,282.41203)\x22>\x0a \
     <g\x0a        \
 id=\x22g851\x22>\x0a    \
    <g\x0a         \
  id=\x22g1059\x22\x0a   \
        transfor\
m=\x22matrix(1.9986\
219,0,0,1.998618\
5,17.324484,-313\
.52314)\x22>\x0a      \
    <path\x0a      \
       inkscape:\
transform-center\
-y=\x223.175\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.07000\
433;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
            d=\x22M\
 25.399999,271.6\
0002 -8.0000008e\
-7,246.20002 H 5\
0.799999 Z\x22\x0a    \
         id=\x22pat\
h883\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 sodipodi:nodety\
pes=\x22cccc\x22 />\x0a  \
        <path\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22\x0a           \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a             \
id=\x22path880\x22\x0a   \
          d=\x22m 2\
5.399999,271.600\
02 25.399999,25.\
4 H 0 Z\x22\x0a       \
      inkscape:t\
ransform-center-\
y=\x22-3.1749995\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   ry=\x225.0534658\
\x22\x0a             y\
=\x22253.84885\x22\x0a   \
          x=\x227.6\
487389\x22\x0a        \
     height=\x2235.\
528759\x22\x0a        \
     width=\x2235.5\
28786\x22\x0a         \
    id=\x22rect870\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.06184419;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <circle\x0a      \
       r=\x2225.396\
828\x22\x0a           \
  cy=\x22271.60001\x22\
\x0a             cx\
=\x2225.4\x22\x0a        \
     id=\x22path872\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07635882;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <circle\x0a     \
        transfor\
m=\x22rotate(-45)\x22\x0a\
             cx=\
\x22-174.08969\x22\x0a   \
          cy=\x2221\
0.01071\x22\x0a       \
      r=\x2212.6560\
71\x22\x0a            \
 id=\x22path876\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
399406;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
path\x0a           \
  inkscape:trans\
form-center-x=\x22-\
3.1749999\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22\x0a             i\
nkscape:connecto\
r-curvature=\x220\x22\x0a\
             id=\
\x22path904\x22\x0a      \
       d=\x22m 25.4\
,271.60002 -25.4\
0000040000004,25\
.4 v -50.8 z\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
path\x0a           \
  inkscape:trans\
form-center-x=\x223\
.175\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22\x0a      \
       d=\x22m 25.3\
99999,271.60002 \
25.4,-25.4 v 50.\
8 z\x22\x0a           \
  id=\x22path906\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22 />\x0a         \
 <rect\x0a         \
    ry=\x225.051492\
2\x22\x0a             \
y=\x22256.39301\x22\x0a  \
           x=\x222.\
5663135\x22\x0a       \
      height=\x2230\
.440479\x22\x0a       \
      width=\x2245.\
693634\x22\x0a        \
     id=\x22rect837\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <rect\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.0657438;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22\x0a     \
        id=\x22rect\
831\x22\x0a           \
  width=\x2245.6935\
88\x22\x0a            \
 height=\x2230.4405\
1\x22\x0a             \
x=\x22248.76645\x22\x0a  \
           y=\x22-4\
0.633385\x22\x0a      \
       ry=\x225.051\
497\x22\x0a           \
  transform=\x22rot\
ate(90)\x22 />\x0a    \
    </g>\x0a      <\
/g>\x0a    </g>\x0a   \
 <path\x0a       st\
yle=\x22fill:#ff000\
0;stroke:#ff0000\
;stroke-width:0.\
52916664;stroke-\
linecap:butt;str\
oke-linejoin:mit\
er;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-opacity:1\x22\x0a \
      d=\x22m 1.319\
2054,293.02755 2\
.6532555,2.65327\
\x22\x0a       id=\x22pat\
h826\x22\x0a       ink\
scape:connector-\
curvature=\x220\x22 />\
\x0a    <path\x0a     \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a       id=\x22pa\
th842\x22\x0a       d=\
\x22m 3.9724723,293\
.02756 -2.653278\
2,2.65325\x22\x0a     \
  style=\x22fill:#f\
f0000;stroke:#ff\
0000;stroke-widt\
h:0.52916664;str\
oke-linecap:butt\
;stroke-linejoin\
:miter;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-opacity:\
1\x22 />\x0a    <circl\
e\x0a       style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:1;stroke:#ff000\
0;stroke-width:0\
.5292387;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22\x0a       id=\x22p\
ath829\x22\x0a       c\
x=\x222.6458311\x22\x0a  \
     cy=\x22294.354\
19\x22\x0a       r=\x222.\
381216\x22 />\x0a  </g\
>\x0a</svg>\x0a\
\x00\x00 \x00\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22che\
ckbox_checked.sv\
g\x22\x0a   inkscape:e\
xport-filename=\x22\
/home/yeison/Dev\
elopment/piton/a\
rt/icon_lite.png\
\x22\x0a   inkscape:ex\
port-xdpi=\x2296\x22\x0a \
  inkscape:expor\
t-ydpi=\x2296\x22>\x0a  <\
defs\x0a     id=\x22de\
fs2\x22 />\x0a  <sodip\
odi:namedview\x0a  \
   id=\x22base\x22\x0a   \
  pagecolor=\x22#ff\
ffff\x22\x0a     borde\
rcolor=\x22#666666\x22\
\x0a     borderopac\
ity=\x221.0\x22\x0a     i\
nkscape:pageopac\
ity=\x220.0\x22\x0a     i\
nkscape:pageshad\
ow=\x222\x22\x0a     inks\
cape:zoom=\x2228.70\
4912\x22\x0a     inksc\
ape:cx=\x227.427174\
9\x22\x0a     inkscape\
:cy=\x2212.838164\x22\x0a\
     inkscape:do\
cument-units=\x22px\
\x22\x0a     inkscape:\
current-layer=\x22l\
ayer1\x22\x0a     show\
grid=\x22true\x22\x0a    \
 inkscape:window\
-width=\x221920\x22\x0a  \
   inkscape:wind\
ow-height=\x221015\x22\
\x0a     inkscape:w\
indow-x=\x220\x22\x0a    \
 inkscape:window\
-y=\x220\x22\x0a     inks\
cape:window-maxi\
mized=\x221\x22\x0a     i\
nkscape:showpage\
shadow=\x22false\x22\x0a \
    units=\x22px\x22\x0a \
    inkscape:pag\
echeckerboard=\x22f\
alse\x22\x0a     showg\
uides=\x22false\x22\x0a  \
   inkscape:snap\
-bbox=\x22true\x22\x0a   \
  inkscape:bbox-\
paths=\x22true\x22\x0a   \
  inkscape:bbox-\
nodes=\x22true\x22\x0a   \
  inkscape:snap-\
bbox-edge-midpoi\
nts=\x22true\x22\x0a     \
inkscape:snap-bb\
ox-midpoints=\x22tr\
ue\x22\x0a     inkscap\
e:snap-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:object-paths=\x22\
true\x22\x0a     inksc\
ape:snap-interse\
ction-paths=\x22tru\
e\x22\x0a     inkscape\
:snap-smooth-nod\
es=\x22true\x22\x0a     i\
nkscape:snap-mid\
points=\x22true\x22\x0a  \
   inkscape:snap\
-global=\x22true\x22\x0a \
    fit-margin-t\
op=\x220\x22\x0a     fit-\
margin-left=\x220\x22\x0a\
     fit-margin-\
right=\x220\x22\x0a     f\
it-margin-bottom\
=\x220\x22\x0a     inksca\
pe:guide-bbox=\x22t\
rue\x22>\x0a    <inksc\
ape:grid\x0a       \
type=\x22xygrid\x22\x0a  \
     id=\x22grid974\
\x22\x0a       empspac\
ing=\x228\x22\x0a       s\
pacingx=\x220.26458\
332\x22\x0a       spac\
ingy=\x220.26458332\
\x22\x0a       dotted=\
\x22false\x22\x0a       v\
isible=\x22true\x22\x0a  \
     enabled=\x22tr\
ue\x22\x0a       snapv\
isiblegridlineso\
nly=\x22true\x22\x0a     \
  originx=\x220\x22\x0a  \
     originy=\x220\x22\
 />\x0a  </sodipodi\
:namedview>\x0a  <m\
etadata\x0a     id=\
\x22metadata5\x22>\x0a   \
 <rdf:RDF>\x0a     \
 <cc:Work\x0a      \
   rdf:about=\x22\x22>\
\x0a        <dc:for\
mat>image/svg+xm\
l</dc:format>\x0a  \
      <dc:type\x0a \
          rdf:re\
source=\x22http://p\
url.org/dc/dcmit\
ype/StillImage\x22 \
/>\x0a        <dc:t\
itle></dc:title>\
\x0a      </cc:Work\
>\x0a    </rdf:RDF>\
\x0a  </metadata>\x0a \
 <g\x0a     inkscap\
e:label=\x22Layer 1\
\x22\x0a     inkscape:\
groupmode=\x22layer\
\x22\x0a     id=\x22layer\
1\x22\x0a     transfor\
m=\x22translate(0,-\
291.70835)\x22>\x0a   \
 <path\x0a       st\
yle=\x22opacity:1;f\
ill:#ff0000;fill\
-opacity:1;strok\
e:none;stroke-wi\
dth:2;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
\x0a       d=\x22M 2 0\
 C 0.89199975 0 \
0 0.8919864 0 2 \
L 0 18 C 0 19.10\
8014 0.89199975 \
20 2 20 L 18 20 \
C 19.108 20 20 1\
9.108014 20 18 L\
 20 2 C 20 0.891\
9864 19.108 0 18\
 0 L 2 0 z M 15.\
878906 3.78125 L\
 17.996094 5.900\
3906 L 7.6835938\
 16.220703 L 2 1\
0.529297 L 4.119\
1406 8.4101562 L\
 7.6835938 11.97\
6562 L 15.878906\
 3.78125 z \x22\x0a   \
    transform=\x22m\
atrix(0.26458332\
,0,0,0.26458332,\
0,291.70835)\x22\x0a  \
     id=\x22rect833\
\x22 />\x0a    <g\x0a    \
   id=\x22g847\x22\x0a   \
    transform=\x22m\
atrix(0.05207439\
,0,0,0.05207453,\
-0.90125164,282.\
41203)\x22>\x0a      <\
g\x0a         id=\x22g\
851\x22>\x0a        <g\
\x0a           id=\x22\
g1059\x22\x0a         \
  transform=\x22mat\
rix(1.9986219,0,\
0,1.9986185,17.3\
24484,-313.52314\
)\x22>\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-y=\x223.\
175\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      d=\x22M 25.39\
9999,271.60002 -\
8.0000008e-7,246\
.20002 H 50.7999\
99 Z\x22\x0a          \
   id=\x22path883\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22 />\x0a        \
  <path\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          id=\x22pa\
th880\x22\x0a         \
    d=\x22m 25.3999\
99,271.60002 25.\
399999,25.4 H 0 \
Z\x22\x0a             \
inkscape:transfo\
rm-center-y=\x22-3.\
1749995\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             ry=\
\x225.0534658\x22\x0a    \
         y=\x22253.\
84885\x22\x0a         \
    x=\x227.6487389\
\x22\x0a             h\
eight=\x2235.528759\
\x22\x0a             w\
idth=\x2235.528786\x22\
\x0a             id\
=\x22rect870\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06184\
419;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <cir\
cle\x0a            \
 r=\x2225.396828\x22\x0a \
            cy=\x22\
271.60001\x22\x0a     \
        cx=\x2225.4\
\x22\x0a             i\
d=\x22path872\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0763\
5882;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <ci\
rcle\x0a           \
  transform=\x22rot\
ate(-45)\x22\x0a      \
       cx=\x22-174.\
08969\x22\x0a         \
    cy=\x22210.0107\
1\x22\x0a             \
r=\x2212.656071\x22\x0a  \
           id=\x22p\
ath876\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07399406\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x22-3.1749\
999\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22\x0a    \
         inkscap\
e:connector-curv\
ature=\x220\x22\x0a      \
       id=\x22path9\
04\x22\x0a            \
 d=\x22m 25.4,271.6\
0002 -25.4000004\
0000004,25.4 v -\
50.8 z\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x223.175\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a            \
 d=\x22m 25.399999,\
271.60002 25.4,-\
25.4 v 50.8 z\x22\x0a \
            id=\x22\
path906\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22 />\
\x0a          <rect\
\x0a             ry\
=\x225.0514922\x22\x0a   \
          y=\x22256\
.39301\x22\x0a        \
     x=\x222.566313\
5\x22\x0a             \
height=\x2230.44047\
9\x22\x0a             \
width=\x2245.693634\
\x22\x0a             i\
d=\x22rect837\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <rec\
t\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22\x0a           \
  id=\x22rect831\x22\x0a \
            widt\
h=\x2245.693588\x22\x0a  \
           heigh\
t=\x2230.44051\x22\x0a   \
          x=\x22248\
.76645\x22\x0a        \
     y=\x22-40.6333\
85\x22\x0a            \
 ry=\x225.051497\x22\x0a \
            tran\
sform=\x22rotate(90\
)\x22 />\x0a        </\
g>\x0a      </g>\x0a  \
  </g>\x0a    <path\
\x0a       style=\x22o\
pacity:1;fill:#f\
fc107;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
38596651;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-opacit\
y:1\x22\x0a       d=\x22m\
 50.206421,401.6\
7683 c 110.21720\
9,0.71279 55.108\
609,0.3564 0,0 z\
\x22\x0a       id=\x22rec\
t997\x22\x0a       ink\
scape:connector-\
curvature=\x220\x22 />\
\x0a  </g>\x0a</svg>\x0a\
\x00\x00 \x15\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22che\
ckbox_unchecked.\
svg\x22\x0a   inkscape\
:export-filename\
=\x22/home/yeison/D\
evelopment/piton\
/art/icon_lite.p\
ng\x22\x0a   inkscape:\
export-xdpi=\x2296\x22\
\x0a   inkscape:exp\
ort-ydpi=\x2296\x22>\x0a \
 <defs\x0a     id=\x22\
defs2\x22 />\x0a  <sod\
ipodi:namedview\x0a\
     id=\x22base\x22\x0a \
    pagecolor=\x22#\
ffffff\x22\x0a     bor\
dercolor=\x22#66666\
6\x22\x0a     borderop\
acity=\x221.0\x22\x0a    \
 inkscape:pageop\
acity=\x220.0\x22\x0a    \
 inkscape:pagesh\
adow=\x222\x22\x0a     in\
kscape:zoom=\x2224.\
802597\x22\x0a     ink\
scape:cx=\x228.2644\
565\x22\x0a     inksca\
pe:cy=\x226.6655853\
\x22\x0a     inkscape:\
document-units=\x22\
px\x22\x0a     inkscap\
e:current-layer=\
\x22layer1\x22\x0a     sh\
owgrid=\x22true\x22\x0a  \
   inkscape:wind\
ow-width=\x221920\x22\x0a\
     inkscape:wi\
ndow-height=\x22101\
5\x22\x0a     inkscape\
:window-x=\x220\x22\x0a  \
   inkscape:wind\
ow-y=\x220\x22\x0a     in\
kscape:window-ma\
ximized=\x221\x22\x0a    \
 inkscape:showpa\
geshadow=\x22false\x22\
\x0a     units=\x22px\x22\
\x0a     inkscape:p\
agecheckerboard=\
\x22false\x22\x0a     sho\
wguides=\x22false\x22\x0a\
     inkscape:sn\
ap-bbox=\x22true\x22\x0a \
    inkscape:bbo\
x-paths=\x22true\x22\x0a \
    inkscape:bbo\
x-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-bbox-edge-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
bbox-midpoints=\x22\
true\x22\x0a     inksc\
ape:snap-nodes=\x22\
true\x22\x0a     inksc\
ape:object-paths\
=\x22true\x22\x0a     ink\
scape:snap-inter\
section-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-smooth-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-global=\x22true\x22\
\x0a     fit-margin\
-top=\x220\x22\x0a     fi\
t-margin-left=\x220\
\x22\x0a     fit-margi\
n-right=\x220\x22\x0a    \
 fit-margin-bott\
om=\x220\x22\x0a     inks\
cape:guide-bbox=\
\x22true\x22>\x0a    <ink\
scape:grid\x0a     \
  type=\x22xygrid\x22\x0a\
       id=\x22grid9\
74\x22\x0a       empsp\
acing=\x228\x22\x0a      \
 spacingx=\x220.264\
58332\x22\x0a       sp\
acingy=\x220.264583\
32\x22\x0a       dotte\
d=\x22false\x22\x0a      \
 visible=\x22true\x22\x0a\
       enabled=\x22\
true\x22\x0a       sna\
pvisiblegridline\
sonly=\x22true\x22\x0a   \
    originx=\x220\x22\x0a\
       originy=\x22\
0\x22 />\x0a  </sodipo\
di:namedview>\x0a  \
<metadata\x0a     i\
d=\x22metadata5\x22>\x0a \
   <rdf:RDF>\x0a   \
   <cc:Work\x0a    \
     rdf:about=\x22\
\x22>\x0a        <dc:f\
ormat>image/svg+\
xml</dc:format>\x0a\
        <dc:type\
\x0a           rdf:\
resource=\x22http:/\
/purl.org/dc/dcm\
itype/StillImage\
\x22 />\x0a        <dc\
:title></dc:titl\
e>\x0a      </cc:Wo\
rk>\x0a    </rdf:RD\
F>\x0a  </metadata>\
\x0a  <g\x0a     inksc\
ape:label=\x22Layer\
 1\x22\x0a     inkscap\
e:groupmode=\x22lay\
er\x22\x0a     id=\x22lay\
er1\x22\x0a     transf\
orm=\x22translate(0\
,-291.70835)\x22>\x0a \
   <path\x0a       \
style=\x22opacity:1\
;fill:#ff0000;fi\
ll-opacity:1;str\
oke:none;stroke-\
width:2;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a       d=\x22M 2\
 0 C 0.89199975 \
0 0 0.8919864 0 \
2 L 0 18 C -2.96\
05947e-16 19.108\
014 0.89199975 2\
0 2 20 L 18 20 C\
 19.108 20 20 19\
.108014 20 18 L \
20 2 C 20 0.8919\
864 19.108 0 18 \
0 L 2 0 z M 5 3 \
L 15 3 C 16.108 \
3 17 3.8919889 1\
7 5 L 17 15 C 17\
 16.108011 16.10\
8 17 15 17 L 5 1\
7 C 3.892 17 3 1\
6.108011 3 15 L \
3 5 C 3 3.891988\
9 3.892 3 5 3 z \
\x22\x0a       transfo\
rm=\x22matrix(0.264\
58332,0,0,0.2645\
8332,0,291.70835\
)\x22\x0a       id=\x22re\
ct833\x22 />\x0a    <g\
\x0a       id=\x22g847\
\x22\x0a       transfo\
rm=\x22matrix(0.052\
07439,0,0,0.0520\
7453,-0.90125164\
,282.41203)\x22>\x0a  \
    <g\x0a         \
id=\x22g851\x22>\x0a     \
   <g\x0a          \
 id=\x22g1059\x22\x0a    \
       transform\
=\x22matrix(1.99862\
19,0,0,1.9986185\
,17.324484,-313.\
52314)\x22>\x0a       \
   <path\x0a       \
      inkscape:t\
ransform-center-\
y=\x223.175\x22\x0a      \
       style=\x22op\
acity:1;fill:non\
e;fill-opacity:0\
.49382719;stroke\
:#ffffff00;strok\
e-width:0.070004\
33;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22\x0a  \
           d=\x22M \
25.399999,271.60\
002 -8.0000008e-\
7,246.20002 H 50\
.799999 Z\x22\x0a     \
        id=\x22path\
883\x22\x0a           \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a             \
sodipodi:nodetyp\
es=\x22cccc\x22 />\x0a   \
       <path\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             i\
d=\x22path880\x22\x0a    \
         d=\x22m 25\
.399999,271.6000\
2 25.399999,25.4\
 H 0 Z\x22\x0a        \
     inkscape:tr\
ansform-center-y\
=\x22-3.1749995\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
rect\x0a           \
  ry=\x225.0534658\x22\
\x0a             y=\
\x22253.84885\x22\x0a    \
         x=\x227.64\
87389\x22\x0a         \
    height=\x2235.5\
28759\x22\x0a         \
    width=\x2235.52\
8786\x22\x0a          \
   id=\x22rect870\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
06184419;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <circle\x0a       \
      r=\x2225.3968\
28\x22\x0a            \
 cy=\x22271.60001\x22\x0a\
             cx=\
\x2225.4\x22\x0a         \
    id=\x22path872\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.07635882;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <circle\x0a      \
       transform\
=\x22rotate(-45)\x22\x0a \
            cx=\x22\
-174.08969\x22\x0a    \
         cy=\x22210\
.01071\x22\x0a        \
     r=\x2212.65607\
1\x22\x0a             \
id=\x22path876\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.073\
99406;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-x=\x22-3\
.1749999\x22\x0a      \
       sodipodi:\
nodetypes=\x22cccc\x22\
\x0a             in\
kscape:connector\
-curvature=\x220\x22\x0a \
            id=\x22\
path904\x22\x0a       \
      d=\x22m 25.4,\
271.60002 -25.40\
000040000004,25.\
4 v -50.8 z\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-x=\x223.\
175\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      d=\x22m 25.39\
9999,271.60002 2\
5.4,-25.4 v 50.8\
 z\x22\x0a            \
 id=\x22path906\x22\x0a  \
           inksc\
ape:connector-cu\
rvature=\x220\x22\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22 />\x0a          \
<rect\x0a          \
   ry=\x225.0514922\
\x22\x0a             y\
=\x22256.39301\x22\x0a   \
          x=\x222.5\
663135\x22\x0a        \
     height=\x2230.\
440479\x22\x0a        \
     width=\x2245.6\
93634\x22\x0a         \
    id=\x22rect837\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.0657438;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <rect\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.0657438;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22\x0a      \
       id=\x22rect8\
31\x22\x0a            \
 width=\x2245.69358\
8\x22\x0a             \
height=\x2230.44051\
\x22\x0a             x\
=\x22248.76645\x22\x0a   \
          y=\x22-40\
.633385\x22\x0a       \
      ry=\x225.0514\
97\x22\x0a            \
 transform=\x22rota\
te(90)\x22 />\x0a     \
   </g>\x0a      </\
g>\x0a    </g>\x0a    \
<path\x0a       sty\
le=\x22opacity:1;fi\
ll:#ffc107;fill-\
opacity:1;stroke\
:none;stroke-wid\
th:0.38596651;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-o\
pacity:1\x22\x0a      \
 d=\x22m 50.206421,\
401.67683 c 110.\
217209,0.71279 5\
5.108609,0.3564 \
0,0 z\x22\x0a       id\
=\x22rect997\x22\x0a     \
  inkscape:conne\
ctor-curvature=\x22\
0\x22 />\x0a  </g>\x0a</s\
vg>\x0a\
\x00\x00 \xca\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22dow\
narrow.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2228.704913\x22\x0a \
    inkscape:cx=\
\x2210.702147\x22\x0a    \
 inkscape:cy=\x222.\
4334445\x22\x0a     in\
kscape:document-\
units=\x22px\x22\x0a     \
inkscape:current\
-layer=\x22layer1\x22\x0a\
     showgrid=\x22t\
rue\x22\x0a     inksca\
pe:window-width=\
\x221920\x22\x0a     inks\
cape:window-heig\
ht=\x221015\x22\x0a     i\
nkscape:window-x\
=\x220\x22\x0a     inksca\
pe:window-y=\x220\x22\x0a\
     inkscape:wi\
ndow-maximized=\x22\
1\x22\x0a     inkscape\
:showpageshadow=\
\x22false\x22\x0a     uni\
ts=\x22px\x22\x0a     ink\
scape:pagechecke\
rboard=\x22false\x22\x0a \
    showguides=\x22\
true\x22\x0a     inksc\
ape:snap-bbox=\x22t\
rue\x22\x0a     inksca\
pe:bbox-paths=\x22t\
rue\x22\x0a     inksca\
pe:bbox-nodes=\x22t\
rue\x22\x0a     inksca\
pe:snap-bbox-edg\
e-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-bbox-midpo\
ints=\x22true\x22\x0a    \
 inkscape:snap-n\
odes=\x22true\x22\x0a    \
 inkscape:object\
-paths=\x22true\x22\x0a  \
   inkscape:snap\
-intersection-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-sm\
ooth-nodes=\x22true\
\x22\x0a     inkscape:\
snap-midpoints=\x22\
true\x22\x0a     inksc\
ape:snap-global=\
\x22true\x22\x0a     fit-\
margin-top=\x220\x22\x0a \
    fit-margin-l\
eft=\x220\x22\x0a     fit\
-margin-right=\x220\
\x22\x0a     fit-margi\
n-bottom=\x220\x22\x0a   \
  inkscape:guide\
-bbox=\x22true\x22>\x0a  \
  <inkscape:grid\
\x0a       type=\x22xy\
grid\x22\x0a       id=\
\x22grid974\x22\x0a      \
 empspacing=\x228\x22\x0a\
       spacingx=\
\x220.26458332\x22\x0a   \
    spacingy=\x220.\
26458332\x22\x0a      \
 dotted=\x22false\x22\x0a\
       visible=\x22\
true\x22\x0a       ena\
bled=\x22true\x22\x0a    \
   snapvisiblegr\
idlinesonly=\x22tru\
e\x22\x0a       origin\
x=\x220\x22\x0a       ori\
giny=\x220\x22 />\x0a  </\
sodipodi:namedvi\
ew>\x0a  <metadata\x0a\
     id=\x22metadat\
a5\x22>\x0a    <rdf:RD\
F>\x0a      <cc:Wor\
k\x0a         rdf:a\
bout=\x22\x22>\x0a       \
 <dc:format>imag\
e/svg+xml</dc:fo\
rmat>\x0a        <d\
c:type\x0a         \
  rdf:resource=\x22\
http://purl.org/\
dc/dcmitype/Stil\
lImage\x22 />\x0a     \
   <dc:title></d\
c:title>\x0a      <\
/cc:Work>\x0a    </\
rdf:RDF>\x0a  </met\
adata>\x0a  <g\x0a    \
 inkscape:label=\
\x22Layer 1\x22\x0a     i\
nkscape:groupmod\
e=\x22layer\x22\x0a     i\
d=\x22layer1\x22\x0a     \
transform=\x22trans\
late(0,-291.7083\
5)\x22>\x0a    <g\x0a    \
   id=\x22g847\x22\x0a   \
    transform=\x22m\
atrix(0.05207439\
,0,0,0.05207453,\
-0.90125164,282.\
41203)\x22>\x0a      <\
g\x0a         id=\x22g\
851\x22>\x0a        <g\
\x0a           id=\x22\
g1059\x22\x0a         \
  transform=\x22mat\
rix(1.9986219,0,\
0,1.9986185,17.3\
24484,-313.52314\
)\x22>\x0a          <p\
ath\x0a            \
 inkscape:transf\
orm-center-y=\x223.\
175\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07000433;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      d=\x22M 25.39\
9999,271.60002 -\
8.0000008e-7,246\
.20002 H 50.7999\
99 Z\x22\x0a          \
   id=\x22path883\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22 />\x0a        \
  <path\x0a        \
     sodipodi:no\
detypes=\x22cccc\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          id=\x22pa\
th880\x22\x0a         \
    d=\x22m 25.3999\
99,271.60002 25.\
399999,25.4 H 0 \
Z\x22\x0a             \
inkscape:transfo\
rm-center-y=\x22-3.\
1749995\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22 />\x0a\
          <rect\x0a\
             ry=\
\x225.0534658\x22\x0a    \
         y=\x22253.\
84885\x22\x0a         \
    x=\x227.6487389\
\x22\x0a             h\
eight=\x2235.528759\
\x22\x0a             w\
idth=\x2235.528786\x22\
\x0a             id\
=\x22rect870\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06184\
419;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <cir\
cle\x0a            \
 r=\x2225.396828\x22\x0a \
            cy=\x22\
271.60001\x22\x0a     \
        cx=\x2225.4\
\x22\x0a             i\
d=\x22path872\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0763\
5882;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <ci\
rcle\x0a           \
  transform=\x22rot\
ate(-45)\x22\x0a      \
       cx=\x22-174.\
08969\x22\x0a         \
    cy=\x22210.0107\
1\x22\x0a             \
r=\x2212.656071\x22\x0a  \
           id=\x22p\
ath876\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07399406\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x22-3.1749\
999\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22\x0a    \
         inkscap\
e:connector-curv\
ature=\x220\x22\x0a      \
       id=\x22path9\
04\x22\x0a            \
 d=\x22m 25.4,271.6\
0002 -25.4000004\
0000004,25.4 v -\
50.8 z\x22\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.07000433\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22 />\x0a \
         <path\x0a \
            inks\
cape:transform-c\
enter-x=\x223.175\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22\x0a            \
 d=\x22m 25.399999,\
271.60002 25.4,-\
25.4 v 50.8 z\x22\x0a \
            id=\x22\
path906\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22 />\
\x0a          <rect\
\x0a             ry\
=\x225.0514922\x22\x0a   \
          y=\x22256\
.39301\x22\x0a        \
     x=\x222.566313\
5\x22\x0a             \
height=\x2230.44047\
9\x22\x0a             \
width=\x2245.693634\
\x22\x0a             i\
d=\x22rect837\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0657\
438;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a          <rec\
t\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22\x0a           \
  id=\x22rect831\x22\x0a \
            widt\
h=\x2245.693588\x22\x0a  \
           heigh\
t=\x2230.44051\x22\x0a   \
          x=\x22248\
.76645\x22\x0a        \
     y=\x22-40.6333\
85\x22\x0a            \
 ry=\x225.051497\x22\x0a \
            tran\
sform=\x22rotate(90\
)\x22 />\x0a        </\
g>\x0a      </g>\x0a  \
  </g>\x0a    <path\
\x0a       style=\x22o\
pacity:1;fill:#f\
fc107;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
38596651;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-opacit\
y:1\x22\x0a       d=\x22m\
 50.206421,401.6\
7683 c 110.21720\
9,0.71279 55.108\
609,0.3564 0,0 z\
\x22\x0a       id=\x22rec\
t997\x22\x0a       ink\
scape:connector-\
curvature=\x220\x22 />\
\x0a    <path\x0a     \
  sodipodi:type=\
\x22star\x22\x0a       st\
yle=\x22opacity:1;f\
ill:#ff0000;fill\
-opacity:1;strok\
e:none;stroke-wi\
dth:1.38742065;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22\x0a      \
 id=\x22path828\x22\x0a  \
     sodipodi:si\
des=\x223\x22\x0a       s\
odipodi:cx=\x222.64\
58332\x22\x0a       so\
dipodi:cy=\x22294.0\
8537\x22\x0a       sod\
ipodi:r1=\x221.3874\
207\x22\x0a       sodi\
podi:r2=\x220.69371\
033\x22\x0a       sodi\
podi:arg1=\x221.570\
7963\x22\x0a       sod\
ipodi:arg2=\x222.61\
79939\x22\x0a       in\
kscape:flatsided\
=\x22true\x22\x0a       i\
nkscape:rounded=\
\x220.1\x22\x0a       ink\
scape:randomized\
=\x220\x22\x0a       d=\x22m\
 2.6458333,295.4\
7278 c -0.240308\
4,0 -1.3216958,-\
1.87302 -1.20154\
16,-2.08113 0.12\
01541,-0.20812 2\
.2829289,-0.2081\
2 2.403083,0 0.1\
201542,0.20811 -\
0.9612331,2.0811\
3 -1.2015414,2.0\
8113 z\x22\x0a       i\
nkscape:transfor\
m-center-y=\x220.22\
979542\x22 />\x0a  </g\
>\x0a</svg>\x0a\
\x00\x00-\x9a\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22too\
lbar-handle-vert\
ical.svg\x22\x0a   ink\
scape:export-fil\
ename=\x22/home/yei\
son/Development/\
piton/art/icon_l\
ite.png\x22\x0a   inks\
cape:export-xdpi\
=\x2296\x22\x0a   inkscap\
e:export-ydpi=\x229\
6\x22>\x0a  <defs\x0a    \
 id=\x22defs2\x22 />\x0a \
 <sodipodi:named\
view\x0a     id=\x22ba\
se\x22\x0a     pagecol\
or=\x22#ffffff\x22\x0a   \
  bordercolor=\x22#\
666666\x22\x0a     bor\
deropacity=\x221.0\x22\
\x0a     inkscape:p\
ageopacity=\x220.0\x22\
\x0a     inkscape:p\
ageshadow=\x222\x22\x0a  \
   inkscape:zoom\
=\x2212.401299\x22\x0a   \
  inkscape:cx=\x22-\
6.6600281\x22\x0a     \
inkscape:cy=\x225.8\
024891\x22\x0a     ink\
scape:document-u\
nits=\x22px\x22\x0a     i\
nkscape:current-\
layer=\x22layer1\x22\x0a \
    showgrid=\x22tr\
ue\x22\x0a     inkscap\
e:window-width=\x22\
1920\x22\x0a     inksc\
ape:window-heigh\
t=\x221004\x22\x0a     in\
kscape:window-x=\
\x220\x22\x0a     inkscap\
e:window-y=\x220\x22\x0a \
    inkscape:win\
dow-maximized=\x221\
\x22\x0a     inkscape:\
showpageshadow=\x22\
false\x22\x0a     unit\
s=\x22px\x22\x0a     inks\
cape:pagechecker\
board=\x22false\x22\x0a  \
   showguides=\x22t\
rue\x22\x0a     inksca\
pe:snap-bbox=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-paths=\x22tr\
ue\x22\x0a     inkscap\
e:bbox-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-bbox-edge\
-midpoints=\x22true\
\x22\x0a     inkscape:\
snap-bbox-midpoi\
nts=\x22true\x22\x0a     \
inkscape:snap-no\
des=\x22true\x22\x0a     \
inkscape:object-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
intersection-pat\
hs=\x22true\x22\x0a     i\
nkscape:snap-smo\
oth-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-global=\x22\
true\x22\x0a     fit-m\
argin-top=\x220\x22\x0a  \
   fit-margin-le\
ft=\x220\x22\x0a     fit-\
margin-right=\x220\x22\
\x0a     fit-margin\
-bottom=\x220\x22\x0a    \
 inkscape:guide-\
bbox=\x22true\x22>\x0a   \
 <inkscape:grid\x0a\
       type=\x22xyg\
rid\x22\x0a       id=\x22\
grid974\x22\x0a       \
empspacing=\x228\x22\x0a \
      spacingx=\x22\
0.26458332\x22\x0a    \
   spacingy=\x220.2\
6458332\x22\x0a       \
dotted=\x22false\x22\x0a \
      visible=\x22t\
rue\x22\x0a       enab\
led=\x22true\x22\x0a     \
  snapvisiblegri\
dlinesonly=\x22true\
\x22\x0a       originx\
=\x220\x22\x0a       orig\
iny=\x220\x22 />\x0a  </s\
odipodi:namedvie\
w>\x0a  <metadata\x0a \
    id=\x22metadata\
5\x22>\x0a    <rdf:RDF\
>\x0a      <cc:Work\
\x0a         rdf:ab\
out=\x22\x22>\x0a        \
<dc:format>image\
/svg+xml</dc:for\
mat>\x0a        <dc\
:type\x0a          \
 rdf:resource=\x22h\
ttp://purl.org/d\
c/dcmitype/Still\
Image\x22 />\x0a      \
  <dc:title />\x0a \
     </cc:Work>\x0a\
    </rdf:RDF>\x0a \
 </metadata>\x0a  <\
g\x0a     inkscape:\
label=\x22Layer 1\x22\x0a\
     inkscape:gr\
oupmode=\x22layer\x22\x0a\
     id=\x22layer1\x22\
\x0a     transform=\
\x22translate(0,-29\
1.70835)\x22>\x0a    <\
g\x0a       id=\x22g84\
7\x22\x0a       transf\
orm=\x22matrix(0.05\
207439,0,0,0.052\
07453,-0.9012516\
4,282.41203)\x22>\x0a \
     <g\x0a        \
 id=\x22g851\x22>\x0a    \
    <g\x0a         \
  id=\x22g1059\x22\x0a   \
        transfor\
m=\x22matrix(1.9986\
219,0,0,1.998618\
5,17.324484,-313\
.52314)\x22>\x0a      \
    <path\x0a      \
       inkscape:\
transform-center\
-y=\x223.175\x22\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.07000\
433;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22\x0a \
            d=\x22M\
 25.399999,271.6\
0002 -8.0000008e\
-7,246.20002 H 5\
0.799999 Z\x22\x0a    \
         id=\x22pat\
h883\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 sodipodi:nodety\
pes=\x22cccc\x22 />\x0a  \
        <path\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22\x0a           \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a             \
id=\x22path880\x22\x0a   \
          d=\x22m 2\
5.399999,271.600\
02 25.399999,25.\
4 H 0 Z\x22\x0a       \
      inkscape:t\
ransform-center-\
y=\x22-3.1749995\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   ry=\x225.0534658\
\x22\x0a             y\
=\x22253.84885\x22\x0a   \
          x=\x227.6\
487389\x22\x0a        \
     height=\x2235.\
528759\x22\x0a        \
     width=\x2235.5\
28786\x22\x0a         \
    id=\x22rect870\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.06184419;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <circle\x0a      \
       r=\x2225.396\
828\x22\x0a           \
  cy=\x22271.60001\x22\
\x0a             cx\
=\x2225.4\x22\x0a        \
     id=\x22path872\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07635882;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <circle\x0a     \
        transfor\
m=\x22rotate(-45)\x22\x0a\
             cx=\
\x22-174.08969\x22\x0a   \
          cy=\x2221\
0.01071\x22\x0a       \
      r=\x2212.6560\
71\x22\x0a            \
 id=\x22path876\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
399406;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
path\x0a           \
  inkscape:trans\
form-center-x=\x22-\
3.1749999\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22\x0a             i\
nkscape:connecto\
r-curvature=\x220\x22\x0a\
             id=\
\x22path904\x22\x0a      \
       d=\x22m 25.4\
,271.60002 -25.4\
0000040000004,25\
.4 v -50.8 z\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22 />\x0a          <\
path\x0a           \
  inkscape:trans\
form-center-x=\x223\
.175\x22\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.07000433;s\
troke-linecap:ro\
und;stroke-linej\
oin:round;stroke\
-miterlimit:4;st\
roke-dasharray:n\
one;stroke-dasho\
ffset:0;stroke-o\
pacity:1;paint-o\
rder:stroke fill\
 markers\x22\x0a      \
       d=\x22m 25.3\
99999,271.60002 \
25.4,-25.4 v 50.\
8 z\x22\x0a           \
  id=\x22path906\x22\x0a \
            inks\
cape:connector-c\
urvature=\x220\x22\x0a   \
          sodipo\
di:nodetypes=\x22cc\
cc\x22 />\x0a         \
 <rect\x0a         \
    ry=\x225.051492\
2\x22\x0a             \
y=\x22256.39301\x22\x0a  \
           x=\x222.\
5663135\x22\x0a       \
      height=\x2230\
.440479\x22\x0a       \
      width=\x2245.\
693634\x22\x0a        \
     id=\x22rect837\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.0657438;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <rect\x0a        \
     style=\x22opac\
ity:1;fill:none;\
fill-opacity:0.4\
9382719;stroke:#\
ffffff00;stroke-\
width:0.0657438;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22\x0a     \
        id=\x22rect\
831\x22\x0a           \
  width=\x2245.6935\
88\x22\x0a            \
 height=\x2230.4405\
1\x22\x0a             \
x=\x22248.76645\x22\x0a  \
           y=\x22-4\
0.633385\x22\x0a      \
       ry=\x225.051\
497\x22\x0a           \
  transform=\x22rot\
ate(90)\x22 />\x0a    \
    </g>\x0a      <\
/g>\x0a    </g>\x0a   \
 <path\x0a       st\
yle=\x22opacity:1;f\
ill:#ffc107;fill\
-opacity:1;strok\
e:none;stroke-wi\
dth:0.38596651;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
opacity:1\x22\x0a     \
  d=\x22m 50.206421\
,401.67683 c 110\
.217209,0.71279 \
55.108609,0.3564\
 0,0 z\x22\x0a       i\
d=\x22rect997\x22\x0a    \
   inkscape:conn\
ector-curvature=\
\x220\x22 />\x0a    <g\x0a  \
     id=\x22g850\x22\x0a \
      transform=\
\x22rotate(90,2.645\
8333,294.35418)\x22\
>\x0a      <g\x0a     \
    id=\x22g839\x22>\x0a \
       <rect\x0a   \
        y=\x22291.7\
0834\x22\x0a          \
 x=\x221.5875\x22\x0a    \
       height=\x220\
.52916664\x22\x0a     \
      width=\x220.5\
2916664\x22\x0a       \
    id=\x22rect830\x22\
\x0a           styl\
e=\x22opacity:1;fil\
l:#ff0000;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22 />\x0a     \
   <rect\x0a       \
    style=\x22opaci\
ty:1;fill:#ff000\
0;fill-opacity:1\
;stroke:none;str\
oke-width:0.5291\
6664;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1\x22\x0a\
           id=\x22r\
ect832\x22\x0a        \
   width=\x220.5291\
6664\x22\x0a          \
 height=\x220.52916\
664\x22\x0a           \
x=\x221.5875\x22\x0a     \
      y=\x22293.295\
84\x22 />\x0a        <\
rect\x0a           \
y=\x22294.88336\x22\x0a  \
         x=\x221.58\
75\x22\x0a           h\
eight=\x220.5291666\
4\x22\x0a           wi\
dth=\x220.52916664\x22\
\x0a           id=\x22\
rect834\x22\x0a       \
    style=\x22opaci\
ty:1;fill:#ff000\
0;fill-opacity:1\
;stroke:none;str\
oke-width:0.5291\
6664;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1\x22 \
/>\x0a        <rect\
\x0a           styl\
e=\x22opacity:1;fil\
l:#ff0000;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22\x0a        \
   id=\x22rect836\x22\x0a\
           width\
=\x220.52916664\x22\x0a  \
         height=\
\x220.52916664\x22\x0a   \
        x=\x221.587\
5\x22\x0a           y=\
\x22296.47086\x22 />\x0a \
       <rect\x0a   \
        y=\x22292.5\
0208\x22\x0a          \
 x=\x222.3812499\x22\x0a \
          height\
=\x220.52916664\x22\x0a  \
         width=\x22\
0.52916664\x22\x0a    \
       id=\x22rect8\
38\x22\x0a           s\
tyle=\x22opacity:1;\
fill:#ff0000;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:0.52916664;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1\x22 />\x0a  \
      <rect\x0a    \
       style=\x22op\
acity:1;fill:#ff\
0000;fill-opacit\
y:1;stroke:none;\
stroke-width:0.5\
2916664;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1\x22\x0a           id\
=\x22rect840\x22\x0a     \
      width=\x220.5\
2916664\x22\x0a       \
    height=\x220.52\
916664\x22\x0a        \
   x=\x222.3812499\x22\
\x0a           y=\x222\
94.0896\x22 />\x0a    \
    <rect\x0a      \
     y=\x22295.6770\
9\x22\x0a           x=\
\x222.3812499\x22\x0a    \
       height=\x220\
.52916664\x22\x0a     \
      width=\x220.5\
2916664\x22\x0a       \
    id=\x22rect842\x22\
\x0a           styl\
e=\x22opacity:1;fil\
l:#ff0000;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22 />\x0a     \
   <rect\x0a       \
    style=\x22opaci\
ty:1;fill:#ff000\
0;fill-opacity:1\
;stroke:none;str\
oke-width:0.5291\
6664;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1\x22\x0a\
           id=\x22r\
ect844\x22\x0a        \
   width=\x220.5291\
6664\x22\x0a          \
 height=\x220.52916\
664\x22\x0a           \
x=\x223.175\x22\x0a      \
     y=\x22291.7083\
4\x22 />\x0a        <r\
ect\x0a           y\
=\x22293.29584\x22\x0a   \
        x=\x223.175\
\x22\x0a           hei\
ght=\x220.52916664\x22\
\x0a           widt\
h=\x220.52916664\x22\x0a \
          id=\x22re\
ct846\x22\x0a         \
  style=\x22opacity\
:1;fill:#ff0000;\
fill-opacity:1;s\
troke:none;strok\
e-width:0.529166\
64;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1\x22 />\
\x0a        <rect\x0a \
          style=\
\x22opacity:1;fill:\
#ff0000;fill-opa\
city:1;stroke:no\
ne;stroke-width:\
0.52916664;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1\x22\x0a          \
 id=\x22rect848\x22\x0a  \
         width=\x22\
0.52916664\x22\x0a    \
       height=\x220\
.52916664\x22\x0a     \
      x=\x223.175\x22\x0a\
           y=\x2229\
4.88336\x22 />\x0a    \
    <rect\x0a      \
     y=\x22296.4708\
6\x22\x0a           x=\
\x223.175\x22\x0a        \
   height=\x220.529\
16664\x22\x0a         \
  width=\x220.52916\
664\x22\x0a           \
id=\x22rect850\x22\x0a   \
        style=\x22o\
pacity:1;fill:#f\
f0000;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
52916664;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22 />\x0a      </g\
>\x0a    </g>\x0a  </g\
>\x0a</svg>\x0a\
\x00\x00!.\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22lef\
tarrow.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2211.745467\x22\x0a \
    inkscape:cx=\
\x22-19.921584\x22\x0a   \
  inkscape:cy=\x22-\
13.919269\x22\x0a     \
inkscape:documen\
t-units=\x22px\x22\x0a   \
  inkscape:curre\
nt-layer=\x22layer1\
\x22\x0a     showgrid=\
\x22true\x22\x0a     inks\
cape:window-widt\
h=\x221920\x22\x0a     in\
kscape:window-he\
ight=\x221015\x22\x0a    \
 inkscape:window\
-x=\x220\x22\x0a     inks\
cape:window-y=\x220\
\x22\x0a     inkscape:\
window-maximized\
=\x221\x22\x0a     inksca\
pe:showpageshado\
w=\x22false\x22\x0a     u\
nits=\x22px\x22\x0a     i\
nkscape:pagechec\
kerboard=\x22false\x22\
\x0a     showguides\
=\x22true\x22\x0a     ink\
scape:snap-bbox=\
\x22true\x22\x0a     inks\
cape:bbox-paths=\
\x22true\x22\x0a     inks\
cape:bbox-nodes=\
\x22true\x22\x0a     inks\
cape:snap-bbox-e\
dge-midpoints=\x22t\
rue\x22\x0a     inksca\
pe:snap-bbox-mid\
points=\x22true\x22\x0a  \
   inkscape:snap\
-nodes=\x22true\x22\x0a  \
   inkscape:obje\
ct-paths=\x22true\x22\x0a\
     inkscape:sn\
ap-intersection-\
paths=\x22true\x22\x0a   \
  inkscape:snap-\
smooth-nodes=\x22tr\
ue\x22\x0a     inkscap\
e:snap-midpoints\
=\x22true\x22\x0a     ink\
scape:snap-globa\
l=\x22true\x22\x0a     fi\
t-margin-top=\x220\x22\
\x0a     fit-margin\
-left=\x220\x22\x0a     f\
it-margin-right=\
\x220\x22\x0a     fit-mar\
gin-bottom=\x220\x22\x0a \
    inkscape:gui\
de-bbox=\x22true\x22>\x0a\
    <inkscape:gr\
id\x0a       type=\x22\
xygrid\x22\x0a       i\
d=\x22grid974\x22\x0a    \
   empspacing=\x228\
\x22\x0a       spacing\
x=\x220.26458332\x22\x0a \
      spacingy=\x22\
0.26458332\x22\x0a    \
   dotted=\x22false\
\x22\x0a       visible\
=\x22true\x22\x0a       e\
nabled=\x22true\x22\x0a  \
     snapvisible\
gridlinesonly=\x22t\
rue\x22\x0a       orig\
inx=\x220\x22\x0a       o\
riginy=\x220\x22 />\x0a  \
</sodipodi:named\
view>\x0a  <metadat\
a\x0a     id=\x22metad\
ata5\x22>\x0a    <rdf:\
RDF>\x0a      <cc:W\
ork\x0a         rdf\
:about=\x22\x22>\x0a     \
   <dc:format>im\
age/svg+xml</dc:\
format>\x0a        \
<dc:type\x0a       \
    rdf:resource\
=\x22http://purl.or\
g/dc/dcmitype/St\
illImage\x22 />\x0a   \
     <dc:title /\
>\x0a      </cc:Wor\
k>\x0a    </rdf:RDF\
>\x0a  </metadata>\x0a\
  <g\x0a     inksca\
pe:label=\x22Layer \
1\x22\x0a     inkscape\
:groupmode=\x22laye\
r\x22\x0a     id=\x22laye\
r1\x22\x0a     transfo\
rm=\x22translate(0,\
-291.70835)\x22>\x0a  \
  <g\x0a       id=\x22\
g847\x22\x0a       tra\
nsform=\x22matrix(0\
.05207439,0,0,0.\
05207453,-0.9012\
5164,282.41203)\x22\
>\x0a      <g\x0a     \
    id=\x22g851\x22>\x0a \
       <g\x0a      \
     id=\x22g1059\x22\x0a\
           trans\
form=\x22matrix(1.9\
986219,0,0,1.998\
6185,17.324484,-\
313.52314)\x22>\x0a   \
       <path\x0a   \
          inksca\
pe:transform-cen\
ter-y=\x223.175\x22\x0a  \
           style\
=\x22opacity:1;fill\
:none;fill-opaci\
ty:0.49382719;st\
roke:#ffffff00;s\
troke-width:0.07\
000433;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a             d\
=\x22M 25.399999,27\
1.60002 -8.00000\
08e-7,246.20002 \
H 50.799999 Z\x22\x0a \
            id=\x22\
path883\x22\x0a       \
      inkscape:c\
onnector-curvatu\
re=\x220\x22\x0a         \
    sodipodi:nod\
etypes=\x22cccc\x22 />\
\x0a          <path\
\x0a             so\
dipodi:nodetypes\
=\x22cccc\x22\x0a        \
     inkscape:co\
nnector-curvatur\
e=\x220\x22\x0a          \
   id=\x22path880\x22\x0a\
             d=\x22\
m 25.399999,271.\
60002 25.399999,\
25.4 H 0 Z\x22\x0a    \
         inkscap\
e:transform-cent\
er-y=\x22-3.1749995\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.07000433;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <rect\x0a       \
      ry=\x225.0534\
658\x22\x0a           \
  y=\x22253.84885\x22\x0a\
             x=\x22\
7.6487389\x22\x0a     \
        height=\x22\
35.528759\x22\x0a     \
        width=\x223\
5.528786\x22\x0a      \
       id=\x22rect8\
70\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.06184419;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22 />\x0a     \
     <circle\x0a   \
          r=\x2225.\
396828\x22\x0a        \
     cy=\x22271.600\
01\x22\x0a            \
 cx=\x2225.4\x22\x0a     \
        id=\x22path\
872\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.07635882;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22 />\x0a    \
      <circle\x0a  \
           trans\
form=\x22rotate(-45\
)\x22\x0a             \
cx=\x22-174.08969\x22\x0a\
             cy=\
\x22210.01071\x22\x0a    \
         r=\x2212.6\
56071\x22\x0a         \
    id=\x22path876\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.07399406;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-x\
=\x22-3.1749999\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22\x0a           \
  inkscape:conne\
ctor-curvature=\x22\
0\x22\x0a             \
id=\x22path904\x22\x0a   \
          d=\x22m 2\
5.4,271.60002 -2\
5.40000040000004\
,25.4 v -50.8 z\x22\
\x0a             st\
yle=\x22opacity:1;f\
ill:none;fill-op\
acity:0.49382719\
;stroke:#ffffff0\
0;stroke-width:0\
.07000433;stroke\
-linecap:round;s\
troke-linejoin:r\
ound;stroke-mite\
rlimit:4;stroke-\
dasharray:none;s\
troke-dashoffset\
:0;stroke-opacit\
y:1;paint-order:\
stroke fill mark\
ers\x22 />\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-x\
=\x223.175\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          d=\x22m 2\
5.399999,271.600\
02 25.4,-25.4 v \
50.8 z\x22\x0a        \
     id=\x22path906\
\x22\x0a             i\
nkscape:connecto\
r-curvature=\x220\x22\x0a\
             sod\
ipodi:nodetypes=\
\x22cccc\x22 />\x0a      \
    <rect\x0a      \
       ry=\x225.051\
4922\x22\x0a          \
   y=\x22256.39301\x22\
\x0a             x=\
\x222.5663135\x22\x0a    \
         height=\
\x2230.440479\x22\x0a    \
         width=\x22\
45.693634\x22\x0a     \
        id=\x22rect\
837\x22\x0a           \
  style=\x22opacity\
:1;fill:none;fil\
l-opacity:0.4938\
2719;stroke:#fff\
fff00;stroke-wid\
th:0.0657438;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22 />\x0a     \
     <rect\x0a     \
        style=\x22o\
pacity:1;fill:no\
ne;fill-opacity:\
0.49382719;strok\
e:#ffffff00;stro\
ke-width:0.06574\
38;stroke-lineca\
p:round;stroke-l\
inejoin:round;st\
roke-miterlimit:\
4;stroke-dasharr\
ay:none;stroke-d\
ashoffset:0;stro\
ke-opacity:1;pai\
nt-order:stroke \
fill markers\x22\x0a  \
           id=\x22r\
ect831\x22\x0a        \
     width=\x2245.6\
93588\x22\x0a         \
    height=\x2230.4\
4051\x22\x0a          \
   x=\x22248.76645\x22\
\x0a             y=\
\x22-40.633385\x22\x0a   \
          ry=\x225.\
051497\x22\x0a        \
     transform=\x22\
rotate(90)\x22 />\x0a \
       </g>\x0a    \
  </g>\x0a    </g>\x0a\
    <path\x0a      \
 style=\x22opacity:\
1;fill:#ffc107;f\
ill-opacity:1;st\
roke:none;stroke\
-width:0.3859665\
1;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-opacity:1\x22\x0a  \
     d=\x22m 50.206\
421,401.67683 c \
110.217209,0.712\
79 55.108609,0.3\
564 0,0 z\x22\x0a     \
  id=\x22rect997\x22\x0a \
      inkscape:c\
onnector-curvatu\
re=\x220\x22 />\x0a    <p\
ath\x0a       sodip\
odi:type=\x22star\x22\x0a\
       style=\x22op\
acity:1;fill:#ff\
0000;fill-opacit\
y:1;stroke:none;\
stroke-width:1.3\
8742065;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22\x0a       id=\x22pa\
th828\x22\x0a       so\
dipodi:sides=\x223\x22\
\x0a       sodipodi\
:cx=\x22-2.6458433\x22\
\x0a       sodipodi\
:cy=\x22-294.16339\x22\
\x0a       sodipodi\
:r1=\x221.3874207\x22\x0a\
       sodipodi:\
r2=\x220.69371033\x22\x0a\
       sodipodi:\
arg1=\x221.5707963\x22\
\x0a       sodipodi\
:arg2=\x222.6179939\
\x22\x0a       inkscap\
e:flatsided=\x22tru\
e\x22\x0a       inksca\
pe:rounded=\x220.1\x22\
\x0a       inkscape\
:randomized=\x220\x22\x0a\
       d=\x22m -2.6\
458432,-292.7759\
7 c -0.2403083,0\
 -1.3216958,-1.8\
7301 -1.2015416,\
-2.08113 0.12015\
41,-0.20811 2.28\
29289,-0.20811 2\
.403083,0 0.1201\
542,0.20812 -0.9\
612331,2.08113 -\
1.2015414,2.0811\
3 z\x22\x0a       inks\
cape:transform-c\
enter-y=\x22-5.0863\
116e-06\x22\x0a       \
transform=\x22rotat\
e(90,-294.12438,\
2.6458332)\x22\x0a    \
   inkscape:tran\
sform-center-x=\x22\
0.22980664\x22 />\x0a \
 </g>\x0a</svg>\x0a\
\x00\x00 q\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22flo\
at.svg\x22\x0a   inksc\
ape:export-filen\
ame=\x22/home/yeiso\
n/Development/pi\
ton/art/icon_lit\
e.png\x22\x0a   inksca\
pe:export-xdpi=\x22\
96\x22\x0a   inkscape:\
export-ydpi=\x2296\x22\
>\x0a  <defs\x0a     i\
d=\x22defs2\x22 />\x0a  <\
sodipodi:namedvi\
ew\x0a     id=\x22base\
\x22\x0a     pagecolor\
=\x22#ffffff\x22\x0a     \
bordercolor=\x22#66\
6666\x22\x0a     borde\
ropacity=\x221.0\x22\x0a \
    inkscape:pag\
eopacity=\x220.0\x22\x0a \
    inkscape:pag\
eshadow=\x222\x22\x0a    \
 inkscape:zoom=\x22\
23.490934\x22\x0a     \
inkscape:cx=\x2212.\
388735\x22\x0a     ink\
scape:cy=\x227.1323\
576\x22\x0a     inksca\
pe:document-unit\
s=\x22px\x22\x0a     inks\
cape:current-lay\
er=\x22layer1\x22\x0a    \
 showgrid=\x22true\x22\
\x0a     inkscape:w\
indow-width=\x22192\
0\x22\x0a     inkscape\
:window-height=\x22\
1004\x22\x0a     inksc\
ape:window-x=\x220\x22\
\x0a     inkscape:w\
indow-y=\x220\x22\x0a    \
 inkscape:window\
-maximized=\x221\x22\x0a \
    inkscape:sho\
wpageshadow=\x22fal\
se\x22\x0a     units=\x22\
px\x22\x0a     inkscap\
e:pagecheckerboa\
rd=\x22false\x22\x0a     \
showguides=\x22true\
\x22\x0a     inkscape:\
snap-bbox=\x22true\x22\
\x0a     inkscape:b\
box-paths=\x22true\x22\
\x0a     inkscape:b\
box-nodes=\x22true\x22\
\x0a     inkscape:s\
nap-bbox-edge-mi\
dpoints=\x22true\x22\x0a \
    inkscape:sna\
p-bbox-midpoints\
=\x22true\x22\x0a     ink\
scape:snap-nodes\
=\x22false\x22\x0a     in\
kscape:object-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-in\
tersection-paths\
=\x22true\x22\x0a     ink\
scape:snap-smoot\
h-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-global=\x22tr\
ue\x22\x0a     fit-mar\
gin-top=\x220\x22\x0a    \
 fit-margin-left\
=\x220\x22\x0a     fit-ma\
rgin-right=\x220\x22\x0a \
    fit-margin-b\
ottom=\x220\x22\x0a     i\
nkscape:guide-bb\
ox=\x22true\x22>\x0a    <\
inkscape:grid\x0a  \
     type=\x22xygri\
d\x22\x0a       id=\x22gr\
id974\x22\x0a       em\
pspacing=\x228\x22\x0a   \
    spacingx=\x220.\
26458332\x22\x0a      \
 spacingy=\x220.264\
58332\x22\x0a       do\
tted=\x22false\x22\x0a   \
    visible=\x22tru\
e\x22\x0a       enable\
d=\x22true\x22\x0a       \
snapvisiblegridl\
inesonly=\x22true\x22\x0a\
       originx=\x22\
0\x22\x0a       origin\
y=\x220\x22 />\x0a  </sod\
ipodi:namedview>\
\x0a  <metadata\x0a   \
  id=\x22metadata5\x22\
>\x0a    <rdf:RDF>\x0a\
      <cc:Work\x0a \
        rdf:abou\
t=\x22\x22>\x0a        <d\
c:format>image/s\
vg+xml</dc:forma\
t>\x0a        <dc:t\
ype\x0a           r\
df:resource=\x22htt\
p://purl.org/dc/\
dcmitype/StillIm\
age\x22 />\x0a        \
<dc:title />\x0a   \
   </cc:Work>\x0a  \
  </rdf:RDF>\x0a  <\
/metadata>\x0a  <g\x0a\
     inkscape:la\
bel=\x22Layer 1\x22\x0a  \
   inkscape:grou\
pmode=\x22layer\x22\x0a  \
   id=\x22layer1\x22\x0a \
    transform=\x22t\
ranslate(0,-291.\
70835)\x22>\x0a    <g\x0a\
       id=\x22g847\x22\
\x0a       transfor\
m=\x22matrix(0.0520\
7439,0,0,0.05207\
453,-0.90125164,\
282.41203)\x22>\x0a   \
   <g\x0a         i\
d=\x22g851\x22>\x0a      \
  <g\x0a           \
id=\x22g1059\x22\x0a     \
      transform=\
\x22matrix(1.998621\
9,0,0,1.9986185,\
17.324484,-313.5\
2314)\x22>\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-y\
=\x223.175\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          d=\x22M 2\
5.399999,271.600\
02 -8.0000008e-7\
,246.20002 H 50.\
799999 Z\x22\x0a      \
       id=\x22path8\
83\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22 />\x0a    \
      <path\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             id\
=\x22path880\x22\x0a     \
        d=\x22m 25.\
399999,271.60002\
 25.399999,25.4 \
H 0 Z\x22\x0a         \
    inkscape:tra\
nsform-center-y=\
\x22-3.1749995\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <r\
ect\x0a            \
 ry=\x225.0534658\x22\x0a\
             y=\x22\
253.84885\x22\x0a     \
        x=\x227.648\
7389\x22\x0a          \
   height=\x2235.52\
8759\x22\x0a          \
   width=\x2235.528\
786\x22\x0a           \
  id=\x22rect870\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
6184419;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<circle\x0a        \
     r=\x2225.39682\
8\x22\x0a             \
cy=\x22271.60001\x22\x0a \
            cx=\x22\
25.4\x22\x0a          \
   id=\x22path872\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07635882;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <circle\x0a       \
      transform=\
\x22rotate(-45)\x22\x0a  \
           cx=\x22-\
174.08969\x22\x0a     \
        cy=\x22210.\
01071\x22\x0a         \
    r=\x2212.656071\
\x22\x0a             i\
d=\x22path876\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0739\
9406;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x22-3.\
1749999\x22\x0a       \
      sodipodi:n\
odetypes=\x22cccc\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           id=\x22p\
ath904\x22\x0a        \
     d=\x22m 25.4,2\
71.60002 -25.400\
00040000004,25.4\
 v -50.8 z\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0700\
0433;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x223.1\
75\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07000433;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a        \
     d=\x22m 25.399\
999,271.60002 25\
.4,-25.4 v 50.8 \
z\x22\x0a             \
id=\x22path906\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22 />\x0a          <\
rect\x0a           \
  ry=\x225.0514922\x22\
\x0a             y=\
\x22256.39301\x22\x0a    \
         x=\x222.56\
63135\x22\x0a         \
    height=\x2230.4\
40479\x22\x0a         \
    width=\x2245.69\
3634\x22\x0a          \
   id=\x22rect837\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      id=\x22rect83\
1\x22\x0a             \
width=\x2245.693588\
\x22\x0a             h\
eight=\x2230.44051\x22\
\x0a             x=\
\x22248.76645\x22\x0a    \
         y=\x22-40.\
633385\x22\x0a        \
     ry=\x225.05149\
7\x22\x0a             \
transform=\x22rotat\
e(90)\x22 />\x0a      \
  </g>\x0a      </g\
>\x0a    </g>\x0a    <\
path\x0a       styl\
e=\x22opacity:1;fil\
l:#ffc107;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.38596651;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-op\
acity:1\x22\x0a       \
d=\x22m 50.206421,4\
01.67683 c 110.2\
17209,0.71279 55\
.108609,0.3564 0\
,0 z\x22\x0a       id=\
\x22rect997\x22\x0a      \
 inkscape:connec\
tor-curvature=\x220\
\x22 />\x0a    <rect\x0a \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:1;\
stroke:#ff0000;s\
troke-width:0.52\
916664;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
;paint-order:str\
oke fill markers\
\x22\x0a       id=\x22rec\
t829\x22\x0a       wid\
th=\x222.6581812\x22\x0a \
      height=\x222.\
658181\x22\x0a       x\
=\x220.6522209\x22\x0a   \
    y=\x22293.68961\
\x22\x0a       ry=\x220.2\
9536656\x22 />\x0a    \
<rect\x0a       ry=\
\x220.29536656\x22\x0a   \
    y=\x22292.3606\x22\
\x0a       x=\x221.981\
2645\x22\x0a       hei\
ght=\x222.658181\x22\x0a \
      width=\x222.6\
581812\x22\x0a       i\
d=\x22rect839\x22\x0a    \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:1;str\
oke:#ff0000;stro\
ke-width:0.52916\
664;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1;pa\
int-order:stroke\
 fill markers\x22 /\
>\x0a  </g>\x0a</svg>\x0a\
\
\x00\x00,\xc0\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22too\
lbar-handle-hori\
zontal.svg\x22\x0a   i\
nkscape:export-f\
ilename=\x22/home/y\
eison/Developmen\
t/piton/art/icon\
_lite.png\x22\x0a   in\
kscape:export-xd\
pi=\x2296\x22\x0a   inksc\
ape:export-ydpi=\
\x2296\x22>\x0a  <defs\x0a  \
   id=\x22defs2\x22 />\
\x0a  <sodipodi:nam\
edview\x0a     id=\x22\
base\x22\x0a     pagec\
olor=\x22#ffffff\x22\x0a \
    bordercolor=\
\x22#666666\x22\x0a     b\
orderopacity=\x221.\
0\x22\x0a     inkscape\
:pageopacity=\x220.\
0\x22\x0a     inkscape\
:pageshadow=\x222\x22\x0a\
     inkscape:zo\
om=\x2224.802598\x22\x0a \
    inkscape:cx=\
\x223.483525\x22\x0a     \
inkscape:cy=\x2210.\
683358\x22\x0a     ink\
scape:document-u\
nits=\x22px\x22\x0a     i\
nkscape:current-\
layer=\x22g839\x22\x0a   \
  showgrid=\x22true\
\x22\x0a     inkscape:\
window-width=\x2219\
20\x22\x0a     inkscap\
e:window-height=\
\x221004\x22\x0a     inks\
cape:window-x=\x220\
\x22\x0a     inkscape:\
window-y=\x220\x22\x0a   \
  inkscape:windo\
w-maximized=\x221\x22\x0a\
     inkscape:sh\
owpageshadow=\x22fa\
lse\x22\x0a     units=\
\x22px\x22\x0a     inksca\
pe:pagecheckerbo\
ard=\x22false\x22\x0a    \
 showguides=\x22tru\
e\x22\x0a     inkscape\
:snap-bbox=\x22true\
\x22\x0a     inkscape:\
bbox-paths=\x22true\
\x22\x0a     inkscape:\
bbox-nodes=\x22true\
\x22\x0a     inkscape:\
snap-bbox-edge-m\
idpoints=\x22true\x22\x0a\
     inkscape:sn\
ap-bbox-midpoint\
s=\x22true\x22\x0a     in\
kscape:snap-node\
s=\x22true\x22\x0a     in\
kscape:object-pa\
ths=\x22true\x22\x0a     \
inkscape:snap-in\
tersection-paths\
=\x22true\x22\x0a     ink\
scape:snap-smoot\
h-nodes=\x22true\x22\x0a \
    inkscape:sna\
p-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-global=\x22tr\
ue\x22\x0a     fit-mar\
gin-top=\x220\x22\x0a    \
 fit-margin-left\
=\x220\x22\x0a     fit-ma\
rgin-right=\x220\x22\x0a \
    fit-margin-b\
ottom=\x220\x22\x0a     i\
nkscape:guide-bb\
ox=\x22true\x22>\x0a    <\
inkscape:grid\x0a  \
     type=\x22xygri\
d\x22\x0a       id=\x22gr\
id974\x22\x0a       em\
pspacing=\x228\x22\x0a   \
    spacingx=\x220.\
26458332\x22\x0a      \
 spacingy=\x220.264\
58332\x22\x0a       do\
tted=\x22false\x22\x0a   \
    visible=\x22tru\
e\x22\x0a       enable\
d=\x22true\x22\x0a       \
snapvisiblegridl\
inesonly=\x22true\x22\x0a\
       originx=\x22\
0\x22\x0a       origin\
y=\x220\x22 />\x0a  </sod\
ipodi:namedview>\
\x0a  <metadata\x0a   \
  id=\x22metadata5\x22\
>\x0a    <rdf:RDF>\x0a\
      <cc:Work\x0a \
        rdf:abou\
t=\x22\x22>\x0a        <d\
c:format>image/s\
vg+xml</dc:forma\
t>\x0a        <dc:t\
ype\x0a           r\
df:resource=\x22htt\
p://purl.org/dc/\
dcmitype/StillIm\
age\x22 />\x0a        \
<dc:title />\x0a   \
   </cc:Work>\x0a  \
  </rdf:RDF>\x0a  <\
/metadata>\x0a  <g\x0a\
     inkscape:la\
bel=\x22Layer 1\x22\x0a  \
   inkscape:grou\
pmode=\x22layer\x22\x0a  \
   id=\x22layer1\x22\x0a \
    transform=\x22t\
ranslate(0,-291.\
70835)\x22>\x0a    <g\x0a\
       id=\x22g847\x22\
\x0a       transfor\
m=\x22matrix(0.0520\
7439,0,0,0.05207\
453,-0.90125164,\
282.41203)\x22>\x0a   \
   <g\x0a         i\
d=\x22g851\x22>\x0a      \
  <g\x0a           \
id=\x22g1059\x22\x0a     \
      transform=\
\x22matrix(1.998621\
9,0,0,1.9986185,\
17.324484,-313.5\
2314)\x22>\x0a        \
  <path\x0a        \
     inkscape:tr\
ansform-center-y\
=\x223.175\x22\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0700043\
3;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1;pain\
t-order:stroke f\
ill markers\x22\x0a   \
          d=\x22M 2\
5.399999,271.600\
02 -8.0000008e-7\
,246.20002 H 50.\
799999 Z\x22\x0a      \
       id=\x22path8\
83\x22\x0a            \
 inkscape:connec\
tor-curvature=\x220\
\x22\x0a             s\
odipodi:nodetype\
s=\x22cccc\x22 />\x0a    \
      <path\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             id\
=\x22path880\x22\x0a     \
        d=\x22m 25.\
399999,271.60002\
 25.399999,25.4 \
H 0 Z\x22\x0a         \
    inkscape:tra\
nsform-center-y=\
\x22-3.1749995\x22\x0a   \
          style=\
\x22opacity:1;fill:\
none;fill-opacit\
y:0.49382719;str\
oke:#ffffff00;st\
roke-width:0.070\
00433;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1;\
paint-order:stro\
ke fill markers\x22\
 />\x0a          <r\
ect\x0a            \
 ry=\x225.0534658\x22\x0a\
             y=\x22\
253.84885\x22\x0a     \
        x=\x227.648\
7389\x22\x0a          \
   height=\x2235.52\
8759\x22\x0a          \
   width=\x2235.528\
786\x22\x0a           \
  id=\x22rect870\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
6184419;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<circle\x0a        \
     r=\x2225.39682\
8\x22\x0a             \
cy=\x22271.60001\x22\x0a \
            cx=\x22\
25.4\x22\x0a          \
   id=\x22path872\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07635882;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <circle\x0a       \
      transform=\
\x22rotate(-45)\x22\x0a  \
           cx=\x22-\
174.08969\x22\x0a     \
        cy=\x22210.\
01071\x22\x0a         \
    r=\x2212.656071\
\x22\x0a             i\
d=\x22path876\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0739\
9406;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x22-3.\
1749999\x22\x0a       \
      sodipodi:n\
odetypes=\x22cccc\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           id=\x22p\
ath904\x22\x0a        \
     d=\x22m 25.4,2\
71.60002 -25.400\
00040000004,25.4\
 v -50.8 z\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0700\
0433;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22 \
/>\x0a          <pa\
th\x0a             \
inkscape:transfo\
rm-center-x=\x223.1\
75\x22\x0a            \
 style=\x22opacity:\
1;fill:none;fill\
-opacity:0.49382\
719;stroke:#ffff\
ff00;stroke-widt\
h:0.07000433;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1;paint-ord\
er:stroke fill m\
arkers\x22\x0a        \
     d=\x22m 25.399\
999,271.60002 25\
.4,-25.4 v 50.8 \
z\x22\x0a             \
id=\x22path906\x22\x0a   \
          inksca\
pe:connector-cur\
vature=\x220\x22\x0a     \
        sodipodi\
:nodetypes=\x22cccc\
\x22 />\x0a          <\
rect\x0a           \
  ry=\x225.0514922\x22\
\x0a             y=\
\x22256.39301\x22\x0a    \
         x=\x222.56\
63135\x22\x0a         \
    height=\x2230.4\
40479\x22\x0a         \
    width=\x2245.69\
3634\x22\x0a          \
   id=\x22rect837\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
0657438;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<rect\x0a          \
   style=\x22opacit\
y:1;fill:none;fi\
ll-opacity:0.493\
82719;stroke:#ff\
ffff00;stroke-wi\
dth:0.0657438;st\
roke-linecap:rou\
nd;stroke-linejo\
in:round;stroke-\
miterlimit:4;str\
oke-dasharray:no\
ne;stroke-dashof\
fset:0;stroke-op\
acity:1;paint-or\
der:stroke fill \
markers\x22\x0a       \
      id=\x22rect83\
1\x22\x0a             \
width=\x2245.693588\
\x22\x0a             h\
eight=\x2230.44051\x22\
\x0a             x=\
\x22248.76645\x22\x0a    \
         y=\x22-40.\
633385\x22\x0a        \
     ry=\x225.05149\
7\x22\x0a             \
transform=\x22rotat\
e(90)\x22 />\x0a      \
  </g>\x0a      </g\
>\x0a    </g>\x0a    <\
path\x0a       styl\
e=\x22opacity:1;fil\
l:#ffc107;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.38596651;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-op\
acity:1\x22\x0a       \
d=\x22m 50.206421,4\
01.67683 c 110.2\
17209,0.71279 55\
.108609,0.3564 0\
,0 z\x22\x0a       id=\
\x22rect997\x22\x0a      \
 inkscape:connec\
tor-curvature=\x220\
\x22 />\x0a    <g\x0a    \
   id=\x22g839\x22>\x0a  \
    <rect\x0a      \
   style=\x22opacit\
y:1;fill:#ff0000\
;fill-opacity:1;\
stroke:none;stro\
ke-width:0.52916\
664;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1\x22\x0a \
        id=\x22rect\
830\x22\x0a         wi\
dth=\x220.52916664\x22\
\x0a         height\
=\x220.52916664\x22\x0a  \
       x=\x221.8520\
832\x22\x0a         y=\
\x22291.70834\x22 />\x0a \
     <rect\x0a     \
    y=\x22293.29584\
\x22\x0a         x=\x221.\
8520832\x22\x0a       \
  height=\x220.5291\
6664\x22\x0a         w\
idth=\x220.52916664\
\x22\x0a         id=\x22r\
ect832\x22\x0a        \
 style=\x22opacity:\
1;fill:#ff0000;f\
ill-opacity:1;st\
roke:none;stroke\
-width:0.5291666\
4;stroke-linecap\
:round;stroke-li\
nejoin:round;str\
oke-miterlimit:4\
;stroke-dasharra\
y:none;stroke-da\
shoffset:0;strok\
e-opacity:1\x22 />\x0a\
      <rect\x0a    \
     style=\x22opac\
ity:1;fill:#ff00\
00;fill-opacity:\
1;stroke:none;st\
roke-width:0.529\
16664;stroke-lin\
ecap:round;strok\
e-linejoin:round\
;stroke-miterlim\
it:4;stroke-dash\
array:none;strok\
e-dashoffset:0;s\
troke-opacity:1\x22\
\x0a         id=\x22re\
ct834\x22\x0a         \
width=\x220.5291666\
4\x22\x0a         heig\
ht=\x220.52916664\x22\x0a\
         x=\x221.85\
20832\x22\x0a         \
y=\x22294.88336\x22 />\
\x0a      <rect\x0a   \
      y=\x22296.470\
86\x22\x0a         x=\x22\
1.8520832\x22\x0a     \
    height=\x220.52\
916664\x22\x0a        \
 width=\x220.529166\
64\x22\x0a         id=\
\x22rect836\x22\x0a      \
   style=\x22opacit\
y:1;fill:#ff0000\
;fill-opacity:1;\
stroke:none;stro\
ke-width:0.52916\
664;stroke-linec\
ap:round;stroke-\
linejoin:round;s\
troke-miterlimit\
:4;stroke-dashar\
ray:none;stroke-\
dashoffset:0;str\
oke-opacity:1\x22 /\
>\x0a      <rect\x0a  \
       style=\x22op\
acity:1;fill:#ff\
0000;fill-opacit\
y:1;stroke:none;\
stroke-width:0.5\
2916664;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1\x22\x0a         id=\x22\
rect838\x22\x0a       \
  width=\x220.52916\
664\x22\x0a         he\
ight=\x220.52916664\
\x22\x0a         x=\x222.\
3812499\x22\x0a       \
  y=\x22292.50208\x22 \
/>\x0a      <rect\x0a \
        y=\x22294.0\
896\x22\x0a         x=\
\x222.3812499\x22\x0a    \
     height=\x220.5\
2916664\x22\x0a       \
  width=\x220.52916\
664\x22\x0a         id\
=\x22rect840\x22\x0a     \
    style=\x22opaci\
ty:1;fill:#ff000\
0;fill-opacity:1\
;stroke:none;str\
oke-width:0.5291\
6664;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1\x22 \
/>\x0a      <rect\x0a \
        style=\x22o\
pacity:1;fill:#f\
f0000;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
52916664;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22\x0a         id=\
\x22rect842\x22\x0a      \
   width=\x220.5291\
6664\x22\x0a         h\
eight=\x220.5291666\
4\x22\x0a         x=\x222\
.3812499\x22\x0a      \
   y=\x22295.67709\x22\
 />\x0a      <rect\x0a\
         y=\x22291.\
70834\x22\x0a         \
x=\x222.9104166\x22\x0a  \
       height=\x220\
.52916664\x22\x0a     \
    width=\x220.529\
16664\x22\x0a         \
id=\x22rect844\x22\x0a   \
      style=\x22opa\
city:1;fill:#ff0\
000;fill-opacity\
:1;stroke:none;s\
troke-width:0.52\
916664;stroke-li\
necap:round;stro\
ke-linejoin:roun\
d;stroke-miterli\
mit:4;stroke-das\
harray:none;stro\
ke-dashoffset:0;\
stroke-opacity:1\
\x22 />\x0a      <rect\
\x0a         style=\
\x22opacity:1;fill:\
#ff0000;fill-opa\
city:1;stroke:no\
ne;stroke-width:\
0.52916664;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1\x22\x0a         i\
d=\x22rect846\x22\x0a    \
     width=\x220.52\
916664\x22\x0a        \
 height=\x220.52916\
664\x22\x0a         x=\
\x222.9104166\x22\x0a    \
     y=\x22293.2958\
4\x22 />\x0a      <rec\
t\x0a         y=\x2229\
4.88336\x22\x0a       \
  x=\x222.9104166\x22\x0a\
         height=\
\x220.52916664\x22\x0a   \
      width=\x220.5\
2916664\x22\x0a       \
  id=\x22rect848\x22\x0a \
        style=\x22o\
pacity:1;fill:#f\
f0000;fill-opaci\
ty:1;stroke:none\
;stroke-width:0.\
52916664;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1\x22 />\x0a      <re\
ct\x0a         styl\
e=\x22opacity:1;fil\
l:#ff0000;fill-o\
pacity:1;stroke:\
none;stroke-widt\
h:0.52916664;str\
oke-linecap:roun\
d;stroke-linejoi\
n:round;stroke-m\
iterlimit:4;stro\
ke-dasharray:non\
e;stroke-dashoff\
set:0;stroke-opa\
city:1\x22\x0a        \
 id=\x22rect850\x22\x0a  \
       width=\x220.\
52916664\x22\x0a      \
   height=\x220.529\
16664\x22\x0a         \
x=\x222.9104166\x22\x0a  \
       y=\x22296.47\
086\x22 />\x0a    </g>\
\x0a  </g>\x0a</svg>\x0a\
\x00\x00\x1dw\
<\
?xml version=\x221.\
0\x22 encoding=\x22UTF\
-8\x22 standalone=\x22\
no\x22?>\x0a<!-- Creat\
ed with Inkscape\
 (http://www.ink\
scape.org/) -->\x0a\
\x0a<svg\x0a   xmlns:d\
c=\x22http://purl.o\
rg/dc/elements/1\
.1/\x22\x0a   xmlns:cc\
=\x22http://creativ\
ecommons.org/ns#\
\x22\x0a   xmlns:rdf=\x22\
http://www.w3.or\
g/1999/02/22-rdf\
-syntax-ns#\x22\x0a   \
xmlns:svg=\x22http:\
//www.w3.org/200\
0/svg\x22\x0a   xmlns=\
\x22http://www.w3.o\
rg/2000/svg\x22\x0a   \
xmlns:sodipodi=\x22\
http://sodipodi.\
sourceforge.net/\
DTD/sodipodi-0.d\
td\x22\x0a   xmlns:ink\
scape=\x22http://ww\
w.inkscape.org/n\
amespaces/inksca\
pe\x22\x0a   width=\x2220\
\x22\x0a   height=\x2220\x22\
\x0a   viewBox=\x220 0\
 5.2916664 5.291\
6664\x22\x0a   version\
=\x221.1\x22\x0a   id=\x22sv\
g8\x22\x0a   inkscape:\
version=\x220.92.4 \
5da689c313, 2019\
-01-14\x22\x0a   sodip\
odi:docname=\x22che\
ckbox_checked.sv\
g\x22\x0a   inkscape:e\
xport-filename=\x22\
/home/yeison/Dev\
elopment/piton/a\
rt/icon_lite.png\
\x22\x0a   inkscape:ex\
port-xdpi=\x2296\x22\x0a \
  inkscape:expor\
t-ydpi=\x2296\x22>\x0a  <\
defs\x0a     id=\x22de\
fs2\x22 />\x0a  <sodip\
odi:namedview\x0a  \
   id=\x22base\x22\x0a   \
  pagecolor=\x22#ff\
ffff\x22\x0a     borde\
rcolor=\x22#666666\x22\
\x0a     borderopac\
ity=\x221.0\x22\x0a     i\
nkscape:pageopac\
ity=\x220.0\x22\x0a     i\
nkscape:pageshad\
ow=\x222\x22\x0a     inks\
cape:zoom=\x2217.53\
8085\x22\x0a     inksc\
ape:cx=\x226.604083\
6\x22\x0a     inkscape\
:cy=\x229.0271347\x22\x0a\
     inkscape:do\
cument-units=\x22px\
\x22\x0a     inkscape:\
current-layer=\x22l\
ayer1\x22\x0a     show\
grid=\x22true\x22\x0a    \
 inkscape:window\
-width=\x221920\x22\x0a  \
   inkscape:wind\
ow-height=\x221015\x22\
\x0a     inkscape:w\
indow-x=\x220\x22\x0a    \
 inkscape:window\
-y=\x220\x22\x0a     inks\
cape:window-maxi\
mized=\x221\x22\x0a     i\
nkscape:showpage\
shadow=\x22false\x22\x0a \
    units=\x22px\x22\x0a \
    inkscape:pag\
echeckerboard=\x22f\
alse\x22\x0a     showg\
uides=\x22true\x22\x0a   \
  inkscape:snap-\
bbox=\x22true\x22\x0a    \
 inkscape:bbox-p\
aths=\x22true\x22\x0a    \
 inkscape:bbox-n\
odes=\x22true\x22\x0a    \
 inkscape:snap-b\
box-edge-midpoin\
ts=\x22true\x22\x0a     i\
nkscape:snap-bbo\
x-midpoints=\x22tru\
e\x22\x0a     inkscape\
:snap-nodes=\x22tru\
e\x22\x0a     inkscape\
:object-paths=\x22t\
rue\x22\x0a     inksca\
pe:snap-intersec\
tion-paths=\x22true\
\x22\x0a     inkscape:\
snap-smooth-node\
s=\x22true\x22\x0a     in\
kscape:snap-midp\
oints=\x22true\x22\x0a   \
  inkscape:snap-\
global=\x22true\x22\x0a  \
   fit-margin-to\
p=\x220\x22\x0a     fit-m\
argin-left=\x220\x22\x0a \
    fit-margin-r\
ight=\x220\x22\x0a     fi\
t-margin-bottom=\
\x220\x22\x0a     inkscap\
e:guide-bbox=\x22tr\
ue\x22>\x0a    <inksca\
pe:grid\x0a       t\
ype=\x22xygrid\x22\x0a   \
    id=\x22grid974\x22\
\x0a       empspaci\
ng=\x228\x22\x0a       sp\
acingx=\x220.264583\
32\x22\x0a       spaci\
ngy=\x220.26458332\x22\
\x0a       dotted=\x22\
false\x22\x0a       vi\
sible=\x22true\x22\x0a   \
    enabled=\x22tru\
e\x22\x0a       snapvi\
siblegridlineson\
ly=\x22true\x22\x0a      \
 originx=\x220\x22\x0a   \
    originy=\x220\x22 \
/>\x0a  </sodipodi:\
namedview>\x0a  <me\
tadata\x0a     id=\x22\
metadata5\x22>\x0a    \
<rdf:RDF>\x0a      \
<cc:Work\x0a       \
  rdf:about=\x22\x22>\x0a\
        <dc:form\
at>image/svg+xml\
</dc:format>\x0a   \
     <dc:type\x0a  \
         rdf:res\
ource=\x22http://pu\
rl.org/dc/dcmity\
pe/StillImage\x22 /\
>\x0a        <dc:ti\
tle></dc:title>\x0a\
      </cc:Work>\
\x0a    </rdf:RDF>\x0a\
  </metadata>\x0a  \
<g\x0a     inkscape\
:label=\x22Layer 1\x22\
\x0a     inkscape:g\
roupmode=\x22layer\x22\
\x0a     id=\x22layer1\
\x22\x0a     transform\
=\x22translate(0,-2\
91.70835)\x22>\x0a    \
<g\x0a       id=\x22g8\
47\x22\x0a       trans\
form=\x22matrix(0.0\
5207439,0,0,0.05\
207453,-0.901251\
64,282.41203)\x22>\x0a\
      <g\x0a       \
  id=\x22g851\x22>\x0a   \
     <g\x0a        \
   id=\x22g1059\x22\x0a  \
         transfo\
rm=\x22matrix(1.998\
6219,0,0,1.99861\
85,17.324484,-31\
3.52314)\x22>\x0a     \
     <path\x0a     \
        inkscape\
:transform-cente\
r-y=\x223.175\x22\x0a    \
         style=\x22\
opacity:1;fill:n\
one;fill-opacity\
:0.49382719;stro\
ke:#ffffff00;str\
oke-width:0.0700\
0433;stroke-line\
cap:round;stroke\
-linejoin:round;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-dashoffset:0;st\
roke-opacity:1;p\
aint-order:strok\
e fill markers\x22\x0a\
             d=\x22\
M 25.399999,271.\
60002 -8.0000008\
e-7,246.20002 H \
50.799999 Z\x22\x0a   \
          id=\x22pa\
th883\x22\x0a         \
    inkscape:con\
nector-curvature\
=\x220\x22\x0a           \
  sodipodi:nodet\
ypes=\x22cccc\x22 />\x0a \
         <path\x0a \
            sodi\
podi:nodetypes=\x22\
cccc\x22\x0a          \
   inkscape:conn\
ector-curvature=\
\x220\x22\x0a            \
 id=\x22path880\x22\x0a  \
           d=\x22m \
25.399999,271.60\
002 25.399999,25\
.4 H 0 Z\x22\x0a      \
       inkscape:\
transform-center\
-y=\x22-3.1749995\x22\x0a\
             sty\
le=\x22opacity:1;fi\
ll:none;fill-opa\
city:0.49382719;\
stroke:#ffffff00\
;stroke-width:0.\
07000433;stroke-\
linecap:round;st\
roke-linejoin:ro\
und;stroke-miter\
limit:4;stroke-d\
asharray:none;st\
roke-dashoffset:\
0;stroke-opacity\
:1;paint-order:s\
troke fill marke\
rs\x22 />\x0a         \
 <rect\x0a         \
    ry=\x225.053465\
8\x22\x0a             \
y=\x22253.84885\x22\x0a  \
           x=\x227.\
6487389\x22\x0a       \
      height=\x2235\
.528759\x22\x0a       \
      width=\x2235.\
528786\x22\x0a        \
     id=\x22rect870\
\x22\x0a             s\
tyle=\x22opacity:1;\
fill:none;fill-o\
pacity:0.4938271\
9;stroke:#ffffff\
00;stroke-width:\
0.06184419;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <circle\x0a     \
        r=\x2225.39\
6828\x22\x0a          \
   cy=\x22271.60001\
\x22\x0a             c\
x=\x2225.4\x22\x0a       \
      id=\x22path87\
2\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.07635882;stro\
ke-linecap:round\
;stroke-linejoin\
:round;stroke-mi\
terlimit:4;strok\
e-dasharray:none\
;stroke-dashoffs\
et:0;stroke-opac\
ity:1;paint-orde\
r:stroke fill ma\
rkers\x22 />\x0a      \
    <circle\x0a    \
         transfo\
rm=\x22rotate(-45)\x22\
\x0a             cx\
=\x22-174.08969\x22\x0a  \
           cy=\x222\
10.01071\x22\x0a      \
       r=\x2212.656\
071\x22\x0a           \
  id=\x22path876\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7399406;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<path\x0a          \
   inkscape:tran\
sform-center-x=\x22\
-3.1749999\x22\x0a    \
         sodipod\
i:nodetypes=\x22ccc\
c\x22\x0a             \
inkscape:connect\
or-curvature=\x220\x22\
\x0a             id\
=\x22path904\x22\x0a     \
        d=\x22m 25.\
4,271.60002 -25.\
40000040000004,2\
5.4 v -50.8 z\x22\x0a \
            styl\
e=\x22opacity:1;fil\
l:none;fill-opac\
ity:0.49382719;s\
troke:#ffffff00;\
stroke-width:0.0\
7000433;stroke-l\
inecap:round;str\
oke-linejoin:rou\
nd;stroke-miterl\
imit:4;stroke-da\
sharray:none;str\
oke-dashoffset:0\
;stroke-opacity:\
1;paint-order:st\
roke fill marker\
s\x22 />\x0a          \
<path\x0a          \
   inkscape:tran\
sform-center-x=\x22\
3.175\x22\x0a         \
    style=\x22opaci\
ty:1;fill:none;f\
ill-opacity:0.49\
382719;stroke:#f\
fffff00;stroke-w\
idth:0.07000433;\
stroke-linecap:r\
ound;stroke-line\
join:round;strok\
e-miterlimit:4;s\
troke-dasharray:\
none;stroke-dash\
offset:0;stroke-\
opacity:1;paint-\
order:stroke fil\
l markers\x22\x0a     \
        d=\x22m 25.\
399999,271.60002\
 25.4,-25.4 v 50\
.8 z\x22\x0a          \
   id=\x22path906\x22\x0a\
             ink\
scape:connector-\
curvature=\x220\x22\x0a  \
           sodip\
odi:nodetypes=\x22c\
ccc\x22 />\x0a        \
  <rect\x0a        \
     ry=\x225.05149\
22\x22\x0a            \
 y=\x22256.39301\x22\x0a \
            x=\x222\
.5663135\x22\x0a      \
       height=\x223\
0.440479\x22\x0a      \
       width=\x2245\
.693634\x22\x0a       \
      id=\x22rect83\
7\x22\x0a             \
style=\x22opacity:1\
;fill:none;fill-\
opacity:0.493827\
19;stroke:#fffff\
f00;stroke-width\
:0.0657438;strok\
e-linecap:round;\
stroke-linejoin:\
round;stroke-mit\
erlimit:4;stroke\
-dasharray:none;\
stroke-dashoffse\
t:0;stroke-opaci\
ty:1;paint-order\
:stroke fill mar\
kers\x22 />\x0a       \
   <rect\x0a       \
      style=\x22opa\
city:1;fill:none\
;fill-opacity:0.\
49382719;stroke:\
#ffffff00;stroke\
-width:0.0657438\
;stroke-linecap:\
round;stroke-lin\
ejoin:round;stro\
ke-miterlimit:4;\
stroke-dasharray\
:none;stroke-das\
hoffset:0;stroke\
-opacity:1;paint\
-order:stroke fi\
ll markers\x22\x0a    \
         id=\x22rec\
t831\x22\x0a          \
   width=\x2245.693\
588\x22\x0a           \
  height=\x2230.440\
51\x22\x0a            \
 x=\x22248.76645\x22\x0a \
            y=\x22-\
40.633385\x22\x0a     \
        ry=\x225.05\
1497\x22\x0a          \
   transform=\x22ro\
tate(90)\x22 />\x0a   \
     </g>\x0a      \
</g>\x0a    </g>\x0a  \
  <path\x0a       s\
tyle=\x22opacity:1;\
fill:#ffc107;fil\
l-opacity:1;stro\
ke:none;stroke-w\
idth:0.38596651;\
stroke-miterlimi\
t:4;stroke-dasha\
rray:none;stroke\
-opacity:1\x22\x0a    \
   d=\x22m 50.20642\
1,401.67683 c 11\
0.217209,0.71279\
 55.108609,0.356\
4 0,0 z\x22\x0a       \
id=\x22rect997\x22\x0a   \
    inkscape:con\
nector-curvature\
=\x220\x22 />\x0a  </g>\x0a<\
/svg>\x0a\
"

qt_resource_name = b"\
\x00\x04\
\x00\x06\xfa^\
\x00i\
\x00c\x00o\x00n\
\x00\x08\
\x00\x97\x9f\xd4\
\x00d\
\x00i\x00s\x00a\x00b\x00l\x00e\x00d\
\x00\x07\
\x07\x908y\
\x00p\
\x00r\x00i\x00m\x00a\x00r\x00y\
\x00\x0c\
\x06AM\x07\
\x00s\
\x00i\x00z\x00e\x00g\x00r\x00i\x00p\x00.\x00s\x00v\x00g\
\x00\x0b\
\x09\x92\x8b\xe7\
\x00u\
\x00p\x00a\x00r\x00r\x00o\x00w\x00.\x00s\x00v\x00g\
\x00\x0d\
\x02h\xefG\
\x00t\
\x00a\x00b\x00_\x00c\x00l\x00o\x00s\x00e\x00.\x00s\x00v\x00g\
\x00\x15\
\x0c\xcb\x0d\xe7\
\x00s\
\x00p\x00l\x00i\x00t\x00t\x00e\x00r\x00-\x00v\x00e\x00r\x00t\x00i\x00c\x00a\x00l\
\x00.\x00s\x00v\x00g\
\x00\x0a\
\x0a\xca\x1f'\
\x00s\
\x00l\x00i\x00d\x00e\x00r\x00.\x00s\x00v\x00g\
\x00\x1a\
\x01\x87\xa3\xe7\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00i\x00n\x00d\x00e\x00t\x00e\x00r\x00m\
\x00i\x00n\x00a\x00t\x00e\x00.\x00s\x00v\x00g\
\x00\x17\
\x04\xb5\xb8'\
\x00r\
\x00a\x00d\x00i\x00o\x00b\x00u\x00t\x00t\x00o\x00n\x00_\x00c\x00h\x00e\x00c\x00k\
\x00e\x00d\x00.\x00s\x00v\x00g\
\x00\x17\
\x0a>Y\xe7\
\x00s\
\x00p\x00l\x00i\x00t\x00t\x00e\x00r\x00-\x00h\x00o\x00r\x00i\x00z\x00o\x00n\x00t\
\x00a\x00l\x00.\x00s\x00v\x00g\
\x00\x0e\
\x06\xd9\x15\xc7\
\x00r\
\x00i\x00g\x00h\x00t\x00a\x00r\x00r\x00o\x00w\x00.\x00s\x00v\x00g\
\x00\x08\
\x05\xe2T\xa7\
\x00l\
\x00o\x00g\x00o\x00.\x00s\x00v\x00g\
\x00\x0e\
\x0f\xfe\xfd\x07\
\x00l\
\x00o\x00g\x00o\x00_\x00f\x00r\x00a\x00m\x00e\x00.\x00s\x00v\x00g\
\x00\x19\
\x08\x11$\xc7\
\x00r\
\x00a\x00d\x00i\x00o\x00b\x00u\x00t\x00t\x00o\x00n\x00_\x00u\x00n\x00c\x00h\x00e\
\x00c\x00k\x00e\x00d\x00.\x00s\x00v\x00g\
\x00\x09\
\x06\x98\x8e\xa7\
\x00c\
\x00l\x00o\x00s\x00e\x00.\x00s\x00v\x00g\
\x00\x14\
\x07\xec\xdcG\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00c\x00h\x00e\x00c\x00k\x00e\x00d\x00.\
\x00s\x00v\x00g\
\x00\x16\
\x01u\xc1\x07\
\x00c\
\x00h\x00e\x00c\x00k\x00b\x00o\x00x\x00_\x00u\x00n\x00c\x00h\x00e\x00c\x00k\x00e\
\x00d\x00.\x00s\x00v\x00g\
\x00\x0d\
\x0f\xb6\xcaG\
\x00d\
\x00o\x00w\x00n\x00a\x00r\x00r\x00o\x00w\x00.\x00s\x00v\x00g\
\x00\x1b\
\x09\xb79\xa7\
\x00t\
\x00o\x00o\x00l\x00b\x00a\x00r\x00-\x00h\x00a\x00n\x00d\x00l\x00e\x00-\x00v\x00e\
\x00r\x00t\x00i\x00c\x00a\x00l\x00.\x00s\x00v\x00g\
\x00\x0d\
\x0c\x15\x0a'\
\x00l\
\x00e\x00f\x00t\x00a\x00r\x00r\x00o\x00w\x00.\x00s\x00v\x00g\
\x00\x09\
\x05\x87\x80\xa7\
\x00f\
\x00l\x00o\x00a\x00t\x00.\x00s\x00v\x00g\
\x00\x1d\
\x06\x0b\xe3\x07\
\x00t\
\x00o\x00o\x00l\x00b\x00a\x00r\x00-\x00h\x00a\x00n\x00d\x00l\x00e\x00-\x00h\x00o\
\x00r\x00i\x00z\x00o\x00n\x00t\x00a\x00l\x00.\x00s\x00v\x00g\
\x00\x08\
\x08\x98W\xc7\
\x00b\
\x00a\x00s\x00e\x00.\x00s\x00v\x00g\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x02\x00\x00\x00\x02\
\x00\x00\x00\x0e\x00\x02\x00\x00\x00\x15\x00\x00\x00\x19\
\x00\x00\x00$\x00\x02\x00\x00\x00\x15\x00\x00\x00\x04\
\x00\x00\x02V\x00\x00\x00\x00\x00\x01\x00\x01\xb4O\
\x00\x00\x00\xdc\x00\x00\x00\x00\x00\x01\x00\x00\xae\xd0\
\x00\x00\x00r\x00\x00\x00\x00\x00\x01\x00\x00Jt\
\x00\x00\x01\x16\x00\x00\x00\x00\x00\x01\x00\x00\xce\x83\
\x00\x00\x03\x04\x00\x00\x00\x00\x00\x01\x00\x02D\x06\
\x00\x00\x01\xa0\x00\x00\x00\x00\x00\x01\x00\x015\xab\
\x00\x00\x03\x1c\x00\x00\x00\x00\x00\x01\x00\x02d{\
\x00\x00\x008\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x02\x10\x00\x00\x00\x00\x00\x01\x00\x01t\x8d\
\x00\x00\x01~\x00\x00\x00\x00\x00\x01\x00\x01\x14v\
\x00\x00\x02(\x00\x00\x00\x00\x00\x01\x00\x01\x94K\
\x00\x00\x01\xd8\x00\x00\x00\x00\x00\x01\x00\x01Tj\
\x00\x00\x03\x5c\x00\x00\x00\x00\x00\x01\x00\x02\x91?\
\x00\x00\x00V\x00\x00\x00\x00\x00\x01\x00\x00)M\
\x00\x00\x02\xa8\x00\x00\x00\x00\x00\x01\x00\x01\xf56\
\x00\x00\x01J\x00\x00\x00\x00\x00\x01\x00\x00\xef\xfc\
\x00\x00\x00\xc2\x00\x00\x00\x00\x00\x01\x00\x00\x8e\xdd\
\x00\x00\x02\xe4\x00\x00\x00\x00\x00\x01\x00\x02\x22\xd4\
\x00\x00\x00\x92\x00\x00\x00\x00\x00\x01\x00\x00j,\
\x00\x00\x02\x88\x00\x00\x00\x00\x00\x01\x00\x01\xd4h\
\x00\x00\x01\xb6\x00\x00\x00\x00\x00\x01\x00\x01?*\
\x00\x00\x02V\x00\x00\x00\x00\x00\x01\x00\x04c\x09\
\x00\x00\x00\xdc\x00\x00\x00\x00\x00\x01\x00\x03]\x8a\
\x00\x00\x00r\x00\x00\x00\x00\x00\x01\x00\x02\xf9.\
\x00\x00\x01\x16\x00\x00\x00\x00\x00\x01\x00\x03}=\
\x00\x00\x03\x04\x00\x00\x00\x00\x00\x01\x00\x04\xf2\xc0\
\x00\x00\x01\xa0\x00\x00\x00\x00\x00\x01\x00\x03\xe4e\
\x00\x00\x03\x1c\x00\x00\x00\x00\x00\x01\x00\x05\x135\
\x00\x00\x008\x00\x00\x00\x00\x00\x01\x00\x02\xae\xba\
\x00\x00\x02\x10\x00\x00\x00\x00\x00\x01\x00\x04#G\
\x00\x00\x01~\x00\x00\x00\x00\x00\x01\x00\x03\xc30\
\x00\x00\x02(\x00\x00\x00\x00\x00\x01\x00\x04C\x05\
\x00\x00\x01\xd8\x00\x00\x00\x00\x00\x01\x00\x04\x03$\
\x00\x00\x03\x5c\x00\x00\x00\x00\x00\x01\x00\x05?\xf9\
\x00\x00\x00V\x00\x00\x00\x00\x00\x01\x00\x02\xd8\x07\
\x00\x00\x02\xa8\x00\x00\x00\x00\x00\x01\x00\x04\xa3\xf0\
\x00\x00\x01J\x00\x00\x00\x00\x00\x01\x00\x03\x9e\xb6\
\x00\x00\x00\xc2\x00\x00\x00\x00\x00\x01\x00\x03=\x97\
\x00\x00\x02\xe4\x00\x00\x00\x00\x00\x01\x00\x04\xd1\x8e\
\x00\x00\x00\x92\x00\x00\x00\x00\x00\x01\x00\x03\x18\xe6\
\x00\x00\x02\x88\x00\x00\x00\x00\x00\x01\x00\x04\x83\x22\
\x00\x00\x01\xb6\x00\x00\x00\x00\x00\x01\x00\x03\xed\xe4\
"

def qInitResources():
    QtCore.qRegisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(0x01, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
